@@ -23,6 +23,6 @@ import org.apache.accumulo.core.iterators.Combiner;
 
 public class TestCombiner extends Combiner {
     public Value reduce(Key key, Iterator<Value> iter) {
-        return new Value("TestY".getBytes());
+        return new Value("TestX".getBytes());
     }
 }
