@@ -20,9 +20,11 @@ package org.apache.accumulo.core.classloader;
 
 import static java.util.concurrent.TimeUnit.MINUTES;
 
+import java.io.IOException;
 import java.util.Map;
 import java.util.Set;
 import java.util.concurrent.ScheduledFuture;
+import java.util.concurrent.ScheduledThreadPoolExecutor;
 import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.function.Supplier;
 import java.util.stream.Collectors;
@@ -58,30 +60,32 @@ public class DefaultContextClassLoaderFactory implements ContextClassLoaderFacto
     }
     Supplier<Map<String,String>> contextConfigSupplier =
         () -> accConf.getAllPropertiesWithPrefix(VFS_CONTEXT_CLASSPATH_PROPERTY);
-    setContextConfig(contextConfigSupplier);
+    setContextConfig(contextConfigSupplier, accConf::invalidateCache);
     LOG.debug("ContextManager configuration set");
     startCleanupThread(accConf, contextConfigSupplier);
   }
 
   @SuppressWarnings("deprecation")
-  private static void setContextConfig(Supplier<Map<String,String>> contextConfigSupplier) {
+  private static void setContextConfig(Supplier<Map<String,String>> contextConfigSupplier,
+      Runnable contextConfigInvalidator) {
     org.apache.accumulo.start.classloader.vfs.AccumuloVFSClassLoader
-        .setContextConfig(contextConfigSupplier);
+        .setContextConfig(contextConfigSupplier, contextConfigInvalidator);
   }
 
   private static void startCleanupThread(final AccumuloConfiguration conf,
       final Supplier<Map<String,String>> contextConfigSupplier) {
-    ScheduledFuture<?> future = ThreadPools.getClientThreadPools((t, e) -> {
-      LOG.error("context classloader cleanup thread has failed.", e);
-    }).createGeneralScheduledExecutorService(conf)
-        .scheduleWithFixedDelay(Threads.createNamedRunnable(className + "-cleanup", () -> {
-          LOG.trace("{}-cleanup thread, properties: {}", className, conf);
-          Set<String> contextsInUse = contextConfigSupplier.get().keySet().stream()
-              .map(p -> p.substring(VFS_CONTEXT_CLASSPATH_PROPERTY.getKey().length()))
-              .collect(Collectors.toSet());
-          LOG.trace("{}-cleanup thread, contexts in use: {}", className, contextsInUse);
-          removeUnusedContexts(contextsInUse);
-        }), 1, 1, MINUTES);
+    ScheduledFuture<?> future =
+        ((ScheduledThreadPoolExecutor) ThreadPools.getClientThreadPools(conf, (t, e) -> {
+          LOG.error("context classloader cleanup thread has failed.", e);
+        }).createExecutorService(conf, Property.GENERAL_THREADPOOL_SIZE, false))
+            .scheduleWithFixedDelay(Threads.createNamedRunnable(className + "-cleanup", () -> {
+              LOG.trace("{}-cleanup thread, properties: {}", className, conf);
+              Set<String> contextsInUse = contextConfigSupplier.get().keySet().stream()
+                  .map(p -> p.substring(VFS_CONTEXT_CLASSPATH_PROPERTY.getKey().length()))
+                  .collect(Collectors.toSet());
+              LOG.trace("{}-cleanup thread, contexts in use: {}", className, contextsInUse);
+              removeUnusedContexts(contextsInUse);
+            }), 1, 1, MINUTES);
     ThreadPools.watchNonCriticalScheduledTask(future);
     LOG.debug("Context cleanup timer started at 60s intervals");
   }
@@ -94,8 +98,12 @@ public class DefaultContextClassLoaderFactory implements ContextClassLoaderFacto
 
   @SuppressWarnings("deprecation")
   @Override
-  public ClassLoader getClassLoader(String contextName) {
-    return org.apache.accumulo.start.classloader.vfs.AccumuloVFSClassLoader
-        .getContextClassLoader(contextName);
+  public ClassLoader getClassLoader(String contextName) throws ContextClassLoaderException {
+    try {
+      return org.apache.accumulo.start.classloader.vfs.AccumuloVFSClassLoader
+          .getContextClassLoader(contextName);
+    } catch (RuntimeException | IOException e) {
+      throw new ContextClassLoaderException(contextName, e);
+    }
   }
 }
