@@ -55,7 +55,7 @@ public class IteratorSetting implements Writable {
   private int priority;
   private String name;
   private String iteratorClass;
-  private Map<String,String> properties;
+  private final Map<String,String> properties;
 
   /**
    * Get layer at which this iterator applies. See {@link #setPriority(int)} for how the priority is
@@ -70,9 +70,8 @@ public class IteratorSetting implements Writable {
   /**
    * Set layer at which this iterator applies.
    *
-   * @param priority
-   *          determines the order in which iterators are applied (system iterators are always
-   *          applied first, then user-configured iterators, lowest priority first)
+   * @param priority determines the order in which iterators are applied (system iterators are
+   *        always applied first, then user-configured iterators, lowest priority first)
    */
   public void setPriority(int priority) {
     checkArgument(priority > 0, "property must be strictly positive");
@@ -120,12 +119,9 @@ public class IteratorSetting implements Writable {
    * Constructs an iterator setting configured for the scan scope with no parameters. (Parameters
    * can be added later.)
    *
-   * @param priority
-   *          the priority for the iterator (see {@link #setPriority(int)})
-   * @param name
-   *          the distinguishing name for the iterator
-   * @param iteratorClass
-   *          the fully qualified class name for the iterator
+   * @param priority the priority for the iterator (see {@link #setPriority(int)})
+   * @param name the distinguishing name for the iterator
+   * @param iteratorClass the fully qualified class name for the iterator
    */
   public IteratorSetting(int priority, String name, String iteratorClass) {
     this(priority, name, iteratorClass, new HashMap<>());
@@ -135,14 +131,10 @@ public class IteratorSetting implements Writable {
    * Constructs an iterator setting configured for the specified scopes with the specified
    * parameters.
    *
-   * @param priority
-   *          the priority for the iterator (see {@link #setPriority(int)})
-   * @param name
-   *          the distinguishing name for the iterator
-   * @param iteratorClass
-   *          the fully qualified class name for the iterator
-   * @param properties
-   *          any properties for the iterator
+   * @param priority the priority for the iterator (see {@link #setPriority(int)})
+   * @param name the distinguishing name for the iterator
+   * @param iteratorClass the fully qualified class name for the iterator
+   * @param properties any properties for the iterator
    */
   public IteratorSetting(int priority, String name, String iteratorClass,
       Map<String,String> properties) {
@@ -157,10 +149,8 @@ public class IteratorSetting implements Writable {
    * Constructs an iterator setting using the given class's SimpleName for the iterator name. The
    * iterator setting will be configured for the scan scope with no parameters.
    *
-   * @param priority
-   *          the priority for the iterator (see {@link #setPriority(int)})
-   * @param iteratorClass
-   *          the class for the iterator
+   * @param priority the priority for the iterator (see {@link #setPriority(int)})
+   * @param iteratorClass the class for the iterator
    */
   public IteratorSetting(int priority,
       Class<? extends SortedKeyValueIterator<Key,Value>> iteratorClass) {
@@ -172,12 +162,9 @@ public class IteratorSetting implements Writable {
    * Constructs an iterator setting using the given class's SimpleName for the iterator name and
    * configured for the specified scopes with the specified parameters.
    *
-   * @param priority
-   *          the priority for the iterator (see {@link #setPriority(int)})
-   * @param iteratorClass
-   *          the class for the iterator
-   * @param properties
-   *          any properties for the iterator
+   * @param priority the priority for the iterator (see {@link #setPriority(int)})
+   * @param iteratorClass the class for the iterator
+   * @param properties any properties for the iterator
    */
   public IteratorSetting(int priority,
       Class<? extends SortedKeyValueIterator<Key,Value>> iteratorClass,
@@ -188,12 +175,9 @@ public class IteratorSetting implements Writable {
   /**
    * Constructs an iterator setting configured for the scan scope with no parameters.
    *
-   * @param priority
-   *          the priority for the iterator (see {@link #setPriority(int)})
-   * @param name
-   *          the distinguishing name for the iterator
-   * @param iteratorClass
-   *          the class for the iterator
+   * @param priority the priority for the iterator (see {@link #setPriority(int)})
+   * @param name the distinguishing name for the iterator
+   * @param iteratorClass the class for the iterator
    */
   public IteratorSetting(int priority, String name,
       Class<? extends SortedKeyValueIterator<Key,Value>> iteratorClass) {
@@ -204,14 +188,10 @@ public class IteratorSetting implements Writable {
    * Constructs an iterator setting using the provided name and the provided class's name for the
    * scan scope with the provided parameters.
    *
-   * @param priority
-   *          The priority for the iterator (see {@link #setPriority(int)})
-   * @param name
-   *          The distinguishing name for the iterator
-   * @param iteratorClass
-   *          The class for the iterator
-   * @param properties
-   *          Any properties for the iterator
+   * @param priority The priority for the iterator (see {@link #setPriority(int)})
+   * @param name The distinguishing name for the iterator
+   * @param iteratorClass The class for the iterator
+   * @param properties Any properties for the iterator
    *
    * @since 1.6.0
    */
@@ -232,10 +212,8 @@ public class IteratorSetting implements Writable {
   /**
    * Add another option to the iterator.
    *
-   * @param option
-   *          the name of the option
-   * @param value
-   *          the value of the option
+   * @param option the name of the option
+   * @param value the value of the option
    */
   public void addOption(String option, String value) {
     checkArgument(option != null, "option is null");
@@ -246,8 +224,7 @@ public class IteratorSetting implements Writable {
   /**
    * Remove an option from the iterator.
    *
-   * @param option
-   *          the name of the option
+   * @param option the name of the option
    * @return the value previously associated with the option, or null if no such option existed
    */
   public String removeOption(String option) {
@@ -258,8 +235,7 @@ public class IteratorSetting implements Writable {
   /**
    * Add many options to the iterator.
    *
-   * @param propertyEntries
-   *          a set of entries to add to the options
+   * @param propertyEntries a set of entries to add to the options
    */
   public void addOptions(Set<Entry<String,String>> propertyEntries) {
     checkArgument(propertyEntries != null, "propertyEntries is null");
@@ -271,8 +247,7 @@ public class IteratorSetting implements Writable {
   /**
    * Add many options to the iterator.
    *
-   * @param properties
-   *          a map of entries to add to the options
+   * @param properties a map of entries to add to the options
    */
   public void addOptions(Map<String,String> properties) {
     checkArgument(properties != null, "properties is null");
@@ -308,25 +283,33 @@ public class IteratorSetting implements Writable {
 
   @Override
   public boolean equals(Object obj) {
-    if (this == obj)
+    if (this == obj) {
       return true;
-    if (obj == null)
+    }
+    if (obj == null) {
       return false;
-    if (!(obj instanceof IteratorSetting))
+    }
+    if (!(obj instanceof IteratorSetting)) {
       return false;
+    }
     IteratorSetting other = (IteratorSetting) obj;
     if (iteratorClass == null) {
-      if (other.iteratorClass != null)
+      if (other.iteratorClass != null) {
         return false;
-    } else if (!iteratorClass.equals(other.iteratorClass))
+      }
+    } else if (!iteratorClass.equals(other.iteratorClass)) {
       return false;
+    }
     if (name == null) {
-      if (other.name != null)
+      if (other.name != null) {
         return false;
-    } else if (!name.equals(other.name))
+      }
+    } else if (!name.equals(other.name)) {
       return false;
-    if (priority != other.priority)
+    }
+    if (priority != other.priority) {
       return false;
+    }
     if (properties == null) {
       return other.properties == null;
     } else {
