@@ -40,7 +40,7 @@ public class RowIterator implements Iterator<Iterator<Entry<Key,Value>>> {
    * Iterate over entries in a single row.
    */
   private static class SingleRowIter implements Iterator<Entry<Key,Value>> {
-    private PeekingIterator<Entry<Key,Value>> source;
+    private final PeekingIterator<Entry<Key,Value>> source;
     private Text currentRow = null;
     private long count = 0;
     private boolean disabled = false;
@@ -51,27 +51,31 @@ public class RowIterator implements Iterator<Iterator<Entry<Key,Value>>> {
      */
     public SingleRowIter(PeekingIterator<Entry<Key,Value>> source) {
       this.source = source;
-      if (source.hasNext())
+      if (source.hasNext()) {
         currentRow = source.peek().getKey().getRow();
+      }
     }
 
     @Override
     public boolean hasNext() {
-      if (disabled)
+      if (disabled) {
         throw new IllegalStateException("SingleRowIter no longer valid");
+      }
       return currentRow != null;
     }
 
     @Override
     public Entry<Key,Value> next() {
-      if (disabled)
+      if (disabled) {
         throw new IllegalStateException("SingleRowIter no longer valid");
+      }
       return _next();
     }
 
     private Entry<Key,Value> _next() {
-      if (currentRow == null)
+      if (currentRow == null) {
         throw new NoSuchElementException();
+      }
       count++;
       Entry<Key,Value> kv = source.next();
       if (!source.hasNext() || !source.peek().getKey().getRow().equals(currentRow)) {
@@ -98,8 +102,9 @@ public class RowIterator implements Iterator<Iterator<Entry<Key,Value>>> {
      */
     public void consume() {
       disabled = true;
-      while (currentRow != null)
+      while (currentRow != null) {
         _next();
+      }
     }
   }
 
@@ -143,8 +148,9 @@ public class RowIterator implements Iterator<Iterator<Entry<Key,Value>>> {
    */
   @Override
   public Iterator<Entry<Key,Value>> next() {
-    if (!hasNext())
+    if (!hasNext()) {
       throw new NoSuchElementException();
+    }
     return lastIter = new SingleRowIter(iter);
   }
 
