@@ -25,15 +25,16 @@ package org.apache.accumulo.core.client.lexicoder;
  */
 public class DoubleLexicoder extends AbstractLexicoder<Double> {
 
-  private ULongLexicoder longEncoder = new ULongLexicoder();
+  private final ULongLexicoder longEncoder = new ULongLexicoder();
 
   @Override
   public byte[] encode(Double d) {
     long l = Double.doubleToRawLongBits(d);
-    if (l < 0)
+    if (l < 0) {
       l = ~l;
-    else
+    } else {
       l = l ^ 0x8000000000000000L;
+    }
 
     return longEncoder.encode(l);
   }
@@ -48,10 +49,11 @@ public class DoubleLexicoder extends AbstractLexicoder<Double> {
   @Override
   protected Double decodeUnchecked(byte[] data, int offset, int len) {
     long l = longEncoder.decodeUnchecked(data, offset, len);
-    if (l < 0)
+    if (l < 0) {
       l = l ^ 0x8000000000000000L;
-    else
+    } else {
       l = ~l;
+    }
     return Double.longBitsToDouble(l);
   }
 
