@@ -502,7 +502,9 @@ public abstract class AbstractInputFormat<K,V> implements InputFormat<K,V> {
           }
           if (isIsolated) {
             log.info("Creating isolated scanner");
-            scanner = new IsolatedScanner(scanner);
+            @SuppressWarnings("resource")
+            var wrapped = new IsolatedScanner(scanner);
+            scanner = wrapped;
           }
           if (usesLocalIterators) {
             log.info("Using local iterators");
