@@ -64,10 +64,8 @@ public class AccumuloFileOutputFormat extends FileOutputFormat<Key,Value> {
    * Sets the compression type to use for data blocks. Specifying a compression may require
    * additional libraries to be available to your Job.
    *
-   * @param job
-   *          the Hadoop job instance to be configured
-   * @param compressionType
-   *          one of "none", "gz", "bzip2", "lzo", "lz4", "snappy", or "zstd"
+   * @param job the Hadoop job instance to be configured
+   * @param compressionType one of "none", "gz", "bzip2", "lzo", "lz4", "snappy", or "zstd"
    * @since 1.5.0
    */
   public static void setCompressionType(JobConf job, String compressionType) {
@@ -83,10 +81,8 @@ public class AccumuloFileOutputFormat extends FileOutputFormat<Key,Value> {
    * Making this value smaller may increase seek performance, but at the cost of increasing the size
    * of the indexes (which can also affect seek performance).
    *
-   * @param job
-   *          the Hadoop job instance to be configured
-   * @param dataBlockSize
-   *          the block size, in bytes
+   * @param job the Hadoop job instance to be configured
+   * @param dataBlockSize the block size, in bytes
    * @since 1.5.0
    */
   public static void setDataBlockSize(JobConf job, long dataBlockSize) {
@@ -97,10 +93,8 @@ public class AccumuloFileOutputFormat extends FileOutputFormat<Key,Value> {
    * Sets the size for file blocks in the file system; file blocks are managed, and replicated, by
    * the underlying file system.
    *
-   * @param job
-   *          the Hadoop job instance to be configured
-   * @param fileBlockSize
-   *          the block size, in bytes
+   * @param job the Hadoop job instance to be configured
+   * @param fileBlockSize the block size, in bytes
    * @since 1.5.0
    */
   public static void setFileBlockSize(JobConf job, long fileBlockSize) {
@@ -112,10 +106,8 @@ public class AccumuloFileOutputFormat extends FileOutputFormat<Key,Value> {
    * within the file, while larger blocks mean a more shallow index hierarchy within the file. This
    * can affect the performance of queries.
    *
-   * @param job
-   *          the Hadoop job instance to be configured
-   * @param indexBlockSize
-   *          the block size, in bytes
+   * @param job the Hadoop job instance to be configured
+   * @param indexBlockSize the block size, in bytes
    * @since 1.5.0
    */
   public static void setIndexBlockSize(JobConf job, long indexBlockSize) {
@@ -126,10 +118,8 @@ public class AccumuloFileOutputFormat extends FileOutputFormat<Key,Value> {
    * Sets the file system replication factor for the resulting file, overriding the file system
    * default.
    *
-   * @param job
-   *          the Hadoop job instance to be configured
-   * @param replication
-   *          the number of replicas for produced files
+   * @param job the Hadoop job instance to be configured
+   * @param replication the number of replicas for produced files
    * @since 1.5.0
    */
   public static void setReplication(JobConf job, int replication) {
@@ -140,10 +130,8 @@ public class AccumuloFileOutputFormat extends FileOutputFormat<Key,Value> {
    * Specify a sampler to be used when writing out data. This will result in the output file having
    * sample data.
    *
-   * @param job
-   *          The Hadoop job instance to be configured
-   * @param samplerConfig
-   *          The configuration for creating sample data in the output file.
+   * @param job The Hadoop job instance to be configured
+   * @param samplerConfig The configuration for creating sample data in the output file.
    * @since 1.8.0
    */
 
@@ -169,8 +157,9 @@ public class AccumuloFileOutputFormat extends FileOutputFormat<Key,Value> {
 
       @Override
       public void close(Reporter reporter) throws IOException {
-        if (out != null)
+        if (out != null) {
           out.close();
+        }
       }
 
       @Override
