@@ -58,10 +58,8 @@ public class AccumuloMultiTableInputFormat extends AbstractInputFormat<Key,Value
    * Sets the {@link org.apache.accumulo.core.client.mapreduce.InputTableConfig} objects on the
    * given Hadoop configuration
    *
-   * @param job
-   *          the Hadoop job instance to be configured
-   * @param configs
-   *          the table query configs to be set on the configuration.
+   * @param job the Hadoop job instance to be configured
+   * @param configs the table query configs to be set on the configuration.
    * @since 1.6.0
    */
   public static void setInputTableConfigs(JobConf job,
@@ -84,9 +82,10 @@ public class AccumuloMultiTableInputFormat extends AbstractInputFormat<Key,Value
               Map.Entry<Key,Value> entry = scannerIterator.next();
               key.set(currentKey = entry.getKey());
               value.set(entry.getValue().get());
-              if (log.isTraceEnabled())
+              if (log.isTraceEnabled()) {
                 log.trace(
                     "Processing key/value pair: " + DefaultFormatter.formatEntry(entry, true));
+              }
               return true;
             }
             return false;
