@@ -425,7 +425,7 @@ public class AccumuloOutputFormat implements OutputFormat<Text,Mutation> {
      */
     @Override
     public void write(Text table, Mutation mutation) throws IOException {
-      if (table == null || table.toString().isEmpty()) {
+      if (table == null || table.getLength() == 0) {
         table = this.defaultTableName;
       }
 
