@@ -38,8 +38,8 @@ public class Bulk {
    * WARNING : do not change this class, its used for serialization to Json
    */
   public static class Mapping {
-    private Tablet tablet;
-    private Collection<FileInfo> files;
+    private final Tablet tablet;
+    private final Collection<FileInfo> files;
 
     public Mapping(KeyExtent tablet, Files files) {
       this.tablet = toTablet(tablet);
@@ -64,8 +64,8 @@ public class Bulk {
    */
   public static class Tablet {
 
-    private byte[] endRow;
-    private byte[] prevEndRow;
+    private final byte[] endRow;
+    private final byte[] prevEndRow;
 
     public Tablet(Text endRow, Text prevEndRow) {
       this.endRow = endRow == null ? null : TextUtil.getBytes(endRow);
@@ -138,10 +138,12 @@ public class Bulk {
 
     @Override
     public boolean equals(Object o) {
-      if (o == this)
+      if (o == this) {
         return true;
-      if (!(o instanceof FileInfo))
+      }
+      if (!(o instanceof FileInfo)) {
         return false;
+      }
       FileInfo other = (FileInfo) o;
       return this.name.equals(other.name) && this.estSize == other.estSize
           && this.estEntries == other.estEntries;
@@ -201,10 +203,12 @@ public class Bulk {
 
     @Override
     public boolean equals(Object o) {
-      if (o == this)
+      if (o == this) {
         return true;
-      if (!(o instanceof Files))
+      }
+      if (!(o instanceof Files)) {
         return false;
+      }
       Files other = (Files) o;
       return this.files.equals(other.files);
     }
