@@ -46,19 +46,20 @@ import com.google.common.annotations.VisibleForTesting;
 
 class ConcurrentKeyExtentCache implements KeyExtentCache {
 
-  private static Logger log = LoggerFactory.getLogger(ConcurrentKeyExtentCache.class);
+  private static final Logger log = LoggerFactory.getLogger(ConcurrentKeyExtentCache.class);
 
   private static final Text MAX = new Text();
 
-  private Set<Text> rowsToLookup = Collections.synchronizedSet(new HashSet<>());
+  private final Set<Text> rowsToLookup = Collections.synchronizedSet(new HashSet<>());
 
   List<Text> lookupRows = new ArrayList<>();
 
-  private ConcurrentSkipListMap<Text,KeyExtent> extents = new ConcurrentSkipListMap<>((t1, t2) -> {
-    return (t1 == t2) ? 0 : (t1 == MAX ? 1 : (t2 == MAX ? -1 : t1.compareTo(t2)));
-  });
-  private TableId tableId;
-  private ClientContext ctx;
+  private final ConcurrentSkipListMap<Text,KeyExtent> extents =
+      new ConcurrentSkipListMap<>((t1, t2) -> {
+        return (t1 == t2) ? 0 : (t1 == MAX ? 1 : (t2 == MAX ? -1 : t1.compareTo(t2)));
+      });
+  private final TableId tableId;
+  private final ClientContext ctx;
 
   ConcurrentKeyExtentCache(TableId tableId, ClientContext ctx) {
     this.tableId = tableId;
@@ -98,8 +99,9 @@ class ConcurrentKeyExtentCache implements KeyExtentCache {
     while (true) {
 
       KeyExtent ke = getFromCache(row);
-      if (ke != null)
+      if (ke != null) {
         return ke;
+      }
 
       // If a metadata lookup is currently in progress, then multiple threads can queue up their
       // rows. The next lookup will process all queued. Processing multiple at once can be more
@@ -132,8 +134,9 @@ class ConcurrentKeyExtentCache implements KeyExtentCache {
                 Iterator<KeyExtent> iter = lookupExtents(lookupRow).iterator();
                 while (iter.hasNext()) {
                   KeyExtent ke2 = iter.next();
-                  if (inCache(ke2))
+                  if (inCache(ke2)) {
                     break;
+                  }
                   updateCache(ke2);
                 }
                 break;
