@@ -22,6 +22,7 @@ import java.io.DataOutputStream;
 import java.io.IOException;
 import java.io.OutputStream;
 import java.nio.ByteBuffer;
+import java.util.concurrent.atomic.AtomicBoolean;
 
 /**
  * Buffers all input in a growing buffer until flush() is called. Then entire buffer is written,
@@ -32,8 +33,10 @@ public class BlockedOutputStream extends OutputStream {
   int blockSize;
   DataOutputStream out;
   ByteBuffer bb;
+  private final AtomicBoolean openTracker;
 
-  public BlockedOutputStream(OutputStream out, int blockSize, int bufferSize) {
+  public BlockedOutputStream(OutputStream out, int blockSize, int bufferSize,
+      AtomicBoolean openTracker) {
     if (bufferSize <= 0) {
       throw new IllegalArgumentException("bufferSize must be greater than 0.");
     }
@@ -50,6 +53,7 @@ public class BlockedOutputStream extends OutputStream {
     // some buffer space + bytes to make the buffer evened up with the cipher block size - 4 bytes
     // for the size int
     bb = ByteBuffer.allocate(bufferSize + remainder - 4);
+    this.openTracker = openTracker;
   }
 
   @Override
@@ -113,5 +117,6 @@ public class BlockedOutputStream extends OutputStream {
   public void close() throws IOException {
     flush();
     out.close();
+    openTracker.compareAndSet(true, false);
   }
 }
