@@ -19,6 +19,7 @@
 package org.apache.accumulo.core.file.blockfile.cache.lru;
 
 import java.util.LinkedList;
+import java.util.Objects;
 import java.util.PriorityQueue;
 
 /**
@@ -36,21 +37,20 @@ import java.util.PriorityQueue;
  */
 public class CachedBlockQueue implements HeapSize {
 
-  private PriorityQueue<CachedBlock> queue;
+  private final PriorityQueue<CachedBlock> queue;
 
   private long heapSize;
-  private long maxSize;
+  private final long maxSize;
 
   /**
-   * @param maxSize
-   *          the target size of elements in the queue
-   * @param blockSize
-   *          expected average size of blocks
+   * @param maxSize the target size of elements in the queue
+   * @param blockSize expected average size of blocks
    */
   public CachedBlockQueue(long maxSize, long blockSize) {
     int initialSize = (int) Math.ceil(maxSize / (double) blockSize);
-    if (initialSize == 0)
+    if (initialSize == 0) {
       initialSize++;
+    }
     queue = new PriorityQueue<>(initialSize);
     heapSize = 0;
     this.maxSize = maxSize;
@@ -64,15 +64,15 @@ public class CachedBlockQueue implements HeapSize {
    * smallest element in the queue, the element will be added to the queue. Otherwise, there is no
    * side effect of this call.
    *
-   * @param cb
-   *          block to try to add to the queue
+   * @param cb block to try to add to the queue
    */
   public void add(CachedBlock cb) {
     if (heapSize < maxSize) {
       queue.add(cb);
       heapSize += cb.heapSize();
     } else {
-      CachedBlock head = queue.peek();
+      CachedBlock head =
+          Objects.requireNonNull(queue.peek(), "No cached blocks available from queue");
       if (cb.compareTo(head) > 0) {
         heapSize += cb.heapSize();
         heapSize -= head.heapSize();
@@ -96,20 +96,7 @@ public class CachedBlockQueue implements HeapSize {
     while (!queue.isEmpty()) {
       blocks.addFirst(queue.poll());
     }
-    return blocks.toArray(new CachedBlock[blocks.size()]);
-  }
-
-  /**
-   * Get a sorted List of all elements in this queue, in descending order.
-   *
-   * @return list of cached elements in descending order
-   */
-  public LinkedList<CachedBlock> getList() {
-    LinkedList<CachedBlock> blocks = new LinkedList<>();
-    while (!queue.isEmpty()) {
-      blocks.addFirst(queue.poll());
-    }
-    return blocks;
+    return blocks.toArray(new CachedBlock[0]);
   }
 
   /**
