@@ -38,18 +38,17 @@ public abstract class SynchronousLoadingBlockCache implements BlockCache {
   private final Lock[] loadLocks;
 
   /**
-   * @param numLocks
-   *          this controls how many load operations can run concurrently
+   * @param numLocks this controls how many load operations can run concurrently
    */
   SynchronousLoadingBlockCache(int numLocks) {
     loadLocks = new Lock[numLocks];
     for (int i = 0; i < loadLocks.length; i++) {
-      loadLocks[i] = new ReentrantLock();
+      loadLocks[i] = new ReentrantLock(true);
     }
   }
 
   public SynchronousLoadingBlockCache() {
-    this(2017);
+    this(5003);
   }
 
   private Map<String,byte[]> resolveDependencies(Map<String,Loader> loaderDeps) {
@@ -114,8 +113,8 @@ public abstract class SynchronousLoadingBlockCache implements BlockCache {
     int lockIndex = (blockName.hashCode() & 0x7fffffff) % loadLocks.length;
     Lock loadLock = loadLocks[lockIndex];
 
+    loadLock.lock();
     try {
-      loadLock.lock();
 
       // check again after getting lock, could have loaded while waiting on lock
       ce = getBlockNoStats(blockName);
