@@ -34,14 +34,15 @@ import org.apache.accumulo.core.iterators.SortedKeyValueIterator;
 class IndexIterator implements SortedKeyValueIterator<Key,Value> {
 
   private Key key;
-  private Iterator<IndexEntry> indexIter;
+  private final Iterator<IndexEntry> indexIter;
 
   IndexIterator(Iterator<IndexEntry> indexIter) {
     this.indexIter = indexIter;
-    if (indexIter.hasNext())
+    if (indexIter.hasNext()) {
       key = indexIter.next().getKey();
-    else
+    } else {
       key = null;
+    }
   }
 
   @Override
@@ -72,10 +73,11 @@ class IndexIterator implements SortedKeyValueIterator<Key,Value> {
 
   @Override
   public void next() throws IOException {
-    if (indexIter.hasNext())
+    if (indexIter.hasNext()) {
       key = indexIter.next().getKey();
-    else
+    } else {
       key = null;
+    }
   }
 
   @Override
