@@ -52,7 +52,7 @@ public class MultiLevelIndex {
     private long offset;
     private long compressedSize;
     private long rawSize;
-    private boolean newFormat;
+    private final boolean newFormat;
 
     IndexEntry(Key k, int e, long offset, long compressedSize, long rawSize) {
       this.key = k;
@@ -208,7 +208,7 @@ public class MultiLevelIndex {
   // a list that deserializes index entries on demand
   private static class SerializedIndex extends SerializedIndexBase<IndexEntry> {
 
-    private boolean newFormat;
+    private final boolean newFormat;
 
     SerializedIndex(int[] offsets, byte[] data, boolean newFormat) {
       super(offsets, data);
@@ -451,7 +451,7 @@ public class MultiLevelIndex {
    */
   public static class BufferedWriter {
 
-    private Writer writer;
+    private final Writer writer;
     private DataOutputStream buffer;
     private int buffered;
     private ByteArrayOutputStream baos;
@@ -503,15 +503,15 @@ public class MultiLevelIndex {
   }
 
   public static class Writer {
-    private int threshold;
+    private final int threshold;
 
-    private ArrayList<IndexBlock> levels;
+    private final ArrayList<IndexBlock> levels;
 
     private int totalAdded;
 
     private boolean addedLast = false;
 
-    private BCFile.Writer blockFileWriter;
+    private final BCFile.Writer blockFileWriter;
 
     Writer(BCFile.Writer blockFileWriter, int maxBlockSize) {
       this.blockFileWriter = blockFileWriter;
@@ -592,14 +592,14 @@ public class MultiLevelIndex {
 
   public static class Reader {
     private IndexBlock rootBlock;
-    private CachableBlockFile.Reader blockStore;
-    private int version;
+    private final CachableBlockFile.Reader blockStore;
+    private final int version;
     private int size;
 
     public class Node {
 
-      private Node parent;
-      private IndexBlock indexBlock;
+      private final Node parent;
+      private final IndexBlock indexBlock;
       private int currentPos;
 
       Node(Node parent, IndexBlock iBlock) {
