@@ -259,8 +259,9 @@ public class PrintInfo implements KeywordExecutable {
             Value value = dataIter.getTopValue();
             if (formatter != null) {
               System.out.println(formatter.apply(key, value));
-              if (System.out.checkError())
+              if (System.out.checkError()) {
                 return;
+              }
             }
 
             if (opts.histogram) {
@@ -339,7 +340,7 @@ public class PrintInfo implements KeywordExecutable {
             + Key.toPrintableString(cryptoParams, 0, cryptoParams.length, cryptoParams.length));
       }
     } catch (IOException ioe) {
-      log.error("Error reading crypto params", ioe);
+      System.out.println("Unable to read crypto params");
     }
   }
 }
