@@ -71,13 +71,23 @@ public class VisibilityFilter extends Filter implements OptionDescriber {
     this.cache = new LRUMap<>(1000);
   }
 
+  @Override
+  public SortedKeyValueIterator<Key,Value> deepCopy(IteratorEnvironment env) {
+    VisibilityFilter result = (VisibilityFilter) super.deepCopy(env);
+    result.filterInvalid = this.filterInvalid;
+    result.ve = this.ve;
+    result.cache = this.cache;
+    return result;
+  }
+
   @Override
   public boolean accept(Key k, Value v) {
     ByteSequence testVis = k.getColumnVisibilityData();
     if (filterInvalid) {
       Boolean b = cache.get(testVis);
-      if (b != null)
+      if (b != null) {
         return b;
+      }
       try {
         new ColumnVisibility(testVis.toArray());
         cache.put(testVis, true);
@@ -92,8 +102,9 @@ public class VisibilityFilter extends Filter implements OptionDescriber {
       }
 
       Boolean b = cache.get(testVis);
-      if (b != null)
+      if (b != null) {
         return b;
+      }
 
       try {
         boolean bb = ve.evaluate(new ColumnVisibility(testVis.toArray()));
