@@ -20,6 +20,7 @@ package org.apache.accumulo.core.metadata.schema;
 
 import java.util.Base64;
 
+import org.apache.accumulo.core.data.Mutation;
 import org.apache.accumulo.core.data.TableId;
 import org.apache.accumulo.core.dataImpl.KeyExtent;
 import org.apache.accumulo.core.util.TextUtil;
@@ -136,4 +137,11 @@ public class ExternalCompactionFinalState {
   public String toString() {
     return toJson();
   }
+
+  public Mutation toMutation() {
+    String prefix = MetadataSchema.ExternalCompactionSection.getRowPrefix();
+    Mutation m = new Mutation(prefix + getExternalCompactionId().canonical());
+    m.put("", "", toJson());
+    return m;
+  }
 }
