@@ -73,6 +73,42 @@ import io.micrometer.core.instrument.MeterRegistry;
  * <td>FunctionCounter</td>
  * <td>Number of entries written by all threads performing compactions</td>
  * </tr>
+ * <tr>
+ * <td>N/A</td>
+ * <td>N/A</td>
+ * <td>{@value #METRICS_COMPACTOR_COMPACTIONS_CANCELLED}</td>
+ * <td>FunctionCounter</td>
+ * <td>Number of compactions cancelled on a compactor</td>
+ * </tr>
+ * <tr>
+ * <td>N/A</td>
+ * <td>N/A</td>
+ * <td>{@value #METRICS_COMPACTOR_COMPACTIONS_COMPLETED}</td>
+ * <td>FunctionCounter</td>
+ * <td>Number of compactions completed on a compactor</td>
+ * </tr>
+ * <tr>
+ * <td>N/A</td>
+ * <td>N/A</td>
+ * <td>{@value #METRICS_COMPACTOR_COMPACTIONS_FAILED}</td>
+ * <td>FunctionCounter</td>
+ * <td>Number of compactions failed on a compactor</td>
+ * </tr>
+ * <tr>
+ * <td>N/A</td>
+ * <td>N/A</td>
+ * <td>{@value #METRICS_COMPACTOR_FAILURES_CONSECUTIVE}</td>
+ * <td>Gauge</td>
+ * <td>Number of consecutive compaction failures on a compactor</td>
+ * </tr>
+ * <tr>
+ * <td>N/A</td>
+ * <td>N/A</td>
+ * <td>{@value #METRICS_COMPACTOR_FAILURES_TERMINATION}</td>
+ * <td>Gauge</td>
+ * <td>Number of Compactors terminated due to consecutive failures. Process exits after this metric
+ * is incremented, so it's not guaranteed to be seen.</td>
+ * </tr>
  * <!-- fate -->
  * <tr>
  * <td>currentFateOps</td>
@@ -362,25 +398,25 @@ import io.micrometer.core.instrument.MeterRegistry;
  * </tr>
  * <!-- scan server -->
  * <tr>
- * <th>N/A</th>
- * <th>N/A</th>
- * <th>{@value #METRICS_SCAN_RESERVATION_TOTAL_TIMER}</th>
- * <th>Timer</th>
- * <th>Time to reserve a tablets files for scan</th>
+ * <td>N/A</td>
+ * <td>N/A</td>
+ * <td>{@value #METRICS_SCAN_RESERVATION_TOTAL_TIMER}</td>
+ * <td>Timer</td>
+ * <td>Time to reserve a tablets files for scan</td>
  * </tr>
  * <tr>
- * <th>N/A</th>
- * <th>N/A</th>
- * <th>{@value #METRICS_SCAN_BUSY_TIMEOUT_COUNTER}</th>
- * <th>Counter</th>
- * <th>Count of the scans where a busy timeout happened</th>
+ * <td>N/A</td>
+ * <td>N/A</td>
+ * <td>{@value #METRICS_SCAN_BUSY_TIMEOUT_COUNTER}</td>
+ * <td>Counter</td>
+ * <td>Count of the scans where a busy timeout happened</td>
  * </tr>
  * <tr>
- * <th>N/A</th>
- * <th>N/A</th>
- * <th>{@value #METRICS_SCAN_TABLET_METADATA_CACHE}</th>
- * <th>Cache</th>
- * <th>scan server tablet cache metrics</th>
+ * <td>N/A</td>
+ * <td>N/A</td>
+ * <td>{@value #METRICS_SCAN_TABLET_METADATA_CACHE}</td>
+ * <td>Cache</td>
+ * <td>scan server tablet cache metrics</td>
  * </tr>
  * <!-- scans -->
  * <tr>
@@ -463,6 +499,13 @@ import io.micrometer.core.instrument.MeterRegistry;
  * <td>Prior to 2.1.0 this metric was reported as a rate, it is now the count and the rate can be
  * derived</td>
  * </tr>
+ * <tr>
+ * <td>N/A</td>
+ * <td>N/A</td>
+ * <td>{@value #METRICS_SCAN_ZOMBIE_THREADS}</td>
+ * <td>Gauge</td>
+ * <td></td>
+ * </tr>
  * <!-- major compactions -->
  * <tr>
  * <td>{i|e}_{compactionServiceName}_{executor_name}_queued</td>
@@ -600,7 +643,7 @@ import io.micrometer.core.instrument.MeterRegistry;
  * <tr>
  * <td>N/A</td>
  * <td>N/A</td>
- * <td>{@value METRICS_MANAGER_BALANCER_MIGRATIONS_NEEDED}</td>
+ * <td>{@value #METRICS_MANAGER_BALANCER_MIGRATIONS_NEEDED}</td>
  * <td>Gauge</td>
  * <td>The number of migrations that need to complete before the system is balanced</td>
  * </tr>
@@ -618,6 +661,12 @@ public interface MetricsProducer {
   String METRICS_COMPACTOR_MAJC_STUCK = METRICS_COMPACTOR_PREFIX + "majc.stuck";
   String METRICS_COMPACTOR_ENTRIES_READ = METRICS_COMPACTOR_PREFIX + "entries.read";
   String METRICS_COMPACTOR_ENTRIES_WRITTEN = METRICS_COMPACTOR_PREFIX + "entries.written";
+  String METRICS_COMPACTOR_COMPACTIONS_CANCELLED = METRICS_COMPACTOR_PREFIX + "majc.cancelled";
+  String METRICS_COMPACTOR_COMPACTIONS_COMPLETED = METRICS_COMPACTOR_PREFIX + "majc.completed";
+  String METRICS_COMPACTOR_COMPACTIONS_FAILED = METRICS_COMPACTOR_PREFIX + "majc.failed";
+  String METRICS_COMPACTOR_FAILURES_CONSECUTIVE =
+      METRICS_COMPACTOR_PREFIX + "majc.failures.consecutive";
+  String METRICS_COMPACTOR_FAILURES_TERMINATION = METRICS_COMPACTOR_PREFIX + "terminated";
 
   String METRICS_FATE_PREFIX = "accumulo.fate.";
   String METRICS_FATE_TYPE_IN_PROGRESS = METRICS_FATE_PREFIX + "ops.in.progress.by.type";
@@ -674,7 +723,7 @@ public interface MetricsProducer {
   String METRICS_SCAN_QUERY_SCAN_RESULTS = METRICS_SCAN_PREFIX + "query.results";
   String METRICS_SCAN_QUERY_SCAN_RESULTS_BYTES = METRICS_SCAN_PREFIX + "query.results.bytes";
   String METRICS_SCAN_SCANNED_ENTRIES = METRICS_SCAN_PREFIX + "query.scanned.entries";
-
+  String METRICS_SCAN_ZOMBIE_THREADS = METRICS_SCAN_PREFIX + "zombie.threads";
   String METRICS_SCAN_TABLET_METADATA_CACHE = METRICS_SCAN_PREFIX + "tablet.metadata.cache";
 
   String METRICS_TSERVER_PREFIX = "accumulo.tserver.";
