@@ -43,9 +43,11 @@ import org.apache.accumulo.core.util.ByteBufferUtil;
 public class Authorizations implements Iterable<byte[]>, Serializable, AuthorizationContainer {
 
   private static final long serialVersionUID = 1L;
+  private static final Set<ByteSequence> EMPTY_AUTH_SET = Collections.emptySet();
+  private static final List<byte[]> EMPTY_AUTH_LIST = Collections.emptyList();
 
-  private final HashSet<ByteSequence> auths = new HashSet<>();
-  private final ArrayList<byte[]> authsList = new ArrayList<>(); // sorted order
+  private final Set<ByteSequence> auths;
+  private final List<byte[]> authsList; // sorted order
 
   /**
    * An empty set of authorizations.
@@ -101,21 +103,39 @@ public class Authorizations implements Iterable<byte[]>, Serializable, Authoriza
     }
   }
 
+  private static Set<ByteSequence> createInternalSet(int size) {
+    if (size < 1) {
+      return EMPTY_AUTH_SET;
+    } else {
+      return new HashSet<>(size);
+    }
+  }
+
+  private static List<byte[]> createInternalList(int size) {
+    if (size < 1) {
+      return EMPTY_AUTH_LIST;
+    } else {
+      return new ArrayList<>(size);
+    }
+
+  }
+
   /**
    * Constructs an authorization object from a collection of string authorizations that have each
    * already been encoded as UTF-8 bytes. Warning: This method does not verify that each encoded
    * string is valid UTF-8.
    *
-   * @param authorizations
-   *          collection of authorizations, as strings encoded in UTF-8
-   * @throws IllegalArgumentException
-   *           if authorizations is null
+   * @param authorizations collection of authorizations, as strings encoded in UTF-8
+   * @throws IllegalArgumentException if authorizations is null
    * @see #Authorizations(String...)
    */
   public Authorizations(Collection<byte[]> authorizations) {
     checkArgument(authorizations != null, "authorizations is null");
-    for (byte[] auth : authorizations)
+    this.auths = createInternalSet(authorizations.size());
+    this.authsList = createInternalList(authorizations.size());
+    for (byte[] auth : authorizations) {
       auths.add(new ArrayByteSequence(auth));
+    }
     checkAuths();
   }
 
@@ -124,14 +144,14 @@ public class Authorizations implements Iterable<byte[]>, Serializable, Authoriza
    * been encoded as UTF-8 bytes. Warning: This method does not verify that each encoded string is
    * valid UTF-8.
    *
-   * @param authorizations
-   *          list of authorizations, as strings encoded in UTF-8 and placed in buffers
-   * @throws IllegalArgumentException
-   *           if authorizations is null
+   * @param authorizations list of authorizations, as strings encoded in UTF-8 and placed in buffers
+   * @throws IllegalArgumentException if authorizations is null
    * @see #Authorizations(String...)
    */
   public Authorizations(List<ByteBuffer> authorizations) {
     checkArgument(authorizations != null, "authorizations is null");
+    this.auths = createInternalSet(authorizations.size());
+    this.authsList = createInternalList(authorizations.size());
     for (ByteBuffer buffer : authorizations) {
       auths.add(new ArrayByteSequence(ByteBufferUtil.toBytes(buffer)));
     }
@@ -143,31 +163,41 @@ public class Authorizations implements Iterable<byte[]>, Serializable, Authoriza
    * of authorizations of size one. Warning: This method does not verify that the encoded serialized
    * form is valid UTF-8.
    *
-   * @param authorizations
-   *          a serialized authorizations string produced by {@link #getAuthorizationsArray()} or
-   *          {@link #serialize()}, converted to UTF-8 bytes
-   * @throws IllegalArgumentException
-   *           if authorizations is null
+   * @param authorizations a serialized authorizations string produced by
+   *        {@link #getAuthorizationsArray()} or {@link #serialize()}, converted to UTF-8 bytes
+   * @throws IllegalArgumentException if authorizations is null
    */
   public Authorizations(byte[] authorizations) {
 
     checkArgument(authorizations != null, "authorizations is null");
 
     String authsString = new String(authorizations, UTF_8);
+
     if (authsString.startsWith(HEADER)) {
       // it's the new format
       authsString = authsString.substring(HEADER.length());
+      String[] parts = authsString.split(",");
+
+      this.auths = createInternalSet(parts.length);
+      this.authsList = createInternalList(parts.length);
       if (!authsString.isEmpty()) {
-        for (String encAuth : authsString.split(",")) {
-          byte[] auth = Base64.getDecoder().decode(encAuth);
+        for (String encAuth : parts) {
+          byte[] auth = Base64.getDecoder().decode(encAuth.getBytes(UTF_8));
           auths.add(new ArrayByteSequence(auth));
         }
         checkAuths();
       }
     } else {
       // it's the old format
-      if (authorizations.length > 0)
-        setAuthorizations(authsString.split(","));
+      if (authorizations.length > 0) {
+        String[] parts = authsString.split(",");
+        this.auths = createInternalSet(parts.length);
+        this.authsList = createInternalList(parts.length);
+        setAuthorizations(parts);
+      } else {
+        this.auths = EMPTY_AUTH_SET;
+        this.authsList = EMPTY_AUTH_LIST;
+      }
     }
   }
 
@@ -176,17 +206,21 @@ public class Authorizations implements Iterable<byte[]>, Serializable, Authoriza
    *
    * @see #Authorizations(String...)
    */
-  public Authorizations() {}
+  public Authorizations() {
+    this.auths = EMPTY_AUTH_SET;
+    this.authsList = EMPTY_AUTH_LIST;
+  }
 
   /**
    * Constructs an authorizations object from a set of human-readable authorizations.
    *
-   * @param authorizations
-   *          array of authorizations
-   * @throws IllegalArgumentException
-   *           if authorizations is null
+   * @param authorizations array of authorizations
+   * @throws IllegalArgumentException if authorizations is null
    */
   public Authorizations(String... authorizations) {
+    checkArgument(authorizations != null, "authorizations is null");
+    this.auths = createInternalSet(authorizations.length);
+    this.authsList = createInternalList(authorizations.length);
     setAuthorizations(authorizations);
   }
 
@@ -258,8 +292,7 @@ public class Authorizations implements Iterable<byte[]>, Serializable, Authoriza
   /**
    * Checks whether this object contains the given authorization.
    *
-   * @param auth
-   *          authorization, as a string encoded in UTF-8
+   * @param auth authorization, as a string encoded in UTF-8
    * @return true if authorization is in this collection
    */
   public boolean contains(byte[] auth) {
@@ -270,8 +303,7 @@ public class Authorizations implements Iterable<byte[]>, Serializable, Authoriza
    * Checks whether this object contains the given authorization. Warning: This method does not
    * verify that the encoded string is valid UTF-8.
    *
-   * @param auth
-   *          authorization, as a string encoded in UTF-8
+   * @param auth authorization, as a string encoded in UTF-8
    * @return true if authorization is in this collection
    */
   @Override
@@ -282,8 +314,7 @@ public class Authorizations implements Iterable<byte[]>, Serializable, Authoriza
   /**
    * Checks whether this object contains the given authorization.
    *
-   * @param auth
-   *          authorization
+   * @param auth authorization
    * @return true if authorization is in this collection
    */
   public boolean contains(String auth) {
@@ -308,8 +339,9 @@ public class Authorizations implements Iterable<byte[]>, Serializable, Authoriza
   @Override
   public int hashCode() {
     int result = 0;
-    for (ByteSequence b : auths)
+    for (ByteSequence b : auths) {
       result += b.hashCode();
+    }
     return result;
   }
 
