@@ -35,6 +35,7 @@ import java.util.Map.Entry;
 import java.util.Set;
 import java.util.SortedMap;
 import java.util.TreeMap;
+import java.util.concurrent.TimeUnit;
 import java.util.function.Supplier;
 import java.util.regex.Pattern;
 import java.util.stream.Collectors;
@@ -56,6 +57,7 @@ import org.apache.accumulo.core.spi.balancer.data.TableStatistics;
 import org.apache.accumulo.core.spi.balancer.data.TabletMigration;
 import org.apache.accumulo.core.spi.balancer.data.TabletServerId;
 import org.apache.accumulo.core.spi.balancer.data.TabletStatistics;
+import org.apache.accumulo.core.util.Timer;
 import org.apache.commons.lang3.builder.ToStringBuilder;
 import org.apache.commons.lang3.builder.ToStringStyle;
 import org.slf4j.Logger;
@@ -153,7 +155,7 @@ public class HostRegexTableLoadBalancer extends TableLoadBalancer {
     private final Map<String,Pattern> poolNameToRegexPattern;
 
     HrtlbConf(PluginEnvironment.Configuration conf) {
-      System.out.println("building hrtlb conf");
+      LOG.info("Building conf");
       String oobProperty = conf.get(HOST_BALANCER_OOB_CHECK_KEY);
       if (oobProperty != null) {
         oobCheckMillis = ConfigurationTypeHelper.getTimeInMillis(oobProperty);
@@ -181,7 +183,7 @@ public class HostRegexTableLoadBalancer extends TableLoadBalancer {
   }
 
   private static final Set<TabletId> EMPTY_MIGRATIONS = Collections.emptySet();
-  private volatile long lastOOBCheck = System.currentTimeMillis();
+  protected final Map<String,Long> lastOOBCheckTimes = new HashMap<>();
   private Map<String,SortedMap<TabletServerId,TServerStatus>> pools = new HashMap<>();
   private final Map<TabletId,TabletMigration> migrationsFromLastPass = new HashMap<>();
   private final Map<TableId,Long> tableToTimeSinceNoMigrations = new HashMap<>();
@@ -352,6 +354,7 @@ public class HostRegexTableLoadBalancer extends TableLoadBalancer {
         .collect(Collectors.toMap(Map.Entry::getValue, Map.Entry::getKey));
 
     // Send a view of the current servers to the tables tablet balancer
+    Timer assignmentTimer = Timer.startNew();
     for (Entry<TableId,Map<TabletId,TabletServerId>> e : groupedUnassigned.entrySet()) {
       Map<TabletId,TabletServerId> newAssignments = new HashMap<>();
       String tableName = tableIdToTableName.get(e.getKey());
@@ -367,10 +370,14 @@ public class HostRegexTableLoadBalancer extends TableLoadBalancer {
           continue;
         }
       }
-      LOG.debug("Sending {} tablets to balancer for table {} for assignment within tservers {}",
-          e.getValue().size(), tableName, currentView.keySet());
+      LOG.debug("Sending {} tablets to balancer for table {} for assignment within {} tservers",
+          e.getValue().size(), tableName, currentView.keySet().size());
+      LOG.trace("table {} tserver assignment set {}", tableName, currentView.keySet());
+      assignmentTimer.restart();
       getBalancerForTable(e.getKey())
           .getAssignments(new AssignmentParamsImpl(currentView, e.getValue(), newAssignments));
+      LOG.debug("assignment results table:{} assignments:{} time:{}ms", tableName,
+          newAssignments.size(), assignmentTimer.elapsed(TimeUnit.MILLISECONDS));
       newAssignments.forEach(params::addAssignment);
     }
   }
@@ -379,7 +386,7 @@ public class HostRegexTableLoadBalancer extends TableLoadBalancer {
   public long balance(BalanceParameters params) {
     long minBalanceTime = 20_000;
     // Iterate over the tables and balance each of them
-    Map<String,TableId> tableIdMap = environment.getTableIdMap();
+    Map<String,TableId> tableIdMap = params.getTablesToBalance();
     Map<TableId,String> tableIdToTableName = tableIdMap.entrySet().stream()
         .collect(Collectors.toMap(Map.Entry::getValue, Map.Entry::getKey));
     tableIdToTableName.keySet().forEach(this::checkTableConfig);
@@ -394,7 +401,9 @@ public class HostRegexTableLoadBalancer extends TableLoadBalancer {
 
     Map<String,SortedMap<TabletServerId,TServerStatus>> currentGrouped =
         splitCurrentByRegex(params.currentStatus());
-    if ((now - this.lastOOBCheck) > myConf.oobCheckMillis) {
+
+    if ((now - this.lastOOBCheckTimes.computeIfAbsent(params.partitionName(),
+        (p) -> System.currentTimeMillis())) > myConf.oobCheckMillis) {
       try {
         // Check to see if a tablet is assigned outside the bounds of the pool. If so, migrate it.
         for (String table : tableIdMap.keySet()) {
@@ -454,7 +463,7 @@ public class HostRegexTableLoadBalancer extends TableLoadBalancer {
         }
       } finally {
         // this could have taken a while...get a new time
-        this.lastOOBCheck = System.currentTimeMillis();
+        this.lastOOBCheckTimes.put(params.partitionName(), System.currentTimeMillis());
       }
     }
 
@@ -498,6 +507,7 @@ public class HostRegexTableLoadBalancer extends TableLoadBalancer {
       migrationsFromLastPass.clear();
     }
 
+    Timer balanceTimer = Timer.startNew();
     for (TableId tableId : tableIdMap.values()) {
       String tableName = tableIdToTableName.get(tableId);
       String regexTableName = getPoolNameForTable(tableName);
@@ -507,8 +517,13 @@ public class HostRegexTableLoadBalancer extends TableLoadBalancer {
         continue;
       }
       ArrayList<TabletMigration> newMigrations = new ArrayList<>();
-      getBalancerForTable(tableId)
-          .balance(new BalanceParamsImpl(currentView, migrations, newMigrations));
+      balanceTimer.restart();
+      TabletBalancer tableBalancer = getBalancerForTable(tableId);
+      tableBalancer.balance(new BalanceParamsImpl(currentView, migrations, newMigrations,
+          params.partitionName() + ":" + tableId, Map.of(tableName, tableId)));
+      LOG.debug("balance results class:{} tableId:{} migrations:{} time:{}ms",
+          tableBalancer.getClass().getSimpleName(), tableId, newMigrations.size(),
+          balanceTimer.elapsed(TimeUnit.MILLISECONDS));
 
       if (newMigrations.isEmpty()) {
         tableToTimeSinceNoMigrations.remove(tableId);
@@ -534,7 +549,7 @@ public class HostRegexTableLoadBalancer extends TableLoadBalancer {
     }
 
     LOG.info("Migrating {} tablets for balance.", migrationsOut.size());
-    LOG.debug("Tablets currently migrating: {}", migrationsOut);
+    LOG.trace("Tablets currently migrating: {}", migrationsOut);
     return minBalanceTime;
   }
 
