@@ -53,12 +53,12 @@ public class SpaceAwareVolumeChooser extends PreferredVolumeChooser {
   public static final String RECOMPUTE_INTERVAL = "spaceaware.volume.chooser.recompute.interval";
 
   // Default time to wait in ms. Defaults to 5 min
-  private long defaultComputationCacheDuration = 300000;
+  private final long defaultComputationCacheDuration = 300000;
   private LoadingCache<Set<String>,WeightedRandomCollection> choiceCache = null;
 
   private static final Logger log = LoggerFactory.getLogger(SpaceAwareVolumeChooser.class);
 
-  private Configuration conf = new Configuration();
+  private final Configuration conf = new Configuration();
 
   protected double getFreeSpace(String uri) throws IOException {
     FileSystem pathFs = new Path(uri).getFileSystem(conf);
