@@ -18,8 +18,6 @@
  */
 package org.apache.accumulo.core.summary;
 
-import java.io.IOException;
-
 import org.apache.accumulo.core.classloader.ClassLoaderUtil;
 import org.apache.accumulo.core.client.summary.Summarizer;
 import org.apache.accumulo.core.client.summary.SummarizerConfiguration;
@@ -41,8 +39,7 @@ public class SummarizerFactory {
     this.context = ClassLoaderUtil.tableContext(tableConfig);
   }
 
-  private Summarizer newSummarizer(String classname)
-      throws IOException, ReflectiveOperationException {
+  private Summarizer newSummarizer(String classname) throws ReflectiveOperationException {
     if (classloader != null) {
       return classloader.loadClass(classname).asSubclass(Summarizer.class).getDeclaredConstructor()
           .newInstance();
@@ -55,7 +52,7 @@ public class SummarizerFactory {
   public Summarizer getSummarizer(SummarizerConfiguration conf) {
     try {
       return newSummarizer(conf.getClassName());
-    } catch (ReflectiveOperationException | IOException e) {
+    } catch (ReflectiveOperationException e) {
       throw new RuntimeException(e);
     }
   }
