@@ -27,8 +27,8 @@ import org.apache.accumulo.core.data.Value;
 import org.apache.hadoop.io.Text;
 
 public class ColumnFQ implements Comparable<ColumnFQ> {
-  private Text colf;
-  private Text colq;
+  private final Text colf;
+  private final Text colq;
 
   public ColumnFQ(Text colf, Text colq) {
     if (colf == null || colq == null) {
@@ -73,10 +73,12 @@ public class ColumnFQ implements Comparable<ColumnFQ> {
 
   @Override
   public boolean equals(Object o) {
-    if (!(o instanceof ColumnFQ))
+    if (!(o instanceof ColumnFQ)) {
       return false;
-    if (this == o)
+    }
+    if (this == o) {
       return true;
+    }
     ColumnFQ ocfq = (ColumnFQ) o;
     return ocfq.colf.equals(colf) && ocfq.colq.equals(colq);
   }
@@ -98,8 +100,9 @@ public class ColumnFQ implements Comparable<ColumnFQ> {
   public int compareTo(ColumnFQ o) {
     int cmp = colf.compareTo(o.colf);
 
-    if (cmp == 0)
+    if (cmp == 0) {
       cmp = colq.compareTo(o.colq);
+    }
 
     return cmp;
   }
