@@ -23,6 +23,7 @@ import static java.util.concurrent.TimeUnit.MINUTES;
 import static java.util.concurrent.TimeUnit.SECONDS;
 import static org.apache.accumulo.core.util.threads.ThreadPoolNames.ACCUMULO_POOL_PREFIX;
 import static org.apache.accumulo.core.util.threads.ThreadPoolNames.GC_DELETE_POOL;
+import static org.apache.accumulo.core.util.threads.ThreadPoolNames.GC_WAL_DELETE_POOL;
 import static org.apache.accumulo.core.util.threads.ThreadPoolNames.GENERAL_SERVER_POOL;
 import static org.apache.accumulo.core.util.threads.ThreadPoolNames.GENERAL_SERVER_SIMPLETIMER_POOL;
 import static org.apache.accumulo.core.util.threads.ThreadPoolNames.MANAGER_BULK_IMPORT_POOL;
@@ -40,6 +41,7 @@ import static org.apache.accumulo.core.util.threads.ThreadPoolNames.TSERVER_SUMM
 import static org.apache.accumulo.core.util.threads.ThreadPoolNames.TSERVER_WORKQ_POOL;
 
 import java.lang.Thread.UncaughtExceptionHandler;
+import java.util.ArrayList;
 import java.util.Iterator;
 import java.util.List;
 import java.util.OptionalInt;
@@ -56,6 +58,8 @@ import java.util.concurrent.ScheduledThreadPoolExecutor;
 import java.util.concurrent.SynchronousQueue;
 import java.util.concurrent.ThreadPoolExecutor;
 import java.util.concurrent.TimeUnit;
+import java.util.concurrent.atomic.AtomicBoolean;
+import java.util.concurrent.atomic.AtomicReference;
 import java.util.function.IntSupplier;
 
 import org.apache.accumulo.core.conf.AccumuloConfiguration;
@@ -68,6 +72,7 @@ import org.slf4j.LoggerFactory;
 import com.google.common.base.Preconditions;
 
 import edu.umd.cs.findbugs.annotations.SuppressFBWarnings;
+import io.micrometer.core.instrument.MeterRegistry;
 import io.micrometer.core.instrument.Metrics;
 import io.micrometer.core.instrument.binder.jvm.ExecutorServiceMetrics;
 
@@ -95,8 +100,15 @@ public class ThreadPools {
     return SERVER_INSTANCE;
   }
 
-  public static final ThreadPools getClientThreadPools(UncaughtExceptionHandler ueh) {
-    return new ThreadPools(ueh);
+  public static final ThreadPools getClientThreadPools(AccumuloConfiguration conf,
+      UncaughtExceptionHandler ueh) {
+    ThreadPools clientPools = new ThreadPools(ueh);
+    if (conf.getBoolean(Property.GENERAL_MICROMETER_ENABLED) == false) {
+      clientPools.disableThreadPoolMetrics();
+    } else {
+      clientPools.setMeterRegistry(Metrics.globalRegistry);
+    }
+    return clientPools;
   }
 
   private static final ThreadPoolExecutor SCHEDULED_FUTURE_CHECKER_POOL =
@@ -250,6 +262,9 @@ public class ThreadPools {
   }
 
   private final UncaughtExceptionHandler handler;
+  private final AtomicBoolean metricsEnabled = new AtomicBoolean(true);
+  private final AtomicReference<MeterRegistry> registry = new AtomicReference<>();
+  private final List<ExecutorServiceMetrics> earlyExecutorServices = new ArrayList<>();
 
   private ThreadPools(UncaughtExceptionHandler ueh) {
     handler = ueh;
@@ -375,6 +390,8 @@ public class ThreadPools {
           builder.enableThreadPoolMetrics();
         }
         return builder.build();
+      case GC_DELETE_WAL_THREADS:
+        return getPoolBuilder(GC_WAL_DELETE_POOL).numCoreThreads(conf.getCount(p)).build();
       case GC_DELETE_THREADS:
         return getPoolBuilder(GC_DELETE_POOL).numCoreThreads(conf.getCount(p)).build();
       case REPLICATION_WORKER_THREADS:
@@ -399,7 +416,7 @@ public class ThreadPools {
   }
 
   /**
-   * Fet a fluent-style pool builder.
+   * Get a fluent-style pool builder.
    *
    * @param name the pool name - the name trimed and prepended with the ACCUMULO_POOL_PREFIX so that
    *        pool names begin with a consistent prefix.
@@ -409,7 +426,11 @@ public class ThreadPools {
     if (trimmed.startsWith(ACCUMULO_POOL_PREFIX.poolName)) {
       return new ThreadPoolExecutorBuilder(trimmed);
     } else {
-      return new ThreadPoolExecutorBuilder(ACCUMULO_POOL_PREFIX.poolName + trimmed);
+      if (trimmed.startsWith(".")) {
+        return new ThreadPoolExecutorBuilder(ACCUMULO_POOL_PREFIX.poolName + trimmed);
+      } else {
+        return new ThreadPoolExecutorBuilder(ACCUMULO_POOL_PREFIX.poolName + "." + trimmed);
+      }
     }
   }
 
@@ -594,7 +615,7 @@ public class ThreadPools {
       result.allowCoreThreadTimeOut(true);
     }
     if (emitThreadPoolMetrics) {
-      ThreadPools.addExecutorServiceMetrics(result, name);
+      addExecutorServiceMetrics(result, name);
     }
     return result;
   }
@@ -637,7 +658,7 @@ public class ThreadPools {
    *        errors over long time periods.
    * @return ScheduledThreadPoolExecutor
    */
-  private ScheduledThreadPoolExecutor createScheduledExecutorService(int numThreads,
+  public ScheduledThreadPoolExecutor createScheduledExecutorService(int numThreads,
       final String name, boolean emitThreadPoolMetrics) {
     LOG.trace("Creating ScheduledThreadPoolExecutor for {} with {} threads", name, numThreads);
     var result =
@@ -701,13 +722,46 @@ public class ThreadPools {
 
         };
     if (emitThreadPoolMetrics) {
-      ThreadPools.addExecutorServiceMetrics(result, name);
+      addExecutorServiceMetrics(result, name);
     }
     return result;
   }
 
-  private static void addExecutorServiceMetrics(ExecutorService executor, String name) {
-    new ExecutorServiceMetrics(executor, name, List.of()).bindTo(Metrics.globalRegistry);
+  private void addExecutorServiceMetrics(ExecutorService executor, String name) {
+    if (!metricsEnabled.get()) {
+      return;
+    }
+    ExecutorServiceMetrics esm = new ExecutorServiceMetrics(executor, name, List.of());
+    synchronized (earlyExecutorServices) {
+      MeterRegistry r = registry.get();
+      if (r != null) {
+        esm.bindTo(r);
+      } else {
+        earlyExecutorServices.add(esm);
+      }
+    }
+  }
+
+  public void setMeterRegistry(MeterRegistry r) {
+    if (registry.compareAndSet(null, r)) {
+      synchronized (earlyExecutorServices) {
+        earlyExecutorServices.forEach(e -> e.bindTo(r));
+        earlyExecutorServices.clear();
+      }
+    } else {
+      throw new IllegalStateException("setMeterRegistry called more than once");
+    }
+  }
+
+  /**
+   * Called by MetricsInfoImpl.init on the server side if metrics are disabled. ClientContext calls
+   * {@code #getClientThreadPools(AccumuloConfiguration, UncaughtExceptionHandler)} above.
+   */
+  public void disableThreadPoolMetrics() {
+    metricsEnabled.set(false);
+    synchronized (earlyExecutorServices) {
+      earlyExecutorServices.clear();
+    }
   }
 
 }
