@@ -1,29 +1,31 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.core.client;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertNull;
-import static org.junit.Assert.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import java.io.File;
 import java.io.IOException;
 
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 @SuppressWarnings("deprecation")
 public class ClientConfigurationTest {
@@ -70,15 +72,15 @@ public class ClientConfigurationTest {
   @Test
   public void testConfPath() throws IOException {
     File target = new File(System.getProperty("user.dir"), "target");
-    assertTrue("'target' build directory does not exist", target.exists());
+    assertTrue(target.exists(), "'target' build directory does not exist");
     File testDir = new File(target, getClass().getName());
     if (!testDir.exists()) {
-      assertTrue("Failed to create test dir " + testDir, testDir.mkdirs());
+      assertTrue(testDir.mkdirs(), "Failed to create test dir " + testDir);
     }
 
     File clientConf = new File(testDir, "client.conf");
     if (!clientConf.exists()) {
-      assertTrue("Failed to create file " + clientConf, clientConf.createNewFile());
+      assertTrue(clientConf.createNewFile(), "Failed to create file " + clientConf);
     }
 
     // A directory should return the path with client.conf appended.
