@@ -1,18 +1,20 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.core.client;
 
@@ -20,34 +22,36 @@ import static java.nio.charset.StandardCharsets.UTF_8;
 import static org.easymock.EasyMock.createMock;
 import static org.easymock.EasyMock.expect;
 import static org.easymock.EasyMock.replay;
-import static org.junit.Assert.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertThrows;
 
 import java.util.List;
 import java.util.UUID;
 
 import org.apache.accumulo.core.Constants;
-import org.apache.accumulo.fate.zookeeper.ZooCache;
-import org.apache.accumulo.fate.zookeeper.ZooCacheFactory;
+import org.apache.accumulo.core.data.InstanceId;
+import org.apache.accumulo.core.fate.zookeeper.ZooCache;
+import org.apache.accumulo.core.fate.zookeeper.ZooCacheFactory;
 import org.easymock.EasyMock;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
-@Deprecated
+@Deprecated(since = "2.0.0")
 public class ZooKeeperInstanceTest {
-  private static final UUID IID = UUID.randomUUID();
-  private static final String IID_STRING = IID.toString();
+  private static final InstanceId IID = InstanceId.of(UUID.randomUUID());
+  private static final String IID_STRING = IID.canonical();
   private ZooCacheFactory zcf;
   private ZooCache zc;
   private ZooKeeperInstance zki;
 
-  private static org.apache.accumulo.core.client.ClientConfiguration.ClientProperty INSTANCE_ID =
-      org.apache.accumulo.core.client.ClientConfiguration.ClientProperty.INSTANCE_ID;
-  private static org.apache.accumulo.core.client.ClientConfiguration.ClientProperty INSTANCE_NAME =
-      org.apache.accumulo.core.client.ClientConfiguration.ClientProperty.INSTANCE_NAME;
-  private static org.apache.accumulo.core.client.ClientConfiguration.ClientProperty INSTANCE_ZK_HOST =
-      org.apache.accumulo.core.client.ClientConfiguration.ClientProperty.INSTANCE_ZK_HOST;
-  private static org.apache.accumulo.core.client.ClientConfiguration.ClientProperty INSTANCE_ZK_TIMEOUT =
-      org.apache.accumulo.core.client.ClientConfiguration.ClientProperty.INSTANCE_ZK_TIMEOUT;
+  private static final ClientConfiguration.ClientProperty INSTANCE_ID =
+      ClientConfiguration.ClientProperty.INSTANCE_ID;
+  private static final ClientConfiguration.ClientProperty INSTANCE_NAME =
+      ClientConfiguration.ClientProperty.INSTANCE_NAME;
+  private static final ClientConfiguration.ClientProperty INSTANCE_ZK_HOST =
+      ClientConfiguration.ClientProperty.INSTANCE_ZK_HOST;
+  private static final ClientConfiguration.ClientProperty INSTANCE_ZK_TIMEOUT =
+      ClientConfiguration.ClientProperty.INSTANCE_ZK_TIMEOUT;
 
   private void mockIdConstruction(ClientConfiguration config) {
     expect(config.get(INSTANCE_ID)).andReturn(IID_STRING);
@@ -63,7 +67,7 @@ public class ZooKeeperInstanceTest {
     expect(config.get(INSTANCE_ZK_TIMEOUT)).andReturn("30");
   }
 
-  @Before
+  @BeforeEach
   public void setUp() {
     ClientConfiguration config = createMock(ClientConfiguration.class);
     mockNameConstruction(config);
@@ -79,16 +83,16 @@ public class ZooKeeperInstanceTest {
     EasyMock.resetToDefault(zc);
   }
 
-  @Test(expected = IllegalArgumentException.class)
+  @Test
   public void testInvalidConstruction() {
     ClientConfiguration config = createMock(ClientConfiguration.class);
     expect(config.get(INSTANCE_ID)).andReturn(IID_STRING);
     mockNameConstruction(config);
     replay(config);
-    new ZooKeeperInstance(config);
+    assertThrows(IllegalArgumentException.class, () -> new ZooKeeperInstance(config));
   }
 
-  @Test(expected = IllegalArgumentException.class)
+  @Test
   public void testInvalidConstruction2() {
     ClientConfiguration config = createMock(ClientConfiguration.class);
     expect(config.get(INSTANCE_ID)).andReturn(null);
@@ -96,7 +100,7 @@ public class ZooKeeperInstanceTest {
     expect(config.get(INSTANCE_ZK_HOST)).andReturn("zk1");
     expect(config.get(INSTANCE_ZK_TIMEOUT)).andReturn("30");
     replay(config);
-    new ZooKeeperInstance(config);
+    assertThrows(IllegalArgumentException.class, () -> new ZooKeeperInstance(config));
   }
 
   @Test
@@ -126,25 +130,25 @@ public class ZooKeeperInstanceTest {
     assertEquals(IID_STRING, zki.getInstanceID());
   }
 
-  @Test(expected = RuntimeException.class)
+  @Test
   public void testGetInstanceID_NoMapping() {
     ClientConfiguration config = createMock(ClientConfiguration.class);
     expect(zc.get(Constants.ZROOT + Constants.ZINSTANCES + "/instance")).andReturn(null);
     replay(zc);
     EasyMock.reset(config, zcf);
-    new ZooKeeperInstance(config, zcf);
+    assertThrows(RuntimeException.class, () -> new ZooKeeperInstance(config, zcf));
   }
 
-  @Test(expected = RuntimeException.class)
+  @Test
   public void testGetInstanceID_IDMissingForName() {
     expect(zc.get(Constants.ZROOT + Constants.ZINSTANCES + "/instance"))
         .andReturn(IID_STRING.getBytes(UTF_8));
     expect(zc.get(Constants.ZROOT + "/" + IID_STRING)).andReturn(null);
     replay(zc);
-    zki.getInstanceID();
+    assertThrows(RuntimeException.class, () -> zki.getInstanceID());
   }
 
-  @Test(expected = RuntimeException.class)
+  @Test
   public void testGetInstanceID_IDMissingForID() {
     ClientConfiguration config = createMock(ClientConfiguration.class);
     mockIdConstruction(config);
@@ -152,7 +156,7 @@ public class ZooKeeperInstanceTest {
     zki = new ZooKeeperInstance(config, zcf);
     expect(zc.get(Constants.ZROOT + "/" + IID_STRING)).andReturn(null);
     replay(zc);
-    zki.getInstanceID();
+    assertThrows(RuntimeException.class, () -> zki.getInstanceID());
   }
 
   @Test
