@@ -35,6 +35,7 @@ import org.apache.accumulo.core.client.security.tokens.KerberosToken;
 import org.apache.accumulo.core.conf.ClientProperty;
 import org.apache.accumulo.core.rpc.SaslConnectionParams;
 import org.apache.accumulo.core.rpc.SslConnectionParams;
+import org.apache.accumulo.core.rpc.clients.ThriftClientTypes;
 import org.apache.accumulo.core.util.HostAndPort;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.fs.CommonConfigurationKeysPublic;
@@ -76,9 +77,8 @@ public class ThriftTransportKeyTest {
     replay(clientCtx);
 
     try {
-      assertThrows(RuntimeException.class,
-          () -> new ThriftTransportKey(HostAndPort.fromParts("localhost", 9999), 120_000,
-              clientCtx));
+      assertThrows(RuntimeException.class, () -> new ThriftTransportKey(ThriftClientTypes.CLIENT,
+          HostAndPort.fromParts("localhost", 9999), 120_000, clientCtx));
     } finally {
       verify(clientCtx);
     }
@@ -98,9 +98,10 @@ public class ThriftTransportKeyTest {
         user1.doAs((PrivilegedExceptionAction<SaslConnectionParams>) () -> createSaslParams(token));
 
     ThriftTransportKey ttk1 =
-        new ThriftTransportKey(HostAndPort.fromParts("localhost", 9997), 1L, null, saslParams1),
-        ttk2 =
-            new ThriftTransportKey(HostAndPort.fromParts("localhost", 9997), 1L, null, saslParams2);
+        new ThriftTransportKey(ThriftClientTypes.CLIENT, HostAndPort.fromParts("localhost", 9997),
+            1L, null, saslParams1),
+        ttk2 = new ThriftTransportKey(ThriftClientTypes.CLIENT,
+            HostAndPort.fromParts("localhost", 9997), 1L, null, saslParams2);
 
     // Should equals() and hashCode() to make sure we don't throw away thrift cnxns
     assertEquals(ttk1, ttk2);
@@ -119,9 +120,10 @@ public class ThriftTransportKeyTest {
         user2.doAs((PrivilegedExceptionAction<SaslConnectionParams>) () -> createSaslParams(token));
 
     ThriftTransportKey ttk1 =
-        new ThriftTransportKey(HostAndPort.fromParts("localhost", 9997), 1L, null, saslParams1),
-        ttk2 =
-            new ThriftTransportKey(HostAndPort.fromParts("localhost", 9997), 1L, null, saslParams2);
+        new ThriftTransportKey(ThriftClientTypes.CLIENT, HostAndPort.fromParts("localhost", 9997),
+            1L, null, saslParams1),
+        ttk2 = new ThriftTransportKey(ThriftClientTypes.CLIENT,
+            HostAndPort.fromParts("localhost", 9997), 1L, null, saslParams2);
 
     assertNotEquals(ttk1, ttk2);
     assertNotEquals(ttk1.hashCode(), ttk2.hashCode());
@@ -136,9 +138,10 @@ public class ThriftTransportKeyTest {
 
     replay(clientCtx);
 
-    ThriftTransportKey ttk =
-        new ThriftTransportKey(HostAndPort.fromParts("localhost", 9999), 120_000, clientCtx);
+    ThriftTransportKey ttk = new ThriftTransportKey(ThriftClientTypes.CLIENT,
+        HostAndPort.fromParts("localhost", 9999), 120_000, clientCtx);
 
     assertEquals(ttk, ttk, "Normal ThriftTransportKey doesn't equal itself");
+    assertEquals(ttk.hashCode(), ttk.hashCode());
   }
 }
