@@ -1,25 +1,30 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.core.data;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertNotSame;
-import static org.junit.Assert.assertSame;
-import static org.junit.Assert.assertTrue;
+import static java.nio.charset.StandardCharsets.UTF_8;
+import static org.junit.jupiter.api.Assertions.assertArrayEquals;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertNotSame;
+import static org.junit.jupiter.api.Assertions.assertSame;
+import static org.junit.jupiter.api.Assertions.assertThrows;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import java.util.ArrayList;
 import java.util.Iterator;
@@ -29,16 +34,19 @@ import org.apache.accumulo.core.dataImpl.thrift.TKey;
 import org.apache.accumulo.core.dataImpl.thrift.TKeyValue;
 import org.apache.accumulo.core.security.ColumnVisibility;
 import org.apache.hadoop.io.Text;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 public class KeyTest {
 
   @Test
   public void testDeletedCompare() {
-    Key k1 = new Key("r1".getBytes(), "cf".getBytes(), "cq".getBytes(), new byte[0], 0, false);
-    Key k2 = new Key("r1".getBytes(), "cf".getBytes(), "cq".getBytes(), new byte[0], 0, false);
-    Key k3 = new Key("r1".getBytes(), "cf".getBytes(), "cq".getBytes(), new byte[0], 0, true);
-    Key k4 = new Key("r1".getBytes(), "cf".getBytes(), "cq".getBytes(), new byte[0], 0, true);
+    final byte[] row = "r1".getBytes(UTF_8);
+    final byte[] cf = "cf".getBytes(UTF_8);
+    final byte[] cq = "cq".getBytes(UTF_8);
+    Key k1 = new Key(row, cf, cq, new byte[0], 0, false);
+    Key k2 = new Key(row, cf, cq, new byte[0], 0, false);
+    Key k3 = new Key(row, cf, cq, new byte[0], 0, true);
+    Key k4 = new Key(row, cf, cq, new byte[0], 0, true);
 
     assertEquals(k1, k2);
     assertEquals(k3, k4);
@@ -48,10 +56,10 @@ public class KeyTest {
 
   @Test
   public void testCopyData() {
-    byte[] row = "r".getBytes();
-    byte[] cf = "cf".getBytes();
-    byte[] cq = "cq".getBytes();
-    byte[] cv = "cv".getBytes();
+    byte[] row = "r".getBytes(UTF_8);
+    byte[] cf = "cf".getBytes(UTF_8);
+    byte[] cq = "cq".getBytes(UTF_8);
+    byte[] cv = "cv".getBytes(UTF_8);
 
     Key k1 = new Key(row, cf, cq, cv, 5L, false, false);
     Key k2 = new Key(row, cf, cq, cv, 5L, false, true);
@@ -80,6 +88,114 @@ public class KeyTest {
 
   }
 
+  @Test
+  public void testCopyDataWithByteArrayConstructors() {
+    byte[] row = "r".getBytes(UTF_8);
+    byte[] cf = "cf".getBytes(UTF_8);
+    byte[] cq = "cq".getBytes(UTF_8);
+    byte[] cv = "cv".getBytes(UTF_8);
+    byte[] empty = "".getBytes(UTF_8);
+
+    Key kRow = new Key(row);
+    Key kRowcolFam = new Key(row, cf);
+    Key kRowcolFamColQual = new Key(row, cf, cq);
+    Key kRowcolFamColQualColVis = new Key(row, cf, cq, cv);
+    Key kRowcolFamColQualColVisTimeStamp = new Key(row, cf, cq, cv, 5L);
+
+    // test row constructor
+    assertNotSameByteArray(kRow, row, empty, empty, empty);
+
+    // test row, column family constructor
+    assertNotSameByteArray(kRowcolFam, row, cf, empty, empty);
+
+    // test row, column family, column qualifier constructor
+    assertNotSameByteArray(kRowcolFamColQual, row, cf, cq, empty);
+
+    // test row, column family, column qualifier, column visibility constructor
+    assertNotSameByteArray(kRowcolFamColQualColVis, row, cf, cq, cv);
+
+    // test row, column family, column qualifier, column visibility, timestamp constructor
+    assertNotSameByteArray(kRowcolFamColQualColVisTimeStamp, row, cf, cq, cv);
+  }
+
+  private void assertNotSameByteArray(Key key, byte[] row, byte[] cf, byte[] cq, byte[] cv) {
+    if (key.getRowBytes().length != 0) {
+      assertNotSame(row, key.getRowBytes());
+      assertNotSame(row, key.getRowData().getBackingArray());
+      assertArrayEquals(row, key.getRowBytes());
+
+    }
+    if (key.getColFamily().length != 0) {
+      assertNotSame(cf, key.getColFamily());
+      assertNotSame(cf, key.getColumnFamilyData().getBackingArray());
+      assertArrayEquals(cf, key.getColFamily());
+
+    }
+    if (key.getColQualifier().length != 0) {
+      assertNotSame(cq, key.getColQualifier());
+      assertNotSame(cq, key.getColumnQualifierData().getBackingArray());
+      assertArrayEquals(cq, key.getColQualifier());
+
+    }
+    if (key.getColVisibility().length != 0) {
+      assertNotSame(cv, key.getColVisibility());
+      assertNotSame(cv, key.getColumnVisibilityData().getBackingArray());
+      assertArrayEquals(cv, key.getColVisibility());
+    }
+  }
+
+  @Test
+  public void testTextConstructorByteArrayConversion() {
+    Text rowText = new Text("r");
+    Text cfText = new Text("cf");
+    Text cqText = new Text("cq");
+    Text cvText = new Text("cv");
+
+    // make Keys from Text parameters
+    Key kRow = new Key(rowText);
+    Key kRowColFam = new Key(rowText, cfText);
+    Key kRowColFamColQual = new Key(rowText, cfText, cqText);
+    Key kRowColFamColQualColVis = new Key(rowText, cfText, cqText, cvText);
+    Key kRowColFamColQualColVisTimeStamp = new Key(rowText, cfText, cqText, cvText, 5L);
+
+    // test row constructor
+    assertTextValueConversionToByteArray(kRow);
+
+    // test row, column family constructor
+    assertTextValueConversionToByteArray(kRowColFam);
+
+    // test row, column family, column qualifier constructor
+    assertTextValueConversionToByteArray(kRowColFamColQual);
+
+    // test row, column family, column qualifier, column visibility constructor
+    assertTextValueConversionToByteArray(kRowColFamColQualColVis);
+
+    // test row, column family, column qualifier, column visibility, timestamp constructor
+    assertTextValueConversionToByteArray(kRowColFamColQualColVisTimeStamp);
+  }
+
+  private void assertTextValueConversionToByteArray(Key key) {
+    byte[] row = "r".getBytes(UTF_8);
+    byte[] cf = "cf".getBytes(UTF_8);
+    byte[] cq = "cq".getBytes(UTF_8);
+    byte[] cv = "cv".getBytes(UTF_8);
+    // show Text values submitted in constructor
+    // are converted to byte array containing
+    // the same value
+    if (key.getRowBytes().length != 0) {
+      assertArrayEquals(row, key.getRowBytes());
+    }
+    if (key.getColFamily().length != 0) {
+      assertArrayEquals(cf, key.getColFamily());
+    }
+    if (key.getColQualifier().length != 0) {
+      assertArrayEquals(cq, key.getColQualifier());
+    }
+    if (key.getColVisibility().length != 0) {
+      assertArrayEquals(cv, key.getColVisibility());
+    }
+  }
+
   @Test
   public void testString() {
     Key k1 = new Key("r1");
@@ -115,6 +231,7 @@ public class KeyTest {
         "r f:q [v%00;] " + Long.MAX_VALUE + " false");
   }
 
+  @Test
   public void testVisibilityGetters() {
     Key k = new Key("r", "f", "q", "v1|(v2&v3)");
 
@@ -132,12 +249,12 @@ public class KeyTest {
     assertEquals(k, k2);
   }
 
-  @Test(expected = IllegalArgumentException.class)
+  @Test
   public void testThrift_Invalid() {
     Key k = new Key("r1", "cf2", "cq2", "cv");
     TKey tk = k.toThrift();
     tk.setRow((byte[]) null);
-    new Key(tk);
+    assertThrows(IllegalArgumentException.class, () -> new Key(tk));
   }
 
   @Test
