@@ -18,6 +18,7 @@
  */
 package org.apache.accumulo.core.data;
 
+import static java.nio.charset.StandardCharsets.UTF_8;
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertFalse;
 import static org.junit.jupiter.api.Assertions.assertNull;
@@ -34,6 +35,7 @@ import java.util.HashSet;
 import java.util.List;
 
 import org.apache.accumulo.core.dataImpl.KeyExtent;
+import org.apache.accumulo.core.dataImpl.RangeImpl;
 import org.apache.accumulo.core.dataImpl.thrift.TRange;
 import org.apache.hadoop.io.Text;
 import org.junit.jupiter.api.Test;
@@ -41,12 +43,14 @@ import org.junit.jupiter.api.Test;
 public class RangeTest {
   private Range newRange(String k1, String k2) {
     Key ik1 = null;
-    if (k1 != null)
+    if (k1 != null) {
       ik1 = new Key(new Text(k1), 0L);
+    }
 
     Key ik2 = null;
-    if (k2 != null)
+    if (k2 != null) {
       ik2 = new Key(new Text(k2), 0L);
+    }
 
     return new Range(ik1, ik2);
   }
@@ -266,9 +270,9 @@ public class RangeTest {
 
   @Test
   public void testMergeOverlapping21() {
-    for (boolean b1 : new boolean[] {true, false})
-      for (boolean b2 : new boolean[] {true, false})
-        for (boolean b3 : new boolean[] {true, false})
+    for (boolean b1 : new boolean[] {true, false}) {
+      for (boolean b2 : new boolean[] {true, false}) {
+        for (boolean b3 : new boolean[] {true, false}) {
           for (boolean b4 : new boolean[] {true, false}) {
 
             // System.out.println("b1:"+b1+" b2:"+b2+" b3:"+b3+" b4:"+b4);
@@ -298,6 +302,9 @@ public class RangeTest {
                 new Range(new Key(new Text("a")), b1 || b3, new Key(new Text("n")), b2 || b4));
             check(Range.mergeOverlapping(rl), expected);
           }
+        }
+      }
+    }
 
   }
 
@@ -484,11 +491,13 @@ public class RangeTest {
     Text tr1 = null;
     Text tr2 = null;
 
-    if (r1 != null)
+    if (r1 != null) {
       tr1 = new Text(r1);
+    }
 
-    if (r2 != null)
+    if (r2 != null) {
       tr2 = new Text(r2);
+    }
 
     return new Range(tr1, r1i, tr2, r2i);
 
@@ -610,11 +619,10 @@ public class RangeTest {
     runClipTest(fence, range);
 
     // scanner was not handling edge case properly...
-    Range scanRange =
-        new Range(
-            new Key("10;007cdc5b0".getBytes(), "~tab".getBytes(), "~pr".getBytes(), "".getBytes(),
-                130962, false),
-            false, new Key(new Text("10<")).followingKey(PartialKey.ROW), false);
+    Range scanRange = new Range(
+        new Key("10;007cdc5b0".getBytes(UTF_8), "~tab".getBytes(UTF_8), "~pr".getBytes(UTF_8),
+            "".getBytes(UTF_8), 130962, false),
+        false, new Key(new Text("10<")).followingKey(PartialKey.ROW), false);
     // below is the proper check the scanner now does instead of just comparing the row bytes
     scanRange.afterEndKey(new Key(new Text("10<")).followingKey(PartialKey.ROW));
   }
@@ -637,7 +645,7 @@ public class RangeTest {
   }
 
   private static Column newColumn(String cf, String cq) {
-    return new Column(cf.getBytes(), cq == null ? null : cq.getBytes(), null);
+    return new Column(cf.getBytes(UTF_8), cq == null ? null : cq.getBytes(UTF_8), null);
   }
 
   private static Column newColumn(String cf) {
@@ -721,6 +729,44 @@ public class RangeTest {
     assertTrue(range7.contains(newKey("row1", "b", "x")));
     assertTrue(range7.contains(newKey("row1", "f", "x")));
     assertFalse(range7.contains(newKey("row1", "f", "z")));
+
+    // These columns fall completely after the columns in range1, should fail
+    assertThrows(IllegalArgumentException.class,
+        () -> range1.bound(newColumn("g"), newColumn("x")));
+    // run the same test as above but produce empty range instead
+    Range range8 = RangeImpl.bound(range1, newColumn("g"), newColumn("x"), true);
+    assertFalse(range8.contains(range8.getStartKey()));
+    var expectedKey = newKey("row1", "g", "");
+    expectedKey.setDeleted(true);
+    assertEquals(new Range(expectedKey, true, expectedKey, false), range8);
+
+    // These columns fall completely before the columns in range1, should fail
+    assertThrows(IllegalArgumentException.class,
+        () -> range1.bound(newColumn("!"), newColumn("+")));
+    // run the same test as above but produce empty range instead
+    Range range9 = RangeImpl.bound(range1, newColumn("!"), newColumn("+"), true);
+    assertFalse(range9.contains(range9.getStartKey()));
+    assertEquals(range1.getStartKey(), range9.getStartKey());
+    assertTrue(range9.isStartKeyInclusive());
+    assertEquals(range1.getStartKey(), range9.getEndKey());
+    assertFalse(range9.isEndKeyInclusive());
+  }
+
+  @Test
+  public void testBoundEmpty() {
+    Text row = new Text(new byte[] {'!', '0', 0});
+    // BigRootTabletIT produced this exact range and it caused Range.bound to throw an exception
+    Range range = new Range(new Key(row), true, new Key(row), false);
+    assertThrows(IllegalArgumentException.class,
+        () -> range.bound(newColumn("loc"), newColumn("~tab")));
+
+    // this should produce an empty range
+    Range bounded = RangeImpl.bound(range, newColumn("loc"), newColumn("~tab"), true);
+    assertFalse(bounded.contains(bounded.getStartKey()));
+    var expectedKey = new Key(row, new Text("loc"));
+    expectedKey.setDeleted(true);
+    assertEquals(expectedKey, bounded.getStartKey());
+    assertTrue(bounded.isStartKeyInclusive());
   }
 
   @Test
