@@ -7,13 +7,14 @@
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.core.data;
 
@@ -21,12 +22,13 @@ import static java.nio.charset.StandardCharsets.UTF_8;
 import static org.easymock.EasyMock.createMock;
 import static org.easymock.EasyMock.expect;
 import static org.easymock.EasyMock.replay;
-import static org.junit.Assert.assertArrayEquals;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertNotEquals;
-import static org.junit.Assert.assertNotSame;
-import static org.junit.Assert.assertSame;
-import static org.junit.Assert.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertArrayEquals;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertNotEquals;
+import static org.junit.jupiter.api.Assertions.assertNotSame;
+import static org.junit.jupiter.api.Assertions.assertSame;
+import static org.junit.jupiter.api.Assertions.assertThrows;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import java.io.ByteArrayInputStream;
 import java.io.ByteArrayOutputStream;
@@ -35,8 +37,8 @@ import java.io.DataOutputStream;
 import java.nio.ByteBuffer;
 
 import org.apache.hadoop.io.Text;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 public class ValueTest {
   private static final byte[] toBytes(String s) {
@@ -49,7 +51,7 @@ public class ValueTest {
     DATABUFF.put(DATA);
   }
 
-  @Before
+  @BeforeEach
   public void setUp() {
     DATABUFF.rewind();
   }
@@ -60,25 +62,25 @@ public class ValueTest {
     assertEquals(0, v.get().length);
   }
 
-  @Test(expected = NullPointerException.class)
+  @Test
   public void testNullBytesConstructor() {
-    new Value((byte[]) null);
+    assertThrows(NullPointerException.class, () -> new Value((byte[]) null));
   }
 
-  @Test(expected = NullPointerException.class)
+  @Test
   public void testNullCopyConstructor() {
-    new Value((Value) null);
+    assertThrows(NullPointerException.class, () -> new Value((Value) null));
   }
 
-  @Test(expected = NullPointerException.class)
+  @Test
   public void testNullByteBufferConstructor() {
-    new Value((ByteBuffer) null);
+    assertThrows(NullPointerException.class, () -> new Value((ByteBuffer) null));
   }
 
-  @Test(expected = NullPointerException.class)
+  @Test
   public void testNullSet() {
     Value v = new Value();
-    v.set(null);
+    assertThrows(NullPointerException.class, () -> v.set(null));
   }
 
   @Test
@@ -198,20 +200,20 @@ public class ValueTest {
     assertEquals(v2, v1);
   }
 
-  @Test(expected = NullPointerException.class)
+  @Test
   public void testNullCharSequence() {
-    new Value((CharSequence) null);
+    assertThrows(NullPointerException.class, () -> new Value((CharSequence) null));
   }
 
   @Test
   public void testText() {
     Value v1 = new Value(new Text("abc"));
-    Value v2 = new Value("abc".getBytes(UTF_8));
+    Value v2 = new Value("abc");
     assertEquals(v2, v1);
   }
 
-  @Test(expected = NullPointerException.class)
+  @Test
   public void testNullText() {
-    new Value((Text) null);
+    assertThrows(NullPointerException.class, () -> new Value((Text) null));
   }
 }
