@@ -1,27 +1,29 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
-
 package org.apache.accumulo.core.file.rfile;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertTrue;
+import static java.nio.charset.StandardCharsets.UTF_8;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import org.apache.accumulo.core.data.Key;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 import com.google.common.primitives.Bytes;
 
@@ -45,19 +47,19 @@ public class KeyShortenerTest {
    * append 0xff to end of string
    */
   private byte[] apendFF(String s) {
-    return Bytes.concat(s.getBytes(), FF);
+    return Bytes.concat(s.getBytes(UTF_8), FF);
   }
 
   /**
    * append 0x00 to end of string
    */
   private byte[] append00(String s) {
-    return Bytes.concat(s.getBytes(), new byte[] {(byte) 0x00});
+    return Bytes.concat(s.getBytes(UTF_8), new byte[] {(byte) 0x00});
   }
 
   private byte[] toBytes(Object o) {
     if (o instanceof String) {
-      return ((String) o).getBytes();
+      return ((String) o).getBytes(UTF_8);
     } else if (o instanceof byte[]) {
       return (byte[]) o;
     }
@@ -103,8 +105,8 @@ public class KeyShortenerTest {
 
   @Test
   public void testOneCharacterDifferenceAndFF() {
-    byte[] ff1 = Bytes.concat(apendFF("mop"), "b".getBytes());
-    byte[] ff2 = Bytes.concat(apendFF("mop"), FF, "b".getBytes());
+    byte[] ff1 = Bytes.concat(apendFF("mop"), "b".getBytes(UTF_8));
+    byte[] ff2 = Bytes.concat(apendFF("mop"), FF, "b".getBytes(UTF_8));
 
     String eff1 = "moq";
 
