@@ -1,25 +1,28 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.core.iterators;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import java.io.IOException;
+import java.util.Set;
 import java.util.TreeMap;
 
 import org.apache.accumulo.core.client.IteratorSetting;
@@ -27,22 +30,22 @@ import org.apache.accumulo.core.data.Key;
 import org.apache.accumulo.core.data.PartialKey;
 import org.apache.accumulo.core.data.Range;
 import org.apache.accumulo.core.data.Value;
-import org.apache.accumulo.core.iterators.system.CountingIterator;
-import org.apache.accumulo.core.util.LocalityGroupUtil;
-import org.junit.Test;
+import org.apache.accumulo.core.iteratorsImpl.ClientIteratorEnvironment;
+import org.apache.accumulo.core.iteratorsImpl.system.CountingIterator;
+import org.apache.accumulo.core.iteratorsImpl.system.SortedMapIterator;
+import org.junit.jupiter.api.Test;
 
 public class FirstEntryInRowIteratorTest {
 
   private static long process(TreeMap<Key,Value> sourceMap, TreeMap<Key,Value> resultMap,
       Range range, IteratorSetting iteratorSetting) throws IOException {
-    org.apache.accumulo.core.iterators.SortedMapIterator source = new SortedMapIterator(sourceMap);
+    SortedMapIterator source = new SortedMapIterator(sourceMap);
     CountingIterator counter = new CountingIterator(source);
     FirstEntryInRowIterator feiri = new FirstEntryInRowIterator();
-    IteratorEnvironment env = new DefaultIteratorEnvironment();
 
-    feiri.init(counter, iteratorSetting.getOptions(), env);
+    feiri.init(counter, iteratorSetting.getOptions(), ClientIteratorEnvironment.DEFAULT);
 
-    feiri.seek(range, LocalityGroupUtil.EMPTY_CF_SET, false);
+    feiri.seek(range, Set.of(), false);
     while (feiri.hasTop()) {
       resultMap.put(feiri.getTopKey(), feiri.getTopValue());
       feiri.next();
@@ -53,7 +56,7 @@ public class FirstEntryInRowIteratorTest {
   @Test
   public void test() throws IOException {
     TreeMap<Key,Value> sourceMap = new TreeMap<>();
-    Value emptyValue = new Value("".getBytes());
+    Value emptyValue = new Value("");
     IteratorSetting iteratorSetting = new IteratorSetting(1, FirstEntryInRowIterator.class);
     FirstEntryInRowIterator.setNumScansBeforeSeek(iteratorSetting, 10);
     assertTrue(
