@@ -22,15 +22,23 @@ import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertFalse;
 import static org.junit.jupiter.api.Assertions.assertTrue;
 
+import java.io.IOException;
+import java.util.ArrayList;
 import java.util.Collection;
 import java.util.HashSet;
+import java.util.List;
+import java.util.Set;
 import java.util.TreeMap;
+import java.util.function.Consumer;
 
 import org.apache.accumulo.core.data.ArrayByteSequence;
 import org.apache.accumulo.core.data.ByteSequence;
 import org.apache.accumulo.core.data.Key;
+import org.apache.accumulo.core.data.PartialKey;
 import org.apache.accumulo.core.data.Range;
 import org.apache.accumulo.core.data.Value;
+import org.apache.accumulo.core.iterators.SortedKeyValueIterator;
+import org.apache.accumulo.core.iterators.WrappingIterator;
 import org.apache.accumulo.core.iteratorsImpl.system.ColumnFamilySkippingIterator;
 import org.apache.accumulo.core.iteratorsImpl.system.CountingIterator;
 import org.apache.accumulo.core.iteratorsImpl.system.SortedMapIterator;
@@ -45,9 +53,12 @@ public class ColumnFamilySkippingIteratorTest {
     return new Key(new Text(row), new Text(cf), new Text(cq), time);
   }
 
+  String format(int field) {
+    return String.format("%06d", field);
+  }
+
   Key newKey(int row, int cf, int cq, long time) {
-    return newKey(String.format("%06d", row), String.format("%06d", cf), String.format("%06d", cq),
-        time);
+    return newKey(format(row), format(cf), format(cq), time);
   }
 
   void put(TreeMap<Key,Value> tm, String row, String cf, String cq, long time, Value val) {
@@ -163,8 +174,9 @@ public class ColumnFamilySkippingIteratorTest {
     colfams.add(new ArrayByteSequence(String.format("%06d", 61)));
     runTest(cfi, 30000, 90, allColfams, colfams);
 
-    for (int i = 62; i < 100; i++)
+    for (int i = 62; i < 100; i++) {
       colfams.add(new ArrayByteSequence(String.format("%06d", i)));
+    }
 
     runTest(cfi, 30000, 1230, allColfams, colfams);
 
@@ -250,4 +262,117 @@ public class ColumnFamilySkippingIteratorTest {
 
     // System.out.println(ci.getCount());
   }
+
+  private static class SeekCaptureIter extends WrappingIterator {
+
+    private final Consumer<Range> rangeConsumer;
+
+    SeekCaptureIter(Consumer<Range> rangeConsumer, SortedKeyValueIterator<Key,Value> source) {
+      this.rangeConsumer = rangeConsumer;
+      setSource(source);
+    }
+
+    @Override
+    public void seek(Range range, Collection<ByteSequence> columnFamilies, boolean inclusive)
+        throws IOException {
+      rangeConsumer.accept(range);
+      super.seek(range, columnFamilies, inclusive);
+    }
+  }
+
+  /**
+   * Test to ensure the seek range is bounded using the min and max column families.
+   */
+  @Test
+  public void testBoundedSeek() throws Exception {
+    TreeMap<Key,Value> tm1 = new TreeMap<>();
+
+    for (int r = 0; r < 3; r++) {
+      for (int cf = 4; cf < 1000; cf++) {
+        for (int cq = 0; cq < 1; cq++) {
+          put(tm1, r, cf, cq, 6, r * cf * cq);
+        }
+      }
+    }
+
+    List<Range> capturedRanges = new ArrayList<>();
+    // Add an iterator that captures the seek range that ColumnFamilySkippingIterator passes down
+    SeekCaptureIter seekCaptureIter =
+        new SeekCaptureIter(capturedRanges::add, new SortedMapIterator(tm1));
+    ColumnFamilySkippingIterator cfi = new ColumnFamilySkippingIterator(seekCaptureIter);
+
+    cfi.seek(new Range(format(1)),
+        Set.of(new ArrayByteSequence(format(8)), new ArrayByteSequence(format(10))), true);
+    assertEquals(1, capturedRanges.size());
+    // verify the seek on the underlying iterator was narrowed using the min and max columns
+    var startKey = new Key(format(1), format(8));
+    startKey.setDeleted(true);
+    var endKey = new Key(format(1), format(10)).followingKey(PartialKey.ROW_COLFAM);
+    // check that the seek range was bounded using the columns
+    assertEquals(new Range(startKey, true, endKey, false), capturedRanges.get(0));
+
+    // check the data is correct after the seek
+    for (int cf = 8; cf <= 10; cf += 2) {
+      for (int cq = 0; cq < 1; cq++) {
+        assertTrue(cfi.hasTop());
+        assertEquals(cfi.getTopKey(), newKey(1, cf, cq, 6));
+        cfi.next();
+      }
+    }
+
+    assertFalse(cfi.hasTop());
+
+    // ensure that bounding does not widen the range
+    var seekRange =
+        new Range(new Key(format(1), format(9)), true, new Key(format(2), format(9)), false);
+    capturedRanges.clear();
+    cfi.seek(seekRange, Set.of(new ArrayByteSequence(format(8)), new ArrayByteSequence(format(10))),
+        true);
+    assertEquals(1, capturedRanges.size());
+    // the range is more narrow than what bounding the range by the min and max family would have
+    // produced so nothing should be done to the seek range
+    assertEquals(seekRange, capturedRanges.get(0));
+
+    // with the range supplied should see family 10 for row 1 and family 8 for row 2
+    for (int cq = 0; cq < 1; cq++) {
+      assertTrue(cfi.hasTop());
+      assertEquals(cfi.getTopKey(), newKey(1, 10, cq, 6));
+      cfi.next();
+    }
+    for (int cq = 0; cq < 1; cq++) {
+      assertTrue(cfi.hasTop());
+      assertEquals(cfi.getTopKey(), newKey(2, 8, cq, 6));
+      cfi.next();
+    }
+    assertFalse(cfi.hasTop());
+
+    // test narrowing a range that crosses multiple rows
+    seekRange = new Range(format(1), true, format(2), true);
+    capturedRanges.clear();
+    cfi.seek(seekRange, Set.of(new ArrayByteSequence(format(7))), true);
+    startKey = new Key(format(1), format(7));
+    startKey.setDeleted(true);
+    endKey = new Key(format(2), format(7)).followingKey(PartialKey.ROW_COLFAM);
+    // check that the seek range was bounded using the columns
+    assertEquals(new Range(startKey, true, endKey, false), capturedRanges.get(0));
+
+    for (int r = 1; r <= 2; r++) {
+      for (int cq = 0; cq < 1; cq++) {
+        assertTrue(cfi.hasTop());
+        assertEquals(cfi.getTopKey(), newKey(r, 7, cq, 6));
+        cfi.next();
+      }
+    }
+    assertFalse(cfi.hasTop());
+
+    // test the case where the columns and range are disjoint
+    seekRange =
+        new Range(new Key(format(1), format(9)), true, new Key(format(1), format(11)), false);
+    capturedRanges.clear();
+    cfi.seek(seekRange, Set.of(new ArrayByteSequence(format(7))), true);
+    assertFalse(cfi.hasTop());
+    assertEquals(new Range(seekRange.getStartKey(), true, seekRange.getStartKey(), false),
+        capturedRanges.get(0));
+
+  }
 }
