@@ -1,25 +1,28 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.core.iterators.system;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertThrows;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.jupiter.api.Assertions.fail;
 
 import java.io.IOException;
 import java.util.ArrayList;
@@ -32,10 +35,11 @@ import org.apache.accumulo.core.data.Key;
 import org.apache.accumulo.core.data.Range;
 import org.apache.accumulo.core.data.Value;
 import org.apache.accumulo.core.iterators.SortedKeyValueIterator;
-import org.apache.accumulo.core.iterators.SortedMapIterator;
-import org.apache.accumulo.core.iterators.system.DeletingIterator.Behavior;
+import org.apache.accumulo.core.iteratorsImpl.system.DeletingIterator;
+import org.apache.accumulo.core.iteratorsImpl.system.DeletingIterator.Behavior;
+import org.apache.accumulo.core.iteratorsImpl.system.SortedMapIterator;
 import org.apache.hadoop.io.Text;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 public class DeletingIteratorTest {
 
@@ -45,9 +49,9 @@ public class DeletingIteratorTest {
   public void test1() {
     Text colf = new Text("a");
     Text colq = new Text("b");
-    Value dvOld = new Value("old".getBytes());
-    Value dvDel = new Value("old".getBytes());
-    Value dvNew = new Value("new".getBytes());
+    Value dvOld = new Value("old");
+    Value dvDel = new Value("old");
+    Value dvNew = new Value("new");
 
     TreeMap<Key,Value> tm = new TreeMap<>();
     Key k;
@@ -67,7 +71,7 @@ public class DeletingIteratorTest {
         tm.put(k, dvNew);
       }
     }
-    assertEquals("Initial size was " + tm.size(), 21, tm.size());
+    assertEquals(21, tm.size(), "Initial size was " + tm.size());
 
     Text checkRow = new Text("000");
     try {
@@ -80,7 +84,7 @@ public class DeletingIteratorTest {
         tmOut.put(it.getTopKey(), it.getTopValue());
         it.next();
       }
-      assertEquals("size after no propagation was " + tmOut.size(), 15, tmOut.size());
+      assertEquals(15, tmOut.size(), "size after no propagation was " + tmOut.size());
       for (Entry<Key,Value> e : tmOut.entrySet()) {
         if (e.getKey().getRow().equals(checkRow)) {
           byte[] b = e.getValue().get();
@@ -102,7 +106,7 @@ public class DeletingIteratorTest {
         tmOut.put(it.getTopKey(), it.getTopValue());
         it.next();
       }
-      assertEquals("size after propagation was " + tmOut.size(), 16, tmOut.size());
+      assertEquals(16, tmOut.size(), "size after propagation was " + tmOut.size());
       for (Entry<Key,Value> e : tmOut.entrySet()) {
         if (e.getKey().getRow().equals(checkRow)) {
           byte[] b = e.getValue().get();
@@ -241,13 +245,22 @@ public class DeletingIteratorTest {
     SortedKeyValueIterator<Key,Value> it =
         DeletingIterator.wrap(new SortedMapIterator(tm), false, Behavior.FAIL);
     it.seek(new Range(), EMPTY_COL_FAMS, false);
-    try {
-      while (it.hasTop()) {
-        it.getTopKey();
-        it.next();
-      }
-      fail();
-    } catch (IllegalStateException e) {}
+
+    // first entry should pass
+    it.getTopKey();
+    it.next();
+
+    // second entry should fail due to delete
+    assertThrows(IllegalStateException.class, it::getTopKey);
+    it.next();
+
+    // third entry should pass
+    it.getTopKey();
+    it.next();
+
+    // fourth entry should pass
+    it.getTopKey();
+    it.next();
   }
 
   private Range newRange(String row, long ts, boolean inclusive) {
@@ -266,6 +279,6 @@ public class DeletingIteratorTest {
       String val) {
     Key k = newKey(row, ts);
     k.setDeleted(deleted);
-    tm.put(k, new Value(val.getBytes()));
+    tm.put(k, new Value(val));
   }
 }
