@@ -1,25 +1,27 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.core.iterators.system;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertSame;
-import static org.junit.Assert.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertSame;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import java.io.IOException;
 import java.util.HashSet;
@@ -29,9 +31,10 @@ import org.apache.accumulo.core.client.IteratorSetting;
 import org.apache.accumulo.core.data.Key;
 import org.apache.accumulo.core.data.Range;
 import org.apache.accumulo.core.data.Value;
-import org.apache.accumulo.core.iterators.SortedMapIterator;
+import org.apache.accumulo.core.iteratorsImpl.system.SortedMapIterator;
+import org.apache.accumulo.core.iteratorsImpl.system.TimeSettingIterator;
 import org.apache.hadoop.io.Text;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 public class TimeSettingIteratorTest {
 
@@ -39,11 +42,11 @@ public class TimeSettingIteratorTest {
   public void test1() throws Exception {
     TreeMap<Key,Value> tm1 = new TreeMap<>();
 
-    tm1.put(new Key("r0", "cf1", "cq1", 9L), new Value("v0".getBytes()));
-    tm1.put(new Key("r1", "cf1", "cq1", Long.MAX_VALUE), new Value("v1".getBytes()));
-    tm1.put(new Key("r1", "cf1", "cq1", 90L), new Value("v2".getBytes()));
-    tm1.put(new Key("r1", "cf1", "cq1", 0L), new Value("v3".getBytes()));
-    tm1.put(new Key("r2", "cf1", "cq1", 6L), new Value("v4".getBytes()));
+    tm1.put(new Key("r0", "cf1", "cq1", 9L), new Value("v0"));
+    tm1.put(new Key("r1", "cf1", "cq1", Long.MAX_VALUE), new Value("v1"));
+    tm1.put(new Key("r1", "cf1", "cq1", 90L), new Value("v2"));
+    tm1.put(new Key("r1", "cf1", "cq1", 0L), new Value("v3"));
+    tm1.put(new Key("r2", "cf1", "cq1", 6L), new Value("v4"));
 
     TimeSettingIterator tsi = new TimeSettingIterator(new SortedMapIterator(tm1), 50);
 
@@ -99,7 +102,7 @@ public class TimeSettingIteratorTest {
     TreeMap<Key,Value> tm1 = new TreeMap<>();
     final Key k = new Key("r0", "cf1", "cq1", 9L);
 
-    tm1.put(k, new Value("v0".getBytes()));
+    tm1.put(k, new Value("v0"));
 
     TimeSettingIterator tsi = new TimeSettingIterator(new SortedMapIterator(tm1), 50);
 
@@ -107,7 +110,7 @@ public class TimeSettingIteratorTest {
 
     assertTrue(tsi.hasTop());
     final Key topKey = tsi.getTopKey();
-    assertSame("Expected the topKey to be the same object", k, topKey);
+    assertSame(k, topKey, "Expected the topKey to be the same object");
     assertEquals(new Key("r0", "cf1", "cq1", 50L), topKey);
     assertEquals("v0", tsi.getTopValue().toString());
     tsi.next();
@@ -125,10 +128,10 @@ public class TimeSettingIteratorTest {
     for (boolean inclusiveEndRange : new boolean[] {true, false}) {
       TreeMap<Key,Value> sources = new TreeMap<>();
       sources.put(new Key(row.getBytes(), colf.getBytes(), colq.getBytes(), cv.getBytes(),
-          Long.MIN_VALUE, true), new Value("00".getBytes()));
+          Long.MIN_VALUE, true), new Value("00"));
       sources.put(
           new Key(row.getBytes(), colf.getBytes(), colq.getBytes(), cv.getBytes(), Long.MIN_VALUE),
-          new Value("11".getBytes()));
+          new Value("11"));
 
       TimeSettingIterator it = new TimeSettingIterator(new SortedMapIterator(sources), 111L);
       IteratorSetting is = new IteratorSetting(1, TimeSettingIterator.class);
@@ -140,11 +143,11 @@ public class TimeSettingIteratorTest {
       it.seek(testRange, new HashSet<>(), false);
 
       assertTrue(it.hasTop());
-      assertEquals(it.getTopValue(), new Value("00".getBytes()));
+      assertEquals(it.getTopValue(), new Value("00"));
       assertEquals(111L, it.getTopKey().getTimestamp());
       it.next();
       assertTrue(it.hasTop());
-      assertEquals(it.getTopValue(), new Value("11".getBytes()));
+      assertEquals(it.getTopValue(), new Value("11"));
       assertEquals(111L, it.getTopKey().getTimestamp());
       it.next();
       assertFalse(it.hasTop());
