@@ -40,7 +40,6 @@ import org.apache.accumulo.core.data.Value;
 import org.apache.accumulo.core.iterators.Combiner;
 import org.apache.accumulo.core.iterators.Combiner.ValueIterator;
 import org.apache.accumulo.core.iterators.CombinerTestUtil;
-import org.apache.accumulo.core.iterators.DefaultIteratorEnvironment;
 import org.apache.accumulo.core.iterators.IteratorEnvironment;
 import org.apache.accumulo.core.iterators.IteratorUtil.IteratorScope;
 import org.apache.accumulo.core.iterators.LongCombiner;
@@ -50,6 +49,7 @@ import org.apache.accumulo.core.iterators.LongCombiner.VarLenEncoder;
 import org.apache.accumulo.core.iterators.SortedKeyValueIterator;
 import org.apache.accumulo.core.iterators.TypedValueCombiner;
 import org.apache.accumulo.core.iterators.ValueFormatException;
+import org.apache.accumulo.core.iteratorsImpl.ClientIteratorEnvironment;
 import org.apache.accumulo.core.iteratorsImpl.system.MultiIterator;
 import org.apache.accumulo.core.iteratorsImpl.system.SortedMapIterator;
 import org.apache.hadoop.io.Text;
@@ -59,29 +59,8 @@ public class CombinerTest {
 
   private static final Collection<ByteSequence> EMPTY_COL_FAMS = new ArrayList<>();
 
-  static class CombinerIteratorEnvironment extends DefaultIteratorEnvironment {
-
-    private IteratorScope scope;
-    private boolean isFullMajc;
-
-    CombinerIteratorEnvironment(IteratorScope scope, boolean isFullMajc) {
-      this.scope = scope;
-      this.isFullMajc = isFullMajc;
-    }
-
-    @Override
-    public IteratorScope getIteratorScope() {
-      return scope;
-    }
-
-    @Override
-    public boolean isFullMajorCompaction() {
-      return isFullMajc;
-    }
-  }
-
   static final IteratorEnvironment SCAN_IE =
-      new CombinerIteratorEnvironment(IteratorScope.scan, false);
+      new ClientIteratorEnvironment.Builder().withScope(IteratorScope.scan).build();
 
   static Key newKey(int row, int colf, int colq, long ts, boolean deleted) {
     Key k = newKey(row, colf, colq, ts);
@@ -685,8 +664,9 @@ public class CombinerTest {
 
   public static void assertBytesEqual(byte[] a, byte[] b) {
     assertEquals(a.length, b.length);
-    for (int i = 0; i < a.length; i++)
+    for (int i = 0; i < a.length; i++) {
       assertEquals(a[i], b[i]);
+    }
   }
 
   public static void sumArray(Class<? extends Encoder<List<Long>>> encoderClass,
@@ -864,8 +844,9 @@ public class CombinerTest {
 
     ai.init(new SortedMapIterator(input), is.getOptions(), env);
 
-    if (deepCopy)
+    if (deepCopy) {
       assertEquals(expected, readAll(ai.deepCopy(env)));
+    }
     assertEquals(expected, readAll(ai));
 
     long logSize = CombinerTestUtil.cacheSize();
@@ -882,8 +863,10 @@ public class CombinerTest {
 
     TreeMap<Key,Value> input = new TreeMap<>();
 
-    IteratorEnvironment paritalMajcIe = new CombinerIteratorEnvironment(IteratorScope.majc, false);
-    IteratorEnvironment fullMajcIe = new CombinerIteratorEnvironment(IteratorScope.majc, true);
+    IteratorEnvironment paritalMajcIe =
+        new ClientIteratorEnvironment.Builder().withScope(IteratorScope.majc).build();
+    IteratorEnvironment fullMajcIe = new ClientIteratorEnvironment.Builder()
+        .withScope(IteratorScope.majc).isFullMajorCompaction().build();
 
     // keys that aggregate
     newKeyValue(input, 1, 1, 1, 1, false, 4L, encoder);
