@@ -1,30 +1,34 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.core.iterators.user;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
+import static java.nio.charset.StandardCharsets.UTF_8;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertThrows;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import java.io.IOException;
 import java.text.ParseException;
 import java.text.SimpleDateFormat;
 import java.util.ArrayList;
 import java.util.Collection;
+import java.util.Collections;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.Map;
@@ -36,16 +40,16 @@ import org.apache.accumulo.core.data.Column;
 import org.apache.accumulo.core.data.Key;
 import org.apache.accumulo.core.data.Range;
 import org.apache.accumulo.core.data.Value;
-import org.apache.accumulo.core.iterators.DefaultIteratorEnvironment;
 import org.apache.accumulo.core.iterators.Filter;
 import org.apache.accumulo.core.iterators.SortedKeyValueIterator;
-import org.apache.accumulo.core.iterators.SortedMapIterator;
-import org.apache.accumulo.core.iterators.system.ColumnQualifierFilter;
-import org.apache.accumulo.core.iterators.system.VisibilityFilter;
+import org.apache.accumulo.core.iteratorsImpl.ClientIteratorEnvironment;
+import org.apache.accumulo.core.iteratorsImpl.system.ColumnQualifierFilter;
+import org.apache.accumulo.core.iteratorsImpl.system.SortedMapIterator;
+import org.apache.accumulo.core.iteratorsImpl.system.VisibilityFilter;
 import org.apache.accumulo.core.security.Authorizations;
 import org.apache.accumulo.core.security.ColumnVisibility;
 import org.apache.hadoop.io.Text;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 public class FilterTest {
 
@@ -196,11 +200,9 @@ public class FilterTest {
     AgeOffFilter.setTTL(is, 101L);
     AgeOffFilter.setCurrentTime(is, 1001L);
     AgeOffFilter.setNegate(is, true);
-    assertTrue(((AgeOffFilter) a).validateOptions(is.getOptions()));
-    try {
-      ((AgeOffFilter) a).validateOptions(EMPTY_OPTS);
-      fail();
-    } catch (IllegalArgumentException e) {}
+    final AgeOffFilter finalA = (AgeOffFilter) a;
+    assertTrue((finalA.validateOptions(is.getOptions())));
+    assertThrows(IllegalArgumentException.class, () -> finalA.validateOptions(EMPTY_OPTS));
     a.init(new SortedMapIterator(tm), is.getOptions(), null);
     a = a.deepCopy(null);
     SortedKeyValueIterator<Key,Value> copy = a.deepCopy(null);
@@ -228,19 +230,19 @@ public class FilterTest {
 
     ColumnAgeOffFilter a = new ColumnAgeOffFilter();
     assertTrue(a.validateOptions(is.getOptions()));
-    a.init(new SortedMapIterator(tm), is.getOptions(), new DefaultIteratorEnvironment());
+    a.init(new SortedMapIterator(tm), is.getOptions(), ClientIteratorEnvironment.DEFAULT);
     a.overrideCurrentTime(ts);
     a.seek(new Range(), EMPTY_COL_FAMS, false);
     assertEquals(902, size(a));
 
     ColumnAgeOffFilter.addTTL(is, new IteratorSetting.Column("a", "b"), 101L);
-    a.init(new SortedMapIterator(tm), is.getOptions(), new DefaultIteratorEnvironment());
+    a.init(new SortedMapIterator(tm), is.getOptions(), ClientIteratorEnvironment.DEFAULT);
     a.overrideCurrentTime(ts);
     a.seek(new Range(), EMPTY_COL_FAMS, false);
     assertEquals(102, size(a));
 
     ColumnAgeOffFilter.removeTTL(is, new IteratorSetting.Column("a", "b"));
-    a.init(new SortedMapIterator(tm), is.getOptions(), new DefaultIteratorEnvironment());
+    a.init(new SortedMapIterator(tm), is.getOptions(), ClientIteratorEnvironment.DEFAULT);
     a = (ColumnAgeOffFilter) a.deepCopy(null);
     a.overrideCurrentTime(ts);
     a.seek(new Range(), EMPTY_COL_FAMS, false);
@@ -269,19 +271,19 @@ public class FilterTest {
 
     ColumnAgeOffFilter a = new ColumnAgeOffFilter();
     assertTrue(a.validateOptions(is.getOptions()));
-    a.init(new SortedMapIterator(tm), is.getOptions(), new DefaultIteratorEnvironment());
+    a.init(new SortedMapIterator(tm), is.getOptions(), ClientIteratorEnvironment.DEFAULT);
     a.overrideCurrentTime(ts);
     a.seek(new Range(), EMPTY_COL_FAMS, false);
     assertEquals(98, size(a));
 
     ColumnAgeOffFilter.addTTL(is, new IteratorSetting.Column("a", "b"), 101L);
-    a.init(new SortedMapIterator(tm), is.getOptions(), new DefaultIteratorEnvironment());
+    a.init(new SortedMapIterator(tm), is.getOptions(), ClientIteratorEnvironment.DEFAULT);
     a.overrideCurrentTime(ts);
     a.seek(new Range(), EMPTY_COL_FAMS, false);
     assertEquals(898, size(a));
 
     ColumnAgeOffFilter.removeTTL(is, new IteratorSetting.Column("a", "b"));
-    a.init(new SortedMapIterator(tm), is.getOptions(), new DefaultIteratorEnvironment());
+    a.init(new SortedMapIterator(tm), is.getOptions(), ClientIteratorEnvironment.DEFAULT);
     a = (ColumnAgeOffFilter) a.deepCopy(null);
     a.overrideCurrentTime(ts);
     a.seek(new Range(), EMPTY_COL_FAMS, false);
@@ -310,19 +312,19 @@ public class FilterTest {
 
     ColumnAgeOffFilter a = new ColumnAgeOffFilter();
     assertTrue(a.validateOptions(is.getOptions()));
-    a.init(new SortedMapIterator(tm), is.getOptions(), new DefaultIteratorEnvironment());
+    a.init(new SortedMapIterator(tm), is.getOptions(), ClientIteratorEnvironment.DEFAULT);
     a.overrideCurrentTime(ts);
     a.seek(new Range(), EMPTY_COL_FAMS, false);
     assertEquals(902, size(a));
 
     ColumnAgeOffFilter.addTTL(is, new IteratorSetting.Column("negate", "b"), 101L);
-    a.init(new SortedMapIterator(tm), is.getOptions(), new DefaultIteratorEnvironment());
+    a.init(new SortedMapIterator(tm), is.getOptions(), ClientIteratorEnvironment.DEFAULT);
     a.overrideCurrentTime(ts);
     a.seek(new Range(), EMPTY_COL_FAMS, false);
     assertEquals(102, size(a));
 
     ColumnAgeOffFilter.removeTTL(is, new IteratorSetting.Column("negate", "b"));
-    a.init(new SortedMapIterator(tm), is.getOptions(), new DefaultIteratorEnvironment());
+    a.init(new SortedMapIterator(tm), is.getOptions(), ClientIteratorEnvironment.DEFAULT);
     a = (ColumnAgeOffFilter) a.deepCopy(null);
     a.overrideCurrentTime(ts);
     a.seek(new Range(), EMPTY_COL_FAMS, false);
@@ -334,7 +336,7 @@ public class FilterTest {
     Value dv = new Value();
     TreeMap<Key,Value> tm = new TreeMap<>();
     HashSet<Column> hsc = new HashSet<>();
-    hsc.add(new Column("c".getBytes(), null, null));
+    hsc.add(new Column("c".getBytes(UTF_8), null, null));
 
     Text colf1 = new Text("a");
     Text colq1 = new Text("b");
@@ -362,7 +364,7 @@ public class FilterTest {
     assertEquals(1000, size(a));
 
     hsc = new HashSet<>();
-    hsc.add(new Column("a".getBytes(), "b".getBytes(), null));
+    hsc.add(new Column("a".getBytes(UTF_8), "b".getBytes(UTF_8), null));
     a = ColumnQualifierFilter.wrap(new SortedMapIterator(tm), hsc);
     a.seek(new Range(), EMPTY_COL_FAMS, false);
     int size = size(a);
@@ -405,9 +407,7 @@ public class FilterTest {
       throws IOException {
     HashSet<Column> hsc = new HashSet<>();
 
-    for (Column column : columns) {
-      hsc.add(column);
-    }
+    Collections.addAll(hsc, columns);
 
     SortedKeyValueIterator<Key,Value> a =
         ColumnQualifierFilter.wrap(new SortedMapIterator(tm), hsc);
@@ -428,25 +428,25 @@ public class FilterTest {
 
     assertEquals(5, tm.size());
 
-    int size = size(ncqf(tm, new Column("c".getBytes(), null, null)));
+    int size = size(ncqf(tm, new Column("c".getBytes(UTF_8), null, null)));
     assertEquals(5, size);
 
-    size = size(ncqf(tm, new Column("a".getBytes(), null, null)));
+    size = size(ncqf(tm, new Column("a".getBytes(UTF_8), null, null)));
     assertEquals(5, size);
 
-    size = size(ncqf(tm, new Column("a".getBytes(), "x".getBytes(), null)));
+    size = size(ncqf(tm, new Column("a".getBytes(UTF_8), "x".getBytes(UTF_8), null)));
     assertEquals(1, size);
 
-    size = size(ncqf(tm, new Column("a".getBytes(), "x".getBytes(), null),
-        new Column("b".getBytes(), "x".getBytes(), null)));
+    size = size(ncqf(tm, new Column("a".getBytes(UTF_8), "x".getBytes(UTF_8), null),
+        new Column("b".getBytes(UTF_8), "x".getBytes(UTF_8), null)));
     assertEquals(2, size);
 
-    size = size(ncqf(tm, new Column("a".getBytes(), "x".getBytes(), null),
-        new Column("b".getBytes(), "y".getBytes(), null)));
+    size = size(ncqf(tm, new Column("a".getBytes(UTF_8), "x".getBytes(UTF_8), null),
+        new Column("b".getBytes(UTF_8), "y".getBytes(UTF_8), null)));
     assertEquals(2, size);
 
-    size = size(ncqf(tm, new Column("a".getBytes(), "x".getBytes(), null),
-        new Column("b".getBytes(), null, null)));
+    size = size(ncqf(tm, new Column("a".getBytes(UTF_8), "x".getBytes(UTF_8), null),
+        new Column("b".getBytes(UTF_8), null, null)));
     assertEquals(3, size);
   }
 
@@ -558,10 +558,8 @@ public class FilterTest {
     a.seek(new Range(), EMPTY_COL_FAMS, false);
     assertEquals(32, size(a));
 
-    try {
-      a.validateOptions(EMPTY_OPTS);
-      fail();
-    } catch (IllegalArgumentException e) {}
+    final TimestampFilter finalA = a;
+    assertThrows(IllegalArgumentException.class, () -> finalA.validateOptions(EMPTY_OPTS));
   }
 
   @Test
