@@ -1,25 +1,27 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.core.iterators.user;
 
 import static java.nio.charset.StandardCharsets.UTF_8;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import java.io.IOException;
 import java.util.ArrayList;
@@ -31,10 +33,10 @@ import org.apache.accumulo.core.data.ByteSequence;
 import org.apache.accumulo.core.data.Key;
 import org.apache.accumulo.core.data.Range;
 import org.apache.accumulo.core.data.Value;
-import org.apache.accumulo.core.iterators.DefaultIteratorEnvironment;
-import org.apache.accumulo.core.iterators.SortedMapIterator;
+import org.apache.accumulo.core.iteratorsImpl.ClientIteratorEnvironment;
+import org.apache.accumulo.core.iteratorsImpl.system.SortedMapIterator;
 import org.apache.hadoop.io.Text;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 public class RegExFilterTest {
 
@@ -42,7 +44,7 @@ public class RegExFilterTest {
 
   private Key newKeyValue(TreeMap<Key,Value> tm, String row, String cf, String cq, String val) {
     Key k = newKey(row, cf, cq);
-    tm.put(k, new Value(val.getBytes()));
+    tm.put(k, new Value(val));
     return k;
   }
 
@@ -65,7 +67,7 @@ public class RegExFilterTest {
     RegExFilter.setRegexs(is, ".*2", null, null, null, false);
 
     assertTrue(rei.validateOptions(is.getOptions()));
-    rei.init(new SortedMapIterator(tm), is.getOptions(), new DefaultIteratorEnvironment());
+    rei.init(new SortedMapIterator(tm), is.getOptions(), ClientIteratorEnvironment.DEFAULT);
     rei.seek(new Range(), EMPTY_COL_FAMS, false);
 
     assertTrue(rei.hasTop());
@@ -80,7 +82,7 @@ public class RegExFilterTest {
     RegExFilter.setRegexs(is, null, null, null, "amst", false, true); // Should only match hamster
 
     rei.validateOptions(is.getOptions());
-    rei.init(new SortedMapIterator(tm), is.getOptions(), new DefaultIteratorEnvironment());
+    rei.init(new SortedMapIterator(tm), is.getOptions(), ClientIteratorEnvironment.DEFAULT);
     rei.seek(new Range(), EMPTY_COL_FAMS, false);
 
     assertTrue(rei.hasTop());
@@ -93,7 +95,7 @@ public class RegExFilterTest {
 
     RegExFilter.setRegexs(is, null, "ya.*", null, null, false);
     assertTrue(rei.validateOptions(is.getOptions()));
-    rei.init(new SortedMapIterator(tm), is.getOptions(), new DefaultIteratorEnvironment());
+    rei.init(new SortedMapIterator(tm), is.getOptions(), ClientIteratorEnvironment.DEFAULT);
     rei.seek(new Range(), EMPTY_COL_FAMS, false);
 
     assertTrue(rei.hasTop());
@@ -106,7 +108,7 @@ public class RegExFilterTest {
 
     RegExFilter.setRegexs(is, null, null, ".*01", null, false);
     assertTrue(rei.validateOptions(is.getOptions()));
-    rei.init(new SortedMapIterator(tm), is.getOptions(), new DefaultIteratorEnvironment());
+    rei.init(new SortedMapIterator(tm), is.getOptions(), ClientIteratorEnvironment.DEFAULT);
     rei.seek(new Range(), EMPTY_COL_FAMS, false);
 
     assertTrue(rei.hasTop());
@@ -119,7 +121,7 @@ public class RegExFilterTest {
 
     RegExFilter.setRegexs(is, null, null, null, ".*at", false);
     assertTrue(rei.validateOptions(is.getOptions()));
-    rei.init(new SortedMapIterator(tm), is.getOptions(), new DefaultIteratorEnvironment());
+    rei.init(new SortedMapIterator(tm), is.getOptions(), ClientIteratorEnvironment.DEFAULT);
     rei.seek(new Range(), EMPTY_COL_FAMS, false);
 
     assertTrue(rei.hasTop());
@@ -131,7 +133,7 @@ public class RegExFilterTest {
     is.clearOptions();
 
     RegExFilter.setRegexs(is, null, null, null, ".*ap", false);
-    rei.init(new SortedMapIterator(tm), is.getOptions(), new DefaultIteratorEnvironment());
+    rei.init(new SortedMapIterator(tm), is.getOptions(), ClientIteratorEnvironment.DEFAULT);
     rei.seek(new Range(), EMPTY_COL_FAMS, false);
 
     assertFalse(rei.hasTop());
@@ -140,7 +142,7 @@ public class RegExFilterTest {
     is.clearOptions();
 
     RegExFilter.setRegexs(is, null, "ya.*", null, ".*at", false);
-    rei.init(new SortedMapIterator(tm), is.getOptions(), new DefaultIteratorEnvironment());
+    rei.init(new SortedMapIterator(tm), is.getOptions(), ClientIteratorEnvironment.DEFAULT);
     rei.seek(new Range(), EMPTY_COL_FAMS, false);
 
     assertTrue(rei.hasTop());
@@ -152,7 +154,7 @@ public class RegExFilterTest {
     is.clearOptions();
 
     RegExFilter.setRegexs(is, null, "ya.*", null, ".*ap", false);
-    rei.init(new SortedMapIterator(tm), is.getOptions(), new DefaultIteratorEnvironment());
+    rei.init(new SortedMapIterator(tm), is.getOptions(), ClientIteratorEnvironment.DEFAULT);
     rei.seek(new Range(), EMPTY_COL_FAMS, false);
 
     assertFalse(rei.hasTop());
@@ -161,7 +163,7 @@ public class RegExFilterTest {
     is.clearOptions();
 
     RegExFilter.setRegexs(is, "boo1", null, null, null, false);
-    rei.init(new SortedMapIterator(tm), is.getOptions(), new DefaultIteratorEnvironment());
+    rei.init(new SortedMapIterator(tm), is.getOptions(), ClientIteratorEnvironment.DEFAULT);
     rei.seek(new Range(), EMPTY_COL_FAMS, false);
 
     assertTrue(rei.hasTop());
@@ -175,7 +177,7 @@ public class RegExFilterTest {
     // -----------------------------------------------------
     is.clearOptions();
 
-    rei.init(new SortedMapIterator(tm), is.getOptions(), new DefaultIteratorEnvironment());
+    rei.init(new SortedMapIterator(tm), is.getOptions(), ClientIteratorEnvironment.DEFAULT);
     rei.seek(new Range(), EMPTY_COL_FAMS, false);
 
     assertTrue(rei.hasTop());
@@ -193,7 +195,7 @@ public class RegExFilterTest {
     is.clearOptions();
 
     RegExFilter.setRegexs(is, "hamster", null, "hamster", "hamster", true);
-    rei.init(new SortedMapIterator(tm), is.getOptions(), new DefaultIteratorEnvironment());
+    rei.init(new SortedMapIterator(tm), is.getOptions(), ClientIteratorEnvironment.DEFAULT);
     rei.seek(new Range(), EMPTY_COL_FAMS, false);
 
     assertTrue(rei.hasTop());
@@ -205,7 +207,7 @@ public class RegExFilterTest {
     is.clearOptions();
 
     RegExFilter.setRegexs(is, null, "ya.*", "hamster", null, true);
-    rei.init(new SortedMapIterator(tm), is.getOptions(), new DefaultIteratorEnvironment());
+    rei.init(new SortedMapIterator(tm), is.getOptions(), ClientIteratorEnvironment.DEFAULT);
     rei.seek(new Range(), EMPTY_COL_FAMS, false);
 
     assertTrue(rei.hasTop());
@@ -216,22 +218,23 @@ public class RegExFilterTest {
     is.clearOptions();
 
     RegExFilter.setRegexs(is, null, "ya.*", "hamster", null, true);
-    rei.init(new SortedMapIterator(tm), is.getOptions(), new DefaultIteratorEnvironment());
+    rei.init(new SortedMapIterator(tm), is.getOptions(), ClientIteratorEnvironment.DEFAULT);
     rei.seek(new Range(), EMPTY_COL_FAMS, false);
-    rei.deepCopy(new DefaultIteratorEnvironment());
+    rei.deepCopy(ClientIteratorEnvironment.DEFAULT);
 
     // -----------------------------------------------------
-    String multiByteText = new String("\u6d67" + "\u6F68" + "\u7067");
-    String multiByteRegex = new String(".*" + "\u6F68" + ".*");
+    String multiByteText = new String("\u6d67\u6F68\u7067");
+    String multiByteRegex = new String(".*\u6F68.*");
 
-    Key k4 = new Key("boo4".getBytes(), "hoo".getBytes(), "20080203".getBytes(), "".getBytes(), 1L);
-    Value inVal = new Value(multiByteText.getBytes(UTF_8));
+    Key k4 = new Key("boo4".getBytes(UTF_8), "hoo".getBytes(UTF_8), "20080203".getBytes(UTF_8),
+        "".getBytes(UTF_8), 1L);
+    Value inVal = new Value(multiByteText);
     tm.put(k4, inVal);
 
     is.clearOptions();
 
     RegExFilter.setRegexs(is, null, null, null, multiByteRegex, true);
-    rei.init(new SortedMapIterator(tm), is.getOptions(), new DefaultIteratorEnvironment());
+    rei.init(new SortedMapIterator(tm), is.getOptions(), ClientIteratorEnvironment.DEFAULT);
     rei.seek(new Range(), EMPTY_COL_FAMS, false);
 
     assertTrue(rei.hasTop());
@@ -246,14 +249,14 @@ public class RegExFilterTest {
     TreeMap<Key,Value> tm = new TreeMap<>();
 
     String s1 = "first", s2 = "second";
-    byte[] b1 = s1.getBytes(), b2 = s2.getBytes(), ball;
+    byte[] b1 = s1.getBytes(UTF_8), b2 = s2.getBytes(UTF_8), ball;
     ball = new byte[b1.length + b2.length + 1];
     System.arraycopy(b1, 0, ball, 0, b1.length);
     ball[b1.length] = (byte) 0;
     System.arraycopy(b2, 0, ball, b1.length + 1, b2.length);
 
     Key key = new Key(ball, new byte[0], new byte[0], new byte[0], 90, false);
-    Value val = new Value(new byte[0]);
+    Value val = new Value();
     tm.put(key, val);
 
     IteratorSetting is = new IteratorSetting(5, RegExFilter.class);
@@ -263,6 +266,6 @@ public class RegExFilterTest {
     filter.init(new SortedMapIterator(tm), is.getOptions(), null);
     filter.seek(new Range(), EMPTY_COL_FAMS, false);
 
-    assertTrue("iterator couldn't find a match when it should have", filter.hasTop());
+    assertTrue(filter.hasTop(), "iterator couldn't find a match when it should have");
   }
 }
