@@ -1,25 +1,27 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.core.metadata;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertNotEquals;
-import static org.junit.Assert.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNotEquals;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import java.util.HashMap;
 
@@ -28,10 +30,9 @@ import org.apache.accumulo.core.client.AccumuloSecurityException;
 import org.apache.accumulo.core.client.admin.TableOperations;
 import org.apache.accumulo.core.clientImpl.ClientContext;
 import org.apache.accumulo.core.data.TableId;
-import org.apache.accumulo.core.replication.ReplicationTable;
 import org.easymock.EasyMock;
-import org.junit.BeforeClass;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.Test;
 
 public class MetadataServicerTest {
 
@@ -39,12 +40,19 @@ public class MetadataServicerTest {
   private static final TableId userTableId = TableId.of("tableId");
   private static ClientContext context;
 
-  @BeforeClass
+  @SuppressWarnings("deprecation")
+  private static final TableId REPL_TABLE_ID =
+      org.apache.accumulo.core.replication.ReplicationTable.ID;
+  @SuppressWarnings("deprecation")
+  private static final String REPL_TABLE_NAME =
+      org.apache.accumulo.core.replication.ReplicationTable.NAME;
+
+  @BeforeAll
   public static void setupContext() {
     HashMap<String,String> tableNameToIdMap = new HashMap<>();
     tableNameToIdMap.put(RootTable.NAME, RootTable.ID.canonical());
     tableNameToIdMap.put(MetadataTable.NAME, MetadataTable.ID.canonical());
-    tableNameToIdMap.put(ReplicationTable.NAME, ReplicationTable.ID.canonical());
+    tableNameToIdMap.put(REPL_TABLE_NAME, REPL_TABLE_ID.canonical());
     tableNameToIdMap.put(userTableName, userTableId.canonical());
 
     context = EasyMock.createMock(ClientContext.class);
@@ -73,11 +81,11 @@ public class MetadataServicerTest {
     assertEquals(RootTable.NAME, ((TableMetadataServicer) ms).getServicingTableName());
     assertEquals(MetadataTable.ID, ms.getServicedTableId());
 
-    ms = MetadataServicer.forTableId(context, ReplicationTable.ID);
+    ms = MetadataServicer.forTableId(context, REPL_TABLE_ID);
     assertTrue(ms instanceof ServicerForUserTables);
     assertTrue(ms instanceof TableMetadataServicer);
     assertEquals(MetadataTable.NAME, ((TableMetadataServicer) ms).getServicingTableName());
-    assertEquals(ReplicationTable.ID, ms.getServicedTableId());
+    assertEquals(REPL_TABLE_ID, ms.getServicedTableId());
 
     ms = MetadataServicer.forTableId(context, userTableId);
     assertTrue(ms instanceof ServicerForUserTables);
@@ -96,11 +104,11 @@ public class MetadataServicerTest {
     assertEquals(RootTable.NAME, ((TableMetadataServicer) ms).getServicingTableName());
     assertEquals(MetadataTable.ID, ms.getServicedTableId());
 
-    ms = MetadataServicer.forTableName(context, ReplicationTable.NAME);
+    ms = MetadataServicer.forTableName(context, REPL_TABLE_NAME);
     assertTrue(ms instanceof ServicerForUserTables);
     assertTrue(ms instanceof TableMetadataServicer);
     assertEquals(MetadataTable.NAME, ((TableMetadataServicer) ms).getServicingTableName());
-    assertEquals(ReplicationTable.ID, ms.getServicedTableId());
+    assertEquals(REPL_TABLE_ID, ms.getServicedTableId());
 
     ms = MetadataServicer.forTableName(context, userTableName);
     assertTrue(ms instanceof ServicerForUserTables);
