@@ -1,22 +1,25 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.core.replication;
 
-import static org.junit.Assert.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertThrows;
 
 import org.apache.accumulo.core.data.Key;
 import org.apache.accumulo.core.data.Mutation;
@@ -25,8 +28,9 @@ import org.apache.accumulo.core.replication.ReplicationSchema.OrderSection;
 import org.apache.accumulo.core.replication.ReplicationSchema.StatusSection;
 import org.apache.accumulo.core.replication.ReplicationSchema.WorkSection;
 import org.apache.hadoop.io.Text;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
+@Deprecated
 public class ReplicationSchemaTest {
 
   @Test
@@ -38,26 +42,26 @@ public class ReplicationSchemaTest {
     assertEquals(file, extractedFile.toString());
   }
 
-  @Test(expected = NullPointerException.class)
+  @Test
   public void failOnNullKeyForFileExtract() {
     Text extractedFile = new Text();
-    StatusSection.getFile(null, extractedFile);
+    assertThrows(NullPointerException.class, () -> StatusSection.getFile(null, extractedFile));
   }
 
-  @Test(expected = NullPointerException.class)
+  @Test
   public void failOnNullBufferForFileExtract() {
     String file = "hdfs://foo:8020/bar";
     Key k = new Key(file);
     Text extractedFile = null;
-    StatusSection.getFile(k, extractedFile);
+    assertThrows(NullPointerException.class, () -> StatusSection.getFile(k, extractedFile));
   }
 
-  @Test(expected = IllegalArgumentException.class)
+  @Test
   public void failOnExtractEmptyFile() {
     String file = "";
     Key k = new Key(file);
     Text extractedFile = new Text();
-    StatusSection.getFile(k, extractedFile);
+    assertThrows(IllegalArgumentException.class, () -> StatusSection.getFile(k, extractedFile));
     assertEquals(file, extractedFile.toString());
   }
 
@@ -75,30 +79,30 @@ public class ReplicationSchemaTest {
     assertEquals(tableId, StatusSection.getTableId(k));
   }
 
-  @Test(expected = NullPointerException.class)
+  @Test
   public void failOnNullKeyForTableIdExtract() {
     Text extractedFile = new Text();
-    StatusSection.getFile(null, extractedFile);
+    assertThrows(NullPointerException.class, () -> StatusSection.getFile(null, extractedFile));
   }
 
-  @Test(expected = NullPointerException.class)
+  @Test
   public void failOnNullBufferForTableIdExtract() {
     String file = "hdfs://foo:8020/bar";
     Key k = new Key(file);
     Text extractedFile = null;
-    StatusSection.getFile(k, extractedFile);
+    assertThrows(NullPointerException.class, () -> StatusSection.getFile(k, extractedFile));
   }
 
-  @Test(expected = IllegalArgumentException.class)
+  @Test
   public void failOnIncorrectStatusColfam() {
     Key k = new Key("file", WorkSection.NAME.toString(), "");
-    StatusSection.getFile(k, new Text());
+    assertThrows(IllegalArgumentException.class, () -> StatusSection.getFile(k, new Text()));
   }
 
-  @Test(expected = IllegalArgumentException.class)
+  @Test
   public void failOnIncorrectWorkColfam() {
     Key k = new Key("file", StatusSection.NAME.toString(), "");
-    WorkSection.getFile(k, new Text());
+    assertThrows(IllegalArgumentException.class, () -> WorkSection.getFile(k, new Text()));
   }
 
   @Test
