@@ -1,27 +1,29 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.core.security;
 
 import static java.nio.charset.StandardCharsets.UTF_8;
 import static org.apache.accumulo.core.security.ColumnVisibility.quote;
-import static org.junit.Assert.assertArrayEquals;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
+import static org.junit.jupiter.api.Assertions.assertArrayEquals;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertThrows;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import java.util.Comparator;
 
@@ -29,23 +31,21 @@ import org.apache.accumulo.core.security.ColumnVisibility.Node;
 import org.apache.accumulo.core.security.ColumnVisibility.NodeComparator;
 import org.apache.accumulo.core.security.ColumnVisibility.NodeType;
 import org.apache.hadoop.io.Text;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 public class ColumnVisibilityTest {
 
   private void shouldThrow(String... strings) {
-    for (String s : strings)
-      try {
-        new ColumnVisibility(s.getBytes());
-        fail("Should throw: " + s);
-      } catch (IllegalArgumentException e) {
-        // expected
-      }
+    for (String s : strings) {
+      final byte[] sBytes = s.getBytes(UTF_8);
+      assertThrows(IllegalArgumentException.class, () -> new ColumnVisibility(sBytes),
+          "Should throw: " + s);
+    }
   }
 
   private void shouldNotThrow(String... strings) {
     for (String s : strings) {
-      new ColumnVisibility(s.getBytes());
+      new ColumnVisibility(s.getBytes(UTF_8));
     }
   }
 
@@ -89,8 +89,8 @@ public class ColumnVisibilityTest {
 
   public void normalized(String... values) {
     for (int i = 0; i < values.length; i += 2) {
-      ColumnVisibility cv = new ColumnVisibility(values[i].getBytes());
-      assertArrayEquals(cv.flatten(), values[i + 1].getBytes());
+      ColumnVisibility cv = new ColumnVisibility(values[i].getBytes(UTF_8));
+      assertArrayEquals(cv.flatten(), values[i + 1].getBytes(UTF_8));
     }
   }
 
@@ -234,8 +234,8 @@ public class ColumnVisibilityTest {
 
     // Convert to String for indexOf convenience
     String flat = new String(flattened, UTF_8);
-    assertTrue("shortest expressions sort first", flat.indexOf('e') < flat.indexOf('|'));
-    assertTrue("shortest children sort first", flat.indexOf('b') < flat.indexOf('a'));
+    assertTrue(flat.indexOf('e') < flat.indexOf('|'), "shortest expressions sort first");
+    assertTrue(flat.indexOf('b') < flat.indexOf('a'), "shortest children sort first");
   }
 
   private Node parse(String s) {
