@@ -1,31 +1,34 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.core.security;
 
 import static org.apache.accumulo.core.security.ColumnVisibility.quote;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertThrows;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+
+import java.util.List;
 
 import org.apache.accumulo.core.data.ArrayByteSequence;
-import org.apache.accumulo.core.util.BadArgumentException;
 import org.apache.accumulo.core.util.ByteArraySet;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 public class VisibilityEvaluatorTest {
 
@@ -38,55 +41,24 @@ public class VisibilityEvaluatorTest {
     assertTrue(ct.evaluate(new ColumnVisibility(new byte[0])));
 
     // test for and
-    assertTrue("'and' test", ct.evaluate(new ColumnVisibility("one&two")));
+    assertTrue(ct.evaluate(new ColumnVisibility("one&two")), "'and' test");
 
     // test for or
-    assertTrue("'or' test", ct.evaluate(new ColumnVisibility("foor|four")));
+    assertTrue(ct.evaluate(new ColumnVisibility("foor|four")), "'or' test");
 
     // test for and and or
-    assertTrue("'and' and 'or' test", ct.evaluate(new ColumnVisibility("(one&two)|(foo&bar)")));
+    assertTrue(ct.evaluate(new ColumnVisibility("(one&two)|(foo&bar)")), "'and' and 'or' test");
 
     // test for false negatives
     for (String marking : new String[] {"one", "one|five", "five|one", "(one)",
         "(one&two)|(foo&bar)", "(one|foo)&three", "one|foo|bar", "(one|foo)|bar",
         "((one|foo)|bar)&two"}) {
-      assertTrue(marking, ct.evaluate(new ColumnVisibility(marking)));
+      assertTrue(ct.evaluate(new ColumnVisibility(marking)), marking);
     }
 
     // test for false positives
     for (String marking : new String[] {"five", "one&five", "five&one", "((one|foo)|bar)&goober"}) {
-      assertFalse(marking, ct.evaluate(new ColumnVisibility(marking)));
-    }
-
-    // test missing separators; these should throw an exception
-    for (String marking : new String[] {"one(five)", "(five)one", "(one)(two)", "a|(b(c))"}) {
-      try {
-        ct.evaluate(new ColumnVisibility(marking));
-        fail(marking + " failed to throw");
-      } catch (BadArgumentException e) {
-        // all is good
-      }
-    }
-
-    // test unexpected separator
-    for (String marking : new String[] {"&(five)", "|(five)", "(five)&", "five|", "a|(b)&",
-        "(&five)", "(five|)"}) {
-      try {
-        ct.evaluate(new ColumnVisibility(marking));
-        fail(marking + " failed to throw");
-      } catch (BadArgumentException e) {
-        // all is good
-      }
-    }
-
-    // test mismatched parentheses
-    for (String marking : new String[] {"(", ")", "(a&b", "b|a)"}) {
-      try {
-        ct.evaluate(new ColumnVisibility(marking));
-        fail(marking + " failed to throw");
-      } catch (BadArgumentException e) {
-        // all is good
-      }
+      assertFalse(ct.evaluate(new ColumnVisibility(marking)), marking);
     }
   }
 
@@ -139,21 +111,12 @@ public class VisibilityEvaluatorTest {
     assertEquals("a\\b\\c\\d",
         VisibilityEvaluator.unescape(new ArrayByteSequence("a\\\\b\\\\c\\\\d")).toString());
 
-    try {
-      VisibilityEvaluator.unescape(new ArrayByteSequence("a\\b"));
-      fail("Expected failure to unescape invalid escape sequence");
-    } catch (IllegalArgumentException e) {}
-
-    try {
-      VisibilityEvaluator.unescape(new ArrayByteSequence("a\\b\\c"));
-      fail("Expected failure to unescape invalid escape sequence");
-    } catch (IllegalArgumentException e) {}
-
-    try {
-      VisibilityEvaluator.unescape(new ArrayByteSequence("a\"b\\"));
-      fail("Expected failure to unescape invalid escape sequence");
-    } catch (IllegalArgumentException e) {}
+    final String message = "Expected failure to unescape invalid escape sequence";
+    final var invalidEscapeSeqList = List.of(new ArrayByteSequence("a\\b"),
+        new ArrayByteSequence("a\\b\\c"), new ArrayByteSequence("a\"b\\"));
 
+    invalidEscapeSeqList.forEach(seq -> assertThrows(IllegalArgumentException.class,
+        () -> VisibilityEvaluator.unescape(seq), message));
   }
 
   @Test
