@@ -35,13 +35,19 @@ import java.util.Optional;
 import java.util.Set;
 import java.util.stream.Collectors;
 
+import org.apache.accumulo.core.client.TableNotFoundException;
 import org.apache.accumulo.core.client.admin.compaction.CompactableFile;
+import org.apache.accumulo.core.clientImpl.Namespace;
 import org.apache.accumulo.core.conf.ConfigurationCopy;
 import org.apache.accumulo.core.conf.ConfigurationTypeHelper;
 import org.apache.accumulo.core.conf.DefaultConfiguration;
 import org.apache.accumulo.core.conf.Property;
 import org.apache.accumulo.core.conf.SiteConfiguration;
+import org.apache.accumulo.core.data.NamespaceId;
 import org.apache.accumulo.core.data.TableId;
+import org.apache.accumulo.core.data.TabletId;
+import org.apache.accumulo.core.dataImpl.KeyExtent;
+import org.apache.accumulo.core.dataImpl.TabletIdImpl;
 import org.apache.accumulo.core.spi.common.ServiceEnvironment;
 import org.apache.accumulo.core.spi.common.ServiceEnvironment.Configuration;
 import org.apache.accumulo.core.spi.compaction.CompactionPlan.Builder;
@@ -57,6 +63,7 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 import com.google.common.base.Preconditions;
+import com.google.common.collect.Sets;
 
 public class DefaultCompactionPlannerTest {
 
@@ -181,6 +188,145 @@ public class DefaultCompactionPlannerTest {
     assertEquals(CompactionExecutorIdImpl.internalId(csid, "medium"), job.getExecutor());
   }
 
+  @Test
+  public void testRunningCompactionLookAhead() {
+    String executors = "[{'name':'small','type': 'internal','maxSize':'32M','numThreads':1},"
+        + "{'name':'medium','type': 'internal','maxSize':'128M','numThreads':2},"
+        + "{'name':'large','type': 'internal','maxSize':'512M','numThreads':3},"
+        + "{'name':'huge','type': 'internal','numThreads':4}]";
+
+    var planner = createPlanner(defaultConf, executors);
+
+    int count = 0;
+
+    // create 4 files of size 10 as compacting
+    List<String> compactingString = new ArrayList<>();
+    for (int i = 0; i < 4; i++) {
+      compactingString.add("F" + count++);
+      compactingString.add(10 + "");
+    }
+
+    // create 4 files of size 100,1000,10_000, and 100_000 as the tablets files
+    List<String> candidateStrings = new ArrayList<>();
+    for (int size = 100; size < 1_000_000; size *= 10) {
+      for (int i = 0; i < 4; i++) {
+        candidateStrings.add("F" + count++);
+        candidateStrings.add(size + "");
+      }
+    }
+
+    var compacting = createCFs(compactingString.toArray(new String[0]));
+    var candidates = createCFs(candidateStrings.toArray(new String[0]));
+    var all = Sets.union(compacting, candidates);
+    var jobs = Set.of(createJob(CompactionKind.SYSTEM, all, compacting));
+    var params = createPlanningParams(all, candidates, jobs, 2, CompactionKind.SYSTEM);
+    var plan = planner.makePlan(params);
+
+    // The compaction running over the size 10 files would produce a file that would be used by a
+    // compaction over the size 100 files. A compaction over the size 100 files would produce a file
+    // that would be used by a compaction over the size 1000 files. This should continue up the
+    // chain disqualifying all sets of files for compaction.
+    assertEquals(List.of(), plan.getJobs());
+  }
+
+  @Test
+  public void testRunningCompactionLookAhead2() {
+    var aconf = SiteConfiguration.empty()
+        .withOverrides(Map.of(
+            Property.TSERV_COMPACTION_SERVICE_PREFIX.getKey() + "cs1.planner.opts.maxOpen", "10"))
+        .build();
+    ConfigurationImpl config = new ConfigurationImpl(aconf);
+
+    String executors = "[{'name':'small','type': 'internal','maxSize':'32M','numThreads':1},"
+        + "{'name':'medium','type': 'internal','maxSize':'128M','numThreads':2},"
+        + "{'name':'large','type': 'internal','maxSize':'512M','numThreads':3},"
+        + "{'name':'huge','type': 'internal','numThreads':4}]";
+
+    var planner = createPlanner(config, executors);
+
+    int count = 0;
+
+    // create 10 files of size 11 as compacting
+    List<String> compactingString = new ArrayList<>();
+    for (int i = 0; i < 10; i++) {
+      compactingString.add("F" + count++);
+      compactingString.add(11 + "");
+    }
+
+    // create 10 files of size 11 as the tablets files
+    List<String> candidateStrings = new ArrayList<>();
+    for (int i = 0; i < 10; i++) {
+      candidateStrings.add("F" + count++);
+      candidateStrings.add(11 + "");
+    }
+
+    // create 17 files of size 100,1000, and 10_000 as the tablets files
+    for (int size = 100; size < 100_000; size *= 10) {
+      for (int i = 0; i < 17; i++) {
+        candidateStrings.add("F" + count++);
+        candidateStrings.add(size + "");
+      }
+    }
+
+    // create 5 files of 100_000 as the tablets files
+    for (int i = 0; i < 5; i++) {
+      candidateStrings.add("F" + count++);
+      candidateStrings.add(100_000 + "");
+    }
+
+    var compacting = createCFs(compactingString.toArray(new String[0]));
+    var candidates = createCFs(candidateStrings.toArray(new String[0]));
+    var all = Sets.union(compacting, candidates);
+    var jobs = Set.of(createJob(CompactionKind.SYSTEM, all, compacting));
+    var params = createPlanningParams(all, candidates, jobs, 2, CompactionKind.SYSTEM);
+    var plan = planner.makePlan(params);
+
+    // There are currently 20 files of size 11 of which 10 are compacting. The 10 files that are
+    // compacting would produce a file with a projected size of 110. The file with a projected size
+    // of 110 would not be included in a compaction of the 10 files of size 11, therefore its ok to
+    // compact the 10 files of size 11 and they should be found.
+    var job = getOnlyElement(plan.getJobs());
+    assertEquals(10, job.getFiles().size());
+    assertTrue(job.getFiles().stream().allMatch(f -> f.getEstimatedSize() == 11));
+
+    // try planning again incorporating the job returned from previous plan
+    var jobs2 = Sets.union(jobs, Set.copyOf(plan.getJobs()));
+    var candidates2 = new HashSet<>(candidates);
+    candidates2.removeAll(job.getFiles());
+    params = createPlanningParams(all, candidates2, jobs2, 2, CompactionKind.SYSTEM);
+    plan = planner.makePlan(params);
+
+    // All 20 of the size 11 files are compacting, which would produce 2 files of size 110. There
+    // are 17 files of size 100, compacting 10 files of size 100 would not include the two projected
+    // files of size 110. Should find 10 files of size 100 to compact.
+    job = getOnlyElement(plan.getJobs());
+    assertEquals(10, job.getFiles().size());
+    assertTrue(job.getFiles().stream().allMatch(f -> f.getEstimatedSize() == 100));
+
+    // try planning again incorporating the job returned from previous plan
+    var jobs3 = Sets.union(jobs2, Set.copyOf(plan.getJobs()));
+    var candidates3 = new HashSet<>(candidates2);
+    candidates3.removeAll(job.getFiles());
+    params = createPlanningParams(all, candidates3, jobs3, 2, CompactionKind.SYSTEM);
+    plan = planner.makePlan(params);
+
+    // Simulating multiple compactions forward, the next set of files that would not include files
+    // from any other projected or running compactions are 9 files of size 10_000.
+    job = getOnlyElement(plan.getJobs());
+    assertEquals(9, job.getFiles().size());
+    assertTrue(job.getFiles().stream().allMatch(f -> f.getEstimatedSize() == 10_000));
+
+    var jobs4 = Sets.union(jobs3, Set.copyOf(plan.getJobs()));
+    var candidates4 = new HashSet<>(candidates3);
+    candidates4.removeAll(job.getFiles());
+    params = createPlanningParams(all, candidates4, jobs4, 2, CompactionKind.SYSTEM);
+    plan = planner.makePlan(params);
+
+    // The 5 files of size 100_000 should not be found because it would be most optimal to compact
+    // those 5 files with the output of the compactions over the files of size 10_000.
+    assertEquals(0, plan.getJobs().size());
+  }
+
   /**
    * Tests that the maxOpen property overrides the deprecated open.max property with the default
    * service
@@ -519,13 +665,14 @@ public class DefaultCompactionPlannerTest {
     overrides.put(Property.TABLE_FILE_MAX.getKey(), "7");
     var conf = new ConfigurationImpl(SiteConfiguration.empty().withOverrides(overrides).build());
 
-    // For this case need to compact three files and the highest ratio that achieves that is 1.8
+    // The highest ratio is 1.9 so should compact this. Will need a subsequent compaction to bring
+    // it below the limit.
     var planner = createPlanner(conf, executors);
     var all = createCFs(1000, 1.1, 1.9, 1.8, 1.6, 1.3, 1.4, 1.3, 1.2, 1.1);
     var params = createPlanningParams(all, all, Set.of(), 3, CompactionKind.SYSTEM, conf);
     var plan = planner.makePlan(params);
     var job = getOnlyElement(plan.getJobs());
-    assertEquals(createCFs(1000, 1.1, 1.9, 1.8), job.getFiles());
+    assertEquals(createCFs(1000, 1.1, 1.9), job.getFiles());
 
     // For this case need to compact two files and the highest ratio that achieves that is 2.9
     all = createCFs(1000, 2, 2.9, 2.8, 2.7, 2.6, 2.5, 2.4, 2.3);
@@ -558,21 +705,26 @@ public class DefaultCompactionPlannerTest {
       assertEquals(createCFs(1000, 1.9), job.getFiles());
     }
 
-    // In this case the tablet can be brought below the max limit in single compaction, so it should
-    // find this
+    // The max compaction ratio is the first two files, so should compact these. Will require
+    // multiple compactions to bring the tablet below the limit.
     all =
         createCFs(1000, 1.9, 1.8, 1.7, 1.6, 1.5, 1.4, 1.5, 1.2, 1.1, 1.1, 1.1, 1.1, 1.1, 1.1, 1.1);
     params = createPlanningParams(all, all, Set.of(), 3, CompactionKind.SYSTEM, conf);
     plan = planner.makePlan(params);
     job = getOnlyElement(plan.getJobs());
-    assertEquals(createCFs(1000, 1.9, 1.8, 1.7, 1.6, 1.5, 1.4, 1.5, 1.2, 1.1), job.getFiles());
+    assertEquals(createCFs(1000, 1.9), job.getFiles());
+
+    all = createCFs(10, 1.3, 2.2, 2.51, 1.02, 1.7, 2.54, 2.3, 1.7, 1.5, 1.4);
+    params = createPlanningParams(all, all, Set.of(), 3, CompactionKind.SYSTEM, conf);
+    plan = planner.makePlan(params);
+    job = getOnlyElement(plan.getJobs());
+    assertEquals(createCFs(10, 1.3, 2.2, 2.51, 1.02, 1.7, 2.54), job.getFiles());
 
     // each file is 10x the size of the file smaller than it
     all = createCFs(10, 1.1, 1.1, 1.1, 1.1, 1.1, 1.1, 1.1, 1.1);
     params = createPlanningParams(all, all, Set.of(), 3, CompactionKind.SYSTEM, conf);
     plan = planner.makePlan(params);
-    job = getOnlyElement(plan.getJobs());
-    assertEquals(createCFs(10, 1.1, 1.1, 1.1, 1.1, 1.1, 1.1, 1.1, 1.1), job.getFiles());
+    assertTrue(plan.getJobs().isEmpty());
 
     // test with some files growing 20x, ensure those are not included
     for (var ratio : List.of(1.9, 2.0, 3.0, 4.0)) {
@@ -582,7 +734,6 @@ public class DefaultCompactionPlannerTest {
       job = getOnlyElement(plan.getJobs());
       assertEquals(createCFs(10, 1.05, 1.05, 1.25, 1.75), job.getFiles());
     }
-
   }
 
   @Test
@@ -615,12 +766,24 @@ public class DefaultCompactionPlannerTest {
 
     assertTrue(plan.getJobs().isEmpty());
 
-    // a really bad situation, each file is 20 times the size of its smaller file. The algorithm
-    // does not search that for ratios that low.
-    all = createCFs(10, 1.05, 1.05, 1.05, 1.05, 1.05, 1.05, 1.05, 1.05);
+    // a really bad situation, each file is 20 times the size of its smaller file. By default, the
+    // algorithm does not search that for ratios that low.
+    all = createCFs(3, 1.05, 1.05, 1.05, 1.05, 1.05, 1.05, 1.05, 1.05);
     params = createPlanningParams(all, all, Set.of(), 3, CompactionKind.SYSTEM, conf);
     plan = planner.makePlan(params);
     assertTrue(plan.getJobs().isEmpty());
+
+    // adjust the config for the lowest search ratio and recreate the planner, this should allow a
+    // compaction to happen
+    var overrides2 = new HashMap<>(overrides);
+    overrides2.put(
+        Property.TSERV_COMPACTION_SERVICE_PREFIX.getKey() + "cs1.planner.opts.lowestRatio", "1.04");
+    var conf2 = new ConfigurationImpl(SiteConfiguration.empty().withOverrides(overrides2).build());
+    var planner2 = createPlanner(conf2, executors);
+    params = createPlanningParams(all, all, Set.of(), 3, CompactionKind.SYSTEM, conf);
+    plan = planner2.makePlan(params);
+    var job2 = getOnlyElement(plan.getJobs());
+    assertEquals(createCFs(3, 1.05, 1.05, 1.05, 1.05, 1.05, 1.05), job2.getFiles());
   }
 
   // Test to ensure that plugin falls back from TABLE_FILE_MAX to TSERV_SCAN_MAX_OPENFILES
@@ -642,7 +805,7 @@ public class DefaultCompactionPlannerTest {
     var params = createPlanningParams(all, all, Set.of(), 3, CompactionKind.SYSTEM, conf);
     var plan = planner.makePlan(params);
     var job = getOnlyElement(plan.getJobs());
-    assertEquals(createCFs(1000, 1.9, 1.8, 1.7, 1.6, 1.5, 1.4), job.getFiles());
+    assertEquals(createCFs(1000, 1.9), job.getFiles());
   }
 
   private CompactionJob createJob(CompactionKind kind, Set<CompactableFile> all,
@@ -689,7 +852,7 @@ public class DefaultCompactionPlannerTest {
     return createCFs(pairs.toArray(new String[0]));
   }
 
-  private static Set<CompactableFile> createCFs(String... namesSizePairs) {
+  public static Set<CompactableFile> createCFs(String... namesSizePairs) {
     Set<CompactableFile> files = new HashSet<>();
 
     for (int i = 0; i < namesSizePairs.length; i += 2) {
@@ -741,11 +904,21 @@ public class DefaultCompactionPlannerTest {
       CompactionKind kind, Configuration conf) {
     return new CompactionPlanner.PlanningParameters() {
 
+      @Override
+      public NamespaceId getNamespaceId() throws TableNotFoundException {
+        return Namespace.ACCUMULO.id();
+      }
+
       @Override
       public TableId getTableId() {
         return TableId.of("42");
       }
 
+      @Override
+      public TabletId getTabletId() {
+        return new TabletIdImpl(new KeyExtent(getTableId(), null, null));
+      }
+
       @Override
       public ServiceEnvironment getServiceEnvironment() {
         ServiceEnvironment senv = EasyMock.createMock(ServiceEnvironment.class);
@@ -795,14 +968,16 @@ public class DefaultCompactionPlannerTest {
   private static CompactionPlanner.InitParameters getInitParams(Configuration conf,
       String executors) {
 
-    String maxOpen =
-        conf.get(Property.TSERV_COMPACTION_SERVICE_PREFIX.getKey() + "cs1.planner.opts.maxOpen");
     Map<String,String> options = new HashMap<>();
-    options.put("executors", executors.replaceAll("'", "\""));
 
-    if (maxOpen != null) {
-      options.put("maxOpen", maxOpen);
-    }
+    String prefix = Property.TSERV_COMPACTION_SERVICE_PREFIX.getKey() + "cs1.planner.opts.";
+
+    conf.forEach(e -> {
+      if (e.getKey().startsWith(prefix)) {
+        options.put(e.getKey().substring(prefix.length()), e.getValue());
+      }
+    });
+    options.put("executors", executors.replaceAll("'", "\""));
 
     ServiceEnvironment senv = EasyMock.createMock(ServiceEnvironment.class);
     EasyMock.expect(senv.getConfiguration()).andReturn(conf).anyTimes();
