@@ -19,6 +19,7 @@
 package org.apache.accumulo.core.spi.scan;
 
 import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
 import static org.junit.jupiter.api.Assertions.assertNull;
 import static org.junit.jupiter.api.Assertions.assertThrows;
 import static org.junit.jupiter.api.Assertions.assertTrue;
@@ -29,7 +30,9 @@ import java.util.Collection;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.Map;
+import java.util.Optional;
 import java.util.Set;
+import java.util.concurrent.atomic.AtomicReference;
 import java.util.function.Supplier;
 import java.util.stream.Collectors;
 import java.util.stream.Stream;
@@ -39,6 +42,7 @@ import org.apache.accumulo.core.data.TabletId;
 import org.apache.accumulo.core.dataImpl.KeyExtent;
 import org.apache.accumulo.core.dataImpl.TabletIdImpl;
 import org.apache.accumulo.core.spi.common.ServiceEnvironment;
+import org.apache.accumulo.core.util.UtilWaitThread;
 import org.apache.hadoop.io.Text;
 import org.junit.jupiter.api.Test;
 
@@ -47,7 +51,7 @@ public class ConfigurableScanServerSelectorTest {
   static class InitParams implements ScanServerSelector.InitParameters {
 
     private final Map<String,String> opts;
-    private final Map<String,String> scanServers;
+    private final Supplier<Map<String,String>> scanServers;
 
     InitParams(Set<String> scanServers) {
       this(scanServers, Map.of());
@@ -55,12 +59,18 @@ public class ConfigurableScanServerSelectorTest {
 
     InitParams(Set<String> scanServers, Map<String,String> opts) {
       this.opts = opts;
-      this.scanServers = new HashMap<>();
+      var scanServersMap = new HashMap<String,String>();
       scanServers.forEach(
-          sserv -> this.scanServers.put(sserv, ScanServerSelector.DEFAULT_SCAN_SERVER_GROUP_NAME));
+          sserv -> scanServersMap.put(sserv, ScanServerSelector.DEFAULT_SCAN_SERVER_GROUP_NAME));
+      this.scanServers = () -> scanServersMap;
     }
 
     InitParams(Map<String,String> scanServers, Map<String,String> opts) {
+      this.opts = opts;
+      this.scanServers = () -> scanServers;
+    }
+
+    InitParams(Supplier<Map<String,String>> scanServers, Map<String,String> opts) {
       this.opts = opts;
       this.scanServers = scanServers;
     }
@@ -77,7 +87,7 @@ public class ConfigurableScanServerSelectorTest {
 
     @Override
     public Supplier<Collection<ScanServerInfo>> getScanServers() {
-      return () -> scanServers.entrySet().stream().map(entry -> new ScanServerInfo() {
+      return () -> scanServers.get().entrySet().stream().map(entry -> new ScanServerInfo() {
 
         @Override
         public String getAddress() {
@@ -93,19 +103,19 @@ public class ConfigurableScanServerSelectorTest {
     }
   }
 
-  static class DaParams implements ScanServerSelector.SelectorParameters {
+  static class SelectorParams implements ScanServerSelector.SelectorParameters {
 
     private final Collection<TabletId> tablets;
     private final Map<TabletId,Collection<? extends ScanServerAttempt>> attempts;
     private final Map<String,String> hints;
 
-    DaParams(TabletId tablet) {
+    SelectorParams(TabletId tablet) {
       this.tablets = Set.of(tablet);
       this.attempts = Map.of();
       this.hints = Map.of();
     }
 
-    DaParams(TabletId tablet, Map<TabletId,Collection<? extends ScanServerAttempt>> attempts,
+    SelectorParams(TabletId tablet, Map<TabletId,Collection<? extends ScanServerAttempt>> attempts,
         Map<String,String> hints) {
       this.tablets = Set.of(tablet);
       this.attempts = attempts;
@@ -126,6 +136,13 @@ public class ConfigurableScanServerSelectorTest {
     public Map<String,String> getHints() {
       return hints;
     }
+
+    @Override
+    public <T> Optional<T> waitUntil(Supplier<Optional<T>> condition, Duration maxWaitTime,
+        String description) {
+      throw new UnsupportedOperationException();
+    }
+
   }
 
   static class TestScanServerAttempt implements ScanServerAttempt {
@@ -165,7 +182,7 @@ public class ConfigurableScanServerSelectorTest {
     for (int i = 0; i < 100; i++) {
       var tabletId = nti("1", "m");
 
-      ScanServerSelections actions = selector.selectServers(new DaParams(tabletId));
+      ScanServerSelections actions = selector.selectServers(new SelectorParams(tabletId));
 
       servers.add(actions.getScanServer(tabletId));
     }
@@ -205,7 +222,7 @@ public class ConfigurableScanServerSelectorTest {
 
     for (int i = 0; i < 100 * numServers; i++) {
       ScanServerSelections actions =
-          selector.selectServers(new DaParams(tabletId, attempts, hints));
+          selector.selectServers(new SelectorParams(tabletId, attempts, hints));
 
       assertEquals(expectedBusyTimeout, actions.getBusyTimeout().toMillis());
       assertEquals(0, actions.getDelay().toMillis());
@@ -263,7 +280,7 @@ public class ConfigurableScanServerSelectorTest {
       var tabletId = t % 1000 == 0 ? nti("" + t, null) : nti("" + t, endRow);
 
       for (int i = 0; i < 100; i++) {
-        ScanServerSelections actions = selector.selectServers(new DaParams(tabletId));
+        ScanServerSelections actions = selector.selectServers(new SelectorParams(tabletId));
         serversSeen.add(actions.getScanServer(tabletId));
         allServersSeen.merge(actions.getScanServer(tabletId), 1L, Long::sum);
       }
@@ -379,7 +396,7 @@ public class ConfigurableScanServerSelectorTest {
     selector.init(new InitParams(Set.of()));
 
     var tabletId = nti("1", "m");
-    ScanServerSelections actions = selector.selectServers(new DaParams(tabletId));
+    ScanServerSelections actions = selector.selectServers(new SelectorParams(tabletId));
     assertNull(actions.getScanServer(tabletId));
     assertEquals(Duration.ZERO, actions.getDelay());
     assertEquals(Duration.ZERO, actions.getBusyTimeout());
@@ -412,7 +429,7 @@ public class ConfigurableScanServerSelectorTest {
     for (int i = 0; i < 1000; i++) {
       var tabletId = nti("1", "m" + i);
 
-      ScanServerSelections actions = selector.selectServers(new DaParams(tabletId));
+      ScanServerSelections actions = selector.selectServers(new SelectorParams(tabletId));
 
       servers.add(actions.getScanServer(tabletId));
     }
@@ -428,7 +445,7 @@ public class ConfigurableScanServerSelectorTest {
       var tabletId = nti("1", "m" + i);
 
       ScanServerSelections actions =
-          selector.selectServers(new DaParams(tabletId, Map.of(), hints));
+          selector.selectServers(new SelectorParams(tabletId, Map.of(), hints));
 
       servers.add(actions.getScanServer(tabletId));
     }
@@ -444,7 +461,7 @@ public class ConfigurableScanServerSelectorTest {
       var tabletId = nti("1", "m" + i);
 
       ScanServerSelections actions =
-          selector.selectServers(new DaParams(tabletId, Map.of(), hints));
+          selector.selectServers(new SelectorParams(tabletId, Map.of(), hints));
 
       servers.add(actions.getScanServer(tabletId));
     }
@@ -460,11 +477,56 @@ public class ConfigurableScanServerSelectorTest {
       var tabletId = nti("1", "m" + i);
 
       ScanServerSelections actions =
-          selector.selectServers(new DaParams(tabletId, Map.of(), hints));
+          selector.selectServers(new SelectorParams(tabletId, Map.of(), hints));
 
       servers.add(actions.getScanServer(tabletId));
     }
 
     assertEquals(Set.of("ss1:1", "ss2:2", "ss3:3"), servers);
   }
+
+  @Test
+  public void testWaitForScanServers() {
+    // this test ensures that when there are no scan servers that the ConfigurableScanServerSelector
+    // will wait for scan servers
+
+    String defaultProfile =
+        "{'isDefault':true,'maxBusyTimeout':'5m','busyTimeoutMultiplier':4,'timeToWaitForScanServers':'120s',"
+            + "'attemptPlans':[{'servers':'100%', 'busyTimeout':'60s'}]}";
+
+    var opts = Map.of("profiles", "[" + defaultProfile + "]".replace('\'', '"'));
+
+    ConfigurableScanServerSelector selector = new ConfigurableScanServerSelector();
+
+    AtomicReference<Map<String,String>> scanServers = new AtomicReference<>(Map.of());
+
+    selector.init(new InitParams(scanServers::get, opts));
+
+    var tabletId = nti("1", "m");
+
+    var dg = ScanServerSelector.DEFAULT_SCAN_SERVER_GROUP_NAME;
+
+    var params = new SelectorParams(tabletId, Map.of(), Map.of()) {
+      @Override
+      public <T> Optional<T> waitUntil(Supplier<Optional<T>> condition, Duration maxWaitTime,
+          String description) {
+        // make some scan servers available now that wait was called
+        scanServers.set(Map.of("ss1:1", dg, "ss2:2", dg, "ss3:3", dg));
+
+        Optional<T> optional = condition.get();
+
+        while (optional.isEmpty()) {
+          UtilWaitThread.sleep(10);
+          optional = condition.get();
+        }
+
+        return optional;
+      }
+    };
+
+    ScanServerSelections actions = selector.selectServers(params);
+
+    assertTrue(Set.of("ss1:1", "ss2:2", "ss3:3").contains(actions.getScanServer(tabletId)));
+    assertFalse(scanServers.get().isEmpty());
+  }
 }
