@@ -1,36 +1,38 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.core.util;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertNull;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertThrows;
 
 import java.util.Iterator;
 
-import org.junit.Rule;
-import org.junit.Test;
-import org.junit.rules.ExpectedException;
+import org.junit.jupiter.api.Test;
 
+import edu.umd.cs.findbugs.annotations.SuppressFBWarnings;
+
+@SuppressFBWarnings(value = "RV_RETURN_VALUE_IGNORED_NO_SIDE_EFFECT",
+    justification = "lambda assertThrows testing exception thrown")
 public class PreAllocatedArrayTest {
 
-  @Rule
-  public ExpectedException exception = ExpectedException.none();
-
   /**
    * Test method for {@link org.apache.accumulo.core.util.PreAllocatedArray#PreAllocatedArray(int)}.
    */
@@ -48,8 +50,7 @@ public class PreAllocatedArrayTest {
 
   @Test
   public void testPreAllocatedArray_Fail() {
-    exception.expect(IllegalArgumentException.class);
-    new PreAllocatedArray<String>(-5);
+    assertThrows(IllegalArgumentException.class, () -> new PreAllocatedArray<String>(-5));
   }
 
   /**
@@ -87,31 +88,29 @@ public class PreAllocatedArrayTest {
   public void testSetIndexHigh() {
     PreAllocatedArray<String> strings = new PreAllocatedArray<>(3);
     strings.set(2, "in bounds");
-    exception.expect(IndexOutOfBoundsException.class);
-    strings.set(3, "out of bounds");
+    assertThrows(IndexOutOfBoundsException.class, () -> strings.set(3, "out of bounds"));
   }
 
   @Test
   public void testSetIndexNegative() {
     PreAllocatedArray<String> strings = new PreAllocatedArray<>(3);
     strings.set(0, "in bounds");
-    exception.expect(IndexOutOfBoundsException.class);
-    strings.set(-3, "out of bounds");
+    assertThrows(IndexOutOfBoundsException.class, () -> strings.set(-3, "out of bounds"));
   }
 
   @Test
   public void testGetIndexHigh() {
     PreAllocatedArray<String> strings = new PreAllocatedArray<>(3);
-    strings.get(2);
-    exception.expect(IndexOutOfBoundsException.class);
-    strings.get(3);
+    assertNull(strings.get(2));
+    // spotbugs error suppressed at class level for lambda
+    assertThrows(IndexOutOfBoundsException.class, () -> strings.get(3));
   }
 
   @Test
   public void testGetIndexNegative() {
     PreAllocatedArray<String> strings = new PreAllocatedArray<>(3);
-    strings.get(0);
-    exception.expect(IndexOutOfBoundsException.class);
-    strings.get(-3);
+    assertNull(strings.get(0));
+    // spotbugs error suppressed at class level for lambda
+    assertThrows(IndexOutOfBoundsException.class, () -> strings.get(-3));
   }
 }
