@@ -195,7 +195,9 @@ public abstract class AccumuloRecordReader<K,V> implements RecordReader<K,V> {
         }
         if (isIsolated) {
           log.info("Creating isolated scanner");
-          scanner = new IsolatedScanner(scanner);
+          @SuppressWarnings("resource")
+          var wrapped = new IsolatedScanner(scanner);
+          scanner = wrapped;
         }
         if (usesLocalIterators) {
           log.info("Using local iterators");
