@@ -60,14 +60,16 @@ public class BatchInputSplit extends RangeInputSplit {
    */
   @Override
   public float getProgress(Key currentKey) {
-    if (rangeProgress == null)
+    if (rangeProgress == null) {
       rangeProgress = new float[ranges.size()];
+    }
 
     float total = 0; // progress per range could be on different scales, this number is "fuzzy"
 
     if (currentKey == null) {
-      for (float progress : rangeProgress)
+      for (float progress : rangeProgress) {
         total += progress;
+      }
     } else {
       int i = 0;
       for (Range range : ranges) {
@@ -107,8 +109,9 @@ public class BatchInputSplit extends RangeInputSplit {
   @Override
   public long getLength() throws IOException {
     long sum = 0;
-    for (Range range : ranges)
+    for (Range range : ranges) {
       sum += SplitUtils.getRangeLength(range);
+    }
     return sum;
   }
 
@@ -130,8 +133,9 @@ public class BatchInputSplit extends RangeInputSplit {
     super.write(out);
 
     out.writeInt(ranges.size());
-    for (Range r : ranges)
+    for (Range r : ranges) {
       r.write(out);
+    }
   }
 
   @Override
