@@ -59,27 +59,25 @@ public class OutputConfigurator extends ConfiguratorBase {
    * Sets the default table name to use if one emits a null in place of a table name for a given
    * mutation. Table names can only be alpha-numeric and underscores.
    *
-   * @param implementingClass
-   *          the class whose name will be used as a prefix for the property configuration key
-   * @param conf
-   *          the Hadoop configuration object to configure
-   * @param tableName
-   *          the table to use when the tablename is null in the write call
+   * @param implementingClass the class whose name will be used as a prefix for the property
+   *        configuration key
+   * @param conf the Hadoop configuration object to configure
+   * @param tableName the table to use when the tablename is null in the write call
    * @since 1.6.0
    */
   public static void setDefaultTableName(Class<?> implementingClass, Configuration conf,
       String tableName) {
-    if (tableName != null)
+    if (tableName != null) {
       conf.set(enumToConfKey(implementingClass, WriteOpts.DEFAULT_TABLE_NAME), tableName);
+    }
   }
 
   /**
    * Gets the default table name from the configuration.
    *
-   * @param implementingClass
-   *          the class whose name will be used as a prefix for the property configuration key
-   * @param conf
-   *          the Hadoop configuration object to configure
+   * @param implementingClass the class whose name will be used as a prefix for the property
+   *        configuration key
+   * @param conf the Hadoop configuration object to configure
    * @return the default table name
    * @since 1.6.0
    * @see #setDefaultTableName(Class, Configuration, String)
@@ -96,20 +94,25 @@ public class OutputConfigurator extends ConfiguratorBase {
     BatchWriterConfig bwConfig = new BatchWriterConfig();
     Properties props = getClientProperties(implementingClass, conf);
     String property = props.getProperty(BATCH_WRITER_DURABILITY.getKey());
-    if (property != null)
+    if (property != null) {
       bwConfig.setDurability(DurabilityImpl.fromString(property));
+    }
     Long value = BATCH_WRITER_LATENCY_MAX.getTimeInMillis(props);
-    if (value != null)
+    if (value != null) {
       bwConfig.setMaxLatency(value, TimeUnit.MILLISECONDS);
+    }
     value = BATCH_WRITER_MEMORY_MAX.getBytes(props);
-    if (value != null)
+    if (value != null) {
       bwConfig.setMaxMemory(value);
+    }
     value = BATCH_WRITER_TIMEOUT_MAX.getTimeInMillis(props);
-    if (value != null)
+    if (value != null) {
       bwConfig.setTimeout(value, TimeUnit.MILLISECONDS);
+    }
     Integer intValue = BATCH_WRITER_THREADS_MAX.getInteger(props);
-    if (intValue != null)
+    if (intValue != null) {
       bwConfig.setMaxWriteThreads(intValue);
+    }
 
     return bwConfig;
   }
@@ -121,12 +124,10 @@ public class OutputConfigurator extends ConfiguratorBase {
    * <p>
    * By default, this feature is <b>disabled</b>.
    *
-   * @param implementingClass
-   *          the class whose name will be used as a prefix for the property configuration key
-   * @param conf
-   *          the Hadoop configuration object to configure
-   * @param enableFeature
-   *          the feature is enabled if true, disabled otherwise
+   * @param implementingClass the class whose name will be used as a prefix for the property
+   *        configuration key
+   * @param conf the Hadoop configuration object to configure
+   * @param enableFeature the feature is enabled if true, disabled otherwise
    * @since 1.6.0
    */
   public static void setCreateTables(Class<?> implementingClass, Configuration conf,
@@ -137,10 +138,9 @@ public class OutputConfigurator extends ConfiguratorBase {
   /**
    * Determines whether tables are permitted to be created as needed.
    *
-   * @param implementingClass
-   *          the class whose name will be used as a prefix for the property configuration key
-   * @param conf
-   *          the Hadoop configuration object to configure
+   * @param implementingClass the class whose name will be used as a prefix for the property
+   *        configuration key
+   * @param conf the Hadoop configuration object to configure
    * @return true if the feature is disabled, false otherwise
    * @since 1.6.0
    * @see #setCreateTables(Class, Configuration, boolean)
@@ -156,12 +156,10 @@ public class OutputConfigurator extends ConfiguratorBase {
    * <p>
    * By default, this feature is <b>disabled</b>.
    *
-   * @param implementingClass
-   *          the class whose name will be used as a prefix for the property configuration key
-   * @param conf
-   *          the Hadoop configuration object to configure
-   * @param enableFeature
-   *          the feature is enabled if true, disabled otherwise
+   * @param implementingClass the class whose name will be used as a prefix for the property
+   *        configuration key
+   * @param conf the Hadoop configuration object to configure
+   * @param enableFeature the feature is enabled if true, disabled otherwise
    * @since 1.6.0
    */
   public static void setSimulationMode(Class<?> implementingClass, Configuration conf,
@@ -172,10 +170,9 @@ public class OutputConfigurator extends ConfiguratorBase {
   /**
    * Determines whether this feature is enabled.
    *
-   * @param implementingClass
-   *          the class whose name will be used as a prefix for the property configuration key
-   * @param conf
-   *          the Hadoop configuration object to configure
+   * @param implementingClass the class whose name will be used as a prefix for the property
+   *        configuration key
+   * @param conf the Hadoop configuration object to configure
    * @return true if the feature is enabled, false otherwise
    * @since 1.6.0
    * @see #setSimulationMode(Class, Configuration, boolean)
