@@ -113,8 +113,9 @@ public class AccumuloFileOutputFormatIT extends AccumuloClusterHarness {
         try {
           try {
             output.collect(key, value);
-            if (index == 2)
+            if (index == 2) {
               fail();
+            }
           } catch (Exception e) {
             log.error(e.toString(), e);
             assertEquals(2, index);
