@@ -18,6 +18,7 @@
  */
 package org.apache.accumulo.hadoop.its.mapred;
 
+import static java.nio.charset.StandardCharsets.UTF_8;
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertNull;
 
@@ -61,10 +62,11 @@ public class MultiTableInputFormatIT extends AccumuloClusterHarness {
           throws IOException {
         try {
           String tableName = ((RangeInputSplit) reporter.getInputSplit()).getTableName();
-          if (key != null)
-            assertEquals(key.getRow().toString(), new String(v.get()));
+          if (key != null) {
+            assertEquals(key.getRow().toString(), new String(v.get(), UTF_8));
+          }
           assertEquals(new Text(String.format("%s_%09x", tableName, count + 1)), k.getRow());
-          assertEquals(String.format("%s_%09x", tableName, count), new String(v.get()));
+          assertEquals(String.format("%s_%09x", tableName, count), new String(v.get(), UTF_8));
         } catch (AssertionError e) {
           e1 = e;
         }
