@@ -18,6 +18,7 @@
  */
 package org.apache.accumulo.hadoop.its.mapreduce;
 
+import static java.nio.charset.StandardCharsets.UTF_8;
 import static org.junit.jupiter.api.Assertions.assertEquals;
 
 import java.io.IOException;
@@ -112,8 +113,8 @@ public class RowHashIT extends ConfigurableMacBase {
       int i = 0;
       for (Entry<Key,Value> entry : s) {
         MessageDigest md = MessageDigest.getInstance("MD5");
-        byte[] check = Base64.getEncoder().encode(md.digest(("row" + i).getBytes()));
-        assertEquals(entry.getValue().toString(), new String(check));
+        byte[] check = Base64.getEncoder().encode(md.digest(("row" + i).getBytes(UTF_8)));
+        assertEquals(entry.getValue().toString(), new String(check, UTF_8));
         i++;
       }
     }
@@ -210,10 +211,11 @@ public class RowHashIT extends ConfigurableMacBase {
       int idx = col.indexOf(":");
       Text cf = new Text(idx < 0 ? col : col.substring(0, idx));
       Text cq = idx < 0 ? null : new Text(col.substring(idx + 1));
-      if (cf.getLength() > 0)
+      if (cf.getLength() > 0) {
         AccumuloInputFormat.configure().clientProperties(opts.getClientProps())
             .table(opts.tableName).auths(Authorizations.EMPTY)
             .fetchColumns(Collections.singleton(new IteratorSetting.Column(cf, cq))).store(job);
+      }
 
       job.setMapperClass(RowHash.HashDataMapper.class);
       job.setMapOutputKeyClass(Text.class);
