@@ -60,7 +60,7 @@ public class MiniAccumuloClusterClasspathTest extends WithTestNames {
   public static final String ROOT_PASSWORD = "superSecret";
   public static final String ROOT_USER = "root";
 
-  public static File testDir;
+  private static File testDir;
 
   private static MiniAccumuloCluster accumulo;
 
