@@ -42,6 +42,7 @@ import java.util.function.Supplier;
 
 import org.apache.accumulo.core.Constants;
 import org.apache.accumulo.core.clientImpl.ClientContext;
+import org.apache.accumulo.core.clientImpl.ThriftTransportPool;
 import org.apache.accumulo.core.conf.AccumuloConfiguration;
 import org.apache.accumulo.core.conf.DefaultConfiguration;
 import org.apache.accumulo.core.conf.Property;
@@ -83,6 +84,8 @@ import org.apache.zookeeper.KeeperException;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import com.google.common.base.Preconditions;
+
 /**
  * Provides a server context for Accumulo server components that operate with the system credentials
  * and have access to the system files and configuration.
@@ -445,6 +448,11 @@ public class ServerContext extends ClientContext {
     return getClientTimeoutInMillis();
   }
 
+  @Override
+  public synchronized ThriftTransportPool getTransportPool() {
+    return getTransportPoolImpl(true);
+  }
+
   public AuditedSecurityOperation getSecurityOperation() {
     return securityOperation.get();
   }
@@ -455,6 +463,7 @@ public class ServerContext extends ClientContext {
 
   @Override
   public void close() {
+    Preconditions.checkState(!isClosed(), "ServerContext.close was already called.");
     getMetricsInfo().close();
     super.close();
   }
