@@ -20,12 +20,13 @@ package org.apache.accumulo.server.conf.util;
 
 import static java.nio.charset.StandardCharsets.UTF_8;
 import static org.apache.accumulo.core.Constants.ZINSTANCES;
-import static org.apache.accumulo.core.Constants.ZNAMESPACES;
-import static org.apache.accumulo.core.Constants.ZNAMESPACE_NAME;
 import static org.apache.accumulo.core.Constants.ZROOT;
-import static org.apache.accumulo.core.Constants.ZTABLES;
-import static org.apache.accumulo.core.Constants.ZTABLE_NAME;
-import static org.apache.accumulo.core.Constants.ZTABLE_NAMESPACE;
+import static org.apache.accumulo.server.conf.util.ZooPropUtils.getNamespaceIdToNameMap;
+import static org.apache.accumulo.server.conf.util.ZooPropUtils.getTableIdToName;
+import static org.apache.accumulo.server.conf.util.ZooPropUtils.readInstancesFromZk;
+import static org.apache.accumulo.server.zookeeper.ZooAclUtil.checkWritableAuth;
+import static org.apache.accumulo.server.zookeeper.ZooAclUtil.extractAuthName;
+import static org.apache.accumulo.server.zookeeper.ZooAclUtil.translateZooPerm;
 
 import java.io.BufferedWriter;
 import java.io.FileOutputStream;
@@ -38,18 +39,15 @@ import java.time.ZoneId;
 import java.time.ZoneOffset;
 import java.time.format.DateTimeFormatter;
 import java.util.ArrayList;
+import java.util.Comparator;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
-import java.util.SortedMap;
 import java.util.TreeMap;
 import java.util.TreeSet;
-import java.util.UUID;
 import java.util.stream.Collectors;
 
 import org.apache.accumulo.core.cli.ConfigOpts;
-import org.apache.accumulo.core.clientImpl.Namespace;
-import org.apache.accumulo.core.conf.SiteConfiguration;
 import org.apache.accumulo.core.data.InstanceId;
 import org.apache.accumulo.core.data.NamespaceId;
 import org.apache.accumulo.core.data.TableId;
@@ -64,8 +62,13 @@ import org.apache.accumulo.server.conf.store.TablePropKey;
 import org.apache.accumulo.server.conf.store.impl.PropStoreWatcher;
 import org.apache.accumulo.server.conf.store.impl.ReadyMonitor;
 import org.apache.accumulo.server.conf.store.impl.ZooPropStore;
+import org.apache.accumulo.server.zookeeper.ZooAclUtil;
 import org.apache.accumulo.start.spi.KeywordExecutable;
 import org.apache.zookeeper.KeeperException;
+import org.apache.zookeeper.ZKUtil;
+import org.apache.zookeeper.ZooKeeper;
+import org.apache.zookeeper.data.ACL;
+import org.apache.zookeeper.data.Stat;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -81,8 +84,8 @@ public class ZooInfoViewer implements KeywordExecutable {
   private static final DateTimeFormatter tsFormat =
       DateTimeFormatter.ISO_OFFSET_DATE_TIME.withZone(ZoneId.from(ZoneOffset.UTC));
   private static final Logger log = LoggerFactory.getLogger(ZooInfoViewer.class);
-  private final NullWatcher nullWatcher =
-      new NullWatcher(new ReadyMonitor(ZooInfoViewer.class.getSimpleName(), 20_000L));
+
+  private NullWatcher nullWatcher;
 
   private static final String INDENT = "  ";
 
@@ -91,10 +94,6 @@ public class ZooInfoViewer implements KeywordExecutable {
    */
   public ZooInfoViewer() {}
 
-  public static void main(String[] args) throws Exception {
-    new ZooInfoViewer().execute(args);
-  }
-
   @Override
   public String keyword() {
     return "zoo-info-viewer";
@@ -107,6 +106,7 @@ public class ZooInfoViewer implements KeywordExecutable {
 
   @Override
   public void execute(String[] args) throws Exception {
+    nullWatcher = new NullWatcher(new ReadyMonitor(ZooInfoViewer.class.getSimpleName(), 20_000L));
 
     ZooInfoViewer.Opts opts = new ZooInfoViewer.Opts();
     opts.parseArgs(ZooInfoViewer.class.getName(), args);
@@ -115,10 +115,13 @@ public class ZooInfoViewer implements KeywordExecutable {
     log.info("print properties: {}", opts.printProps);
     log.info("print instances: {}", opts.printInstanceIds);
 
-    ZooReader zooReader = new ZooReaderWriter(opts.getSiteConfiguration());
+    try (ServerContext context = getContext(opts)) {
+      generateReport(context.getInstanceID(), opts, context.getZooReader());
+    }
+  }
 
-    InstanceId iid = getInstanceId(zooReader, opts);
-    generateReport(iid, opts, zooReader);
+  ServerContext getContext(ZooInfoViewer.Opts opts) {
+    return new ServerContext(opts.getSiteConfiguration());
   }
 
   void generateReport(final InstanceId iid, final ZooInfoViewer.Opts opts,
@@ -153,70 +156,13 @@ public class ZooInfoViewer implements KeywordExecutable {
         printProps(iid, zooReader, opts, writer);
       }
 
+      if (opts.printAcls) {
+        printAcls(iid, opts, writer);
+      }
       writer.println("-----------------------------------------------");
     }
   }
 
-  /**
-   * Get the instanceID from the command line options, or from value stored in HDFS. The search
-   * order is:
-   * <ol>
-   * <li>command line: --instanceId option</li>
-   * <li>command line: --instanceName option</li>
-   * <li>HDFS</li>
-   * </ol>
-   *
-   * @param zooReader
-   *          a ZooReader
-   * @param opts
-   *          the parsed command line options.
-   * @return an instance id
-   */
-  InstanceId getInstanceId(final ZooReader zooReader, final ZooInfoViewer.Opts opts) {
-
-    if (!opts.instanceId.isEmpty()) {
-      return InstanceId.of(opts.instanceId);
-    }
-    if (!opts.instanceName.isEmpty()) {
-      Map<String,InstanceId> instanceNameToIdMap = readInstancesFromZk(zooReader);
-      String instanceName = opts.instanceName;
-      for (Map.Entry<String,InstanceId> e : instanceNameToIdMap.entrySet()) {
-        if (e.getKey().equals(instanceName)) {
-          return e.getValue();
-        }
-      }
-      throw new IllegalArgumentException(
-          "Specified instance name '" + instanceName + "' not found in ZooKeeper");
-    }
-
-    try (ServerContext context = new ServerContext(SiteConfiguration.auto())) {
-      return context.getInstanceID();
-    } catch (Exception ex) {
-      throw new IllegalArgumentException(
-          "Failed to read instance id from HDFS. Instances can be specified on the command line",
-          ex);
-    }
-  }
-
-  Map<NamespaceId,String> getNamespaceIdToNameMap(InstanceId iid, final ZooReader zooReader) {
-    SortedMap<NamespaceId,String> namespaceToName = new TreeMap<>();
-    String zooNsRoot = ZooUtil.getRoot(iid) + ZNAMESPACES;
-    try {
-      List<String> nsids = zooReader.getChildren(zooNsRoot);
-      for (String id : nsids) {
-        String path = zooNsRoot + "/" + id + ZNAMESPACE_NAME;
-        String name = new String(zooReader.getData(path), UTF_8);
-        namespaceToName.put(NamespaceId.of(id), name);
-      }
-    } catch (InterruptedException ex) {
-      Thread.currentThread().interrupt();
-      throw new IllegalStateException("Interrupted reading namespace ids from ZooKeeper", ex);
-    } catch (KeeperException ex) {
-      throw new IllegalStateException("Failed to read namespace ids from ZooKeeper", ex);
-    }
-    return namespaceToName;
-  }
-
   private void printProps(final InstanceId iid, final ZooReader zooReader, final Opts opts,
       final PrintWriter writer) throws Exception {
 
@@ -274,47 +220,88 @@ public class ZooInfoViewer implements KeywordExecutable {
     writer.println();
   }
 
-  /**
-   * Read the instance names and instance ids from ZooKeeper. The storage structure in ZooKeeper is:
-   *
-   * <pre>
-   *   /accumulo/instances/instance_name  - with the instance id stored as data.
-   * </pre>
-   *
-   * @return a map of (instance name, instance id) entries
-   */
-  Map<String,InstanceId> readInstancesFromZk(final ZooReader zooReader) {
-    String instanceRoot = ZROOT + ZINSTANCES;
-    Map<String,InstanceId> idMap = new TreeMap<>();
-    try {
-      List<String> names = zooReader.getChildren(instanceRoot);
-      names.forEach(name -> {
-        InstanceId iid = getInstanceIdForName(zooReader, name);
-        idMap.put(name, iid);
-      });
-    } catch (InterruptedException ex) {
-      Thread.currentThread().interrupt();
-      throw new IllegalStateException("Interrupted reading instance name info from ZooKeeper", ex);
-    } catch (KeeperException ex) {
-      throw new IllegalStateException("Failed to read instance name info from ZooKeeper", ex);
-    }
-    return idMap;
+  private void printAcls(final InstanceId iid, final Opts opts, final PrintWriter writer) {
+
+    Map<String,List<ACL>> aclMap = new TreeMap<>();
+
+    writer.printf("Output format:\n");
+    writer.printf("ACCUMULO_PERM:OTHER_PERM path user_acls...\n\n");
+
+    writer.printf("ZooKeeper acls for instance ID: %s\n\n", iid.canonical());
+
+    ZooKeeper zooKeeper = new ZooReaderWriter(opts.getSiteConfiguration()).getZooKeeper();
+
+    String instanceRoot = ZooUtil.getRoot(iid);
+
+    final Stat stat = new Stat();
+
+    recursiveAclRead(zooKeeper, ZROOT + ZINSTANCES, stat, aclMap);
+
+    recursiveAclRead(zooKeeper, instanceRoot, stat, aclMap);
+
+    // print formatting
+    aclMap.forEach((path, acl) -> {
+      if (acl == null) {
+        writer.printf("ERROR_ACCUMULO_MISSING_SOME: '%s' : none\n", path);
+      } else {
+        // sort for consistent presentation
+        acl.sort(Comparator.comparing(a -> a.getId().getId()));
+        ZooAclUtil.ZkAccumuloAclStatus aclStatus = checkWritableAuth(acl);
+
+        String authStatus;
+        if (aclStatus.accumuloHasFull()) {
+          authStatus = "ACCUMULO_OKAY";
+        } else {
+          authStatus = "ERROR_ACCUMULO_MISSING_SOME";
+        }
+
+        String otherUpdate;
+        if (aclStatus.othersMayUpdate() || aclStatus.anyCanRead()) {
+          otherUpdate = "NOT_PRIVATE";
+        } else {
+          otherUpdate = "PRIVATE";
+        }
+
+        writer.printf("%s:%s %s", authStatus, otherUpdate, path);
+        boolean addSeparator = false;
+        for (ACL a : acl) {
+          if (addSeparator) {
+            writer.printf(",");
+          }
+          writer.printf(" %s:%s", translateZooPerm(a.getPerms()), extractAuthName(a));
+          addSeparator = true;
+        }
+      }
+      writer.println("");
+    });
+    writer.flush();
   }
 
-  private InstanceId getInstanceIdForName(ZooReader zooReader, String name) {
-    String instanceRoot = ZROOT + ZINSTANCES;
-    String path = "";
+  private void recursiveAclRead(final ZooKeeper zooKeeper, final String rootPath, final Stat stat,
+      final Map<String,List<ACL>> aclMap) {
     try {
-      path = instanceRoot + "/" + name;
-      byte[] uuid = zooReader.getData(path);
-      return InstanceId.of(UUID.fromString(new String(uuid, UTF_8)));
+      ZKUtil.visitSubTreeDFS(zooKeeper, rootPath, false, (rc, path, ctx, name) -> {
+        try {
+          final List<ACL> acls = zooKeeper.getACL(path, stat);
+          // List<ACL> acl = getAcls(childPath, dummy);
+          aclMap.put(path, acls);
+
+        } catch (KeeperException.NoNodeException ex) {
+          throw new IllegalStateException("Node removed during processing", ex);
+        } catch (KeeperException ex) {
+          throw new IllegalStateException("ZooKeeper exception during processing", ex);
+        } catch (InterruptedException ex) {
+          Thread.currentThread().interrupt();
+          throw new IllegalStateException("interrupted during processing", ex);
+        }
+      });
+    } catch (KeeperException ex) {
+      throw new IllegalStateException("ZooKeeper exception during processing", ex);
     } catch (InterruptedException ex) {
       Thread.currentThread().interrupt();
-      throw new IllegalStateException("Interrupted reading instance id from ZooKeeper", ex);
-    } catch (KeeperException ex) {
-      log.warn("Failed to read instance id for " + path);
-      return null;
+      throw new IllegalStateException("interrupted during processing", ex);
     }
+
   }
 
   private void printInstanceIds(final Map<String,InstanceId> instanceIdMap, PrintWriter writer) {
@@ -393,33 +380,6 @@ public class ZooInfoViewer implements KeywordExecutable {
     return results;
   }
 
-  private Map<TableId,String> getTableIdToName(InstanceId iid,
-      Map<NamespaceId,String> id2NamespaceMap, ZooReader zooReader) {
-    SortedMap<TableId,String> idToName = new TreeMap<>();
-
-    String zooTables = ZooUtil.getRoot(iid) + ZTABLES;
-    try {
-      List<String> tids = zooReader.getChildren(zooTables);
-      for (String t : tids) {
-        String path = zooTables + "/" + t;
-        String tname = new String(zooReader.getData(path + ZTABLE_NAME), UTF_8);
-        NamespaceId tNsId =
-            NamespaceId.of(new String(zooReader.getData(path + ZTABLE_NAMESPACE), UTF_8));
-        if (tNsId.equals(Namespace.DEFAULT.id())) {
-          idToName.put(TableId.of(t), tname);
-        } else {
-          idToName.put(TableId.of(t), id2NamespaceMap.get(tNsId) + "." + tname);
-        }
-      }
-    } catch (InterruptedException ex) {
-      Thread.currentThread().interrupt();
-      throw new IllegalStateException("Interrupted reading table ids from ZooKeeper", ex);
-    } catch (KeeperException ex) {
-      throw new IllegalStateException("Failed reading table id info from ZooKeeper");
-    }
-    return idToName;
-  }
-
   private void printSortedProps(final PrintWriter writer,
       final Map<String,VersionedProperties> props) {
     log.trace("Printing: {}", props);
@@ -452,6 +412,13 @@ public class ZooInfoViewer implements KeywordExecutable {
         description = "Write the output to a file, if the file exists will not be overwritten.")
     public String outfile = "";
 
+    @Parameter(names = {"--print-acls"},
+        description = "print the current acls for all ZooKeeper nodes. The acls are evaluated in context of Accumulo "
+            + "operations. Context: ACCUMULO_OKAY | ERROR_ACCUMULO_MISSING_SOME - Accumulo requires cdwra for ZooKeeper "
+            + " nodes that it uses. PRIVATE | NOT_PRIVATE - other than configuration, most nodes are world read-able "
+            + "(NOT_PRIVATE) to permit client access")
+    public boolean printAcls = false;
+
     @Parameter(names = {"--print-id-map"},
         description = "print the namespace and table id, name mappings stored in ZooKeeper")
     public boolean printIdMap = false;
@@ -464,14 +431,6 @@ public class ZooInfoViewer implements KeywordExecutable {
         description = "print the instance ids stored in ZooKeeper")
     public boolean printInstanceIds = false;
 
-    @Parameter(names = {"--instanceName"},
-        description = "Specify the instance name to use. If instance name or id are not provided, determined from configuration (requires a running hdfs instance)")
-    public String instanceName = "";
-
-    @Parameter(names = {"--instanceId"},
-        description = "Specify the instance id to use. If instance name or id are not provided, determined from configuration (requires a running hdfs instance)")
-    public String instanceId = "";
-
     @Parameter(names = {"-ns", "--namespaces"},
         description = "a list of namespace names to print properties, with none specified, print all. Only valid with --print-props",
         variableArity = true)
