@@ -18,10 +18,16 @@
  */
 package org.apache.accumulo.server.manager.state;
 
+import java.io.IOException;
+import java.io.UncheckedIOException;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.List;
 import java.util.Map;
+import java.util.Spliterator;
+import java.util.Spliterators;
+import java.util.stream.Stream;
+import java.util.stream.StreamSupport;
 
 import org.apache.accumulo.core.clientImpl.ClientContext;
 import org.apache.accumulo.core.dataImpl.KeyExtent;
@@ -36,6 +42,11 @@ import org.apache.hadoop.fs.Path;
  */
 public interface TabletStateStore extends Iterable<TabletLocationState> {
 
+  /**
+   * Get the level for this state store
+   */
+  DataLevel getLevel();
+
   /**
    * Identifying name for this tablet state store.
    */
@@ -47,6 +58,22 @@ public interface TabletStateStore extends Iterable<TabletLocationState> {
   @Override
   ClosableIterator<TabletLocationState> iterator();
 
+  /**
+   * Create a stream of TabletLocationState that automatically closes the underlying iterator.
+   */
+  default Stream<TabletLocationState> stream() {
+    ClosableIterator<TabletLocationState> iterator = this.iterator();
+    return StreamSupport
+        .stream(Spliterators.spliteratorUnknownSize(iterator, Spliterator.ORDERED), false)
+        .onClose(() -> {
+          try {
+            iterator.close();
+          } catch (IOException e) {
+            throw new UncheckedIOException(e);
+          }
+        });
+  }
+
   /**
    * Store the assigned locations in the data store.
    */
@@ -106,19 +133,18 @@ public interface TabletStateStore extends Iterable<TabletLocationState> {
     return getStoreForLevel(level, context, null);
   }
 
-  public static TabletStateStore getStoreForLevel(DataLevel level, ClientContext context,
+  static TabletStateStore getStoreForLevel(DataLevel level, ClientContext context,
       CurrentState state) {
-
     TabletStateStore tss;
     switch (level) {
       case ROOT:
-        tss = new ZooTabletStateStore(context);
+        tss = new ZooTabletStateStore(level, context);
         break;
       case METADATA:
-        tss = new RootTabletStateStore(context, state);
+        tss = new MetaDataStateStore(level, context, state, "Metadata Tablets");
         break;
       case USER:
-        tss = new MetaDataStateStore(context, state);
+        tss = new MetaDataStateStore(level, context, state, "Normal Tablets");
         break;
       default:
         throw new IllegalArgumentException("Unknown level " + level);
