@@ -73,7 +73,7 @@ public class ProblemReports implements Iterable<ProblemReport> {
 
   private final ServerContext context;
 
-  public ProblemReports(ServerContext context) {
+  private ProblemReports(ServerContext context) {
     this.context = context;
   }
 
@@ -189,7 +189,7 @@ public class ProblemReports implements Iterable<ProblemReport> {
 
       return new Iterator<>() {
 
-        ZooReaderWriter zoo = context.getZooReaderWriter();
+        final ZooReaderWriter zoo = context.getZooReaderWriter();
         private int iter1Count = 0;
         private Iterator<String> iter1;
 
