@@ -1,18 +1,20 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.server.rpc;
 
@@ -73,7 +75,7 @@ public class UGIAssumingProcessor implements TProcessor {
   }
 
   @Override
-  public boolean process(final TProtocol inProt, final TProtocol outProt) throws TException {
+  public void process(final TProtocol inProt, final TProtocol outProt) throws TException {
     TTransport trans = inProt.getTransport();
     if (!(trans instanceof TSaslServerTransport)) {
       throw new TException("Unexpected non-SASL transport " + trans.getClass() + ": " + trans);
@@ -98,25 +100,26 @@ public class UGIAssumingProcessor implements TProcessor {
         try {
           // Set the principal in the ThreadLocal for access to get authorizations
           rpcPrincipal.set(remoteUser);
-
-          return wrapped.process(inProt, outProt);
+          wrapped.process(inProt, outProt);
         } finally {
           // Unset the principal after we're done using it just to be sure that it's not incorrectly
           // used in the same thread down the line.
           rpcPrincipal.set(null);
         }
+        break;
       case DIGEST_MD5:
         // The CallbackHandler, after deserializing the TokenIdentifier in the name, has already
         // updated
         // the rpcPrincipal for us. We don't need to do it again here.
         try {
           rpcMechanism.set(mechanism);
-          return wrapped.process(inProt, outProt);
+          wrapped.process(inProt, outProt);
         } finally {
           // Unset the mechanism after we're done using it just to be sure that it's not incorrectly
           // used in the same thread down the line.
           rpcMechanism.set(null);
         }
+        break;
       default:
         throw new IllegalArgumentException("Cannot process SASL mechanism " + mechanism);
     }
