@@ -18,13 +18,17 @@
  */
 package org.apache.accumulo.server.security;
 
+import static java.util.stream.Collectors.toList;
+import static java.util.stream.Collectors.toMap;
+
 import java.nio.ByteBuffer;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.List;
 import java.util.Map;
+import java.util.Map.Entry;
 import java.util.Set;
-import java.util.stream.Collectors;
+import java.util.function.Supplier;
 
 import org.apache.accumulo.core.client.TableNotFoundException;
 import org.apache.accumulo.core.clientImpl.Credentials;
@@ -36,7 +40,6 @@ import org.apache.accumulo.core.data.TableId;
 import org.apache.accumulo.core.dataImpl.KeyExtent;
 import org.apache.accumulo.core.dataImpl.thrift.IterInfo;
 import org.apache.accumulo.core.dataImpl.thrift.TColumn;
-import org.apache.accumulo.core.dataImpl.thrift.TKeyExtent;
 import org.apache.accumulo.core.dataImpl.thrift.TRange;
 import org.apache.accumulo.core.manager.thrift.FateOperation;
 import org.apache.accumulo.core.metadata.MetadataTable;
@@ -138,26 +141,22 @@ public class AuditedSecurityOperation extends SecurityOperation {
     return result;
   }
 
-  @Override
-  public boolean canScan(TCredentials credentials, TableId tableId, NamespaceId namespaceId,
-      TRange range, List<TColumn> columns, List<IterInfo> ssiList,
+  private boolean canScan(TCredentials credentials, TableId tableId, NamespaceId namespaceId,
+      Supplier<String> rangeStringSupplier, List<TColumn> columns, List<IterInfo> ssiList,
       Map<String,Map<String,String>> ssio, List<ByteBuffer> authorizations)
       throws ThriftSecurityException {
     if (shouldAudit(credentials, tableId)) {
-      Range convertedRange = new Range(range);
-      List<String> convertedColumns =
-          truncate(columns.stream().map(Column::new).collect(Collectors.toList()));
+      String rangeString = rangeStringSupplier.get();
+      List<String> convertedColumns = truncate(columns.stream().map(Column::new).collect(toList()));
       String tableName = getTableName(tableId);
-
       try {
         boolean canScan = super.canScan(credentials, tableId, namespaceId);
         audit(credentials, canScan, CAN_SCAN_AUDIT_TEMPLATE, tableName,
-            getAuthString(authorizations), convertedRange, convertedColumns, ssiList, ssio);
-
+            getAuthString(authorizations), rangeString, convertedColumns, ssiList, ssio);
         return canScan;
       } catch (ThriftSecurityException ex) {
         audit(credentials, ex, CAN_SCAN_AUDIT_TEMPLATE, getAuthString(authorizations), tableId,
-            convertedRange, convertedColumns, ssiList, ssio);
+            rangeString, convertedColumns, ssiList, ssio);
         throw ex;
       }
     } else {
@@ -165,41 +164,30 @@ public class AuditedSecurityOperation extends SecurityOperation {
     }
   }
 
-  public static final String CAN_SCAN_BATCH_AUDIT_TEMPLATE =
-      "action: scan; targetTable: %s; authorizations: %s; range: %s; columns: %s;"
-          + " iterators: %s; iteratorOptions: %s;";
-
-  @Override
   public boolean canScan(TCredentials credentials, TableId tableId, NamespaceId namespaceId,
-      Map<TKeyExtent,List<TRange>> tbatch, List<TColumn> tcolumns, List<IterInfo> ssiList,
+      TRange range, List<TColumn> columns, List<IterInfo> ssiList,
       Map<String,Map<String,String>> ssio, List<ByteBuffer> authorizations)
       throws ThriftSecurityException {
-    if (shouldAudit(credentials, tableId)) {
+    Supplier<String> rangeToString = () -> new Range(range).toString();
+    return canScan(credentials, tableId, namespaceId, rangeToString, columns, ssiList, ssio,
+        authorizations);
+  }
 
+  public boolean canScan(TCredentials credentials, TableId tableId, NamespaceId namespaceId,
+      Map<KeyExtent,List<TRange>> tbatch, List<TColumn> columns, List<IterInfo> ssiList,
+      Map<String,Map<String,String>> ssio, List<ByteBuffer> authorizations)
+      throws ThriftSecurityException {
+    Supplier<String> rangeToString = () -> {
       // @formatter:off
-      Map<KeyExtent, List<String>> truncated = tbatch.entrySet().stream().collect(Collectors.toMap(
-                      entry -> KeyExtent.fromThrift(entry.getKey()),
-                      entry -> truncate(entry.getValue().stream().map(Range::new).collect(Collectors.toList()))
+      Map<KeyExtent,List<String>> truncated = tbatch.entrySet().stream().collect(toMap(
+          Entry::getKey,
+          entry -> truncate(entry.getValue().stream().map(Range::new).collect(toList()))
       ));
       // @formatter:on
-      List<Column> convertedColumns =
-          tcolumns.stream().map(Column::new).collect(Collectors.toList());
-      String tableName = getTableName(tableId);
-
-      try {
-        boolean canScan = super.canScan(credentials, tableId, namespaceId);
-        audit(credentials, canScan, CAN_SCAN_BATCH_AUDIT_TEMPLATE, tableName,
-            getAuthString(authorizations), truncated, convertedColumns, ssiList, ssio);
-
-        return canScan;
-      } catch (ThriftSecurityException ex) {
-        audit(credentials, ex, CAN_SCAN_BATCH_AUDIT_TEMPLATE, getAuthString(authorizations),
-            tableId, truncated, convertedColumns, ssiList, ssio);
-        throw ex;
-      }
-    } else {
-      return super.canScan(credentials, tableId, namespaceId);
-    }
+      return truncated.toString();
+    };
+    return canScan(credentials, tableId, namespaceId, rangeToString, columns, ssiList, ssio,
+        authorizations);
   }
 
   public static final String CHANGE_AUTHORIZATIONS_AUDIT_TEMPLATE =
