@@ -1,18 +1,20 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.server.security;
 
@@ -27,7 +29,6 @@ import java.util.Set;
 
 import org.apache.accumulo.core.conf.AccumuloConfiguration;
 import org.apache.accumulo.core.conf.Property;
-import org.apache.commons.lang3.StringUtils;
 
 /**
  * When SASL is enabled, this parses properties from the site configuration to build up a set of all
@@ -181,14 +182,15 @@ public class UserImpersonation {
 
     final String hostConfigString = conf.get(Property.INSTANCE_RPC_SASL_ALLOWED_HOST_IMPERSONATION);
     // Pull out the config values, defaulting to at least one value
-    final String[] userConfigs = userConfigString.trim().isEmpty() ? new String[] {""}
-        : StringUtils.split(userConfigString, ';');
-    final String[] hostConfigs = hostConfigString.trim().isEmpty() ? new String[] {""}
-        : StringUtils.split(hostConfigString, ';');
+    final String[] userConfigs =
+        userConfigString.trim().isEmpty() ? new String[] {""} : userConfigString.split(";");
+    final String[] hostConfigs =
+        hostConfigString.trim().isEmpty() ? new String[] {""} : hostConfigString.split(";");
 
     if (userConfigs.length != hostConfigs.length) {
-      String msg = String.format("Should have equal number of user and host"
-          + " impersonation elements in configuration. Got %d and %d elements," + " respectively.",
+      String msg = String.format(
+          "Should have equal number of user and host"
+              + " impersonation elements in configuration. Got %d and %d elements, respectively.",
           userConfigs.length, hostConfigs.length);
       throw new IllegalArgumentException(msg);
     }
@@ -197,7 +199,7 @@ public class UserImpersonation {
       final String userConfig = userConfigs[i];
       final String hostConfig = hostConfigs[i];
 
-      final String[] splitUserConfig = StringUtils.split(userConfig, ':');
+      final String[] splitUserConfig = userConfig.split(":");
       if (splitUserConfig.length != 2) {
         throw new IllegalArgumentException(
             "Expect a single colon-separated pair, but found '" + userConfig + "'");
@@ -212,7 +214,7 @@ public class UserImpersonation {
       if (ALL.equals(allowedImpersonationsForRemoteUser)) {
         usersWithHosts.setAcceptAllUsers(true);
       } else {
-        String[] allowedUsers = StringUtils.split(allowedImpersonationsForRemoteUser, ",");
+        String[] allowedUsers = allowedImpersonationsForRemoteUser.split(",");
         Set<String> usersSet = new HashSet<>();
         usersSet.addAll(Arrays.asList(allowedUsers));
         usersWithHosts.setUsers(usersSet);
@@ -221,7 +223,7 @@ public class UserImpersonation {
       if (ALL.equals(hostConfig)) {
         usersWithHosts.setAcceptAllHosts(true);
       } else {
-        String[] allowedHosts = StringUtils.split(hostConfig, ",");
+        String[] allowedHosts = hostConfig.split(",");
         Set<String> hostsSet = new HashSet<>();
         hostsSet.addAll(Arrays.asList(allowedHosts));
         usersWithHosts.setHosts(hostsSet);
