@@ -25,7 +25,6 @@ import java.io.ByteArrayOutputStream;
 import java.io.DataInputStream;
 import java.io.DataOutputStream;
 import java.io.IOException;
-import java.nio.ByteBuffer;
 import java.security.MessageDigest;
 import java.security.NoSuchAlgorithmException;
 import java.security.SecureRandom;
@@ -41,12 +40,14 @@ import org.apache.accumulo.core.security.NamespacePermission;
 import org.apache.accumulo.core.security.SystemPermission;
 import org.apache.accumulo.core.security.TablePermission;
 import org.apache.commons.codec.digest.Crypt;
+import org.apache.hadoop.io.Text;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 import com.github.benmanes.caffeine.cache.Cache;
 import com.github.benmanes.caffeine.cache.Caffeine;
 import com.github.benmanes.caffeine.cache.Scheduler;
+import com.google.common.annotations.VisibleForTesting;
 
 /**
  * All the static too methods used for this class, so that we can separate out stuff that isn't
@@ -88,8 +89,9 @@ class ZKSecurityTool {
 
   @Deprecated(since = "2.1.0")
   static boolean checkPass(byte[] password, byte[] zkData) {
-    if (zkData == null)
+    if (zkData == null) {
       return false;
+    }
 
     byte[] salt = new byte[SALT_LENGTH];
     System.arraycopy(zkData, 0, salt, 0, SALT_LENGTH);
@@ -120,18 +122,17 @@ class ZKSecurityTool {
     return cryptHash.getBytes(UTF_8);
   }
 
-  private static final Cache<ByteBuffer,String> CRYPT_PASSWORD_CACHE =
+  private static final Cache<Text,String> CRYPT_PASSWORD_CACHE =
       Caffeine.newBuilder().scheduler(Scheduler.systemScheduler())
           .expireAfterAccess(Duration.ofMinutes(1)).initialCapacity(4).maximumSize(64).build();
 
   // This uses a cache to avoid repeated expensive calls to Crypt.crypt for recent inputs
-  public static boolean checkCryptPass(byte[] password, byte[] zkData) {
-    final ByteBuffer key = ByteBuffer.allocate(password.length + zkData.length);
-    key.put(password);
-    key.put(zkData);
-    String cryptHash = CRYPT_PASSWORD_CACHE.getIfPresent(key);
-    if (cryptHash != null) {
-      if (MessageDigest.isEqual(zkData, cryptHash.getBytes(UTF_8))) {
+  public static boolean checkCryptPass(final byte[] password, final byte[] cryptHashInZkToTest) {
+    final Text key = new Text(password);
+    key.append(cryptHashInZkToTest, 0, cryptHashInZkToTest.length);
+    String cachedCryptHash = CRYPT_PASSWORD_CACHE.getIfPresent(key);
+    if (cachedCryptHash != null) {
+      if (MessageDigest.isEqual(cryptHashInZkToTest, cachedCryptHash.getBytes(UTF_8))) {
         // If matches then zkData has not changed from when it was put into the cache
         return true;
       } else {
@@ -140,19 +141,31 @@ class ZKSecurityTool {
       }
     }
     // Either !matches or was not cached
+    String cryptHashToCache;
     try {
-      cryptHash = Crypt.crypt(password, new String(zkData, UTF_8));
+      cryptHashToCache = Crypt.crypt(password, new String(cryptHashInZkToTest, UTF_8));
     } catch (IllegalArgumentException e) {
       log.error("Unrecognized hash format", e);
       return false;
     }
-    boolean matches = MessageDigest.isEqual(zkData, cryptHash.getBytes(UTF_8));
+    boolean matches = MessageDigest.isEqual(cryptHashInZkToTest, cryptHashToCache.getBytes(UTF_8));
     if (matches) {
-      CRYPT_PASSWORD_CACHE.put(key, cryptHash);
+      CRYPT_PASSWORD_CACHE.put(key, cryptHashToCache);
     }
     return matches;
   }
 
+  @VisibleForTesting
+  static long getCryptPasswordCacheSize() {
+    CRYPT_PASSWORD_CACHE.cleanUp();
+    return CRYPT_PASSWORD_CACHE.estimatedSize();
+  }
+
+  @VisibleForTesting
+  static void clearCryptPasswordCache() {
+    CRYPT_PASSWORD_CACHE.invalidateAll();
+  }
+
   public static Authorizations convertAuthorizations(byte[] authorizations) {
     return new Authorizations(authorizations);
   }
@@ -165,8 +178,9 @@ class ZKSecurityTool {
     ByteArrayOutputStream bytes = new ByteArrayOutputStream(systempermissions.size());
     DataOutputStream out = new DataOutputStream(bytes);
     try {
-      for (SystemPermission sp : systempermissions)
+      for (SystemPermission sp : systempermissions) {
         out.writeByte(sp.getId());
+      }
     } catch (IOException e) {
       log.error("{}", e.getMessage(), e);
       throw new RuntimeException(e); // this is impossible with ByteArrayOutputStream; crash hard if
@@ -180,8 +194,9 @@ class ZKSecurityTool {
     DataInputStream in = new DataInputStream(bytes);
     Set<SystemPermission> toReturn = new HashSet<>();
     try {
-      while (in.available() > 0)
+      while (in.available() > 0) {
         toReturn.add(SystemPermission.getPermissionById(in.readByte()));
+      }
     } catch (IOException e) {
       log.error("User database is corrupt; error converting system permissions", e);
       toReturn.clear();
@@ -193,8 +208,9 @@ class ZKSecurityTool {
     ByteArrayOutputStream bytes = new ByteArrayOutputStream(tablepermissions.size());
     DataOutputStream out = new DataOutputStream(bytes);
     try {
-      for (TablePermission tp : tablepermissions)
+      for (TablePermission tp : tablepermissions) {
         out.writeByte(tp.getId());
+      }
     } catch (IOException e) {
       log.error("{}", e.getMessage(), e);
       throw new RuntimeException(e); // this is impossible with ByteArrayOutputStream; crash hard if
@@ -205,8 +221,9 @@ class ZKSecurityTool {
 
   public static Set<TablePermission> convertTablePermissions(byte[] tablepermissions) {
     Set<TablePermission> toReturn = new HashSet<>();
-    for (byte b : tablepermissions)
+    for (byte b : tablepermissions) {
       toReturn.add(TablePermission.getPermissionById(b));
+    }
     return toReturn;
   }
 
@@ -214,8 +231,9 @@ class ZKSecurityTool {
     ByteArrayOutputStream bytes = new ByteArrayOutputStream(namespacepermissions.size());
     DataOutputStream out = new DataOutputStream(bytes);
     try {
-      for (NamespacePermission tnp : namespacepermissions)
+      for (NamespacePermission tnp : namespacepermissions) {
         out.writeByte(tnp.getId());
+      }
     } catch (IOException e) {
       log.error("{}", e.getMessage(), e);
       throw new RuntimeException(e); // this is impossible with ByteArrayOutputStream; crash hard if
@@ -226,8 +244,9 @@ class ZKSecurityTool {
 
   public static Set<NamespacePermission> convertNamespacePermissions(byte[] namespacepermissions) {
     Set<NamespacePermission> toReturn = new HashSet<>();
-    for (byte b : namespacepermissions)
+    for (byte b : namespacepermissions) {
       toReturn.add(NamespacePermission.getPermissionById(b));
+    }
     return toReturn;
   }
 
