@@ -23,8 +23,12 @@ import static java.nio.charset.StandardCharsets.UTF_8;
 import java.security.SecureRandom;
 
 import org.apache.accumulo.core.Constants;
+import org.apache.accumulo.core.conf.DefaultConfiguration;
+import org.apache.accumulo.core.conf.Property;
 import org.apache.accumulo.core.util.FastFormat;
 import org.apache.accumulo.server.ServerContext;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 /**
  * Allocates unique names for an accumulo instance. The names are unique for the lifetime of the
@@ -34,11 +38,17 @@ import org.apache.accumulo.server.ServerContext;
  */
 public class UniqueNameAllocator {
 
-  private ServerContext context;
+  private static final Logger log = LoggerFactory.getLogger(UniqueNameAllocator.class);
+  private static final SecureRandom random = new SecureRandom();
+  private static final Property MIN_PROP = Property.GENERAL_FILE_NAME_ALLOCATION_BATCH_SIZE_MIN;
+  private static final Property MAX_PROP = Property.GENERAL_FILE_NAME_ALLOCATION_BATCH_SIZE_MAX;
+  private static final int DEFAULT_MIN = DefaultConfiguration.getInstance().getCount(MIN_PROP);
+
+  private final ServerContext context;
+  private final String nextNamePath;
+
   private long next = 0;
   private long maxAllocated = 0;
-  private String nextNamePath;
-  private static final SecureRandom random = new SecureRandom();
 
   public UniqueNameAllocator(ServerContext context) {
     this.context = context;
@@ -46,10 +56,8 @@ public class UniqueNameAllocator {
   }
 
   public synchronized String getNextName() {
-
     while (next >= maxAllocated) {
-      final int allocate = 100 + random.nextInt(100);
-
+      final int allocate = getAllocation();
       try {
         byte[] max = context.getZooReaderWriter().mutateExisting(nextNamePath, currentValue -> {
           long l = Long.parseLong(new String(currentValue, UTF_8), Character.MAX_RADIX);
@@ -60,11 +68,31 @@ public class UniqueNameAllocator {
         next = maxAllocated - allocate;
 
       } catch (Exception e) {
-        throw new RuntimeException(e);
+        throw new IllegalStateException(e);
       }
     }
-
     return new String(FastFormat.toZeroPaddedString(next++, 7, Character.MAX_RADIX, new byte[0]),
         UTF_8);
   }
+
+  private int getAllocation() {
+    int minAllocation = context.getConfiguration().getCount(MIN_PROP);
+    int maxAllocation = context.getConfiguration().getCount(MAX_PROP);
+
+    if (minAllocation <= 0) {
+      log.warn("{} was set to {}, but must be greater than 0. Using the default ({}).",
+          MIN_PROP.getKey(), minAllocation, DEFAULT_MIN);
+      minAllocation = DEFAULT_MIN;
+    }
+
+    if (maxAllocation < minAllocation) {
+      log.warn("{} was set to {}, must be greater than or equal to {} ({}). Using {}.",
+          MAX_PROP.getKey(), maxAllocation, MIN_PROP.getKey(), minAllocation, minAllocation);
+      maxAllocation = minAllocation;
+    }
+
+    int actualBatchSize = minAllocation + random.nextInt((maxAllocation - minAllocation) + 1);
+    log.debug("Allocating {} filenames", actualBatchSize);
+    return actualBatchSize;
+  }
 }
