@@ -36,17 +36,20 @@ public class SystemPropUtil {
 
   public static void setSystemProperty(ServerContext context, String property, String value)
       throws IllegalArgumentException {
-    context.getPropStore().putAll(SystemPropKey.of(context),
-        Map.of(validateSystemProperty(property, value), value));
+    final SystemPropKey key = SystemPropKey.of(context);
+    context.getPropStore().putAll(key,
+        Map.of(validateSystemProperty(context, key, property, value), value));
   }
 
   public static void modifyProperties(ServerContext context, long version,
       Map<String,String> properties) throws IllegalArgumentException {
+    final SystemPropKey key = SystemPropKey.of(context);
     final Map<String,
-        String> checkedProperties = properties.entrySet().stream().collect(
-            Collectors.toMap(entry -> validateSystemProperty(entry.getKey(), entry.getValue()),
+        String> checkedProperties = properties.entrySet().stream()
+            .collect(Collectors.toMap(
+                entry -> validateSystemProperty(context, key, entry.getKey(), entry.getValue()),
                 Map.Entry::getValue));
-    context.getPropStore().replaceAll(SystemPropKey.of(context), version, checkedProperties);
+    context.getPropStore().replaceAll(key, version, checkedProperties);
   }
 
   public static void removeSystemProperty(ServerContext context, String property) {
@@ -60,12 +63,13 @@ public class SystemPropUtil {
     removePropWithoutDeprecationWarning(context, resolved);
   }
 
-  public static void removePropWithoutDeprecationWarning(ServerContext context, String property) {
+  private static void removePropWithoutDeprecationWarning(ServerContext context, String property) {
+    logIfFixed(Property.getPropertyByKey(property), null);
     context.getPropStore().removeProperties(SystemPropKey.of(context), List.of(property));
   }
 
-  private static String validateSystemProperty(String property, final String value)
-      throws IllegalArgumentException {
+  private static String validateSystemProperty(ServerContext context, SystemPropKey key,
+      String property, final String value) throws IllegalArgumentException {
     // Retrieve the replacement name for this property, if there is one.
     // Do this before we check if the name is a valid zookeeper name.
     final var original = property;
@@ -85,25 +89,43 @@ public class SystemPropUtil {
       log.trace("Encountered error setting zookeeper property", iae);
       throw iae;
     }
+    if (Property.isValidTablePropertyKey(property)) {
+      PropUtil.validateProperties(context, key, Map.of(property, value));
+    }
 
     // Find the property taking prefix into account
     Property foundProp = null;
     for (Property prop : Property.values()) {
-      if (prop.getType() == PropertyType.PREFIX && property.startsWith(prop.getKey())
+      if ((prop.getType() == PropertyType.PREFIX && property.startsWith(prop.getKey()))
           || prop.getKey().equals(property)) {
         foundProp = prop;
         break;
       }
     }
 
-    if ((foundProp == null || (foundProp.getType() != PropertyType.PREFIX
-        && !foundProp.getType().isValidFormat(value)))) {
+    if (foundProp == null || (foundProp.getType() != PropertyType.PREFIX
+        && !foundProp.getType().isValidFormat(value))) {
       IllegalArgumentException iae = new IllegalArgumentException(
           "Ignoring property " + property + " it is either null or in an invalid format");
       log.trace("Attempted to set zookeeper property.  Value is either null or invalid", iae);
       throw iae;
     }
 
+    logIfFixed(Property.getPropertyByKey(property), value);
+
     return property;
   }
+
+  /**
+   * Done as a last step before the property is finally changed (e.g., after validation). If the
+   * property is fixed, logs a warning that the property change will not take effect until related
+   * processes are restarted.
+   */
+  private static void logIfFixed(Property property, String value) {
+    if (property != null && Property.isFixedZooPropertyKey(property)) {
+      String s = value == null ? String.format("Removing a fixed property %s. ", property)
+          : String.format("Setting a fixed property %s to value %s. ", property, value);
+      log.warn(s + "Change will not take effect until related processes are restarted.");
+    }
+  }
 }
