@@ -36,6 +36,7 @@ import org.apache.accumulo.core.fate.zookeeper.ZooReaderWriter;
 import org.apache.accumulo.core.fate.zookeeper.ZooUtil.NodeExistsPolicy;
 import org.apache.accumulo.core.fate.zookeeper.ZooUtil.NodeMissingPolicy;
 import org.apache.accumulo.core.util.threads.ThreadPools;
+import org.apache.accumulo.server.AbstractServer;
 import org.apache.accumulo.server.ServerContext;
 import org.apache.zookeeper.KeeperException;
 import org.apache.zookeeper.KeeperException.NodeExistsException;
@@ -59,12 +60,13 @@ public class DistributedWorkQueue {
   private static final Logger log = LoggerFactory.getLogger(DistributedWorkQueue.class);
 
   private ThreadPoolExecutor threadPool;
-  private ZooReaderWriter zoo;
-  private String path;
-  private ServerContext context;
-  private long timerInitialDelay, timerPeriod;
+  private final ZooReaderWriter zoo;
+  private final String path;
+  private final AbstractServer server;
+  private final long timerInitialDelay;
+  private final long timerPeriod;
 
-  private AtomicInteger numTask = new AtomicInteger(0);
+  private final AtomicInteger numTask = new AtomicInteger(0);
 
   private void lookForWork(final Processor processor, List<String> children) {
     if (children.isEmpty()) {
@@ -79,6 +81,11 @@ public class DistributedWorkQueue {
     try {
       for (final String child : children) {
 
+        // Don't accept work if the server is shutting down
+        if (server.isShutdownRequested()) {
+          return;
+        }
+
         if (child.equals(LOCKS_NODE)) {
           continue;
         }
@@ -168,23 +175,27 @@ public class DistributedWorkQueue {
     void process(String workID, byte[] data);
   }
 
-  public DistributedWorkQueue(String path, AccumuloConfiguration config, ServerContext context) {
+  public DistributedWorkQueue(String path, AccumuloConfiguration config, AbstractServer server) {
     // Preserve the old delay and period
-    this(path, config, context, random.nextInt(toIntExact(MINUTES.toMillis(1))),
+    this(path, config, server, random.nextInt(toIntExact(MINUTES.toMillis(1))),
         MINUTES.toMillis(1));
   }
 
-  public DistributedWorkQueue(String path, AccumuloConfiguration config, ServerContext context,
+  public DistributedWorkQueue(String path, AccumuloConfiguration config, AbstractServer server,
       long timerInitialDelay, long timerPeriod) {
     this.path = path;
-    this.context = context;
+    this.server = server;
     this.timerInitialDelay = timerInitialDelay;
     this.timerPeriod = timerPeriod;
-    zoo = context.getZooReaderWriter();
+    zoo = server.getContext().getZooReaderWriter();
   }
 
   public ServerContext getContext() {
-    return context;
+    return server.getContext();
+  }
+
+  public AbstractServer getServer() {
+    return server;
   }
 
   public void startProcessing(final Processor processor, ThreadPoolExecutor executorService)
@@ -224,7 +235,7 @@ public class DistributedWorkQueue {
 
     // Add a little jitter to avoid all the tservers slamming zookeeper at once
     ThreadPools.watchCriticalScheduledTask(
-        context.getScheduledExecutor().scheduleWithFixedDelay(new Runnable() {
+        server.getContext().getScheduledExecutor().scheduleWithFixedDelay(new Runnable() {
           @Override
           public void run() {
             log.debug("Looking for work in {}", path);
