@@ -1,23 +1,25 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.server.client;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertNull;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertNull;
 
 import java.util.Collection;
 import java.util.Collections;
@@ -29,8 +31,6 @@ import java.util.TreeSet;
 import org.apache.accumulo.core.clientImpl.ClientContext;
 import org.apache.accumulo.core.clientImpl.TabletLocator;
 import org.apache.accumulo.core.clientImpl.TabletLocator.TabletLocation;
-import org.apache.accumulo.core.conf.DefaultConfiguration;
-import org.apache.accumulo.core.crypto.CryptoServiceFactory;
 import org.apache.accumulo.core.data.Key;
 import org.apache.accumulo.core.data.Mutation;
 import org.apache.accumulo.core.data.Range;
@@ -39,15 +39,17 @@ import org.apache.accumulo.core.data.Value;
 import org.apache.accumulo.core.dataImpl.KeyExtent;
 import org.apache.accumulo.core.file.FileOperations;
 import org.apache.accumulo.core.file.FileSKVWriter;
+import org.apache.accumulo.core.spi.crypto.CryptoService;
+import org.apache.accumulo.core.spi.crypto.NoCryptoServiceFactory;
+import org.apache.accumulo.server.MockServerContext;
 import org.apache.accumulo.server.ServerContext;
-import org.apache.accumulo.server.fs.VolumeManager;
 import org.apache.accumulo.server.fs.VolumeManagerImpl;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.fs.FileSystem;
 import org.apache.hadoop.fs.Path;
 import org.apache.hadoop.io.Text;
 import org.easymock.EasyMock;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 public class BulkImporterTest {
 
@@ -58,9 +60,9 @@ public class BulkImporterTest {
     fakeMetaData.add(new KeyExtent(tableId, new Text("a"), null));
     for (String part : new String[] {"b", "bm", "c", "cm", "d", "dm", "e", "em", "f", "g", "h", "i",
         "j", "k", "l"}) {
-      fakeMetaData.add(new KeyExtent(tableId, new Text(part), fakeMetaData.last().getEndRow()));
+      fakeMetaData.add(new KeyExtent(tableId, new Text(part), fakeMetaData.last().endRow()));
     }
-    fakeMetaData.add(new KeyExtent(tableId, null, fakeMetaData.last().getEndRow()));
+    fakeMetaData.add(new KeyExtent(tableId, null, fakeMetaData.last().endRow()));
   }
 
   class MockTabletLocator extends TabletLocator {
@@ -110,19 +112,16 @@ public class BulkImporterTest {
   public void testFindOverlappingTablets() throws Exception {
     MockTabletLocator locator = new MockTabletLocator();
     FileSystem fs = FileSystem.getLocal(new Configuration());
-    ServerContext context = EasyMock.createMock(ServerContext.class);
-    EasyMock.expect(context.getConfiguration()).andReturn(DefaultConfiguration.getInstance())
-        .anyTimes();
-    EasyMock.expect(context.getCryptoService()).andReturn(CryptoServiceFactory.newDefaultInstance())
-        .anyTimes();
+    ServerContext context = MockServerContext.get();
+    CryptoService cs = NoCryptoServiceFactory.NONE;
     EasyMock.replay(context);
     String file = "target/testFile.rf";
     fs.delete(new Path(file), true);
-    FileSKVWriter writer = FileOperations.getInstance().newWriterBuilder()
-        .forFile(file, fs, fs.getConf(), CryptoServiceFactory.newDefaultInstance())
-        .withTableConfiguration(context.getConfiguration()).build();
+    FileSKVWriter writer =
+        FileOperations.getInstance().newWriterBuilder().forFile(file, fs, fs.getConf(), cs)
+            .withTableConfiguration(context.getConfiguration()).build();
     writer.startDefaultLocalityGroup();
-    Value empty = new Value(new byte[] {});
+    Value empty = new Value();
     writer.append(new Key("a", "cf", "cq"), empty);
     writer.append(new Key("a", "cf", "cq1"), empty);
     writer.append(new Key("a", "cf", "cq2"), empty);
@@ -144,30 +143,31 @@ public class BulkImporterTest {
     writer.append(new Key("iterator", "cf", "cq5"), empty);
     writer.append(new Key("xyzzy", "cf", "cq"), empty);
     writer.close();
-    VolumeManager vm = VolumeManagerImpl.get(context.getConfiguration(), new Configuration());
-    List<TabletLocation> overlaps =
-        BulkImporter.findOverlappingTablets(context, vm, locator, new Path(file));
-    assertEquals(5, overlaps.size());
-    Collections.sort(overlaps);
-    assertEquals(new KeyExtent(tableId, new Text("a"), null), overlaps.get(0).tablet_extent);
-    assertEquals(new KeyExtent(tableId, new Text("d"), new Text("cm")),
-        overlaps.get(1).tablet_extent);
-    assertEquals(new KeyExtent(tableId, new Text("dm"), new Text("d")),
-        overlaps.get(2).tablet_extent);
-    assertEquals(new KeyExtent(tableId, new Text("j"), new Text("i")),
-        overlaps.get(3).tablet_extent);
-    assertEquals(new KeyExtent(tableId, null, new Text("l")), overlaps.get(4).tablet_extent);
+    try (var vm = VolumeManagerImpl.getLocalForTesting("file:///")) {
+      List<TabletLocation> overlaps =
+          BulkImporter.findOverlappingTablets(context, vm, locator, new Path(file), null, null, cs);
+      assertEquals(5, overlaps.size());
+      Collections.sort(overlaps);
+      assertEquals(new KeyExtent(tableId, new Text("a"), null), overlaps.get(0).tablet_extent);
+      assertEquals(new KeyExtent(tableId, new Text("d"), new Text("cm")),
+          overlaps.get(1).tablet_extent);
+      assertEquals(new KeyExtent(tableId, new Text("dm"), new Text("d")),
+          overlaps.get(2).tablet_extent);
+      assertEquals(new KeyExtent(tableId, new Text("j"), new Text("i")),
+          overlaps.get(3).tablet_extent);
+      assertEquals(new KeyExtent(tableId, null, new Text("l")), overlaps.get(4).tablet_extent);
 
-    List<TabletLocation> overlaps2 = BulkImporter.findOverlappingTablets(context, vm, locator,
-        new Path(file), new KeyExtent(tableId, new Text("h"), new Text("b")));
-    assertEquals(3, overlaps2.size());
-    assertEquals(new KeyExtent(tableId, new Text("d"), new Text("cm")),
-        overlaps2.get(0).tablet_extent);
-    assertEquals(new KeyExtent(tableId, new Text("dm"), new Text("d")),
-        overlaps2.get(1).tablet_extent);
-    assertEquals(new KeyExtent(tableId, new Text("j"), new Text("i")),
-        overlaps2.get(2).tablet_extent);
-    assertEquals(locator.invalidated, 1);
+      List<TabletLocation> overlaps2 = BulkImporter.findOverlappingTablets(context, vm, locator,
+          new Path(file), new KeyExtent(tableId, new Text("h"), new Text("b")), cs);
+      assertEquals(3, overlaps2.size());
+      assertEquals(new KeyExtent(tableId, new Text("d"), new Text("cm")),
+          overlaps2.get(0).tablet_extent);
+      assertEquals(new KeyExtent(tableId, new Text("dm"), new Text("d")),
+          overlaps2.get(1).tablet_extent);
+      assertEquals(new KeyExtent(tableId, new Text("j"), new Text("i")),
+          overlaps2.get(2).tablet_extent);
+      assertEquals(locator.invalidated, 1);
+    }
   }
 
   @Test
