@@ -1,24 +1,25 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
-
 package org.apache.accumulo.server.master.balancer;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import java.security.SecureRandom;
 import java.util.ArrayList;
@@ -27,7 +28,6 @@ import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
 import java.util.Map.Entry;
-import java.util.Random;
 import java.util.Set;
 import java.util.SortedMap;
 import java.util.TreeMap;
@@ -36,23 +36,23 @@ import java.util.function.Function;
 import org.apache.accumulo.core.data.TableId;
 import org.apache.accumulo.core.dataImpl.KeyExtent;
 import org.apache.accumulo.core.master.thrift.TabletServerStatus;
+import org.apache.accumulo.core.metadata.TServerInstance;
 import org.apache.accumulo.core.util.MapCounter;
-import org.apache.accumulo.core.util.Pair;
-import org.apache.accumulo.server.master.state.TServerInstance;
 import org.apache.accumulo.server.master.state.TabletMigration;
 import org.apache.hadoop.io.Text;
-import org.junit.Test;
-
-import com.google.common.collect.Iterables;
+import org.junit.jupiter.api.Test;
 
+@Deprecated(since = "2.1.0")
 public class GroupBalancerTest {
 
-  private static Function<KeyExtent,String> partitioner = new Function<KeyExtent,String>() {
+  private static final SecureRandom random = new SecureRandom();
+
+  private static Function<KeyExtent,String> partitioner = new Function<>() {
 
     @Override
     public String apply(KeyExtent input) {
-      return (input == null || input.getEndRow() == null) ? null
-          : input.getEndRow().toString().substring(0, 2);
+      return (input == null || input.endRow() == null) ? null
+          : input.endRow().toString().substring(0, 2);
     }
   };
 
@@ -85,9 +85,8 @@ public class GroupBalancerTest {
       GroupBalancer balancer = new GroupBalancer(TableId.of("1")) {
 
         @Override
-        protected Iterable<Pair<KeyExtent,Location>> getLocationProvider() {
-          return Iterables.transform(tabletLocs.entrySet(),
-              input -> new Pair<>(input.getKey(), new Location(input.getValue())));
+        protected Map<KeyExtent,TServerInstance> getLocationProvider() {
+          return tabletLocs;
         }
 
         @Override
@@ -122,8 +121,8 @@ public class GroupBalancerTest {
 
         balancer.balance(current, migrations, migrationsOut);
 
-        assertTrue("Max Migration exceeded " + maxMigrations + " " + migrationsOut.size(),
-            migrationsOut.size() <= (maxMigrations + 5));
+        assertTrue(migrationsOut.size() <= (maxMigrations + 5),
+            "Max Migration exceeded " + maxMigrations + " " + migrationsOut.size());
 
         for (TabletMigration tabletMigration : migrationsOut) {
           assertEquals(tabletLocs.get(tabletMigration.tablet), tabletMigration.oldServer);
@@ -132,7 +131,7 @@ public class GroupBalancerTest {
           tabletLocs.put(tabletMigration.tablet, tabletMigration.newServer);
         }
 
-        if (migrationsOut.size() == 0) {
+        if (migrationsOut.isEmpty()) {
           break;
         }
       }
@@ -176,10 +175,9 @@ public class GroupBalancerTest {
         int tserverExtra = 0;
         for (String group : groupCounts.keySet()) {
           assertTrue(tgc.get(group) >= expectedCounts.get(group));
-          assertTrue(
+          assertTrue(tgc.get(group) <= expectedCounts.get(group) + 1,
               "Group counts not as expected group:" + group + " actual:" + tgc.get(group)
-                  + " expected:" + (expectedCounts.get(group) + 1) + " tserver:" + entry.getKey(),
-              tgc.get(group) <= expectedCounts.get(group) + 1);
+                  + " expected:" + (expectedCounts.get(group) + 1) + " tserver:" + entry.getKey());
           tserverExtra += tgc.get(group) - expectedCounts.get(group);
         }
 
@@ -187,10 +185,6 @@ public class GroupBalancerTest {
         assertTrue(tserverExtra <= maxExtraGroups);
       }
     }
-
-    Map<KeyExtent,TServerInstance> getLocations() {
-      return tabletLocs;
-    }
   }
 
   @Test
@@ -330,12 +324,11 @@ public class GroupBalancerTest {
   @Test
   public void bigTest() {
     TabletServers tservers = new TabletServers();
-    Random rand = new SecureRandom();
 
     for (int g = 1; g <= 60; g++) {
       for (int t = 1; t <= 241; t++) {
         tservers.addTablet(String.format("%02d:%d", g, t),
-            "192.168.1." + (rand.nextInt(249) + 1) + ":9997");
+            "192.168.1." + (random.nextInt(249) + 1) + ":9997");
       }
     }
 
@@ -349,12 +342,11 @@ public class GroupBalancerTest {
   @Test
   public void bigTest2() {
     TabletServers tservers = new TabletServers();
-    Random rand = new SecureRandom();
 
     for (int g = 1; g <= 60; g++) {
-      for (int t = 1; t <= rand.nextInt(1000); t++) {
+      for (int t = 1; t <= random.nextInt(1000); t++) {
         tservers.addTablet(String.format("%02d:%d", g, t),
-            "192.168.1." + (rand.nextInt(249) + 1) + ":9997");
+            "192.168.1." + (random.nextInt(249) + 1) + ":9997");
       }
     }
 
