@@ -459,8 +459,8 @@ public class HostRegexTableLoadBalancerTest extends BaseHostRegexTableLoadBalanc
       // Report that we have a bar tablet on this server
       TKeyExtent tke = new TKeyExtent();
       tke.setTable(BAR.getId().canonical().getBytes(UTF_8));
-      tke.setEndRow("11".getBytes());
-      tke.setPrevEndRow("10".getBytes());
+      tke.setEndRow("11".getBytes(UTF_8));
+      tke.setPrevEndRow("10".getBytes(UTF_8));
       TabletStats ts = new TabletStats();
       ts.setExtent(tke);
       tablets.add(ts);
@@ -468,8 +468,8 @@ public class HostRegexTableLoadBalancerTest extends BaseHostRegexTableLoadBalanc
       // Report that we have a foo tablet on this server
       TKeyExtent tke = new TKeyExtent();
       tke.setTable(FOO.getId().canonical().getBytes(UTF_8));
-      tke.setEndRow("1".getBytes());
-      tke.setPrevEndRow("0".getBytes());
+      tke.setEndRow("1".getBytes(UTF_8));
+      tke.setPrevEndRow("0".getBytes(UTF_8));
       TabletStats ts = new TabletStats();
       ts.setExtent(tke);
       tablets.add(ts);
