@@ -1,77 +1,54 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.server.rpc;
 
-import static org.junit.Assert.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertThrows;
 
 import java.nio.ByteBuffer;
-import java.util.Map;
 import java.util.UUID;
 import java.util.concurrent.ConcurrentHashMap;
-import java.util.function.Predicate;
 
 import org.apache.accumulo.core.client.security.tokens.AuthenticationToken;
 import org.apache.accumulo.core.client.security.tokens.KerberosToken;
 import org.apache.accumulo.core.client.security.tokens.PasswordToken;
 import org.apache.accumulo.core.clientImpl.thrift.ThriftSecurityException;
-import org.apache.accumulo.core.conf.AccumuloConfiguration;
 import org.apache.accumulo.core.conf.ConfigurationCopy;
 import org.apache.accumulo.core.conf.DefaultConfiguration;
 import org.apache.accumulo.core.conf.Property;
 import org.apache.accumulo.core.securityImpl.thrift.TCredentials;
-import org.junit.After;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 public class TCredentialsUpdatingInvocationHandlerTest {
-  private static final DefaultConfiguration DEFAULT_CONFIG = DefaultConfiguration.getInstance();
 
-  TCredentialsUpdatingInvocationHandler<Object> proxy;
-  ConfigurationCopy cc;
-  AccumuloConfiguration conf;
+  private TCredentialsUpdatingInvocationHandler<Object> proxy;
+  private ConfigurationCopy conf;
 
-  @Before
+  @BeforeEach
   public void setup() {
-    cc = new ConfigurationCopy();
-    conf = new AccumuloConfiguration() {
-      @Override
-      public String get(Property property) {
-        String value = cc.get(property);
-        if (null == value) {
-          return DEFAULT_CONFIG.get(property);
-        }
-        return value;
-      }
-
-      @Override
-      public void getProperties(Map<String,String> props, Predicate<String> filter) {
-        cc.getProperties(props, filter);
-      }
-
-      @Override
-      public long getUpdateCount() {
-        return cc.getUpdateCount();
-      }
-    };
-
+    conf = new ConfigurationCopy(DefaultConfiguration.getInstance());
     proxy = new TCredentialsUpdatingInvocationHandler<>(new Object(), conf);
   }
 
-  @After
+  @AfterEach
   public void teardown() {
     UGIAssumingProcessor.rpcPrincipal.set(null);
   }
@@ -99,38 +76,41 @@ public class TCredentialsUpdatingInvocationHandlerTest {
     assertEquals(KerberosToken.class, cache.get(KerberosToken.CLASS_NAME));
   }
 
-  @Test(expected = ThriftSecurityException.class)
-  public void testMissingPrincipal() throws Exception {
+  @Test
+  public void testMissingPrincipal() {
     final String principal = "root";
     TCredentials tcreds = new TCredentials(principal, KerberosToken.CLASS_NAME,
         ByteBuffer.allocate(0), UUID.randomUUID().toString());
     UGIAssumingProcessor.rpcPrincipal.set(null);
-    proxy.updateArgs(new Object[] {new Object(), tcreds});
+    assertThrows(ThriftSecurityException.class,
+        () -> proxy.updateArgs(new Object[] {new Object(), tcreds}));
   }
 
-  @Test(expected = ThriftSecurityException.class)
-  public void testMismatchedPrincipal() throws Exception {
+  @Test
+  public void testMismatchedPrincipal() {
     final String principal = "root";
     TCredentials tcreds = new TCredentials(principal, KerberosToken.CLASS_NAME,
         ByteBuffer.allocate(0), UUID.randomUUID().toString());
     UGIAssumingProcessor.rpcPrincipal.set(principal + "foobar");
-    proxy.updateArgs(new Object[] {new Object(), tcreds});
+    assertThrows(ThriftSecurityException.class,
+        () -> proxy.updateArgs(new Object[] {new Object(), tcreds}));
   }
 
-  @Test(expected = ThriftSecurityException.class)
-  public void testWrongTokenType() throws Exception {
+  @Test
+  public void testWrongTokenType() {
     final String principal = "root";
     TCredentials tcreds = new TCredentials(principal, PasswordToken.class.getName(),
         ByteBuffer.allocate(0), UUID.randomUUID().toString());
     UGIAssumingProcessor.rpcPrincipal.set(principal);
-    proxy.updateArgs(new Object[] {new Object(), tcreds});
+    assertThrows(ThriftSecurityException.class,
+        () -> proxy.updateArgs(new Object[] {new Object(), tcreds}));
   }
 
   @Test
   public void testAllowedAnyImpersonationForAnyUser() throws Exception {
     final String proxyServer = "proxy";
-    cc.set(Property.INSTANCE_RPC_SASL_ALLOWED_USER_IMPERSONATION, proxyServer + ":*");
-    cc.set(Property.INSTANCE_RPC_SASL_ALLOWED_HOST_IMPERSONATION, "*");
+    conf.set(Property.INSTANCE_RPC_SASL_ALLOWED_USER_IMPERSONATION, proxyServer + ":*");
+    conf.set(Property.INSTANCE_RPC_SASL_ALLOWED_HOST_IMPERSONATION, "*");
     proxy = new TCredentialsUpdatingInvocationHandler<>(new Object(), conf);
     TCredentials tcreds = new TCredentials("client", KerberosToken.class.getName(),
         ByteBuffer.allocate(0), UUID.randomUUID().toString());
@@ -141,8 +121,9 @@ public class TCredentialsUpdatingInvocationHandlerTest {
   @Test
   public void testAllowedImpersonationForSpecificUsers() throws Exception {
     final String proxyServer = "proxy";
-    cc.set(Property.INSTANCE_RPC_SASL_ALLOWED_USER_IMPERSONATION, proxyServer + ":client1,client2");
-    cc.set(Property.INSTANCE_RPC_SASL_ALLOWED_HOST_IMPERSONATION, "*");
+    conf.set(Property.INSTANCE_RPC_SASL_ALLOWED_USER_IMPERSONATION,
+        proxyServer + ":client1,client2");
+    conf.set(Property.INSTANCE_RPC_SASL_ALLOWED_HOST_IMPERSONATION, "*");
     proxy = new TCredentialsUpdatingInvocationHandler<>(new Object(), conf);
     TCredentials tcreds = new TCredentials("client1", KerberosToken.class.getName(),
         ByteBuffer.allocate(0), UUID.randomUUID().toString());
@@ -153,38 +134,40 @@ public class TCredentialsUpdatingInvocationHandlerTest {
     proxy.updateArgs(new Object[] {new Object(), tcreds});
   }
 
-  @Test(expected = ThriftSecurityException.class)
-  public void testDisallowedImpersonationForUser() throws Exception {
+  @Test
+  public void testDisallowedImpersonationForUser() {
     final String proxyServer = "proxy";
     // let "otherproxy" impersonate, but not "proxy"
-    cc.set(Property.INSTANCE_RPC_SASL_ALLOWED_USER_IMPERSONATION, "otherproxy:*");
-    cc.set(Property.INSTANCE_RPC_SASL_ALLOWED_HOST_IMPERSONATION, "*");
+    conf.set(Property.INSTANCE_RPC_SASL_ALLOWED_USER_IMPERSONATION, "otherproxy:*");
+    conf.set(Property.INSTANCE_RPC_SASL_ALLOWED_HOST_IMPERSONATION, "*");
     proxy = new TCredentialsUpdatingInvocationHandler<>(new Object(), conf);
     TCredentials tcreds = new TCredentials("client", KerberosToken.class.getName(),
         ByteBuffer.allocate(0), UUID.randomUUID().toString());
     UGIAssumingProcessor.rpcPrincipal.set(proxyServer);
-    proxy.updateArgs(new Object[] {new Object(), tcreds});
+    assertThrows(ThriftSecurityException.class,
+        () -> proxy.updateArgs(new Object[] {new Object(), tcreds}));
   }
 
-  @Test(expected = ThriftSecurityException.class)
-  public void testDisallowedImpersonationForMultipleUsers() throws Exception {
+  @Test
+  public void testDisallowedImpersonationForMultipleUsers() {
     final String proxyServer = "proxy";
     // let "otherproxy" impersonate, but not "proxy"
-    cc.set(Property.INSTANCE_RPC_SASL_ALLOWED_USER_IMPERSONATION,
+    conf.set(Property.INSTANCE_RPC_SASL_ALLOWED_USER_IMPERSONATION,
         "otherproxy1:*;otherproxy2:client1,client2");
-    cc.set(Property.INSTANCE_RPC_SASL_ALLOWED_HOST_IMPERSONATION, "*;*");
+    conf.set(Property.INSTANCE_RPC_SASL_ALLOWED_HOST_IMPERSONATION, "*;*");
     proxy = new TCredentialsUpdatingInvocationHandler<>(new Object(), conf);
     TCredentials tcreds = new TCredentials("client1", KerberosToken.class.getName(),
         ByteBuffer.allocate(0), UUID.randomUUID().toString());
     UGIAssumingProcessor.rpcPrincipal.set(proxyServer);
-    proxy.updateArgs(new Object[] {new Object(), tcreds});
+    assertThrows(ThriftSecurityException.class,
+        () -> proxy.updateArgs(new Object[] {new Object(), tcreds}));
   }
 
   @Test
   public void testAllowedImpersonationFromSpecificHost() throws Exception {
     final String proxyServer = "proxy", client = "client", host = "host.domain.com";
-    cc.set(Property.INSTANCE_RPC_SASL_ALLOWED_USER_IMPERSONATION, proxyServer + ":" + client);
-    cc.set(Property.INSTANCE_RPC_SASL_ALLOWED_HOST_IMPERSONATION, host);
+    conf.set(Property.INSTANCE_RPC_SASL_ALLOWED_USER_IMPERSONATION, proxyServer + ":" + client);
+    conf.set(Property.INSTANCE_RPC_SASL_ALLOWED_HOST_IMPERSONATION, host);
     proxy = new TCredentialsUpdatingInvocationHandler<>(new Object(), conf);
     TCredentials tcreds = new TCredentials("client", KerberosToken.class.getName(),
         ByteBuffer.allocate(0), UUID.randomUUID().toString());
@@ -193,17 +176,18 @@ public class TCredentialsUpdatingInvocationHandlerTest {
     proxy.updateArgs(new Object[] {new Object(), tcreds});
   }
 
-  @Test(expected = ThriftSecurityException.class)
-  public void testDisallowedImpersonationFromSpecificHost() throws Exception {
+  @Test
+  public void testDisallowedImpersonationFromSpecificHost() {
     final String proxyServer = "proxy", client = "client", host = "host.domain.com";
-    cc.set(Property.INSTANCE_RPC_SASL_ALLOWED_USER_IMPERSONATION, proxyServer + ":" + client);
-    cc.set(Property.INSTANCE_RPC_SASL_ALLOWED_HOST_IMPERSONATION, host);
+    conf.set(Property.INSTANCE_RPC_SASL_ALLOWED_USER_IMPERSONATION, proxyServer + ":" + client);
+    conf.set(Property.INSTANCE_RPC_SASL_ALLOWED_HOST_IMPERSONATION, host);
     proxy = new TCredentialsUpdatingInvocationHandler<>(new Object(), conf);
     TCredentials tcreds = new TCredentials("client", KerberosToken.class.getName(),
         ByteBuffer.allocate(0), UUID.randomUUID().toString());
     UGIAssumingProcessor.rpcPrincipal.set(proxyServer);
     // The RPC came from a different host than is allowed
     TServerUtils.clientAddress.set("otherhost.domain.com");
-    proxy.updateArgs(new Object[] {new Object(), tcreds});
+    assertThrows(ThriftSecurityException.class,
+        () -> proxy.updateArgs(new Object[] {new Object(), tcreds}));
   }
 }
