@@ -1,30 +1,33 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.server.security.delegation;
 
+import static java.util.concurrent.TimeUnit.DAYS;
 import static org.easymock.EasyMock.createMock;
 import static org.easymock.EasyMock.expect;
 import static org.easymock.EasyMock.replay;
 import static org.easymock.EasyMock.reset;
 import static org.easymock.EasyMock.verify;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertNull;
-import static org.junit.Assert.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import java.io.ByteArrayOutputStream;
 import java.io.DataOutputStream;
@@ -37,14 +40,15 @@ import java.util.UUID;
 import javax.crypto.KeyGenerator;
 
 import org.apache.accumulo.core.Constants;
-import org.apache.accumulo.fate.zookeeper.ZooReader;
+import org.apache.accumulo.core.data.InstanceId;
+import org.apache.accumulo.core.fate.zookeeper.ZooReader;
 import org.apache.zookeeper.KeeperException.NoNodeException;
 import org.apache.zookeeper.WatchedEvent;
 import org.apache.zookeeper.Watcher.Event.EventType;
 import org.apache.zookeeper.Watcher.Event.KeeperState;
-import org.junit.Before;
-import org.junit.BeforeClass;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 public class ZooAuthenticationKeyWatcherTest {
 
@@ -53,7 +57,7 @@ public class ZooAuthenticationKeyWatcherTest {
   private static final int KEY_LENGTH = 64;
   private static KeyGenerator keyGen;
 
-  @BeforeClass
+  @BeforeAll
   public static void setupKeyGenerator() throws Exception {
     // From org.apache.hadoop.security.token.SecretManager
     keyGen = KeyGenerator.getInstance(DEFAULT_HMAC_ALGORITHM);
@@ -61,16 +65,16 @@ public class ZooAuthenticationKeyWatcherTest {
   }
 
   private ZooReader zk;
-  private String instanceId;
+  private InstanceId instanceId;
   private String baseNode;
-  private long tokenLifetime = 7 * 24 * 60 * 60 * 1000; // 7days
+  private long tokenLifetime = DAYS.toMillis(7);
   private AuthenticationTokenSecretManager secretManager;
   private ZooAuthenticationKeyWatcher keyWatcher;
 
-  @Before
+  @BeforeEach
   public void setupMocks() {
     zk = createMock(ZooReader.class);
-    instanceId = UUID.randomUUID().toString();
+    instanceId = InstanceId.of(UUID.randomUUID());
     baseNode = "/accumulo/" + instanceId + Constants.ZDELEGATION_TOKEN_KEYS;
     secretManager = new AuthenticationTokenSecretManager(instanceId, tokenLifetime);
     keyWatcher = new ZooAuthenticationKeyWatcher(secretManager, zk, baseNode);
@@ -98,8 +102,8 @@ public class ZooAuthenticationKeyWatcherTest {
     List<String> children = Arrays.asList("1", "2");
 
     expect(zk.getChildren(baseNode, keyWatcher)).andReturn(children);
-    expect(zk.getData(baseNode + "/1", keyWatcher, null)).andReturn(serializedKey1);
-    expect(zk.getData(baseNode + "/2", keyWatcher, null)).andReturn(serializedKey2);
+    expect(zk.getData(baseNode + "/1", keyWatcher)).andReturn(serializedKey1);
+    expect(zk.getData(baseNode + "/2", keyWatcher)).andReturn(serializedKey2);
     replay(zk);
 
     keyWatcher.process(event);
@@ -119,8 +123,8 @@ public class ZooAuthenticationKeyWatcherTest {
     List<String> children = Arrays.asList("1", "2");
 
     expect(zk.getChildren(baseNode, keyWatcher)).andReturn(children);
-    expect(zk.getData(baseNode + "/1", keyWatcher, null)).andReturn(serializedKey1);
-    expect(zk.getData(baseNode + "/2", keyWatcher, null)).andReturn(serializedKey2);
+    expect(zk.getData(baseNode + "/1", keyWatcher)).andReturn(serializedKey1);
+    expect(zk.getData(baseNode + "/2", keyWatcher)).andReturn(serializedKey2);
     replay(zk);
 
     keyWatcher.process(event);
@@ -172,7 +176,7 @@ public class ZooAuthenticationKeyWatcherTest {
     assertEquals(1, secretManager.getKeys().size());
     byte[] serializedKey2 = serialize(key2);
 
-    expect(zk.getData(event.getPath(), keyWatcher, null)).andReturn(serializedKey2);
+    expect(zk.getData(event.getPath(), keyWatcher)).andReturn(serializedKey2);
     replay(zk);
 
     keyWatcher.process(event);
@@ -245,10 +249,8 @@ public class ZooAuthenticationKeyWatcherTest {
 
     expect(zk.exists(baseNode, keyWatcher)).andReturn(true);
     expect(zk.getChildren(baseNode, keyWatcher)).andReturn(children);
-    expect(zk.getData(baseNode + "/" + key1.getKeyId(), keyWatcher, null))
-        .andReturn(serialize(key1));
-    expect(zk.getData(baseNode + "/" + key2.getKeyId(), keyWatcher, null))
-        .andReturn(serialize(key2));
+    expect(zk.getData(baseNode + "/" + key1.getKeyId(), keyWatcher)).andReturn(serialize(key1));
+    expect(zk.getData(baseNode + "/" + key2.getKeyId(), keyWatcher)).andReturn(serialize(key2));
 
     replay(zk);
 
@@ -282,10 +284,8 @@ public class ZooAuthenticationKeyWatcherTest {
 
     expect(zk.exists(baseNode, keyWatcher)).andReturn(true);
     expect(zk.getChildren(baseNode, keyWatcher)).andReturn(children);
-    expect(zk.getData(baseNode + "/" + key1.getKeyId(), keyWatcher, null))
-        .andReturn(serialize(key1));
-    expect(zk.getData(baseNode + "/" + key2.getKeyId(), keyWatcher, null))
-        .andReturn(serialize(key2));
+    expect(zk.getData(baseNode + "/" + key1.getKeyId(), keyWatcher)).andReturn(serialize(key1));
+    expect(zk.getData(baseNode + "/" + key2.getKeyId(), keyWatcher)).andReturn(serialize(key2));
 
     replay(zk);
 
@@ -296,18 +296,16 @@ public class ZooAuthenticationKeyWatcherTest {
     verify(zk);
 
     // We should have no auth keys when we're disconnected
-    assertEquals("Secret manager should be empty after a disconnect", 0,
-        secretManager.getKeys().size());
-    assertNull("Current key should be null", secretManager.getCurrentKey());
+    assertEquals(0, secretManager.getKeys().size(),
+        "Secret manager should be empty after a disconnect");
+    assertNull(secretManager.getCurrentKey(), "Current key should be null");
 
     reset(zk);
 
     expect(zk.exists(baseNode, keyWatcher)).andReturn(true);
     expect(zk.getChildren(baseNode, keyWatcher)).andReturn(children);
-    expect(zk.getData(baseNode + "/" + key1.getKeyId(), keyWatcher, null))
-        .andReturn(serialize(key1));
-    expect(zk.getData(baseNode + "/" + key2.getKeyId(), keyWatcher, null))
-        .andReturn(serialize(key2));
+    expect(zk.getData(baseNode + "/" + key1.getKeyId(), keyWatcher)).andReturn(serialize(key1));
+    expect(zk.getData(baseNode + "/" + key2.getKeyId(), keyWatcher)).andReturn(serialize(key2));
 
     replay(zk);
 
@@ -330,8 +328,8 @@ public class ZooAuthenticationKeyWatcherTest {
     expect(zk.exists(baseNode, keyWatcher)).andReturn(true);
     // We saw key1
     expect(zk.getChildren(baseNode, keyWatcher)).andReturn(children);
-    // but it was gone when we tried to access it (master deleted it)
-    expect(zk.getData(baseNode + "/" + key1.getKeyId(), keyWatcher, null))
+    // but it was gone when we tried to access it (manager deleted it)
+    expect(zk.getData(baseNode + "/" + key1.getKeyId(), keyWatcher))
         .andThrow(new NoNodeException());
 
     replay(zk);
@@ -342,9 +340,9 @@ public class ZooAuthenticationKeyWatcherTest {
     verify(zk);
 
     // We should have no auth keys after initializing things
-    assertEquals("Secret manager should be empty after a disconnect", 0,
-        secretManager.getKeys().size());
-    assertNull("Current key should be null", secretManager.getCurrentKey());
+    assertEquals(0, secretManager.getKeys().size(),
+        "Secret manager should be empty after a disconnect");
+    assertNull(secretManager.getCurrentKey(), "Current key should be null");
   }
 
   private byte[] serialize(AuthenticationKey key) throws IOException {
