@@ -1,84 +1,52 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.server.util;
 
-import static org.easymock.EasyMock.createMock;
-import static org.easymock.EasyMock.expect;
-import static org.easymock.EasyMock.replay;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import java.io.File;
 import java.io.IOException;
 import java.util.ArrayList;
-import java.util.Collection;
 import java.util.HashMap;
-import java.util.Iterator;
 
 import org.apache.accumulo.core.conf.Property;
-import org.apache.accumulo.server.fs.FileRef;
-import org.apache.accumulo.server.fs.VolumeManager;
+import org.apache.accumulo.server.WithTestNames;
 import org.apache.accumulo.server.fs.VolumeManagerImpl;
 import org.apache.hadoop.fs.Path;
-import org.junit.Before;
-import org.junit.Rule;
-import org.junit.Test;
-import org.junit.rules.TemporaryFolder;
-import org.junit.rules.TestName;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.io.TempDir;
 
 import edu.umd.cs.findbugs.annotations.SuppressFBWarnings;
 
 @SuppressFBWarnings(value = "PATH_TRAVERSAL_IN", justification = "paths not set by user input")
-public class FileUtilTest {
-  @SuppressWarnings("deprecation")
-  private static Property INSTANCE_DFS_DIR = Property.INSTANCE_DFS_DIR;
-
-  @Rule
-  public TemporaryFolder tmpDir =
-      new TemporaryFolder(new File(System.getProperty("user.dir") + "/target"));
-
-  @Rule
-  public TestName testName = new TestName();
+public class FileUtilTest extends WithTestNames {
 
+  @TempDir
+  private static File tempDir;
   private File accumuloDir;
 
-  @Before
-  public void createTmpDir() throws IOException {
-    accumuloDir = tmpDir.newFolder(testName.getMethodName());
-  }
-
-  @Test
-  public void testToPathStrings() {
-    Collection<FileRef> c = new java.util.ArrayList<>();
-    FileRef r1 = createMock(FileRef.class);
-    expect(r1.path()).andReturn(new Path("/foo"));
-    replay(r1);
-    c.add(r1);
-    FileRef r2 = createMock(FileRef.class);
-    expect(r2.path()).andReturn(new Path("/bar"));
-    replay(r2);
-    c.add(r2);
-
-    Collection<String> cs = FileUtil.toPathStrings(c);
-    assertEquals(2, cs.size());
-    Iterator<String> iter = cs.iterator();
-    assertEquals("/foo", iter.next());
-    assertEquals("/bar", iter.next());
+  @BeforeEach
+  public void createTmpDir() {
+    accumuloDir = new File(tempDir, testName());
+    assertTrue(accumuloDir.isDirectory() || accumuloDir.mkdir());
   }
 
   @Test
@@ -89,13 +57,13 @@ public class FileUtilTest {
     Path tmpPath1 = new Path(tmp1.toURI());
 
     HashMap<Property,String> testProps = new HashMap<>();
-    testProps.put(INSTANCE_DFS_DIR, accumuloDir.getAbsolutePath());
+    testProps.put(Property.INSTANCE_VOLUMES, accumuloDir.getAbsolutePath());
 
-    VolumeManager fs = VolumeManagerImpl.getLocal(accumuloDir.getAbsolutePath());
+    try (var fs = VolumeManagerImpl.getLocalForTesting(accumuloDir.getAbsolutePath())) {
+      FileUtil.cleanupIndexOp(tmpPath1, fs, new ArrayList<>());
+    }
 
-    FileUtil.cleanupIndexOp(tmpPath1, fs, new ArrayList<>());
-
-    assertFalse("Expected " + tmp1 + " to be cleaned up but it wasn't", tmp1.exists());
+    assertFalse(tmp1.exists(), "Expected " + tmp1 + " to be cleaned up but it wasn't");
   }
 
   @Test
@@ -117,15 +85,12 @@ public class FileUtilTest {
     HashMap<Property,String> testProps = new HashMap<>();
     testProps.put(Property.INSTANCE_VOLUMES, v1.toURI() + "," + v2.toURI());
 
-    VolumeManager fs = VolumeManagerImpl.getLocal(accumuloDir.getAbsolutePath());
-
-    FileUtil.cleanupIndexOp(tmpPath1, fs, new ArrayList<>());
-
-    assertFalse("Expected " + tmp1 + " to be cleaned up but it wasn't", tmp1.exists());
-
-    FileUtil.cleanupIndexOp(tmpPath2, fs, new ArrayList<>());
-
-    assertFalse("Expected " + tmp2 + " to be cleaned up but it wasn't", tmp2.exists());
+    try (var fs = VolumeManagerImpl.getLocalForTesting(accumuloDir.getAbsolutePath())) {
+      FileUtil.cleanupIndexOp(tmpPath1, fs, new ArrayList<>());
+      assertFalse(tmp1.exists(), "Expected " + tmp1 + " to be cleaned up but it wasn't");
+      FileUtil.cleanupIndexOp(tmpPath2, fs, new ArrayList<>());
+      assertFalse(tmp2.exists(), "Expected " + tmp2 + " to be cleaned up but it wasn't");
+    }
   }
 
   @Test
@@ -150,15 +115,12 @@ public class FileUtilTest {
     HashMap<Property,String> testProps = new HashMap<>();
     testProps.put(Property.INSTANCE_VOLUMES, v1.toURI() + "," + v2.toURI());
 
-    VolumeManager fs = VolumeManagerImpl.getLocal(accumuloDir.getAbsolutePath());
-
-    FileUtil.cleanupIndexOp(tmpPath1, fs, new ArrayList<>());
-
-    assertFalse("Expected " + tmp1 + " to be cleaned up but it wasn't", tmp1.exists());
-
-    FileUtil.cleanupIndexOp(tmpPath2, fs, new ArrayList<>());
-
-    assertFalse("Expected " + tmp2 + " to be cleaned up but it wasn't", tmp2.exists());
+    try (var fs = VolumeManagerImpl.getLocalForTesting(accumuloDir.getAbsolutePath())) {
+      FileUtil.cleanupIndexOp(tmpPath1, fs, new ArrayList<>());
+      assertFalse(tmp1.exists(), "Expected " + tmp1 + " to be cleaned up but it wasn't");
+      FileUtil.cleanupIndexOp(tmpPath2, fs, new ArrayList<>());
+      assertFalse(tmp2.exists(), "Expected " + tmp2 + " to be cleaned up but it wasn't");
+    }
   }
 
   @Test
@@ -177,15 +139,12 @@ public class FileUtilTest {
     HashMap<Property,String> testProps = new HashMap<>();
     testProps.put(Property.INSTANCE_VOLUMES, v1.toURI() + "," + v2.toURI());
 
-    VolumeManager fs = VolumeManagerImpl.getLocal(accumuloDir.getAbsolutePath());
-
-    FileUtil.cleanupIndexOp(tmpPath1, fs, new ArrayList<>());
-
-    assertFalse("Expected " + tmp1 + " to be cleaned up but it wasn't", tmp1.exists());
-
-    FileUtil.cleanupIndexOp(tmpPath2, fs, new ArrayList<>());
-
-    assertFalse("Expected " + tmp2 + " to be cleaned up but it wasn't", tmp2.exists());
+    try (var fs = VolumeManagerImpl.getLocalForTesting(accumuloDir.getAbsolutePath())) {
+      FileUtil.cleanupIndexOp(tmpPath1, fs, new ArrayList<>());
+      assertFalse(tmp1.exists(), "Expected " + tmp1 + " to be cleaned up but it wasn't");
+      FileUtil.cleanupIndexOp(tmpPath2, fs, new ArrayList<>());
+      assertFalse(tmp2.exists(), "Expected " + tmp2 + " to be cleaned up but it wasn't");
+    }
   }
 
   @Test
@@ -207,14 +166,11 @@ public class FileUtilTest {
     HashMap<Property,String> testProps = new HashMap<>();
     testProps.put(Property.INSTANCE_VOLUMES, v1.toURI() + "," + v2.toURI());
 
-    VolumeManager fs = VolumeManagerImpl.getLocal(accumuloDir.getAbsolutePath());
-
-    FileUtil.cleanupIndexOp(tmpPath1, fs, new ArrayList<>());
-
-    assertFalse("Expected " + tmp1 + " to be cleaned up but it wasn't", tmp1.exists());
-
-    FileUtil.cleanupIndexOp(tmpPath2, fs, new ArrayList<>());
-
-    assertFalse("Expected " + tmp2 + " to be cleaned up but it wasn't", tmp2.exists());
+    try (var fs = VolumeManagerImpl.getLocalForTesting(accumuloDir.getAbsolutePath())) {
+      FileUtil.cleanupIndexOp(tmpPath1, fs, new ArrayList<>());
+      assertFalse(tmp1.exists(), "Expected " + tmp1 + " to be cleaned up but it wasn't");
+      FileUtil.cleanupIndexOp(tmpPath2, fs, new ArrayList<>());
+      assertFalse(tmp2.exists(), "Expected " + tmp2 + " to be cleaned up but it wasn't");
+    }
   }
 }
