@@ -31,15 +31,19 @@ import java.util.List;
 import java.util.Map;
 import java.util.concurrent.ArrayBlockingQueue;
 import java.util.concurrent.BlockingQueue;
+import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.ExecutionException;
 import java.util.concurrent.ExecutorService;
 import java.util.concurrent.Future;
 import java.util.concurrent.ScheduledThreadPoolExecutor;
 import java.util.concurrent.TimeUnit;
-import java.util.stream.Collectors;
 
+import org.apache.accumulo.core.client.BatchWriter;
+import org.apache.accumulo.core.client.MutationsRejectedException;
+import org.apache.accumulo.core.client.TableNotFoundException;
 import org.apache.accumulo.core.conf.Property;
 import org.apache.accumulo.core.dataImpl.KeyExtent;
+import org.apache.accumulo.core.metadata.schema.Ample;
 import org.apache.accumulo.core.metadata.schema.ExternalCompactionFinalState;
 import org.apache.accumulo.core.metadata.schema.ExternalCompactionFinalState.FinalState;
 import org.apache.accumulo.core.metadata.schema.ExternalCompactionId;
@@ -52,6 +56,7 @@ import org.apache.accumulo.core.rpc.ThriftUtil;
 import org.apache.accumulo.core.rpc.clients.ThriftClientTypes;
 import org.apache.accumulo.core.tabletserver.thrift.TabletClientService;
 import org.apache.accumulo.core.trace.TraceUtil;
+import org.apache.accumulo.core.util.Timer;
 import org.apache.accumulo.core.util.threads.ThreadPools;
 import org.apache.accumulo.server.ServerContext;
 import org.apache.thrift.TException;
@@ -63,21 +68,27 @@ public class CompactionFinalizer {
   private static final Logger LOG = LoggerFactory.getLogger(CompactionFinalizer.class);
 
   protected final ServerContext context;
-  private final ExecutorService ntfyExecutor;
+  private final ExecutorService notifyExecutor;
   private final ExecutorService backgroundExecutor;
   private final BlockingQueue<ExternalCompactionFinalState> pendingNotifications;
   private final long tserverCheckInterval;
+  private final ConcurrentHashMap<Character,SharedBatchWriter> writers =
+      new ConcurrentHashMap<>(16);
+  private final int queueSize;
 
   protected CompactionFinalizer(ServerContext context, ScheduledThreadPoolExecutor schedExecutor) {
     this.context = context;
-    this.pendingNotifications = new ArrayBlockingQueue<>(1000);
+    queueSize =
+        context.getConfiguration().getCount(Property.COMPACTION_COORDINATOR_FINALIZER_QUEUE_SIZE);
+
+    this.pendingNotifications = new ArrayBlockingQueue<>(queueSize);
 
     tserverCheckInterval = this.context.getConfiguration()
         .getTimeInMillis(Property.COMPACTION_COORDINATOR_FINALIZER_COMPLETION_CHECK_INTERVAL);
     int max = this.context.getConfiguration()
         .getCount(Property.COMPACTION_COORDINATOR_FINALIZER_TSERVER_NOTIFIER_MAXTHREADS);
 
-    this.ntfyExecutor = ThreadPools.getServerThreadPools()
+    this.notifyExecutor = ThreadPools.getServerThreadPools()
         .getPoolBuilder(COORDINATOR_FINALIZER_NOTIFIER_POOL).numCoreThreads(3).numMaxThreads(max)
         .withTimeOut(1L, MINUTES).enableThreadPoolMetrics().build();
 
@@ -91,6 +102,13 @@ public class CompactionFinalizer {
 
     ThreadPools.watchCriticalScheduledTask(schedExecutor.scheduleWithFixedDelay(
         this::notifyTservers, 0, tserverCheckInterval, TimeUnit.MILLISECONDS));
+
+  }
+
+  private SharedBatchWriter getWriter(ExternalCompactionId ecid) {
+    return writers.computeIfAbsent(ecid.getFirstUUIDChar(),
+        (prefix) -> new SharedBatchWriter(Ample.DataLevel.USER.metaTable(), prefix, context,
+            queueSize / 16));
   }
 
   public void commitCompaction(ExternalCompactionId ecid, KeyExtent extent, long fileSize,
@@ -99,41 +117,63 @@ public class CompactionFinalizer {
     var ecfs =
         new ExternalCompactionFinalState(ecid, extent, FinalState.FINISHED, fileSize, fileEntries);
 
-    LOG.debug("Initiating commit for external compaction: {}", ecfs);
+    SharedBatchWriter writer = getWriter(ecid);
+
+    LOG.trace("Initiating commit for external compaction: {} {}", ecid, ecfs);
 
     // write metadata entry
-    context.getAmple().putExternalCompactionFinalStates(List.of(ecfs));
+    Timer timer = Timer.startNew();
+    writer.write(ecfs.toMutation());
+    LOG.trace("{} metadata compaction state write completed in {}ms", ecid,
+        timer.elapsed(TimeUnit.MILLISECONDS));
 
     if (!pendingNotifications.offer(ecfs)) {
-      LOG.debug("Queue full, notification to tablet server will happen later {}.", ecfs);
+      LOG.trace("Queue full, notification to tablet server will happen later {}.", ecid);
     } else {
-      LOG.debug("Queued tserver notification for completed external compaction: {}", ecfs);
+      LOG.trace("Queued tserver notification for completed external compaction: {}", ecid);
     }
   }
 
   public void failCompactions(Map<ExternalCompactionId,KeyExtent> compactionsToFail) {
+    if (compactionsToFail.size() == 1) {
+      var e = compactionsToFail.entrySet().iterator().next();
+      var ecfs =
+          new ExternalCompactionFinalState(e.getKey(), e.getValue(), FinalState.FAILED, 0L, 0L);
+      getWriter(e.getKey()).write(ecfs.toMutation());
+    } else {
+      try (BatchWriter writer = context.createBatchWriter(Ample.DataLevel.USER.metaTable())) {
+        for (var e : compactionsToFail.entrySet()) {
+          var ecfs =
+              new ExternalCompactionFinalState(e.getKey(), e.getValue(), FinalState.FAILED, 0L, 0L);
+          writer.addMutation(ecfs.toMutation());
+        }
+      } catch (MutationsRejectedException | TableNotFoundException e) {
+        throw new RuntimeException(e);
+      }
+    }
 
-    var finalStates = compactionsToFail.entrySet().stream().map(
-        e -> new ExternalCompactionFinalState(e.getKey(), e.getValue(), FinalState.FAILED, 0L, 0L))
-        .collect(Collectors.toList());
-
-    context.getAmple().putExternalCompactionFinalStates(finalStates);
-
-    finalStates.forEach(pendingNotifications::offer);
+    for (var e : compactionsToFail.entrySet()) {
+      var ecfs =
+          new ExternalCompactionFinalState(e.getKey(), e.getValue(), FinalState.FAILED, 0L, 0L);
+      if (!pendingNotifications.offer(ecfs)) {
+        break;
+      }
+    }
   }
 
   private void notifyTserver(Location loc, ExternalCompactionFinalState ecfs) {
 
     TabletClientService.Client client = null;
+    Timer timer = Timer.startNew();
     try {
       client = ThriftUtil.getClient(ThriftClientTypes.TABLET_SERVER, loc.getHostAndPort(), context);
       if (ecfs.getFinalState() == FinalState.FINISHED) {
-        LOG.debug("Notifying tserver {} that compaction {} has finished.", loc, ecfs);
+        LOG.trace("Notifying tserver {} that compaction {} has finished.", loc, ecfs);
         client.compactionJobFinished(TraceUtil.traceInfo(), context.rpcCreds(),
             ecfs.getExternalCompactionId().canonical(), ecfs.getExtent().toThrift(),
             ecfs.getFileSize(), ecfs.getEntries());
       } else if (ecfs.getFinalState() == FinalState.FAILED) {
-        LOG.debug("Notifying tserver {} that compaction {} with {} has failed.", loc,
+        LOG.trace("Notifying tserver {} that compaction {} with {} has failed.", loc,
             ecfs.getExternalCompactionId(), ecfs);
         client.compactionJobFailed(TraceUtil.traceInfo(), context.rpcCreds(),
             ecfs.getExternalCompactionId().canonical(), ecfs.getExtent().toThrift());
@@ -145,6 +185,8 @@ public class CompactionFinalizer {
     } finally {
       ThriftUtil.returnClient(client, context);
     }
+    LOG.trace("Tserver {} notification of {} {} took {}ms", loc, ecfs.getExternalCompactionId(),
+        ecfs, timer.elapsed(TimeUnit.MILLISECONDS));
   }
 
   private void processPending() {
@@ -155,23 +197,28 @@ public class CompactionFinalizer {
         batch.add(pendingNotifications.take());
         pendingNotifications.drainTo(batch);
 
+        LOG.trace("Processing pending of batch size {}", batch.size());
+
         List<Future<?>> futures = new ArrayList<>();
 
         List<ExternalCompactionId> statusesToDelete = new ArrayList<>();
 
         Map<KeyExtent,TabletMetadata> tabletsMetadata;
         var extents = batch.stream().map(ExternalCompactionFinalState::getExtent).collect(toList());
+        Timer timer = Timer.startNew();
         try (TabletsMetadata tablets = context.getAmple().readTablets().forTablets(extents)
             .fetch(ColumnType.LOCATION, ColumnType.PREV_ROW, ColumnType.ECOMP).build()) {
           tabletsMetadata = tablets.stream().collect(toMap(TabletMetadata::getExtent, identity()));
         }
+        LOG.trace("Metadata scan completed in {}ms for batch size {}, found {}",
+            timer.elapsed(TimeUnit.MILLISECONDS), batch.size(), tabletsMetadata.size());
 
         for (ExternalCompactionFinalState ecfs : batch) {
 
           TabletMetadata tabletMetadata = tabletsMetadata.get(ecfs.getExtent());
 
-          if (tabletMetadata == null || !tabletMetadata.getExternalCompactions().keySet()
-              .contains(ecfs.getExternalCompactionId())) {
+          if (tabletMetadata == null || !tabletMetadata.getExternalCompactions()
+              .containsKey(ecfs.getExternalCompactionId())) {
             // there is not per tablet external compaction entry, so delete its final state marker
             // from metadata table
             LOG.debug(
@@ -180,8 +227,8 @@ public class CompactionFinalizer {
             statusesToDelete.add(ecfs.getExternalCompactionId());
           } else if (tabletMetadata.getLocation() != null
               && tabletMetadata.getLocation().getType() == LocationType.CURRENT) {
-            futures
-                .add(ntfyExecutor.submit(() -> notifyTserver(tabletMetadata.getLocation(), ecfs)));
+            futures.add(
+                notifyExecutor.submit(() -> notifyTserver(tabletMetadata.getLocation(), ecfs)));
           } else {
             LOG.trace(
                 "External compaction {} is completed, but there is no location for tablet.  Unable to notify tablet, will try again later.",
@@ -190,12 +237,18 @@ public class CompactionFinalizer {
         }
 
         if (!statusesToDelete.isEmpty()) {
-          LOG.info(
-              "Deleting unresolvable completed external compactions from metadata table, ids: {}",
-              statusesToDelete);
+          timer.restart();
           context.getAmple().deleteExternalCompactionFinalStates(statusesToDelete);
+          LOG.info(
+              "Deleted unresolvable completed external compactions from metadata table, ids: {} in {}ms",
+              statusesToDelete.size(), timer.elapsed(TimeUnit.MILLISECONDS));
+          for (var ecid : statusesToDelete) {
+            LOG.debug("Deleted unresolvable completed external compaction {}", ecid);
+          }
         }
 
+        long waitStart = System.currentTimeMillis();
+        LOG.trace("Waiting for notify messages to complete");
         for (Future<?> future : futures) {
           try {
             future.get();
@@ -203,6 +256,7 @@ public class CompactionFinalizer {
             LOG.debug("Failed to notify tserver", e);
           }
         }
+        LOG.trace("Notify messages completed in {}ms", (System.currentTimeMillis() - waitStart));
 
       } catch (InterruptedException e) {
         Thread.currentThread().interrupt();
@@ -214,15 +268,19 @@ public class CompactionFinalizer {
   }
 
   private void notifyTservers() {
-    try {
-      Iterator<ExternalCompactionFinalState> finalStates =
-          context.getAmple().getExternalCompactionFinalStates().iterator();
+    Timer timer = Timer.startNew();
+    try (var finalStatesStream = context.getAmple().getExternalCompactionFinalStates()) {
+      int count = 0;
+      Iterator<ExternalCompactionFinalState> finalStates = finalStatesStream.iterator();
       while (finalStates.hasNext()) {
         ExternalCompactionFinalState state = finalStates.next();
-        LOG.debug("Found external compaction in final state: {}, queueing for tserver notification",
+        count++;
+        LOG.trace("Found external compaction in final state: {}, queueing for tserver notification",
             state);
         pendingNotifications.put(state);
       }
+      LOG.trace("Added {} final compaction states to notification queue in {}ms", count,
+          timer.elapsed(TimeUnit.MILLISECONDS));
     } catch (InterruptedException e) {
       Thread.currentThread().interrupt();
       throw new RuntimeException(e);
