@@ -19,7 +19,6 @@
 package org.apache.accumulo.compactor;
 
 import static java.nio.charset.StandardCharsets.UTF_8;
-import static java.util.concurrent.TimeUnit.MINUTES;
 import static org.apache.accumulo.core.util.UtilWaitThread.sleepUninterruptibly;
 
 import java.io.IOException;
@@ -28,8 +27,11 @@ import java.net.UnknownHostException;
 import java.security.SecureRandom;
 import java.time.Duration;
 import java.util.ArrayList;
+import java.util.Collection;
+import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
+import java.util.Set;
 import java.util.TreeMap;
 import java.util.UUID;
 import java.util.concurrent.CountDownLatch;
@@ -37,6 +39,7 @@ import java.util.concurrent.ScheduledFuture;
 import java.util.concurrent.ScheduledThreadPoolExecutor;
 import java.util.concurrent.TimeUnit;
 import java.util.concurrent.atomic.AtomicBoolean;
+import java.util.concurrent.atomic.AtomicLong;
 import java.util.concurrent.atomic.AtomicReference;
 import java.util.concurrent.atomic.LongAdder;
 import java.util.function.Supplier;
@@ -60,12 +63,13 @@ import org.apache.accumulo.core.compaction.thrift.UnknownCompactionIdException;
 import org.apache.accumulo.core.conf.AccumuloConfiguration;
 import org.apache.accumulo.core.conf.ConfigurationCopy;
 import org.apache.accumulo.core.conf.Property;
+import org.apache.accumulo.core.conf.cluster.ClusterConfigParser;
 import org.apache.accumulo.core.data.NamespaceId;
 import org.apache.accumulo.core.data.TableId;
 import org.apache.accumulo.core.dataImpl.KeyExtent;
 import org.apache.accumulo.core.fate.zookeeper.ServiceLock;
-import org.apache.accumulo.core.fate.zookeeper.ServiceLock.LockLossReason;
 import org.apache.accumulo.core.fate.zookeeper.ServiceLock.LockWatcher;
+import org.apache.accumulo.core.fate.zookeeper.ServiceLockSupport.ServiceLockWatcher;
 import org.apache.accumulo.core.fate.zookeeper.ZooReaderWriter;
 import org.apache.accumulo.core.fate.zookeeper.ZooUtil.NodeExistsPolicy;
 import org.apache.accumulo.core.file.FileOperations;
@@ -79,6 +83,7 @@ import org.apache.accumulo.core.metadata.schema.TabletMetadata;
 import org.apache.accumulo.core.metadata.schema.TabletMetadata.ColumnType;
 import org.apache.accumulo.core.metrics.MetricsInfo;
 import org.apache.accumulo.core.metrics.MetricsProducer;
+import org.apache.accumulo.core.process.thrift.ServerProcessService;
 import org.apache.accumulo.core.rpc.ThriftUtil;
 import org.apache.accumulo.core.rpc.clients.ThriftClientTypes;
 import org.apache.accumulo.core.securityImpl.thrift.TCredentials;
@@ -89,7 +94,6 @@ import org.apache.accumulo.core.tabletserver.thrift.TCompactionStats;
 import org.apache.accumulo.core.tabletserver.thrift.TExternalCompactionJob;
 import org.apache.accumulo.core.trace.TraceUtil;
 import org.apache.accumulo.core.trace.thrift.TInfo;
-import org.apache.accumulo.core.util.Halt;
 import org.apache.accumulo.core.util.HostAndPort;
 import org.apache.accumulo.core.util.ServerServices;
 import org.apache.accumulo.core.util.ServerServices.Service;
@@ -122,10 +126,13 @@ import com.beust.jcommander.Parameter;
 import com.google.common.base.Preconditions;
 
 import io.micrometer.core.instrument.FunctionCounter;
+import io.micrometer.core.instrument.Gauge;
 import io.micrometer.core.instrument.LongTaskTimer;
 import io.micrometer.core.instrument.MeterRegistry;
+import io.micrometer.core.instrument.Tag;
 
-public class Compactor extends AbstractServer implements MetricsProducer, CompactorService.Iface {
+public class Compactor extends AbstractServer
+    implements MetricsProducer, CompactorService.Iface, ServerProcessService.Iface {
 
   public interface FileCompactorRunnable extends Runnable {
     /**
@@ -141,6 +148,51 @@ public class Compactor extends AbstractServer implements MetricsProducer, Compac
 
   private static final SecureRandom random = new SecureRandom();
 
+  private static class ConsecutiveErrorHistory extends HashMap<TableId,HashMap<String,AtomicLong>> {
+
+    private static final long serialVersionUID = 1L;
+
+    public long getTotalFailures() {
+      long total = 0;
+      for (TableId tid : keySet()) {
+        total += getTotalTableFailures(tid);
+      }
+      return total;
+    }
+
+    public long getTotalTableFailures(TableId tid) {
+      long total = 0;
+      for (AtomicLong failures : get(tid).values()) {
+        total += failures.get();
+      }
+      return total;
+    }
+
+    /**
+     * Add error for table
+     *
+     * @param tid table id
+     * @param error exception
+     */
+    public void addError(TableId tid, Throwable error) {
+      computeIfAbsent(tid, t -> new HashMap<String,AtomicLong>())
+          .computeIfAbsent(error.toString(), e -> new AtomicLong(0)).incrementAndGet();
+    }
+
+    @Override
+    public String toString() {
+      StringBuilder buf = new StringBuilder();
+      for (TableId tid : keySet()) {
+        buf.append("\nTable: ").append(tid);
+        for (Entry<String,AtomicLong> error : get(tid).entrySet()) {
+          buf.append("\n\tException: ").append(error.getKey()).append(", count: ")
+              .append(error.getValue().get());
+        }
+      }
+      return buf.toString();
+    }
+  }
+
   public static class CompactorServerOpts extends ServerOpts {
     @Parameter(required = true, names = {"-q", "--queue"}, description = "compaction queue name")
     private String queueName = null;
@@ -152,7 +204,6 @@ public class Compactor extends AbstractServer implements MetricsProducer, Compac
 
   private static final Logger LOG = LoggerFactory.getLogger(Compactor.class);
   private static final long TIME_BETWEEN_GC_CHECKS = 5000;
-  private static final long TIME_BETWEEN_CANCEL_CHECKS = MINUTES.toMillis(5);
 
   private static final long TEN_MEGABYTES = 10485760;
 
@@ -167,14 +218,17 @@ public class Compactor extends AbstractServer implements MetricsProducer, Compac
   private ServiceLock compactorLock;
   private ServerAddress compactorAddress = null;
 
-  // Exposed for tests
-  protected volatile boolean shutdown = false;
-
   private final AtomicBoolean compactionRunning = new AtomicBoolean(false);
+  private final ConsecutiveErrorHistory errorHistory = new ConsecutiveErrorHistory();
+  private final AtomicLong completed = new AtomicLong(0);
+  private final AtomicLong cancelled = new AtomicLong(0);
+  private final AtomicLong failed = new AtomicLong(0);
+  private final AtomicLong terminated = new AtomicLong(0);
 
   protected Compactor(CompactorServerOpts opts, String[] args) {
     super("compactor", opts, args);
     queueName = opts.getQueueName();
+    ClusterConfigParser.validateGroupNames(Set.of(queueName));
   }
 
   private long getTotalEntriesRead() {
@@ -185,6 +239,26 @@ public class Compactor extends AbstractServer implements MetricsProducer, Compac
     return FileCompactor.getTotalEntriesWritten();
   }
 
+  private double getConsecutiveFailures() {
+    return errorHistory.getTotalFailures();
+  }
+
+  private double getCancellations() {
+    return cancelled.get();
+  }
+
+  private double getCompletions() {
+    return completed.get();
+  }
+
+  private double getFailures() {
+    return failed.get();
+  }
+
+  private double getTerminated() {
+    return terminated.get();
+  }
+
   @Override
   public void registerMetrics(MeterRegistry registry) {
     super.registerMetrics(registry);
@@ -195,6 +269,22 @@ public class Compactor extends AbstractServer implements MetricsProducer, Compac
         .builder(METRICS_COMPACTOR_ENTRIES_WRITTEN, this, Compactor::getTotalEntriesWritten)
         .description("Number of entries written by all compactions that have run on this compactor")
         .register(registry);
+    FunctionCounter
+        .builder(METRICS_COMPACTOR_COMPACTIONS_CANCELLED, this, Compactor::getCancellations)
+        .description("Number compactions that have been cancelled on this compactor")
+        .register(registry);
+    FunctionCounter
+        .builder(METRICS_COMPACTOR_COMPACTIONS_COMPLETED, this, Compactor::getCompletions)
+        .description("Number compactions that have succeeded on this compactor").register(registry);
+    FunctionCounter.builder(METRICS_COMPACTOR_COMPACTIONS_FAILED, this, Compactor::getFailures)
+        .description("Number compactions that have failed on this compactor").register(registry);
+    FunctionCounter.builder(METRICS_COMPACTOR_FAILURES_TERMINATION, this, Compactor::getTerminated)
+        .description("Will report 1 if the Compactor terminates due to consecutive failure, else 0")
+        .register(registry);
+    Gauge.builder(METRICS_COMPACTOR_FAILURES_CONSECUTIVE, this, Compactor::getConsecutiveFailures)
+        .description(
+            "Number of consecutive compaction failures. Resets to zero on a successful compaction")
+        .register(registry);
     LongTaskTimer timer = LongTaskTimer.builder(METRICS_COMPACTOR_MAJC_STUCK)
         .description("Number and duration of stuck major compactions").register(registry);
     CompactionWatcher.setTimer(timer);
@@ -285,20 +375,9 @@ public class Compactor extends AbstractServer implements MetricsProducer, Compac
 
     compactorLock = new ServiceLock(getContext().getZooReaderWriter().getZooKeeper(),
         ServiceLock.path(zPath), compactorId);
-    LockWatcher lw = new LockWatcher() {
-      @Override
-      public void lostLock(final LockLossReason reason) {
-        Halt.halt(1, () -> {
-          LOG.error("Compactor lost lock (reason = {}), exiting.", reason);
-          gcLogger.logGCInfo(getConfiguration());
-        });
-      }
 
-      @Override
-      public void unableToMonitorLockNode(final Exception e) {
-        Halt.halt(1, () -> LOG.error("Lost ability to monitor Compactor lock, exiting.", e));
-      }
-    };
+    LockWatcher lw = new ServiceLockWatcher("compactor", () -> getShutdownComplete().get(),
+        (name) -> gcLogger.logGCInfo(getConfiguration()));
 
     try {
       byte[] lockContent =
@@ -329,11 +408,11 @@ public class Compactor extends AbstractServer implements MetricsProducer, Compac
    * @throws UnknownHostException host unknown
    */
   protected ServerAddress startCompactorClientService() throws UnknownHostException {
-    var processor = ThriftProcessorTypes.getCompactorTProcessor(this, getContext());
+    var processor = ThriftProcessorTypes.getCompactorTProcessor(this, this, getContext());
     @SuppressWarnings("deprecation")
     var maxMessageSizeProperty = getConfiguration().resolve(Property.RPC_MAX_MESSAGE_SIZE,
         Property.GENERAL_MAX_MESSAGE_SIZE);
-    ServerAddress sp = TServerUtils.startServer(getContext(), getHostname(),
+    ServerAddress sp = TServerUtils.startServer(getContext(), getBindAddress(),
         Property.COMPACTOR_CLIENTPORT, processor, this.getClass().getSimpleName(),
         "Thrift Client Server", Property.COMPACTOR_PORTSEARCH, Property.COMPACTOR_MINTHREADS,
         Property.COMPACTOR_MINTHREADS_TIMEOUT, Property.COMPACTOR_THREADCHECK,
@@ -389,6 +468,8 @@ public class Compactor extends AbstractServer implements MetricsProducer, Compac
         new RetryableThriftCall<>(1000, RetryableThriftCall.MAX_WAIT_TIME, 25, () -> {
           Client coordinatorClient = getCoordinatorClient();
           try {
+            LOG.trace("Attempting to update compaction state in coordinator {}",
+                job.getExternalCompactionId());
             coordinatorClient.updateCompactionStatus(TraceUtil.traceInfo(), getContext().rpcCreds(),
                 job.getExternalCompactionId(), update, System.currentTimeMillis());
             return "";
@@ -403,16 +484,17 @@ public class Compactor extends AbstractServer implements MetricsProducer, Compac
    * Notify the CompactionCoordinator the job failed
    *
    * @param job current compaction job
+   * @param exception cause of failure
    * @throws RetriesExceededException thrown when retries have been exceeded
    */
-  protected void updateCompactionFailed(TExternalCompactionJob job)
+  protected void updateCompactionFailed(TExternalCompactionJob job, Throwable exception)
       throws RetriesExceededException {
     RetryableThriftCall<String> thriftCall =
         new RetryableThriftCall<>(1000, RetryableThriftCall.MAX_WAIT_TIME, 25, () -> {
           Client coordinatorClient = getCoordinatorClient();
           try {
             coordinatorClient.compactionFailed(TraceUtil.traceInfo(), getContext().rpcCreds(),
-                job.getExternalCompactionId(), job.extent);
+                job.getExternalCompactionId(), job.extent, exception.getClass().getName());
             return "";
           } finally {
             ThriftUtil.returnClient(coordinatorClient, getContext());
@@ -669,6 +751,53 @@ public class Compactor extends AbstractServer implements MetricsProducer, Compac
     return sleepTime;
   }
 
+  protected Collection<Tag> getServiceTags(HostAndPort clientAddress) {
+    return MetricsInfo.serviceTags(getContext().getInstanceName(), getApplicationName(),
+        clientAddress, queueName);
+  }
+
+  private void performFailureProcessing(ConsecutiveErrorHistory errorHistory)
+      throws InterruptedException {
+    // consecutive failure processing
+    final long totalFailures = errorHistory.getTotalFailures();
+    if (totalFailures > 0) {
+      LOG.warn("This Compactor has had {} consecutive failures. Failures: {}", totalFailures,
+          errorHistory.toString()); // ErrorHistory.toString not invoked without .toString
+      final long failureThreshold =
+          getConfiguration().getCount(Property.COMPACTOR_FAILURE_TERMINATION_THRESHOLD);
+      if (failureThreshold > 0 && totalFailures >= failureThreshold) {
+        LOG.error(
+            "Consecutive failures ({}) has met or exceeded failure threshold ({}), exiting...",
+            totalFailures, failureThreshold);
+        terminated.incrementAndGet();
+        throw new InterruptedException(
+            "Consecutive failures has exceeded failure threshold, exiting...");
+      }
+      if (totalFailures
+          >= getConfiguration().getCount(Property.COMPACTOR_FAILURE_BACKOFF_THRESHOLD)) {
+        final long interval =
+            getConfiguration().getTimeInMillis(Property.COMPACTOR_FAILURE_BACKOFF_INTERVAL);
+        if (interval > 0) {
+          final long max =
+              getConfiguration().getTimeInMillis(Property.COMPACTOR_FAILURE_BACKOFF_RESET);
+          final long backoffMS = Math.min(max, interval * totalFailures);
+          LOG.warn(
+              "Not starting next compaction for {}ms due to consecutive failures. Check the log and address any issues.",
+              backoffMS);
+          if (backoffMS == max) {
+            errorHistory.clear();
+          }
+          Thread.sleep(backoffMS);
+        } else if (interval == 0) {
+          LOG.info(
+              "This Compactor has had {} consecutive failures and failure backoff is disabled.",
+              totalFailures);
+          errorHistory.clear();
+        }
+      }
+    }
+  }
+
   @Override
   public void run() {
 
@@ -677,7 +806,8 @@ public class Compactor extends AbstractServer implements MetricsProducer, Compac
     } catch (UnknownHostException e1) {
       throw new RuntimeException("Failed to start the compactor client service", e1);
     }
-    final HostAndPort clientAddress = compactorAddress.getAddress();
+    updateAdvertiseAddress(compactorAddress.getAddress());
+    final HostAndPort clientAddress = getAdvertiseAddress();
 
     try {
       announceExistence(clientAddress);
@@ -686,198 +816,211 @@ public class Compactor extends AbstractServer implements MetricsProducer, Compac
     }
 
     MetricsInfo metricsInfo = getContext().getMetricsInfo();
-    metricsInfo.addServiceTags(getApplicationName(), clientAddress);
 
     metricsInfo.addMetricsProducers(this);
-    metricsInfo.init();
+    metricsInfo.init(getServiceTags(clientAddress));
 
     var watcher = new CompactionWatcher(getConfiguration());
-    var schedExecutor = ThreadPools.getServerThreadPools()
-        .createGeneralScheduledExecutorService(getConfiguration());
+    var schedExecutor = getContext().getScheduledExecutor();
     startGCLogger(schedExecutor);
-    startCancelChecker(schedExecutor, TIME_BETWEEN_CANCEL_CHECKS);
+    startCancelChecker(schedExecutor,
+        getConfiguration().getTimeInMillis(Property.COMPACTOR_CANCEL_CHECK_INTERVAL));
 
     LOG.info("Compactor started, waiting for work");
     try {
 
       final AtomicReference<Throwable> err = new AtomicReference<>();
 
-      while (!shutdown) {
-
-        // mark compactor as idle while not in the compaction loop
-        updateIdleStatus(true);
-
-        currentCompactionId.set(null);
-        err.set(null);
-        JOB_HOLDER.reset();
-
-        TExternalCompactionJob job;
-        try {
-          TNextCompactionJob next = getNextJob(getNextId());
-          job = next.getJob();
-          if (!job.isSetExternalCompactionId()) {
-            LOG.trace("No external compactions in queue {}", this.queueName);
-            UtilWaitThread.sleep(getWaitTimeBetweenCompactionChecks(next.getCompactorCount()));
-            continue;
-          }
-          if (!job.getExternalCompactionId().equals(currentCompactionId.get().toString())) {
-            throw new IllegalStateException("Returned eci " + job.getExternalCompactionId()
-                + " does not match supplied eci " + currentCompactionId.get());
-          }
-        } catch (RetriesExceededException e2) {
-          LOG.warn("Retries exceeded getting next job. Retrying...");
-          continue;
+      while (!isShutdownRequested()) {
+        if (Thread.currentThread().isInterrupted()) {
+          LOG.info("Server process thread has been interrupted, shutting down");
+          break;
         }
-        LOG.debug("Received next compaction job: {}", job);
-
-        final LongAdder totalInputEntries = new LongAdder();
-        final LongAdder totalInputBytes = new LongAdder();
-        final CountDownLatch started = new CountDownLatch(1);
-        final CountDownLatch stopped = new CountDownLatch(1);
-
-        final FileCompactorRunnable fcr =
-            createCompactionJob(job, totalInputEntries, totalInputBytes, started, stopped, err);
-
-        final Thread compactionThread =
-            Threads.createThread("Compaction job for tablet " + job.getExtent().toString(), fcr);
-
-        JOB_HOLDER.set(job, compactionThread, fcr.getFileCompactor());
-
         try {
-          // mark compactor as busy while compacting
-          updateIdleStatus(false);
-
-          // Need to call FileCompactorRunnable.initialize after calling JOB_HOLDER.set
-          fcr.initialize();
-
-          compactionThread.start(); // start the compactionThread
-          started.await(); // wait until the compactor is started
-          final long inputEntries = totalInputEntries.sum();
-          final long waitTime = calculateProgressCheckTime(totalInputBytes.sum());
-          LOG.debug("Progress checks will occur every {} seconds", waitTime);
-          String percentComplete = "unknown";
-
-          while (!stopped.await(waitTime, TimeUnit.SECONDS)) {
-            List<CompactionInfo> running =
-                org.apache.accumulo.server.compaction.FileCompactor.getRunningCompactions();
-            if (!running.isEmpty()) {
-              // Compaction has started. There should only be one in the list
-              CompactionInfo info = running.get(0);
-              if (info != null) {
-                final long entriesRead = info.getEntriesRead();
-                final long entriesWritten = info.getEntriesWritten();
-                if (inputEntries > 0) {
-                  percentComplete = Float.toString((entriesRead / (float) inputEntries) * 100);
-                }
-                String message = String.format(
-                    "Compaction in progress, read %d of %d input entries ( %s %s ), written %d entries",
-                    entriesRead, inputEntries, percentComplete, "%", entriesWritten);
-                watcher.run();
-                try {
-                  LOG.debug("Updating coordinator with compaction progress: {}.", message);
-                  TCompactionStatusUpdate update = new TCompactionStatusUpdate(
-                      TCompactionState.IN_PROGRESS, message, inputEntries, entriesRead,
-                      entriesWritten, fcr.getCompactionAge().toNanos());
-                  updateCompactionState(job, update);
-                } catch (RetriesExceededException e) {
-                  LOG.warn("Error updating coordinator with compaction progress, error: {}",
-                      e.getMessage());
-                }
-              }
-            } else {
-              LOG.debug("Waiting on compaction thread to finish, but no RUNNING compaction");
-            }
-          }
-          compactionThread.join();
-          LOG.trace("Compaction thread finished.");
-          // Run the watcher again to clear out the finished compaction and set the
-          // stuck count to zero.
-          watcher.run();
-
-          if (err.get() != null) {
-            // maybe the error occured because the table was deleted or something like that, so
-            // force a cancel check to possibly reduce noise in the logs
-            checkIfCanceled();
-          }
-
-          if (compactionThread.isInterrupted() || JOB_HOLDER.isCancelled()
-              || (err.get() != null && err.get().getClass().equals(InterruptedException.class))) {
-            LOG.warn("Compaction thread was interrupted, sending CANCELLED state");
-            try {
-              TCompactionStatusUpdate update =
-                  new TCompactionStatusUpdate(TCompactionState.CANCELLED, "Compaction cancelled",
-                      -1, -1, -1, fcr.getCompactionAge().toNanos());
-              updateCompactionState(job, update);
-              updateCompactionFailed(job);
-            } catch (RetriesExceededException e) {
-              LOG.error("Error updating coordinator with compaction cancellation.", e);
-            } finally {
-              currentCompactionId.set(null);
-            }
-          } else if (err.get() != null) {
-            KeyExtent fromThriftExtent = KeyExtent.fromThrift(job.getExtent());
-            try {
-              LOG.info("Updating coordinator with compaction failure: id: {}, extent: {}",
-                  job.getExternalCompactionId(), fromThriftExtent);
-              TCompactionStatusUpdate update = new TCompactionStatusUpdate(TCompactionState.FAILED,
-                  "Compaction failed due to: " + err.get().getMessage(), -1, -1, -1,
-                  fcr.getCompactionAge().toNanos());
-              updateCompactionState(job, update);
-              updateCompactionFailed(job);
-            } catch (RetriesExceededException e) {
-              LOG.error("Error updating coordinator with compaction failure: id: {}, extent: {}",
-                  job.getExternalCompactionId(), fromThriftExtent, e);
-            } finally {
-              currentCompactionId.set(null);
-            }
-          } else {
-            try {
-              LOG.trace("Updating coordinator with compaction completion.");
-              updateCompactionCompleted(job, JOB_HOLDER.getStats());
-            } catch (RetriesExceededException e) {
-              LOG.error(
-                  "Error updating coordinator with compaction completion, cancelling compaction.",
-                  e);
-              try {
-                cancel(job.getExternalCompactionId());
-              } catch (TException e1) {
-                LOG.error("Error cancelling compaction.", e1);
-              }
-            } finally {
-              currentCompactionId.set(null);
-            }
-          }
-        } catch (RuntimeException e1) {
-          LOG.error(
-              "Compactor thread was interrupted waiting for compaction to start, cancelling job",
-              e1);
-          try {
-            cancel(job.getExternalCompactionId());
-          } catch (TException e2) {
-            LOG.error("Error cancelling compaction.", e2);
-          }
-        } finally {
-          currentCompactionId.set(null);
-
-          // mark compactor as idle after compaction completes
+          // mark compactor as idle while not in the compaction loop
           updateIdleStatus(true);
 
-          // In the case where there is an error in the foreground code the background compaction
-          // may still be running. Must cancel it before starting another iteration of the loop to
-          // avoid multiple threads updating shared state.
-          while (compactionThread.isAlive()) {
-            compactionThread.interrupt();
-            compactionThread.join(1000);
+          currentCompactionId.set(null);
+          err.set(null);
+          JOB_HOLDER.reset();
+
+          performFailureProcessing(errorHistory);
+
+          TExternalCompactionJob job;
+          try {
+            TNextCompactionJob next = getNextJob(getNextId());
+            job = next.getJob();
+            if (!job.isSetExternalCompactionId()) {
+              LOG.trace("No external compactions in queue {}", this.queueName);
+              UtilWaitThread.sleep(getWaitTimeBetweenCompactionChecks(next.getCompactorCount()));
+              continue;
+            }
+            if (!job.getExternalCompactionId().equals(currentCompactionId.get().toString())) {
+              throw new IllegalStateException("Returned eci " + job.getExternalCompactionId()
+                  + " does not match supplied eci " + currentCompactionId.get());
+            }
+          } catch (RetriesExceededException e2) {
+            LOG.warn("Retries exceeded getting next job. Retrying...");
+            continue;
           }
+          LOG.debug("Received next compaction job: {}", job);
+
+          final LongAdder totalInputEntries = new LongAdder();
+          final LongAdder totalInputBytes = new LongAdder();
+          final CountDownLatch started = new CountDownLatch(1);
+          final CountDownLatch stopped = new CountDownLatch(1);
+
+          final FileCompactorRunnable fcr =
+              createCompactionJob(job, totalInputEntries, totalInputBytes, started, stopped, err);
+
+          final Thread compactionThread = Threads.createNonCriticalThread(
+              "Compaction job for tablet " + job.getExtent().toString(), fcr);
+
+          JOB_HOLDER.set(job, compactionThread, fcr.getFileCompactor());
+
+          try {
+            // mark compactor as busy while compacting
+            updateIdleStatus(false);
+
+            // Need to call FileCompactorRunnable.initialize after calling JOB_HOLDER.set
+            fcr.initialize();
+
+            compactionThread.start(); // start the compactionThread
+            started.await(); // wait until the compactor is started
+            final long inputEntries = totalInputEntries.sum();
+            final long waitTime = calculateProgressCheckTime(totalInputBytes.sum());
+            LOG.debug("Progress checks will occur every {} seconds", waitTime);
+            String percentComplete = "unknown";
+
+            while (!stopped.await(waitTime, TimeUnit.SECONDS)) {
+              List<CompactionInfo> running =
+                  org.apache.accumulo.server.compaction.FileCompactor.getRunningCompactions();
+              if (!running.isEmpty()) {
+                // Compaction has started. There should only be one in the list
+                CompactionInfo info = running.get(0);
+                if (info != null) {
+                  final long entriesRead = info.getEntriesRead();
+                  final long entriesWritten = info.getEntriesWritten();
+                  if (inputEntries > 0) {
+                    percentComplete = Float.toString((entriesRead / (float) inputEntries) * 100);
+                  }
+                  String message = String.format(
+                      "Compaction in progress, read %d of %d input entries ( %s %s ), written %d entries",
+                      entriesRead, inputEntries, percentComplete, "%", entriesWritten);
+                  watcher.run();
+                  try {
+                    LOG.debug("Updating coordinator with compaction progress: {}.", message);
+                    TCompactionStatusUpdate update = new TCompactionStatusUpdate(
+                        TCompactionState.IN_PROGRESS, message, inputEntries, entriesRead,
+                        entriesWritten, fcr.getCompactionAge().toNanos());
+                    updateCompactionState(job, update);
+                  } catch (RetriesExceededException e) {
+                    LOG.warn("Error updating coordinator with compaction progress, error: {}",
+                        e.getMessage());
+                  }
+                }
+              } else {
+                LOG.debug("Waiting on compaction thread to finish, but no RUNNING compaction");
+              }
+            }
+            compactionThread.join();
+            LOG.trace("Compaction thread finished.");
+            // Run the watcher again to clear out the finished compaction and set the
+            // stuck count to zero.
+            watcher.run();
+
+            if (err.get() != null) {
+              // maybe the error occured because the table was deleted or something like that, so
+              // force a cancel check to possibly reduce noise in the logs
+              checkIfCanceled();
+            }
+
+            if (compactionThread.isInterrupted() || JOB_HOLDER.isCancelled()
+                || (err.get() != null && err.get().getClass().equals(InterruptedException.class))) {
+              LOG.warn("Compaction thread was interrupted, sending CANCELLED state");
+              try {
+                TCompactionStatusUpdate update =
+                    new TCompactionStatusUpdate(TCompactionState.CANCELLED, "Compaction cancelled",
+                        -1, -1, -1, fcr.getCompactionAge().toNanos());
+                updateCompactionState(job, update);
+                updateCompactionFailed(job, null);
+                cancelled.incrementAndGet();
+              } catch (RetriesExceededException e) {
+                LOG.error("Error updating coordinator with compaction cancellation.", e);
+              } finally {
+                currentCompactionId.set(null);
+              }
+            } else if (err.get() != null) {
+              final KeyExtent fromThriftExtent = KeyExtent.fromThrift(job.getExtent());
+              try {
+                LOG.info("Updating coordinator with compaction failure: id: {}, extent: {}",
+                    job.getExternalCompactionId(), fromThriftExtent);
+                TCompactionStatusUpdate update = new TCompactionStatusUpdate(
+                    TCompactionState.FAILED, "Compaction failed due to: " + err.get().getMessage(),
+                    -1, -1, -1, fcr.getCompactionAge().toNanos());
+                updateCompactionState(job, update);
+                updateCompactionFailed(job, err.get());
+                failed.incrementAndGet();
+                errorHistory.addError(fromThriftExtent.tableId(), err.get());
+              } catch (RetriesExceededException e) {
+                LOG.error("Error updating coordinator with compaction failure: id: {}, extent: {}",
+                    job.getExternalCompactionId(), fromThriftExtent, e);
+              } finally {
+                currentCompactionId.set(null);
+              }
+            } else {
+              try {
+                LOG.trace("Updating coordinator with compaction completion.");
+                updateCompactionCompleted(job, JOB_HOLDER.getStats());
+                completed.incrementAndGet();
+                // job completed successfully, clear the error history
+                errorHistory.clear();
+              } catch (RetriesExceededException e) {
+                LOG.error(
+                    "Error updating coordinator with compaction completion, cancelling compaction.",
+                    e);
+                try {
+                  cancel(job.getExternalCompactionId());
+                } catch (TException e1) {
+                  LOG.error("Error cancelling compaction.", e1);
+                }
+              } finally {
+                currentCompactionId.set(null);
+              }
+            }
+          } catch (RuntimeException e1) {
+            LOG.error(
+                "Compactor thread was interrupted waiting for compaction to start, cancelling job",
+                e1);
+            try {
+              cancel(job.getExternalCompactionId());
+            } catch (TException e2) {
+              LOG.error("Error cancelling compaction.", e2);
+            }
+          } finally {
+            currentCompactionId.set(null);
+
+            // mark compactor as idle after compaction completes
+            updateIdleStatus(true);
+
+            // In the case where there is an error in the foreground code the background compaction
+            // may still be running. Must cancel it before starting another iteration of the loop to
+            // avoid multiple threads updating shared state.
+            while (compactionThread.isAlive()) {
+              compactionThread.interrupt();
+              compactionThread.join(1000);
+            }
+          }
+        } catch (InterruptedException e) {
+          LOG.info("Interrupt Exception received, shutting down");
+          gracefulShutdown(getContext().rpcCreds());
         }
-
-      }
-
+      } // end while
     } catch (Exception e) {
       LOG.error("Unhandled error occurred in Compactor", e);
     } finally {
       // Shutdown local thrift server
-      LOG.info("Stopping Thrift Servers");
+      LOG.debug("Stopping Thrift Servers");
       if (compactorAddress.server != null) {
         compactorAddress.server.stop();
       }
@@ -893,6 +1036,8 @@ public class Compactor extends AbstractServer implements MetricsProducer, Compac
       }
 
       gcLogger.logGCInfo(getConfiguration());
+      super.close();
+      getShutdownComplete().set(true);
       LOG.info("stop requested. exiting ... ");
       try {
         if (null != compactorLock) {
@@ -982,4 +1127,10 @@ public class Compactor extends AbstractServer implements MetricsProducer, Compac
       return eci.canonical();
     }
   }
+
+  @Override
+  public ServiceLock getLock() {
+    return compactorLock;
+  }
+
 }
