@@ -18,6 +18,7 @@
  */
 package org.apache.accumulo.compactor;
 
+import static java.nio.charset.StandardCharsets.UTF_8;
 import static org.easymock.EasyMock.expect;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
@@ -25,11 +26,14 @@ import static org.junit.Assert.assertTrue;
 
 import java.net.UnknownHostException;
 import java.time.Duration;
+import java.util.Collection;
+import java.util.List;
 import java.util.Timer;
 import java.util.TimerTask;
 import java.util.UUID;
 import java.util.concurrent.CountDownLatch;
 import java.util.concurrent.ScheduledThreadPoolExecutor;
+import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.concurrent.atomic.AtomicReference;
 import java.util.concurrent.atomic.LongAdder;
 import java.util.function.Supplier;
@@ -47,6 +51,8 @@ import org.apache.accumulo.core.dataImpl.thrift.TKeyExtent;
 import org.apache.accumulo.core.fate.zookeeper.ZooReaderWriter;
 import org.apache.accumulo.core.metadata.schema.ExternalCompactionId;
 import org.apache.accumulo.core.metrics.MetricsInfo;
+import org.apache.accumulo.core.process.thrift.ServerProcessService;
+import org.apache.accumulo.core.securityImpl.thrift.TCredentials;
 import org.apache.accumulo.core.tabletserver.thrift.TCompactionStats;
 import org.apache.accumulo.core.tabletserver.thrift.TExternalCompactionJob;
 import org.apache.accumulo.core.util.Halt;
@@ -71,6 +77,8 @@ import org.powermock.modules.junit4.PowerMockRunner;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import io.micrometer.core.instrument.Tag;
+
 @RunWith(PowerMockRunner.class)
 @PrepareForTest({Compactor.class})
 @SuppressStaticInitializationFor({"org.apache.log4j.LogManager"})
@@ -178,7 +186,7 @@ public class CompactorTest {
 
   }
 
-  public class SuccessfulCompactor extends Compactor {
+  public class SuccessfulCompactor extends Compactor implements ServerProcessService.Iface {
 
     private final Logger LOG = LoggerFactory.getLogger(SuccessfulCompactor.class);
 
@@ -190,10 +198,12 @@ public class CompactorTest {
     private volatile boolean completedCalled = false;
     private volatile boolean failedCalled = false;
     private TCompactionStatusUpdate latestState = null;
+    private final AtomicBoolean shutdown = new AtomicBoolean(false);
+    private final AtomicBoolean shutdownComplete = new AtomicBoolean(false);
 
     SuccessfulCompactor(Supplier<UUID> uuid, ServerAddress address, TExternalCompactionJob job,
-        ServerContext context, ExternalCompactionId eci) {
-      super(new CompactorServerOpts(), new String[] {"-q", "testQ"});
+        ServerContext context, ExternalCompactionId eci, CompactorServerOpts compactorServerOpts) {
+      super(compactorServerOpts, new String[] {"-q", "testQ"});
       this.uuid = uuid;
       this.address = address;
       this.job = job;
@@ -222,10 +232,24 @@ public class CompactorTest {
     protected TNextCompactionJob getNextJob(Supplier<UUID> uuid) throws RetriesExceededException {
       LOG.info("Attempting to get next job, eci = {}", eci);
       currentCompactionId.set(eci);
-      this.shutdown = true;
+      gracefulShutdown(null);
       return new TNextCompactionJob(job, 1);
     }
 
+    @Override
+    public void gracefulShutdown(TCredentials creds) {
+      shutdown.set(true);
+    }
+
+    @Override
+    public boolean isShutdownRequested() {
+      return shutdown.get();
+    }
+
+    public AtomicBoolean getShutdownComplete() {
+      return shutdownComplete;
+    }
+
     @Override
     protected synchronized void checkIfCanceled() {}
 
@@ -248,7 +272,7 @@ public class CompactorTest {
     }
 
     @Override
-    protected void updateCompactionFailed(TExternalCompactionJob job)
+    protected void updateCompactionFailed(TExternalCompactionJob job, Throwable exception)
         throws RetriesExceededException {
       failedCalled = true;
     }
@@ -271,13 +295,22 @@ public class CompactorTest {
       return failedCalled;
     }
 
+    @Override
+    protected Collection<Tag> getServiceTags(HostAndPort clientAddress) {
+      return List.of();
+    }
+
+    @Override
+    protected void startCancelChecker(ScheduledThreadPoolExecutor schedExecutor,
+        long timeBetweenChecks) {}
+
   }
 
-  public class FailedCompactor extends SuccessfulCompactor {
+  public class FailedCompactor extends SuccessfulCompactor implements ServerProcessService.Iface {
 
     FailedCompactor(Supplier<UUID> uuid, ServerAddress address, TExternalCompactionJob job,
-        ServerContext context, ExternalCompactionId eci) {
-      super(uuid, address, job, context, eci);
+        ServerContext context, ExternalCompactionId eci, CompactorServerOpts compactorServerOpts) {
+      super(uuid, address, job, context, eci, compactorServerOpts);
     }
 
     @Override
@@ -288,11 +321,12 @@ public class CompactorTest {
     }
   }
 
-  public class InterruptedCompactor extends SuccessfulCompactor {
+  public class InterruptedCompactor extends SuccessfulCompactor
+      implements ServerProcessService.Iface {
 
     InterruptedCompactor(Supplier<UUID> uuid, ServerAddress address, TExternalCompactionJob job,
-        ServerContext context, ExternalCompactionId eci) {
-      super(uuid, address, job, context, eci);
+        ServerContext context, ExternalCompactionId eci, CompactorServerOpts compactorServerOpts) {
+      super(uuid, address, job, context, eci, compactorServerOpts);
     }
 
     @Override
@@ -334,7 +368,7 @@ public class CompactorTest {
     expect(job.isSetExternalCompactionId()).andReturn(true).anyTimes();
     expect(job.getExternalCompactionId()).andReturn(eci.toString()).anyTimes();
     expect(job.getExtent()).andReturn(extent).anyTimes();
-    expect(extent.getTable()).andReturn("testTable".getBytes()).anyTimes();
+    expect(extent.getTable()).andReturn("testTable".getBytes(UTF_8)).anyTimes();
 
     var conf = new ConfigurationCopy(DefaultConfiguration.getInstance());
     conf.set(Property.INSTANCE_ZK_TIMEOUT, "1d");
@@ -344,6 +378,10 @@ public class CompactorTest {
     MetricsInfo metricsInfo = PowerMock.createNiceMock(MetricsInfo.class);
     expect(context.getMetricsInfo()).andReturn(metricsInfo).anyTimes();
 
+    Compactor.CompactorServerOpts compactorServerOpts =
+        PowerMock.createNiceMock(Compactor.CompactorServerOpts.class);
+    expect(compactorServerOpts.getQueueName()).andReturn("testQ");
+
     ZooReaderWriter zrw = PowerMock.createNiceMock(ZooReaderWriter.class);
     ZooKeeper zk = PowerMock.createNiceMock(ZooKeeper.class);
     expect(context.getZooReaderWriter()).andReturn(zrw).anyTimes();
@@ -354,7 +392,8 @@ public class CompactorTest {
 
     PowerMock.replayAll();
 
-    SuccessfulCompactor c = new SuccessfulCompactor(supplier, client, job, context, eci);
+    SuccessfulCompactor c =
+        new SuccessfulCompactor(supplier, client, job, context, eci, compactorServerOpts);
     c.run();
 
     PowerMock.verifyAll();
@@ -395,6 +434,10 @@ public class CompactorTest {
     MetricsInfo metricsInfo = PowerMock.createNiceMock(MetricsInfo.class);
     expect(context.getMetricsInfo()).andReturn(metricsInfo).anyTimes();
 
+    Compactor.CompactorServerOpts compactorServerOpts =
+        PowerMock.createNiceMock(Compactor.CompactorServerOpts.class);
+    expect(compactorServerOpts.getQueueName()).andReturn("testQ");
+
     ZooReaderWriter zrw = PowerMock.createNiceMock(ZooReaderWriter.class);
     ZooKeeper zk = PowerMock.createNiceMock(ZooKeeper.class);
     expect(context.getZooReaderWriter()).andReturn(zrw).anyTimes();
@@ -405,7 +448,8 @@ public class CompactorTest {
 
     PowerMock.replayAll();
 
-    FailedCompactor c = new FailedCompactor(supplier, client, job, context, eci);
+    FailedCompactor c =
+        new FailedCompactor(supplier, client, job, context, eci, compactorServerOpts);
     c.run();
 
     PowerMock.verifyAll();
@@ -437,7 +481,7 @@ public class CompactorTest {
     expect(job.isSetExternalCompactionId()).andReturn(true).anyTimes();
     expect(job.getExternalCompactionId()).andReturn(eci.toString()).anyTimes();
     expect(job.getExtent()).andReturn(extent).anyTimes();
-    expect(extent.getTable()).andReturn("testTable".getBytes()).anyTimes();
+    expect(extent.getTable()).andReturn("testTable".getBytes(UTF_8)).anyTimes();
 
     var conf = new ConfigurationCopy(DefaultConfiguration.getInstance());
     conf.set(Property.INSTANCE_ZK_TIMEOUT, "1d");
@@ -447,6 +491,10 @@ public class CompactorTest {
     MetricsInfo metricsInfo = PowerMock.createNiceMock(MetricsInfo.class);
     expect(context.getMetricsInfo()).andReturn(metricsInfo).anyTimes();
 
+    Compactor.CompactorServerOpts compactorServerOpts =
+        PowerMock.createNiceMock(Compactor.CompactorServerOpts.class);
+    expect(compactorServerOpts.getQueueName()).andReturn("testQ");
+
     ZooReaderWriter zrw = PowerMock.createNiceMock(ZooReaderWriter.class);
     ZooKeeper zk = PowerMock.createNiceMock(ZooKeeper.class);
     expect(context.getZooReaderWriter()).andReturn(zrw).anyTimes();
@@ -457,7 +505,8 @@ public class CompactorTest {
 
     PowerMock.replayAll();
 
-    InterruptedCompactor c = new InterruptedCompactor(supplier, client, job, context, eci);
+    InterruptedCompactor c =
+        new InterruptedCompactor(supplier, client, job, context, eci, compactorServerOpts);
     c.run();
 
     PowerMock.verifyAll();
@@ -480,9 +529,13 @@ public class CompactorTest {
     ServerContext context = PowerMock.createNiceMock(ServerContext.class);
     expect(context.getConfiguration()).andReturn(conf).anyTimes();
 
+    Compactor.CompactorServerOpts compactorServerOpts =
+        PowerMock.createNiceMock(Compactor.CompactorServerOpts.class);
+    expect(compactorServerOpts.getQueueName()).andReturn("default");
+
     PowerMock.replayAll();
 
-    try (var c = new SuccessfulCompactor(null, null, null, context, null)) {
+    try (var c = new SuccessfulCompactor(null, null, null, context, null, compactorServerOpts)) {
       Long maxWait = c.getWaitTimeBetweenCompactionChecks(1);
       // compaction jitter means maxWait is between 0.9 and 1.1 of the desired value.
       assertTrue(maxWait >= 720L);
