@@ -32,8 +32,7 @@ import org.apache.accumulo.core.client.AccumuloClient;
 import org.apache.accumulo.core.conf.AccumuloConfiguration;
 import org.apache.accumulo.core.conf.Property;
 import org.apache.accumulo.core.fate.zookeeper.ServiceLock;
-import org.apache.accumulo.core.fate.zookeeper.ServiceLock.LockLossReason;
-import org.apache.accumulo.core.fate.zookeeper.ServiceLock.LockWatcher;
+import org.apache.accumulo.core.fate.zookeeper.ServiceLockSupport.HAServiceLockWatcher;
 import org.apache.accumulo.core.gc.thrift.GCMonitorService.Iface;
 import org.apache.accumulo.core.gc.thrift.GCStatus;
 import org.apache.accumulo.core.gc.thrift.GcCycleStats;
@@ -41,10 +40,10 @@ import org.apache.accumulo.core.metadata.MetadataTable;
 import org.apache.accumulo.core.metadata.RootTable;
 import org.apache.accumulo.core.metadata.schema.Ample.DataLevel;
 import org.apache.accumulo.core.metrics.MetricsInfo;
+import org.apache.accumulo.core.process.thrift.ServerProcessService;
 import org.apache.accumulo.core.securityImpl.thrift.TCredentials;
 import org.apache.accumulo.core.trace.TraceUtil;
 import org.apache.accumulo.core.trace.thrift.TInfo;
-import org.apache.accumulo.core.util.Halt;
 import org.apache.accumulo.core.util.HostAndPort;
 import org.apache.accumulo.core.util.ServerServices;
 import org.apache.accumulo.core.util.ServerServices.Service;
@@ -70,7 +69,8 @@ import io.opentelemetry.context.Scope;
 // Could/Should implement HighlyAvailableService but the Thrift server is already started before
 // the ZK lock is acquired. The server is only for metrics, there are no concerns about clients
 // using the service before the lock is acquired.
-public class SimpleGarbageCollector extends AbstractServer implements Iface {
+public class SimpleGarbageCollector extends AbstractServer
+    implements Iface, ServerProcessService.Iface {
 
   private static final Logger log = LoggerFactory.getLogger(SimpleGarbageCollector.class);
 
@@ -78,6 +78,7 @@ public class SimpleGarbageCollector extends AbstractServer implements Iface {
       new GCStatus(new GcCycleStats(), new GcCycleStats(), new GcCycleStats(), new GcCycleStats());
 
   private final GcCycleMetrics gcCycleMetrics = new GcCycleMetrics();
+  private ServiceLock gcLock;
 
   SimpleGarbageCollector(ServerOpts opts, String[] args) {
     super("gc", opts, args);
@@ -151,6 +152,14 @@ public class SimpleGarbageCollector extends AbstractServer implements Iface {
   @Override
   @SuppressFBWarnings(value = "DM_EXIT", justification = "main class can call System.exit")
   public void run() {
+
+    try {
+      waitForUpgrade();
+    } catch (InterruptedException e) {
+      LOG.error("Interrupted while waiting for upgrade to complete, exiting...");
+      System.exit(1);
+    }
+
     final VolumeManager fs = getContext().getVolumeManager();
 
     // Sleep for an initial period, giving the manager time to start up and
@@ -158,19 +167,20 @@ public class SimpleGarbageCollector extends AbstractServer implements Iface {
     log.info("Trying to acquire ZooKeeper lock for garbage collector");
 
     HostAndPort address = startStatsService();
+    updateAdvertiseAddress(address);
 
     try {
-      getZooLock(address);
+      getZooLock(getAdvertiseAddress());
     } catch (Exception ex) {
       log.error("{}", ex.getMessage(), ex);
       System.exit(1);
     }
 
     MetricsInfo metricsInfo = getContext().getMetricsInfo();
-    metricsInfo.addServiceTags(getApplicationName(), address);
 
     metricsInfo.addMetricsProducers(new GcMetrics(this));
-    metricsInfo.init();
+    metricsInfo.init(
+        MetricsInfo.serviceTags(getContext().getInstanceName(), getApplicationName(), address, ""));
     try {
       long delay = getStartDelay();
       log.debug("Sleeping for {} milliseconds before beginning garbage collection cycles", delay);
@@ -192,138 +202,157 @@ public class SimpleGarbageCollector extends AbstractServer implements Iface {
           }
         });
 
-    while (true) {
-      Span outerSpan = TraceUtil.startSpan(this.getClass(), "gc");
-      try (Scope outerScope = outerSpan.makeCurrent()) {
-        Span innerSpan = TraceUtil.startSpan(this.getClass(), "loop");
-        try (Scope innerScope = innerSpan.makeCurrent()) {
-          final long tStart = System.nanoTime();
-          try {
-            System.gc(); // make room
-
-            status.current.started = System.currentTimeMillis();
-            var rootGC = new GCRun(DataLevel.ROOT, getContext());
-            var mdGC = new GCRun(DataLevel.METADATA, getContext());
-            var userGC = new GCRun(DataLevel.USER, getContext());
-
-            log.info("Starting Root table Garbage Collection.");
-            status.current.bulks += new GarbageCollectionAlgorithm().collect(rootGC);
-            incrementStatsForRun(rootGC);
-            logStats();
-
-            log.info("Starting Metadata table Garbage Collection.");
-            status.current.bulks += new GarbageCollectionAlgorithm().collect(mdGC);
-            incrementStatsForRun(mdGC);
-            logStats();
-
-            log.info("Starting User table Garbage Collection.");
-            status.current.bulks += new GarbageCollectionAlgorithm().collect(userGC);
-            incrementStatsForRun(userGC);
-            logStats();
-
-          } catch (Exception e) {
-            TraceUtil.setException(innerSpan, e, false);
-            log.error("{}", e.getMessage(), e);
-          } finally {
-            status.current.finished = System.currentTimeMillis();
-            status.last = status.current;
-            gcCycleMetrics.setLastCollect(status.current);
-            status.current = new GcCycleStats();
-          }
-
-          final long tStop = System.nanoTime();
-          log.info(String.format("Collect cycle took %.2f seconds",
-              (TimeUnit.NANOSECONDS.toMillis(tStop - tStart) / 1000.0)));
-
-          /*
-           * We want to prune references to fully-replicated WALs from the replication table which
-           * are no longer referenced in the metadata table before running
-           * GarbageCollectWriteAheadLogs to ensure we delete as many files as possible.
-           */
-          Span replSpan = TraceUtil.startSpan(this.getClass(), "replicationClose");
-          try (Scope replScope = replSpan.makeCurrent()) {
-            @SuppressWarnings("deprecation")
-            Runnable closeWals =
-                new org.apache.accumulo.gc.replication.CloseWriteAheadLogReferences(getContext());
-            closeWals.run();
-          } catch (Exception e) {
-            TraceUtil.setException(replSpan, e, false);
-            log.error("Error trying to close write-ahead logs for replication table", e);
-          } finally {
-            replSpan.end();
-          }
-
-          // Clean up any unused write-ahead logs
-          Span walSpan = TraceUtil.startSpan(this.getClass(), "walogs");
-          try (Scope walScope = walSpan.makeCurrent()) {
-            GarbageCollectWriteAheadLogs walogCollector =
-                new GarbageCollectWriteAheadLogs(getContext(), fs, liveTServerSet, isUsingTrash());
-            log.info("Beginning garbage collection of write-ahead logs");
-            walogCollector.collect(status);
-            gcCycleMetrics.setLastWalCollect(status.lastLog);
-          } catch (Exception e) {
-            TraceUtil.setException(walSpan, e, false);
-            log.error("{}", e.getMessage(), e);
-          } finally {
-            walSpan.end();
-          }
-        } catch (Exception e) {
-          TraceUtil.setException(innerSpan, e, true);
-          throw e;
-        } finally {
-          innerSpan.end();
-        }
-
-        // we just made a lot of metadata changes: flush them out
-        try {
-          AccumuloClient accumuloClient = getContext();
-
-          final long actionStart = System.nanoTime();
-
-          String action = getConfiguration().get(Property.GC_USE_FULL_COMPACTION);
-          log.debug("gc post action {} started", action);
-
-          switch (action) {
-            case "compact":
-              accumuloClient.tableOperations().compact(MetadataTable.NAME, null, null, true, true);
-              accumuloClient.tableOperations().compact(RootTable.NAME, null, null, true, true);
-              break;
-            case "flush":
-              accumuloClient.tableOperations().flush(MetadataTable.NAME, null, null, true);
-              accumuloClient.tableOperations().flush(RootTable.NAME, null, null, true);
-              break;
-            default:
-              log.trace("'none - no action' or invalid value provided: {}", action);
-          }
-
-          final long actionComplete = System.nanoTime();
-
-          gcCycleMetrics.setPostOpDurationNanos(actionComplete - actionStart);
-
-          log.info("gc post action {} completed in {} seconds", action, String.format("%.2f",
-              (TimeUnit.NANOSECONDS.toMillis(actionComplete - actionStart) / 1000.0)));
-
-        } catch (Exception e) {
-          TraceUtil.setException(outerSpan, e, false);
-          log.warn("{}", e.getMessage(), e);
-        }
-      } catch (Exception e) {
-        TraceUtil.setException(outerSpan, e, true);
-        throw e;
-      } finally {
-        outerSpan.end();
+    while (!isShutdownRequested()) {
+      if (Thread.currentThread().isInterrupted()) {
+        LOG.info("Server process thread has been interrupted, shutting down");
+        break;
       }
       try {
+        Span outerSpan = TraceUtil.startSpan(this.getClass(), "gc");
+        try (Scope outerScope = outerSpan.makeCurrent()) {
+          Span innerSpan = TraceUtil.startSpan(this.getClass(), "loop");
+          try (Scope innerScope = innerSpan.makeCurrent()) {
+            final long tStart = System.nanoTime();
+            try {
+              System.gc(); // make room
 
-        gcCycleMetrics.incrementRunCycleCount();
-        long gcDelay = getConfiguration().getTimeInMillis(Property.GC_CYCLE_DELAY);
-        log.debug("Sleeping for {} milliseconds", gcDelay);
-        Thread.sleep(gcDelay);
+              status.current.started = System.currentTimeMillis();
+              var rootGC = new GCRun(DataLevel.ROOT, getContext());
+              var mdGC = new GCRun(DataLevel.METADATA, getContext());
+              var userGC = new GCRun(DataLevel.USER, getContext());
+
+              log.info("Starting Root table Garbage Collection.");
+              status.current.bulks += new GarbageCollectionAlgorithm().collect(rootGC);
+              incrementStatsForRun(rootGC);
+              logStats();
+
+              log.info("Starting Metadata table Garbage Collection.");
+              status.current.bulks += new GarbageCollectionAlgorithm().collect(mdGC);
+              incrementStatsForRun(mdGC);
+              logStats();
+
+              log.info("Starting User table Garbage Collection.");
+              status.current.bulks += new GarbageCollectionAlgorithm().collect(userGC);
+              incrementStatsForRun(userGC);
+              logStats();
+
+            } catch (Exception e) {
+              TraceUtil.setException(innerSpan, e, false);
+              log.error("{}", e.getMessage(), e);
+            } finally {
+              status.current.finished = System.currentTimeMillis();
+              status.last = status.current;
+              gcCycleMetrics.setLastCollect(status.current);
+              status.current = new GcCycleStats();
+            }
+
+            final long tStop = System.nanoTime();
+            log.info(String.format("Collect cycle took %.2f seconds",
+                (TimeUnit.NANOSECONDS.toMillis(tStop - tStart) / 1000.0)));
+
+            /*
+             * We want to prune references to fully-replicated WALs from the replication table which
+             * are no longer referenced in the metadata table before running
+             * GarbageCollectWriteAheadLogs to ensure we delete as many files as possible.
+             */
+            Span replSpan = TraceUtil.startSpan(this.getClass(), "replicationClose");
+            try (Scope replScope = replSpan.makeCurrent()) {
+              @SuppressWarnings("deprecation")
+              Runnable closeWals =
+                  new org.apache.accumulo.gc.replication.CloseWriteAheadLogReferences(getContext());
+              closeWals.run();
+            } catch (Exception e) {
+              TraceUtil.setException(replSpan, e, false);
+              log.error("Error trying to close write-ahead logs for replication table", e);
+            } finally {
+              replSpan.end();
+            }
+
+            // Clean up any unused write-ahead logs
+            Span walSpan = TraceUtil.startSpan(this.getClass(), "walogs");
+            try (Scope walScope = walSpan.makeCurrent()) {
+              GarbageCollectWriteAheadLogs walogCollector = new GarbageCollectWriteAheadLogs(
+                  getContext(), fs, liveTServerSet, isUsingTrash());
+              log.info("Beginning garbage collection of write-ahead logs");
+              walogCollector.collect(status);
+              gcCycleMetrics.setLastWalCollect(status.lastLog);
+            } catch (Exception e) {
+              TraceUtil.setException(walSpan, e, false);
+              log.error("{}", e.getMessage(), e);
+            } finally {
+              walSpan.end();
+            }
+          } catch (Exception e) {
+            TraceUtil.setException(innerSpan, e, true);
+            throw e;
+          } finally {
+            innerSpan.end();
+          }
+
+          // we just made a lot of metadata changes: flush them out
+          try {
+            AccumuloClient accumuloClient = getContext();
+
+            final long actionStart = System.nanoTime();
+
+            String action = getConfiguration().get(Property.GC_USE_FULL_COMPACTION);
+            log.debug("gc post action {} started", action);
+
+            switch (action) {
+              case "compact":
+                accumuloClient.tableOperations().compact(MetadataTable.NAME, null, null, true,
+                    true);
+                accumuloClient.tableOperations().compact(RootTable.NAME, null, null, true, true);
+                break;
+              case "flush":
+                accumuloClient.tableOperations().flush(MetadataTable.NAME, null, null, true);
+                accumuloClient.tableOperations().flush(RootTable.NAME, null, null, true);
+                break;
+              default:
+                log.trace("'none - no action' or invalid value provided: {}", action);
+            }
+
+            final long actionComplete = System.nanoTime();
+
+            gcCycleMetrics.setPostOpDurationNanos(actionComplete - actionStart);
+
+            log.info("gc post action {} completed in {} seconds", action, String.format("%.2f",
+                (TimeUnit.NANOSECONDS.toMillis(actionComplete - actionStart) / 1000.0)));
+
+          } catch (Exception e) {
+            TraceUtil.setException(outerSpan, e, false);
+            log.warn("{}", e.getMessage(), e);
+          }
+        } catch (Exception e) {
+          TraceUtil.setException(outerSpan, e, true);
+          throw e;
+        } finally {
+          outerSpan.end();
+        }
+        try {
+
+          gcCycleMetrics.incrementRunCycleCount();
+          long gcDelay = getConfiguration().getTimeInMillis(Property.GC_CYCLE_DELAY);
+          log.debug("Sleeping for {} milliseconds", gcDelay);
+          Thread.sleep(gcDelay);
+        } catch (InterruptedException e) {
+          log.warn("{}", e.getMessage(), e);
+          throw e;
+        }
       } catch (InterruptedException e) {
-        log.warn("{}", e.getMessage(), e);
-        return;
+        log.info("Interrupt Exception received, shutting down");
+        gracefulShutdown(getContext().rpcCreds());
       }
     }
+    super.close();
+    getShutdownComplete().set(true);
+    log.info("stop requested. exiting ... ");
+    try {
+      gcLock.unlock();
+    } catch (Exception e) {
+      log.warn("Failed to release GarbageCollector lock", e);
+    }
+
   }
 
   private void incrementStatsForRun(GCRun gcRun) {
@@ -364,38 +393,40 @@ public class SimpleGarbageCollector extends AbstractServer implements Iface {
   private void getZooLock(HostAndPort addr) throws KeeperException, InterruptedException {
     var path = ServiceLock.path(getContext().getZooKeeperRoot() + Constants.ZGC_LOCK);
 
-    LockWatcher lockWatcher = new LockWatcher() {
-      @Override
-      public void lostLock(LockLossReason reason) {
-        Halt.halt("GC lock in zookeeper lost (reason = " + reason + "), exiting!", 1);
-      }
-
-      @Override
-      public void unableToMonitorLockNode(final Exception e) {
-        // ACCUMULO-3651 Level changed to error and FATAL added to message for slf4j compatibility
-        Halt.halt(-1, () -> log.error("FATAL: No longer able to monitor lock node ", e));
-
-      }
-    };
-
     UUID zooLockUUID = UUID.randomUUID();
+    gcLock = new ServiceLock(getContext().getZooReaderWriter().getZooKeeper(), path, zooLockUUID);
+    HAServiceLockWatcher gcLockWatcher =
+        new HAServiceLockWatcher("gc", () -> getShutdownComplete().get());
+
     while (true) {
-      ServiceLock lock =
-          new ServiceLock(getContext().getZooReaderWriter().getZooKeeper(), path, zooLockUUID);
-      if (lock.tryLock(lockWatcher,
-          new ServerServices(addr.toString(), Service.GC_CLIENT).toString().getBytes(UTF_8))) {
-        log.debug("Got GC ZooKeeper lock");
-        return;
+      gcLock.lock(gcLockWatcher,
+          new ServerServices(addr.toString(), Service.GC_CLIENT).toString().getBytes(UTF_8));
+
+      gcLockWatcher.waitForChange();
+
+      if (gcLockWatcher.isLockAcquired()) {
+        break;
       }
+
+      if (!gcLockWatcher.isFailedToAcquireLock()) {
+        throw new IllegalStateException("gc lock in unknown state");
+      }
+
+      gcLock.tryToCancelAsyncLockOrUnlock();
+
       log.debug("Failed to get GC ZooKeeper lock, will retry");
-      sleepUninterruptibly(1, TimeUnit.SECONDS);
+      sleepUninterruptibly(1000, TimeUnit.MILLISECONDS);
     }
+
+    log.info("Got GC lock.");
+
   }
 
   private HostAndPort startStatsService() {
-    var processor = ThriftProcessorTypes.getGcTProcessor(this, getContext());
+    var processor = ThriftProcessorTypes.getGcTProcessor(this, this, getContext());
     IntStream port = getConfiguration().getPortStream(Property.GC_PORT);
-    HostAndPort[] addresses = TServerUtils.getHostAndPorts(getHostname(), port);
+    String hostname = HostAndPort.fromString(getBindAddress()).getHost();
+    HostAndPort[] addresses = TServerUtils.getHostAndPorts(hostname, port);
     @SuppressWarnings("deprecation")
     var maxMessageSizeProperty = getConfiguration().resolve(Property.RPC_MAX_MESSAGE_SIZE,
         Property.GENERAL_MAX_MESSAGE_SIZE);
@@ -439,4 +470,9 @@ public class SimpleGarbageCollector extends AbstractServer implements Iface {
     return gcCycleMetrics;
   }
 
+  @Override
+  public ServiceLock getLock() {
+    return gcLock;
+  }
+
 }
