@@ -81,6 +81,7 @@ import org.apache.accumulo.core.metadata.schema.MetadataTime;
 import org.apache.accumulo.core.metadata.schema.TabletMetadata.Location;
 import org.apache.accumulo.core.security.Authorizations;
 import org.apache.accumulo.core.tabletserver.thrift.NotServingTabletException;
+import org.apache.accumulo.core.util.Timer;
 import org.apache.accumulo.core.util.threads.Threads.AccumuloDaemonThread;
 import org.apache.accumulo.manager.Manager.TabletGoalState;
 import org.apache.accumulo.manager.state.MergeStats;
@@ -326,7 +327,7 @@ abstract class TabletGroupWatcher extends AccumuloDaemonThread {
             switch (state) {
               case HOSTED:
                 if (location.getServerInstance().equals(manager.migrations.get(tls.extent))) {
-                  manager.migrations.remove(tls.extent);
+                  manager.migrations.removeExtent(tls.extent);
                 }
                 break;
               case ASSIGNED_TO_DEAD_SERVER:
@@ -453,7 +454,7 @@ abstract class TabletGroupWatcher extends AccumuloDaemonThread {
         tLists.assignments.add(new Assignment(tablet, dest, unassignedTablet.getLastLocation()));
       } else {
         // get rid of this migration
-        manager.migrations.remove(tablet);
+        manager.migrations.removeExtent(tablet);
         tLists.unassigned.put(tablet, unassignedTablet);
       }
     } else {
@@ -492,7 +493,7 @@ abstract class TabletGroupWatcher extends AccumuloDaemonThread {
       WalStateManager wals) throws WalMarkerException {
     tLists.assignedToDeadServers.add(tls);
     if (location.getServerInstance().equals(manager.migrations.get(tls.extent))) {
-      manager.migrations.remove(tls.extent);
+      manager.migrations.removeExtent(tls.extent);
     }
     TServerInstance tserver = tls.futureOrCurrentServer();
     if (!tLists.logsForDeadServers.containsKey(tserver)) {
@@ -504,7 +505,7 @@ abstract class TabletGroupWatcher extends AccumuloDaemonThread {
     TServerInstance dest = manager.migrations.get(extent);
     TableState tableState = manager.getTableManager().getTableState(extent.tableId());
     if (dest != null && tableState == TableState.OFFLINE) {
-      manager.migrations.remove(extent);
+      manager.migrations.removeExtent(extent);
     }
   }
 
@@ -1120,13 +1121,22 @@ abstract class TabletGroupWatcher extends AccumuloDaemonThread {
 
     handleDeadTablets(tLists, wals);
 
+    int beforeSize = tLists.assignments.size();
+    Timer timer = Timer.startNew();
+
     getAssignmentsFromBalancer(tLists, unassigned);
+    if (!unassigned.isEmpty()) {
+      Manager.log.debug("[{}] requested assignments for {} tablets and got {} in {} ms",
+          store.name(), unassigned.size(), tLists.assignments.size() - beforeSize,
+          timer.elapsed(TimeUnit.MILLISECONDS));
+    }
 
     if (!tLists.assignments.isEmpty()) {
-      Manager.log.info(String.format("Assigning %d tablets", tLists.assignments.size()));
+      Manager.log.info("Assigning {} tablets", tLists.assignments.size());
       store.setFutureLocations(tLists.assignments);
     }
     tLists.assignments.addAll(tLists.assigned);
+    timer.restart();
     for (Assignment a : tLists.assignments) {
       try {
         TServerConnection client = manager.tserverSet.getConnection(a.server);
@@ -1142,6 +1152,10 @@ abstract class TabletGroupWatcher extends AccumuloDaemonThread {
             tException);
       }
     }
+    if (!tLists.assignments.isEmpty()) {
+      Manager.log.debug("[{}] sent {} assignment messages in {} ms", store.name(),
+          tLists.assignments.size(), timer.elapsed(TimeUnit.MILLISECONDS));
+    }
   }
 
   private static void markDeadServerLogsAsClosed(WalStateManager mgr,
