@@ -92,7 +92,7 @@ public abstract class DistributedWorkQueueWorkAssigner implements WorkAssigner {
   protected void initializeWorkQueue(AccumuloConfiguration conf) {
     workQueue =
         new DistributedWorkQueue(ZooUtil.getRoot(client.instanceOperations().getInstanceId())
-            + ReplicationConstants.ZOO_WORK_QUEUE, conf, this.workQueue.getContext());
+            + ReplicationConstants.ZOO_WORK_QUEUE, conf, this.workQueue.getServer());
   }
 
   @Override
