@@ -147,7 +147,7 @@ class CopyFailed extends ManagerRepo {
     if (!loadedFailures.isEmpty()) {
       DistributedWorkQueue bifCopyQueue = new DistributedWorkQueue(
           Constants.ZROOT + "/" + manager.getInstanceID() + Constants.ZBULK_FAILED_COPYQ,
-          manager.getConfiguration(), manager.getContext());
+          manager.getConfiguration(), manager);
 
       HashSet<String> workIds = new HashSet<>();
 
