@@ -33,8 +33,8 @@ public class DeleteTable extends ManagerRepo {
 
   private static final long serialVersionUID = 1L;
 
-  private TableId tableId;
-  private NamespaceId namespaceId;
+  private final TableId tableId;
+  private final NamespaceId namespaceId;
 
   public DeleteTable(NamespaceId namespaceId, TableId tableId) {
     this.namespaceId = namespaceId;
