@@ -31,6 +31,7 @@ import org.apache.accumulo.core.clientImpl.thrift.TableOperation;
 import org.apache.accumulo.core.clientImpl.thrift.TableOperationExceptionType;
 import org.apache.accumulo.core.fate.Repo;
 import org.apache.accumulo.core.file.FileOperations;
+import org.apache.accumulo.core.file.FilePrefix;
 import org.apache.accumulo.manager.Manager;
 import org.apache.accumulo.manager.tableOps.ManagerRepo;
 import org.apache.accumulo.server.fs.VolumeManager;
@@ -45,7 +46,7 @@ class MapImportFileNames extends ManagerRepo {
 
   private static final long serialVersionUID = 1L;
 
-  private ImportedTableInfo tableInfo;
+  private final ImportedTableInfo tableInfo;
 
   MapImportFileNames(ImportedTableInfo ti) {
     this.tableInfo = ti;
@@ -86,7 +87,8 @@ class MapImportFileNames extends ManagerRepo {
             extension = Constants.MAPFILE_EXTENSION;
           }
 
-          String newName = "I" + namer.getNextName() + "." + extension;
+          String newName =
+              FilePrefix.BULK_IMPORT.createFileName(namer.getNextName() + "." + extension);
 
           mappingsWriter.append(fileName);
           mappingsWriter.append(':');
