@@ -23,11 +23,15 @@ import java.util.List;
 
 import org.apache.accumulo.monitor.rest.manager.ManagerInformation;
 
+import edu.umd.cs.findbugs.annotations.SuppressFBWarnings;
+
 /**
  * Generates a list of servers, bad servers, and dead servers
  *
  * @since 2.0.0
  */
+@SuppressFBWarnings(value = "PA_PUBLIC_PRIMITIVE_ATTRIBUTE",
+    justification = "class used for serialization")
 public class TabletServers {
 
   // Variable names become JSON keys
@@ -44,8 +48,7 @@ public class TabletServers {
   /**
    * Adds bad and dead servers to the list
    *
-   * @param info
-   *          Manager information to get bad and dead server information
+   * @param info Manager information to get bad and dead server information
    */
   public void addBadTabletServer(ManagerInformation info) {
     badServers = info.badTabletServers.badTabletServer;
@@ -55,8 +58,7 @@ public class TabletServers {
   /**
    * Adds new tservers to the list
    *
-   * @param tablet
-   *          New tserver
+   * @param tablet New tserver
    */
   public void addTablet(TabletServer tablet) {
     servers.add(tablet.server);
