@@ -50,6 +50,7 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 import com.google.common.annotations.VisibleForTesting;
+import com.google.common.base.Preconditions;
 
 /**
  * This class stores data in a C++ map. Doing this allows us to store more in memory and avoid
@@ -206,23 +207,26 @@ public class NativeMap implements Iterable<Map.Entry<Key,Value>> {
       end = 0;
       index = 0;
 
-      if (source.hasNext())
+      if (source.hasNext()) {
         source.doNextPreCheck();
+      }
 
       int amountRead = 0;
 
       // as we keep filling, increase the read ahead buffer
-      if (nextEntries.length < MAX_READ_AHEAD_ENTRIES)
+      if (nextEntries.length < MAX_READ_AHEAD_ENTRIES) {
         nextEntries =
             new PreAllocatedArray<>(Math.min(nextEntries.length * 2, MAX_READ_AHEAD_ENTRIES));
+      }
 
       while (source.hasNext() && end < nextEntries.length) {
         Entry<Key,Value> ne = source.next();
         nextEntries.set(end++, ne);
         amountRead += ne.getKey().getSize() + ne.getValue().getSize();
 
-        if (amountRead > READ_AHEAD_BYTES)
+        if (amountRead > READ_AHEAD_BYTES) {
           break;
+        }
       }
     }
 
@@ -281,8 +285,8 @@ public class NativeMap implements Iterable<Map.Entry<Key,Value>> {
 
     private final AtomicLong nmiPtr = new AtomicLong(0);
     private boolean hasNext;
-    private int expectedModCount;
-    private int[] fieldsLens = new int[7];
+    private final int expectedModCount;
+    private final int[] fieldsLens = new int[7];
     private byte[] lastRow;
     private final Cleanable cleanableNMI;
 
@@ -301,7 +305,8 @@ public class NativeMap implements Iterable<Map.Entry<Key,Value>> {
       hasNext = nmiPointer != 0;
 
       nmiPtr.set(nmiPointer);
-      cleanableNMI = NativeMapCleanerUtil.deleteNMIterator(this, nmiPtr);
+      // avoid registering a cleanable if there's nothing to delete
+      cleanableNMI = hasNext ? NativeMapCleanerUtil.deleteNMIterator(this, nmiPtr) : null;
     }
 
     // delete is synchronized on a per iterator basis want to ensure only one
@@ -534,20 +539,16 @@ public class NativeMap implements Iterable<Map.Entry<Key,Value>> {
     private ConcurrentIterator iter;
     private Entry<Key,Value> entry;
 
-    private NativeMap map;
+    private final NativeMap map;
     private Range range;
     private AtomicBoolean interruptFlag;
     private int interruptCheckCount = 0;
+    private boolean seeked = false;
 
     private NMSKVIter(NativeMap map, AtomicBoolean interruptFlag) {
       this.map = map;
-      this.range = new Range();
-      iter = map.new ConcurrentIterator();
-      if (iter.hasNext())
-        entry = iter.next();
-      else
-        entry = null;
-
+      this.iter = null;
+      this.entry = null;
       this.interruptFlag = interruptFlag;
     }
 
@@ -567,37 +568,44 @@ public class NativeMap implements Iterable<Map.Entry<Key,Value>> {
 
     @Override
     public boolean hasTop() {
+      Preconditions.checkState(seeked, "seek() was never called");
       return entry != null;
     }
 
     @Override
     public void next() {
-
-      if (entry == null)
+      if (entry == null) {
         throw new NoSuchElementException();
+      }
 
       // checking the interrupt flag for every call to next had bad a bad performance impact
       // so check it every 100th time
-      if (interruptFlag != null && interruptCheckCount++ % 100 == 0 && interruptFlag.get())
+      if (interruptFlag != null && interruptCheckCount++ % 100 == 0 && interruptFlag.get()) {
         throw new IterationInterruptedException();
+      }
 
       if (iter.hasNext()) {
         entry = iter.next();
         if (range.afterEndKey(entry.getKey())) {
           entry = null;
         }
-      } else
+      } else {
         entry = null;
-
+      }
     }
 
     @Override
     public void seek(Range range, Collection<ByteSequence> columnFamilies, boolean inclusive) {
 
-      if (interruptFlag != null && interruptFlag.get())
+      if (interruptFlag != null && interruptFlag.get()) {
         throw new IterationInterruptedException();
+      }
 
-      iter.delete();
+      if (iter != null) {
+        iter.delete();
+      } else {
+        Preconditions.checkState(!seeked);
+      }
 
       this.range = range;
 
@@ -612,9 +620,11 @@ public class NativeMap implements Iterable<Map.Entry<Key,Value>> {
         if (range.afterEndKey(entry.getKey())) {
           entry = null;
         }
-      } else
+      } else {
         entry = null;
+      }
 
+      seeked = true;
       while (hasTop() && range.beforeStartKey(getTopKey())) {
         next();
       }
