@@ -62,6 +62,7 @@ import java.util.concurrent.atomic.AtomicInteger;
 import java.util.concurrent.atomic.AtomicLong;
 import java.util.concurrent.locks.ReentrantLock;
 import java.util.function.Consumer;
+import java.util.function.Supplier;
 
 import org.apache.accumulo.core.Constants;
 import org.apache.accumulo.core.client.Durability;
@@ -73,8 +74,8 @@ import org.apache.accumulo.core.data.InstanceId;
 import org.apache.accumulo.core.data.TableId;
 import org.apache.accumulo.core.dataImpl.KeyExtent;
 import org.apache.accumulo.core.fate.zookeeper.ServiceLock;
-import org.apache.accumulo.core.fate.zookeeper.ServiceLock.LockLossReason;
 import org.apache.accumulo.core.fate.zookeeper.ServiceLock.LockWatcher;
+import org.apache.accumulo.core.fate.zookeeper.ServiceLockSupport.ServiceLockWatcher;
 import org.apache.accumulo.core.fate.zookeeper.ZooCache;
 import org.apache.accumulo.core.fate.zookeeper.ZooReaderWriter;
 import org.apache.accumulo.core.fate.zookeeper.ZooUtil.NodeExistsPolicy;
@@ -89,6 +90,7 @@ import org.apache.accumulo.core.metadata.RootTable;
 import org.apache.accumulo.core.metadata.TServerInstance;
 import org.apache.accumulo.core.metadata.schema.TabletsMetadata;
 import org.apache.accumulo.core.metrics.MetricsInfo;
+import org.apache.accumulo.core.process.thrift.ServerProcessService;
 import org.apache.accumulo.core.rpc.ThriftUtil;
 import org.apache.accumulo.core.rpc.clients.ThriftClientTypes;
 import org.apache.accumulo.core.spi.fs.VolumeChooserEnvironment;
@@ -123,7 +125,6 @@ import org.apache.accumulo.server.manager.recovery.RecoveryPath;
 import org.apache.accumulo.server.rpc.ServerAddress;
 import org.apache.accumulo.server.rpc.TServerUtils;
 import org.apache.accumulo.server.rpc.ThriftProcessorTypes;
-import org.apache.accumulo.server.security.SecurityOperation;
 import org.apache.accumulo.server.security.SecurityUtil;
 import org.apache.accumulo.server.security.delegation.ZooAuthenticationKeyWatcher;
 import org.apache.accumulo.server.util.FileSystemMonitor;
@@ -165,12 +166,12 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 import com.google.common.annotations.VisibleForTesting;
-import com.google.common.collect.Iterators;
 
 import io.opentelemetry.api.trace.Span;
 import io.opentelemetry.context.Scope;
 
-public class TabletServer extends AbstractServer implements TabletHostingServer {
+public class TabletServer extends AbstractServer
+    implements TabletHostingServer, ServerProcessService.Iface {
 
   private static final SecureRandom random = new SecureRandom();
   private static final Logger log = LoggerFactory.getLogger(TabletServer.class);
@@ -213,15 +214,11 @@ public class TabletServer extends AbstractServer implements TabletHostingServer
   final Map<KeyExtent,Long> recentlyUnloadedCache = Collections.synchronizedMap(new LRUMap<>(1000));
 
   final TabletServerResourceManager resourceManager;
-  private final SecurityOperation security;
 
   private final BlockingDeque<ManagerMessage> managerMessages = new LinkedBlockingDeque<>();
 
   volatile HostAndPort clientAddress;
 
-  private volatile boolean serverStopRequested = false;
-  private volatile boolean shutdownComplete = false;
-
   private ServiceLock tabletServerLock;
 
   private TServer server;
@@ -254,7 +251,7 @@ public class TabletServer extends AbstractServer implements TabletHostingServer
     this.sessionManager = new SessionManager(context);
     this.logSorter = new LogSorter(context, aconf);
     @SuppressWarnings("deprecation")
-    var replWorker = new org.apache.accumulo.tserver.replication.ReplicationWorker(context);
+    var replWorker = new org.apache.accumulo.tserver.replication.ReplicationWorker(this);
     this.replWorker = replWorker;
     this.statsKeeper = new TabletStatsKeeper();
     final int numBusyTabletsToLog = aconf.getCount(Property.TSERV_LOG_BUSY_TABLETS_COUNT);
@@ -270,9 +267,9 @@ public class TabletServer extends AbstractServer implements TabletHostingServer
     if (numBusyTabletsToLog > 0) {
       ScheduledFuture<?> future = context.getScheduledExecutor()
           .scheduleWithFixedDelay(Threads.createNamedRunnable("BusyTabletLogger", new Runnable() {
-            private BusiestTracker ingestTracker =
+            private final BusiestTracker ingestTracker =
                 BusiestTracker.newBusiestIngestTracker(numBusyTabletsToLog);
-            private BusiestTracker queryTracker =
+            private final BusiestTracker queryTracker =
                 BusiestTracker.newBusiestQueryTracker(numBusyTabletsToLog);
 
             @Override
@@ -309,6 +306,18 @@ public class TabletServer extends AbstractServer implements TabletHostingServer
         }), 5, 5, TimeUnit.SECONDS);
     watchNonCriticalScheduledTask(future);
 
+    ScheduledFuture<?> cleanupTask =
+        context.getScheduledExecutor().scheduleWithFixedDelay(Threads.createNamedRunnable(
+            "ScanRefCleanupTask", () -> getOnlineTablets().values().forEach(tablet -> {
+              try {
+                tablet.removeBatchedScanRefs();
+              } catch (Exception e) {
+                log.error("Error cleaning up stale scan references for tablet {}",
+                    tablet.getExtent(), e);
+              }
+            })), 5, 5, TimeUnit.MINUTES);
+    watchNonCriticalScheduledTask(cleanupTask);
+
     @SuppressWarnings("deprecation")
     final long walMaxSize =
         aconf.getAsBytes(aconf.resolve(Property.TSERV_WAL_MAX_SIZE, Property.TSERV_WALOG_MAX_SIZE));
@@ -353,7 +362,6 @@ public class TabletServer extends AbstractServer implements TabletHostingServer
     logger = new TabletServerLogger(this, walMaxSize, syncCounter, flushCounter,
         walCreationRetryFactory, walWritingRetryFactory, walMaxAge);
     this.resourceManager = new TabletServerResourceManager(context, this);
-    this.security = context.getSecurityOperation();
 
     watchCriticalScheduledTask(context.getScheduledExecutor().scheduleWithFixedDelay(
         TabletLocator::clearLocators, jitter(), jitter(), TimeUnit.MILLISECONDS));
@@ -401,7 +409,7 @@ public class TabletServer extends AbstractServer implements TabletHostingServer
 
   void requestStop() {
     log.info("Stop requested.");
-    serverStopRequested = true;
+    gracefulShutdown(getContext().rpcCreds());
   }
 
   private class SplitRunner implements Runnable {
@@ -418,7 +426,12 @@ public class TabletServer extends AbstractServer implements TabletHostingServer
   }
 
   public long updateTotalQueuedMutationSize(long additionalMutationSize) {
-    return totalQueuedMutationSize.addAndGet(additionalMutationSize);
+    var newTotal = totalQueuedMutationSize.addAndGet(additionalMutationSize);
+    if (log.isTraceEnabled()) {
+      log.trace("totalQueuedMutationSize is now {} after adding {}", newTotal,
+          additionalMutationSize);
+    }
+    return newTotal;
   }
 
   @Override
@@ -483,7 +496,8 @@ public class TabletServer extends AbstractServer implements TabletHostingServer
     }
   }
 
-  TreeMap<KeyExtent,TabletData> splitTablet(Tablet tablet, byte[] splitPoint) throws IOException {
+  protected TreeMap<KeyExtent,TabletData> splitTablet(Tablet tablet, byte[] splitPoint)
+      throws IOException {
     long t1 = System.currentTimeMillis();
 
     TreeMap<KeyExtent,TabletData> tabletInfo = tablet.split(splitPoint);
@@ -544,7 +558,7 @@ public class TabletServer extends AbstractServer implements TabletHostingServer
     }
   }
 
-  private HostAndPort startServer(String address, TProcessor processor)
+  private ServerAddress startServer(String address, TProcessor processor)
       throws UnknownHostException {
     @SuppressWarnings("deprecation")
     var maxMessageSizeProperty = getConfiguration().resolve(Property.RPC_MAX_MESSAGE_SIZE,
@@ -554,7 +568,7 @@ public class TabletServer extends AbstractServer implements TabletHostingServer
         Property.TSERV_PORTSEARCH, Property.TSERV_MINTHREADS, Property.TSERV_MINTHREADS_TIMEOUT,
         Property.TSERV_THREADCHECK, maxMessageSizeProperty);
     this.server = sp.server;
-    return sp.address;
+    return sp;
   }
 
   private HostAndPort getManagerAddress() {
@@ -603,7 +617,7 @@ public class TabletServer extends AbstractServer implements TabletHostingServer
     ThriftUtil.returnClient(client, context);
   }
 
-  private HostAndPort startTabletClientService() throws UnknownHostException {
+  private ServerAddress startTabletClientService() throws UnknownHostException {
     // start listening for client connection last
     TransactionWatcher watcher = new TransactionWatcher(context);
     WriteTracker writeTracker = new WriteTracker();
@@ -611,11 +625,11 @@ public class TabletServer extends AbstractServer implements TabletHostingServer
     thriftClientHandler = newTabletClientHandler(watcher, writeTracker);
     scanClientHandler = newThriftScanClientHandler(writeTracker);
 
-    TProcessor processor = ThriftProcessorTypes.getTabletServerTProcessor(clientHandler,
+    TProcessor processor = ThriftProcessorTypes.getTabletServerTProcessor(this, clientHandler,
         thriftClientHandler, scanClientHandler, getContext());
-    HostAndPort address = startServer(clientAddress.getHost(), processor);
-    log.info("address = {}", address);
-    return address;
+    ServerAddress sp = startServer(getBindAddress(), processor);
+    log.info("address = {}", sp.address);
+    return sp;
   }
 
   @Deprecated
@@ -678,24 +692,8 @@ public class TabletServer extends AbstractServer implements TabletHostingServer
 
       tabletServerLock = new ServiceLock(zoo.getZooKeeper(), zLockPath, UUID.randomUUID());
 
-      LockWatcher lw = new LockWatcher() {
-
-        @Override
-        public void lostLock(final LockLossReason reason) {
-          Halt.halt(serverStopRequested ? 0 : 1, () -> {
-            if (!serverStopRequested) {
-              log.error("Lost tablet server lock (reason = {}), exiting.", reason);
-            }
-            gcLogger.logGCInfo(getConfiguration());
-          });
-        }
-
-        @Override
-        public void unableToMonitorLockNode(final Exception e) {
-          Halt.halt(1, () -> log.error("Lost ability to monitor tablet server lock, exiting.", e));
-
-        }
-      };
+      LockWatcher lw = new ServiceLockWatcher("tablet server", () -> getShutdownComplete().get(),
+          (name) -> gcLogger.logGCInfo(getConfiguration()));
 
       byte[] lockContent = new ServerServices(getClientAddressString(), Service.TSERV_CLIENT)
           .toString().getBytes(UTF_8);
@@ -708,6 +706,7 @@ public class TabletServer extends AbstractServer implements TabletHostingServer
           lockSessionId = tabletServerLock.getSessionId();
           log.debug("Obtained tablet server lock {} {}", tabletServerLock.getLockPath(),
               getTabletSession());
+          startServiceLockVerificationThread();
           return;
         }
         log.info("Waiting for tablet server lock");
@@ -754,18 +753,21 @@ public class TabletServer extends AbstractServer implements TabletHostingServer
             + " ZooKeeper. Delegation token authentication will be unavailable.", e);
       }
     }
+    ServerAddress address = null;
     try {
-      clientAddress = startTabletClientService();
+      address = startTabletClientService();
+      updateAdvertiseAddress(address.getAddress());
+      clientAddress = getAdvertiseAddress();
     } catch (UnknownHostException e1) {
       throw new RuntimeException("Failed to start the tablet client service", e1);
     }
 
     MetricsInfo metricsInfo = context.getMetricsInfo();
-    metricsInfo.addServiceTags(getApplicationName(), clientAddress);
 
     metrics = new TabletServerMetrics(this);
     updateMetrics = new TabletServerUpdateMetrics();
-    scanMetrics = new TabletServerScanMetrics();
+    scanMetrics = new TabletServerScanMetrics(this.resourceManager::getOpenFiles);
+    sessionManager.setZombieCountConsumer(scanMetrics::setZombieScanThreads);
     mincMetrics = new TabletServerMinCMetrics();
     ceMetrics = new CompactionExecutorsMetrics();
     blockCacheMetrics = new BlockCacheMetrics(this.resourceManager.getIndexCache(),
@@ -773,11 +775,21 @@ public class TabletServer extends AbstractServer implements TabletHostingServer
 
     metricsInfo.addMetricsProducers(this, metrics, updateMetrics, scanMetrics, mincMetrics,
         ceMetrics, blockCacheMetrics);
-    metricsInfo.init();
+    metricsInfo.init(MetricsInfo.serviceTags(context.getInstanceName(), getApplicationName(),
+        clientAddress, ""));
 
-    this.compactionManager = new CompactionManager(() -> Iterators
-        .transform(onlineTablets.snapshot().values().iterator(), Tablet::asCompactable),
-        getContext(), ceMetrics);
+    Supplier<OpeningAndOnlineCompactables> compactables = () -> {
+      // synchronize on both sets to get a consistent snapshot across both sets, this avoids missing
+      // any tablets that are moving between sets
+      synchronized (openingTablets) {
+        synchronized (onlineTablets) {
+          return new OpeningAndOnlineCompactables(Set.copyOf(openingTablets),
+              onlineTablets.snapshot());
+        }
+      }
+    };
+
+    this.compactionManager = new CompactionManager(compactables, getContext(), ceMetrics);
     compactionManager.start();
 
     announceExistence();
@@ -794,9 +806,8 @@ public class TabletServer extends AbstractServer implements TabletHostingServer
         .createExecutorService(getConfiguration(), Property.TSERV_WORKQ_THREADS, true);
 
     // TODO: Remove when Property.TSERV_WORKQ_THREADS is removed
-    DistributedWorkQueue bulkFailedCopyQ =
-        new DistributedWorkQueue(getContext().getZooKeeperRoot() + Constants.ZBULK_FAILED_COPYQ,
-            getConfiguration(), getContext());
+    DistributedWorkQueue bulkFailedCopyQ = new DistributedWorkQueue(
+        getContext().getZooKeeperRoot() + Constants.ZBULK_FAILED_COPYQ, getConfiguration(), this);
     try {
       bulkFailedCopyQ.startProcessing(new BulkFailedCopyProcessor(getContext()),
           distWorkQThreadPool);
@@ -805,7 +816,7 @@ public class TabletServer extends AbstractServer implements TabletHostingServer
     }
 
     try {
-      logSorter.startWatchingForRecoveryLogs();
+      logSorter.startWatchingForRecoveryLogs(this);
     } catch (Exception ex) {
       log.error("Error setting watches for recoveries");
       throw new RuntimeException(ex);
@@ -870,7 +881,11 @@ public class TabletServer extends AbstractServer implements TabletHostingServer
         CLEANUP_BULK_LOADED_CACHE_MILLIS, TimeUnit.MILLISECONDS));
 
     HostAndPort managerHost;
-    while (!serverStopRequested) {
+    while (!isShutdownRequested()) {
+      if (Thread.currentThread().isInterrupted()) {
+        LOG.info("Server process thread has been interrupted, shutting down");
+        break;
+      }
 
       updateIdleStatus(getOnlineTablets().isEmpty());
 
@@ -882,7 +897,7 @@ public class TabletServer extends AbstractServer implements TabletHostingServer
         try {
           // wait until a message is ready to send, or a server stop
           // was requested
-          while (mm == null && !serverStopRequested) {
+          while (mm == null && !isShutdownRequested() && !Thread.currentThread().isInterrupted()) {
             mm = managerMessages.poll(1, TimeUnit.SECONDS);
             updateIdleStatus(getOnlineTablets().isEmpty());
           }
@@ -895,8 +910,8 @@ public class TabletServer extends AbstractServer implements TabletHostingServer
 
           // if while loop does not execute at all and mm != null,
           // then finally block should place mm back on queue
-          while (!serverStopRequested && mm != null && client != null
-              && client.getOutputProtocol() != null
+          while (!Thread.currentThread().isInterrupted() && !isShutdownRequested() && mm != null
+              && client != null && client.getOutputProtocol() != null
               && client.getOutputProtocol().getTransport() != null
               && client.getOutputProtocol().getTransport().isOpen()) {
             try {
@@ -926,7 +941,7 @@ public class TabletServer extends AbstractServer implements TabletHostingServer
         }
       } catch (InterruptedException e) {
         log.info("Interrupt Exception received, shutting down");
-        serverStopRequested = true;
+        gracefulShutdown(getContext().rpcCreds());
       } catch (Exception e) {
         // may have lost connection with manager
         // loop back to the beginning and wait for a new one
@@ -935,21 +950,34 @@ public class TabletServer extends AbstractServer implements TabletHostingServer
       }
     }
 
-    // wait for shutdown
-    // if the main thread exits oldServer the manager listener, the JVM will
-    // kill the other threads and finalize objects. We want the shutdown that is
-    // running in the manager listener thread to complete oldServer this happens.
-    // consider making other threads daemon threads so that objects don't
-    // get prematurely finalized
-    synchronized (this) {
-      while (!shutdownComplete) {
-        try {
-          this.wait(1000);
-        } catch (InterruptedException e) {
-          log.error(e.toString());
-        }
+    ManagerClientService.Client iface = managerConnection(getManagerAddress());
+    try {
+      // Ask the manager to unload our tablets and stop loading new tablets
+      if (iface == null) {
+        Halt.halt(-1, "Error informing Manager that we are shutting down, exiting!");
+      } else {
+        iface.tabletServerStopping(TraceUtil.traceInfo(), getContext().rpcCreds(),
+            getTabletSession().getHostPortSession());
       }
+
+      boolean managerDown = false;
+      while (!getOnlineTablets().isEmpty()) {
+        log.info("Shutdown requested, waiting for manager to unload {} tablets",
+            getOnlineTablets().size());
+
+        managerDown = sendManagerMessages(managerDown, iface);
+
+        UtilWaitThread.sleep(1000);
+      }
+
+      sendManagerMessages(managerDown, iface);
+
+    } catch (TException | RuntimeException e) {
+      Halt.halt(-1, "Error informing Manager that we are shutting down, exiting!", e);
+    } finally {
+      returnManagerConnection(iface);
     }
+
     log.debug("Stopping Replication Server");
     if (this.replServer != null) {
       this.replServer.stop();
@@ -968,9 +996,9 @@ public class TabletServer extends AbstractServer implements TabletHostingServer
     }
 
     gcLogger.logGCInfo(getConfiguration());
-
+    super.close();
+    getShutdownComplete().set(true);
     log.info("TServerInfo: stop requested. exiting ... ");
-
     try {
       tabletServerLock.unlock();
     } catch (Exception e) {
@@ -978,6 +1006,21 @@ public class TabletServer extends AbstractServer implements TabletHostingServer
     }
   }
 
+  private boolean sendManagerMessages(boolean managerDown, ManagerClientService.Client iface) {
+    ManagerMessage mm = managerMessages.poll();
+    while (mm != null && !managerDown) {
+      try {
+        mm.send(getContext().rpcCreds(), getClientAddressString(), iface);
+        mm = managerMessages.poll();
+      } catch (TException e) {
+        managerDown = true;
+        LOG.debug("Error sending message to Manager during tablet unloading, msg: {}",
+            e.getMessage());
+      }
+    }
+    return managerDown;
+  }
+
   @SuppressWarnings("deprecation")
   private void setupReplication(AccumuloConfiguration aconf) {
     // Start the thrift service listening for incoming replication requests
@@ -1056,10 +1099,10 @@ public class TabletServer extends AbstractServer implements TabletHostingServer
   }
 
   private void config() {
-    log.info("Tablet server starting on {}", getHostname());
-    Threads.createThread("Split/MajC initiator", new MajorCompactor(context)).start();
+    log.info("Tablet server starting on {}", getBindAddress());
+    Threads.createCriticalThread("Split/MajC initiator", new MajorCompactor(context)).start();
 
-    clientAddress = HostAndPort.fromParts(getHostname(), 0);
+    clientAddress = HostAndPort.fromParts(getBindAddress(), 0);
 
     final AccumuloConfiguration aconf = getConfiguration();
 
@@ -1286,10 +1329,6 @@ public class TabletServer extends AbstractServer implements TabletHostingServer
     return resourceManager.holdTime();
   }
 
-  public SecurityOperation getSecurityOperation() {
-    return security;
-  }
-
   // avoid unnecessary redundant markings to meta
   final ConcurrentHashMap<DfsLogger,EnumSet<TabletLevel>> metadataTableLogs =
       new ConcurrentHashMap<>();
