@@ -33,7 +33,7 @@ public class TabletStatsKeeper {
     MAJOR, SPLIT, MINOR
   }
 
-  private ActionStats[] map = {major, split, minor};
+  private final ActionStats[] map = {major, split, minor};
 
   public void updateTime(Operation operation, long queued, long start, long count, boolean failed) {
     try {
@@ -52,8 +52,9 @@ public class TabletStatsKeeper {
         data.queueTime += q;
         data.sumDev += t * t;
         data.queueSumDev += q * q;
-        if (data.elapsed < 0 || data.sumDev < 0 || data.queueSumDev < 0 || data.queueTime < 0)
+        if (data.elapsed < 0 || data.sumDev < 0 || data.queueSumDev < 0 || data.queueTime < 0) {
           resetTimes();
+        }
       }
     } catch (Exception E) {
       resetTimes();
@@ -75,8 +76,9 @@ public class TabletStatsKeeper {
         data.elapsed += t;
         data.sumDev += t * t;
 
-        if (data.elapsed < 0 || data.sumDev < 0 || data.queueSumDev < 0 || data.queueTime < 0)
+        if (data.elapsed < 0 || data.sumDev < 0 || data.queueSumDev < 0 || data.queueTime < 0) {
           resetTimes();
+        }
       }
     } catch (Exception E) {
       resetTimes();
