@@ -19,8 +19,9 @@
 package org.apache.accumulo.tserver.metrics;
 
 import java.time.Duration;
-import java.util.concurrent.atomic.AtomicInteger;
+import java.util.concurrent.atomic.AtomicLong;
 import java.util.concurrent.atomic.LongAdder;
+import java.util.function.IntSupplier;
 
 import org.apache.accumulo.core.metrics.MetricsProducer;
 import org.apache.accumulo.server.metrics.NoopMetrics;
@@ -33,7 +34,7 @@ import io.micrometer.core.instrument.Timer;
 
 public class TabletServerScanMetrics implements MetricsProducer {
 
-  private final AtomicInteger openFiles = new AtomicInteger(0);
+  private final IntSupplier openFiles;
   private Timer scans = NoopMetrics.useNoopTimer();
   private DistributionSummary resultsPerScan = NoopMetrics.useNoopDistributionSummary();
   private DistributionSummary yields = NoopMetrics.useNoopDistributionSummary();
@@ -41,7 +42,7 @@ public class TabletServerScanMetrics implements MetricsProducer {
   private Counter continueScanCalls = NoopMetrics.useNoopCounter();;
   private Counter closeScanCalls = NoopMetrics.useNoopCounter();;
   private Counter busyTimeoutCount = NoopMetrics.useNoopCounter();;
-
+  private final AtomicLong zombieScanThreads = new AtomicLong(0);
   private final LongAdder lookupCount = new LongAdder();
   private final LongAdder queryResultCount = new LongAdder();
   private final LongAdder queryResultBytes = new LongAdder();
@@ -95,14 +96,6 @@ public class TabletServerScanMetrics implements MetricsProducer {
     yields.record(value);
   }
 
-  public void incrementOpenFiles(int delta) {
-    openFiles.addAndGet(Math.max(0, delta));
-  }
-
-  public void decrementOpenFiles(int delta) {
-    openFiles.addAndGet(delta < 0 ? delta : delta * -1);
-  }
-
   public void incrementStartScan(double value) {
     startScanCalls.increment(value);
   }
@@ -119,9 +112,21 @@ public class TabletServerScanMetrics implements MetricsProducer {
     busyTimeoutCount.increment(value);
   }
 
+  public void setZombieScanThreads(long count) {
+    zombieScanThreads.set(count);
+  }
+
+  public long getZombieThreadsCount() {
+    return zombieScanThreads.get();
+  }
+
+  public TabletServerScanMetrics(IntSupplier openFileSupplier) {
+    openFiles = openFileSupplier;
+  }
+
   @Override
   public void registerMetrics(MeterRegistry registry) {
-    Gauge.builder(METRICS_SCAN_OPEN_FILES, openFiles::get)
+    Gauge.builder(METRICS_SCAN_OPEN_FILES, openFiles::getAsInt)
         .description("Number of files open for scans").register(registry);
     scans = Timer.builder(METRICS_SCAN_TIMES).description("Scans").register(registry);
     resultsPerScan = DistributionSummary.builder(METRICS_SCAN_RESULTS)
@@ -148,6 +153,9 @@ public class TabletServerScanMetrics implements MetricsProducer {
         .description("Query rate (bytes/sec)").register(registry);
     Gauge.builder(METRICS_SCAN_SCANNED_ENTRIES, this, TabletServerScanMetrics::getScannedCount)
         .description("Scanned rate").register(registry);
+    Gauge.builder(METRICS_SCAN_ZOMBIE_THREADS, this, TabletServerScanMetrics::getZombieThreadsCount)
+        .description("Number of scan threads that have no associated client session")
+        .register(registry);
   }
 
 }
