@@ -21,8 +21,11 @@ package org.apache.accumulo.tserver.session;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.Map;
+import java.util.Objects;
 import java.util.OptionalLong;
 import java.util.Set;
+import java.util.concurrent.TimeUnit;
+import java.util.concurrent.atomic.AtomicReference;
 import java.util.stream.Collectors;
 
 import org.apache.accumulo.core.data.Column;
@@ -34,11 +37,16 @@ import org.apache.accumulo.core.spi.common.Stats;
 import org.apache.accumulo.core.spi.scan.ScanInfo;
 import org.apache.accumulo.core.util.Stat;
 import org.apache.accumulo.tserver.scan.ScanParameters;
+import org.apache.accumulo.tserver.scan.ScanTask;
 import org.apache.accumulo.tserver.tablet.TabletBase;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 import com.google.common.base.Preconditions;
 
-public abstract class ScanSession extends Session implements ScanInfo {
+public abstract class ScanSession<T> extends Session implements ScanInfo {
+
+  private static final Logger log = LoggerFactory.getLogger(ScanSession.class);
 
   public interface TabletResolver {
     TabletBase getTablet(KeyExtent extent);
@@ -48,10 +56,10 @@ public abstract class ScanSession extends Session implements ScanInfo {
 
   public static class ScanMeasurer implements Runnable {
 
-    private ScanSession session;
-    private Runnable task;
+    private final ScanSession<?> session;
+    private final Runnable task;
 
-    ScanMeasurer(ScanSession session, Runnable task) {
+    ScanMeasurer(ScanSession<?> session, Runnable task) {
       this.session = session;
       this.task = task;
     }
@@ -69,18 +77,20 @@ public abstract class ScanSession extends Session implements ScanInfo {
     }
   }
 
-  public static ScanMeasurer wrap(ScanSession scanInfo, Runnable r) {
+  public static ScanMeasurer wrap(ScanSession<?> scanInfo, Runnable r) {
     return new ScanMeasurer(scanInfo, r);
   }
 
   private OptionalLong lastRunTime = OptionalLong.empty();
-  private Stat idleStats = new Stat();
-  public Stat runStats = new Stat();
+  private final Stat idleStats = new Stat();
+  public final Stat runStats = new Stat();
 
   public final ScanParameters scanParams;
-  private Map<String,String> executionHints;
+  private final Map<String,String> executionHints;
   private final TabletResolver tabletResolver;
 
+  private final AtomicReference<ScanTask<T>> scanTaskRef = new AtomicReference<>();
+
   ScanSession(TCredentials credentials, ScanParameters scanParams,
       Map<String,String> executionHints, TabletResolver tabletResolver) {
     super(credentials);
@@ -129,7 +139,7 @@ public abstract class ScanSession extends Session implements ScanInfo {
 
   private class IterConfImpl implements IteratorConfiguration {
 
-    private IterInfo ii;
+    private final IterInfo ii;
 
     IterConfImpl(IterInfo ii) {
       this.ii = ii;
@@ -180,12 +190,71 @@ public abstract class ScanSession extends Session implements ScanInfo {
     return tabletResolver;
   }
 
+  public ScanTask<T> getScanTask() {
+    return scanTaskRef.get();
+  }
+
+  public void setScanTask(ScanTask<T> scanTask) {
+    Objects.requireNonNull(scanTask);
+    scanTaskRef.getAndUpdate(currScanTask -> {
+      Preconditions.checkState(currScanTask == null,
+          "Unable to set a scan task when one is already set");
+      return scanTask;
+    });
+  }
+
+  public void clearScanTask() {
+    scanTaskRef.getAndUpdate(currScanTask -> {
+      // For tracking zombie scan threads, do not want to clear the scan task if it has an active
+      // thread. When the thread is not null and the task has produced a result, the thread should
+      // be in
+      // the process of clearing itself from the scan task.
+      Preconditions.checkState(
+          currScanTask == null || currScanTask.getScanThread() == null
+              || currScanTask.producedResult(),
+          "Can not clear scan task that is still running and has not produced a result");
+      return null;
+    });
+  }
+
+  private boolean loggedZombieStackTrace = false;
+
+  public void logZombieStackTrace() {
+    Preconditions.checkState(getState() == State.REMOVED);
+    var scanTask = scanTaskRef.get();
+    if (scanTask != null) {
+      ScanTask.ScanThreadStackTrace scanStackTrace = scanTask.getStackTrace();
+      if (scanStackTrace != null && !loggedZombieStackTrace) {
+        var changeTimeMillis = elaspedSinceStateChange(TimeUnit.MILLISECONDS);
+        var exception =
+            new Exception("Fake exception to capture stack trace of zombie scan.  Thread id:"
+                + scanStackTrace.threadId + " thread name:" + scanStackTrace.threadName);
+        exception.setStackTrace(scanStackTrace.stackTrace);
+        log.warn(
+            "Scan session with no client active for {}ms has a zombie scan thread. Scan session info : {} ",
+            changeTimeMillis, this, exception);
+        loggedZombieStackTrace = true;
+      }
+    }
+
+  }
+
   @Override
   public boolean cleanup() {
     tabletResolver.close();
+
     if (!super.cleanup()) {
       return false;
     }
+
+    var scanTask = scanTaskRef.get();
+    if (scanTask != null && scanTask.getScanThread() != null) {
+      // Leave the session around if there is still a scan thread associated with it. This will
+      // cause it to still show up in listscans and it will cause it to show up in the count of
+      // zombie scans.
+      return false;
+    }
+
     return true;
   }
 
