@@ -29,8 +29,10 @@ import java.util.concurrent.TimeUnit;
 
 import org.apache.accumulo.core.conf.AccumuloConfiguration;
 import org.apache.accumulo.core.data.ByteSequence;
+import org.apache.accumulo.core.fate.zookeeper.ServiceLock;
 import org.apache.accumulo.core.manager.state.tables.TableState;
 import org.apache.accumulo.core.metadata.TabletFile;
+import org.apache.accumulo.core.util.Halt;
 import org.apache.accumulo.core.util.LocalityGroupUtil;
 import org.apache.accumulo.server.compaction.CompactionStats;
 import org.apache.accumulo.server.compaction.FileCompactor;
@@ -93,11 +95,19 @@ public class MinorCompactor extends FileCompactor {
     try {
       do {
         try {
-          CompactionStats ret = super.call();
-
-          // log.debug(String.format("MinC %,d recs in | %,d recs out | %,d recs/sec | %6.3f secs |
-          // %,d bytes ",map.size(), entriesCompacted,
-          // (int)(map.size()/((t2 - t1)/1000.0)), (t2 - t1)/1000.0, estimatedSizeInBytes()));
+          CompactionStats ret = null;
+          try {
+            ret = super.call();
+          } catch (Exception e) {
+            final ServiceLock tserverLock = tabletServer.getLock();
+            if (tserverLock == null || !tserverLock.verifyLockAtSource()) {
+              log.error("Minor compaction of {} has failed and TabletServer lock does not exist."
+                  + " Halting...", getExtent(), e);
+              Halt.halt(-1, "TabletServer lock does not exist", e);
+            } else {
+              throw e;
+            }
+          }
 
           if (reportedProblem) {
             ProblemReports.getInstance(tabletServer.getContext())
@@ -105,7 +115,7 @@ public class MinorCompactor extends FileCompactor {
           }
 
           return ret;
-        } catch (IOException | UnsatisfiedLinkError e) {
+        } catch (IOException | ReflectiveOperationException | UnsatisfiedLinkError e) {
           log.warn("MinC failed ({}) to create {} retrying ...", e.getMessage(), outputFileName);
           ProblemReports.getInstance(tabletServer.getContext()).report(
               new ProblemReport(getExtent().tableId(), ProblemType.FILE_WRITE, outputFileName, e));
@@ -127,7 +137,7 @@ public class MinorCompactor extends FileCompactor {
           log.warn("MinC failed ({}) to create {} retrying ...", e.getMessage(), outputFileName, e);
           reportedProblem = true;
           retryCounter++;
-        } catch (CompactionCanceledException e) {
+        } catch (CompactionCanceledException | InterruptedException e) {
           throw new IllegalStateException(e);
         }
 
@@ -151,7 +161,6 @@ public class MinorCompactor extends FileCompactor {
 
       } while (true);
     } finally {
-      thread = null;
       runningCompactions.remove(this);
     }
   }
