@@ -1,18 +1,20 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.tserver.log;
 
@@ -21,9 +23,13 @@ import static org.apache.accumulo.tserver.logger.LogEvents.COMPACTION_START;
 import static org.apache.accumulo.tserver.logger.LogEvents.DEFINE_TABLET;
 import static org.apache.accumulo.tserver.logger.LogEvents.MUTATION;
 import static org.apache.accumulo.tserver.logger.LogEvents.OPEN;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
+import static org.easymock.EasyMock.expect;
+import static org.easymock.EasyMock.replay;
+import static org.easymock.EasyMock.reset;
+import static org.easymock.EasyMock.verify;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertThrows;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import java.io.File;
 import java.io.IOException;
@@ -38,39 +44,57 @@ import java.util.Objects;
 import java.util.Set;
 import java.util.TreeMap;
 
+import org.apache.accumulo.core.conf.ConfigurationCopy;
+import org.apache.accumulo.core.conf.DefaultConfiguration;
+import org.apache.accumulo.core.conf.Property;
 import org.apache.accumulo.core.data.Mutation;
 import org.apache.accumulo.core.data.TableId;
 import org.apache.accumulo.core.data.Value;
 import org.apache.accumulo.core.dataImpl.KeyExtent;
+import org.apache.accumulo.core.file.rfile.bcfile.Compression;
+import org.apache.accumulo.core.file.rfile.bcfile.CompressionAlgorithm;
+import org.apache.accumulo.core.file.rfile.bcfile.Utils;
+import org.apache.accumulo.core.file.streams.SeekableDataInputStream;
+import org.apache.accumulo.core.spi.crypto.CryptoServiceFactory;
+import org.apache.accumulo.core.spi.crypto.GenericCryptoServiceFactory;
+import org.apache.accumulo.core.util.Pair;
+import org.apache.accumulo.server.ServerContext;
 import org.apache.accumulo.server.data.ServerMutation;
-import org.apache.accumulo.server.fs.VolumeManager;
 import org.apache.accumulo.server.fs.VolumeManagerImpl;
 import org.apache.accumulo.server.log.SortedLogState;
+import org.apache.accumulo.tserver.WithTestNames;
 import org.apache.accumulo.tserver.logger.LogEvents;
 import org.apache.accumulo.tserver.logger.LogFileKey;
 import org.apache.accumulo.tserver.logger.LogFileValue;
+import org.apache.hadoop.fs.FSDataInputStream;
 import org.apache.hadoop.fs.FileSystem;
 import org.apache.hadoop.fs.Path;
-import org.apache.hadoop.io.MapFile;
-import org.apache.hadoop.io.MapFile.Writer;
 import org.apache.hadoop.io.Text;
-import org.junit.Rule;
-import org.junit.Test;
-import org.junit.rules.ExpectedException;
-import org.junit.rules.TemporaryFolder;
+import org.easymock.EasyMock;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.io.TempDir;
 
 import edu.umd.cs.findbugs.annotations.SuppressFBWarnings;
 
 @SuppressFBWarnings(value = "PATH_TRAVERSAL_IN", justification = "paths not set by user input")
-public class SortedLogRecoveryTest {
+public class SortedLogRecoveryTest extends WithTestNames {
 
+  static final int bufferSize = 5;
   static final KeyExtent extent = new KeyExtent(TableId.of("table"), null, null);
   static final Text cf = new Text("cf");
   static final Text cq = new Text("cq");
-  static final Value value = new Value("value".getBytes());
+  static final Value value = new Value("value");
+  static ServerContext context;
+  static LogSorter logSorter;
 
-  @Rule
-  public ExpectedException thrown = ExpectedException.none();
+  @TempDir
+  private static File tempDir;
+
+  @BeforeEach
+  public void setup() {
+    context = EasyMock.createMock(ServerContext.class);
+  }
 
   static class KeyValue implements Comparable<KeyValue> {
     public final LogFileKey key;
@@ -88,8 +112,7 @@ public class SortedLogRecoveryTest {
 
     @Override
     public boolean equals(Object obj) {
-      return this == obj
-          || (obj != null && obj instanceof KeyValue && 0 == compareTo((KeyValue) obj));
+      return this == obj || (obj instanceof KeyValue && 0 == compareTo((KeyValue) obj));
     }
 
     @Override
@@ -101,26 +124,26 @@ public class SortedLogRecoveryTest {
   private static KeyValue createKeyValue(LogEvents type, long seq, int tid,
       Object fileExtentMutation) {
     KeyValue result = new KeyValue();
-    result.key.event = type;
-    result.key.seq = seq;
-    result.key.tabletId = tid;
+    result.key.setEvent(type);
+    result.key.setSeq(seq);
+    result.key.setTabletId(tid);
     switch (type) {
       case OPEN:
-        result.key.tserverSession = (String) fileExtentMutation;
+        result.key.setTserverSession((String) fileExtentMutation);
         break;
       case COMPACTION_FINISH:
         break;
       case COMPACTION_START:
-        result.key.filename = (String) fileExtentMutation;
+        result.key.setFilename((String) fileExtentMutation);
         break;
       case DEFINE_TABLET:
-        result.key.tablet = (KeyExtent) fileExtentMutation;
+        result.key.setTablet((KeyExtent) fileExtentMutation);
         break;
       case MUTATION:
-        result.value.mutations = Arrays.asList((Mutation) fileExtentMutation);
+        result.value.setMutations(List.of((Mutation) fileExtentMutation));
         break;
       case MANY_MUTATIONS:
-        result.value.mutations = Arrays.asList((Mutation[]) fileExtentMutation);
+        result.value.setMutations(Arrays.asList((Mutation[]) fileExtentMutation));
     }
     return result;
   }
@@ -135,42 +158,51 @@ public class SortedLogRecoveryTest {
     }
   }
 
-  private static List<Mutation> recover(Map<String,KeyValue[]> logs, KeyExtent extent)
-      throws IOException {
-    return recover(logs, new HashSet<>(), extent);
+  private List<Mutation> recover(Map<String,KeyValue[]> logs, KeyExtent extent) throws IOException {
+    return recover(logs, new HashSet<>(), extent, bufferSize);
   }
 
-  private static List<Mutation> recover(Map<String,KeyValue[]> logs, Set<String> files,
-      KeyExtent extent) throws IOException {
-    TemporaryFolder root =
-        new TemporaryFolder(new File(System.getProperty("user.dir") + "/target"));
-    root.create();
-    final String workdir = root.getRoot().getAbsolutePath() + "/workdir";
-    VolumeManager fs = VolumeManagerImpl.getLocal(workdir);
-    final Path workdirPath = new Path("file://" + workdir);
-    fs.deleteRecursively(workdirPath);
-    ArrayList<Path> dirs = new ArrayList<>();
-    try {
+  private List<Mutation> recover(Map<String,KeyValue[]> logs, Set<String> files, KeyExtent extent,
+      int bufferSize) throws IOException {
+
+    final String workdir = new File(tempDir, testName()).getAbsolutePath();
+    try (var fs = VolumeManagerImpl.getLocalForTesting(workdir)) {
+      CryptoServiceFactory cryptoFactory = new GenericCryptoServiceFactory();
+
+      expect(context.getVolumeManager()).andReturn(fs).anyTimes();
+      expect(context.getCryptoFactory()).andReturn(cryptoFactory).anyTimes();
+      expect(context.getConfiguration()).andReturn(DefaultConfiguration.getInstance()).anyTimes();
+      replay(context);
+      logSorter = new LogSorter(context, DefaultConfiguration.getInstance());
+
+      final Path workdirPath = new Path("file://" + workdir);
+      fs.deleteRecursively(workdirPath);
+
+      ArrayList<Path> dirs = new ArrayList<>();
       for (Entry<String,KeyValue[]> entry : logs.entrySet()) {
-        String path = workdir + "/" + entry.getKey();
-        FileSystem ns = fs.getVolumeByPath(new Path(path)).getFileSystem();
-        @SuppressWarnings("deprecation")
-        Writer map = new MapFile.Writer(ns.getConf(), ns, path + "/log1", LogFileKey.class,
-            LogFileValue.class);
-        for (KeyValue lfe : entry.getValue()) {
-          map.append(lfe.key, lfe.value);
+        String destPath = workdir + "/" + entry.getKey();
+        FileSystem ns = fs.getFileSystemByPath(new Path(destPath));
+        // convert test object to Pairs for LogSorter, flushing based on bufferSize
+        List<Pair<LogFileKey,LogFileValue>> buffer = new ArrayList<>();
+        int parts = 0;
+        for (KeyValue pair : entry.getValue()) {
+          buffer.add(new Pair<>(pair.key, pair.value));
+          if (buffer.size() >= bufferSize) {
+            logSorter.writeBuffer(destPath, buffer, parts++);
+            buffer.clear();
+          }
         }
-        map.close();
-        ns.create(SortedLogState.getFinishedMarkerPath(path)).close();
-        dirs.add(new Path(path));
+        logSorter.writeBuffer(destPath, buffer, parts);
+
+        ns.create(SortedLogState.getFinishedMarkerPath(destPath)).close();
+        dirs.add(new Path(destPath));
       }
       // Recover
-      SortedLogRecovery recovery = new SortedLogRecovery(fs);
+      SortedLogRecovery recovery = new SortedLogRecovery(context);
       CaptureMutations capture = new CaptureMutations();
       recovery.recover(extent, dirs, files, capture);
+      verify(context);
       return capture.result;
-    } finally {
-      root.delete();
     }
   }
 
@@ -312,20 +344,18 @@ public class SortedLogRecoveryTest {
     List<Mutation> mutations = recover(logs, extent);
     // Verify recovered data
     assertEquals(0, mutations.size());
-
   }
 
   @Test
-  public void testMissingDefinition() {
+  public void testMissingDefinition() throws IOException {
     // Create a test log
     KeyValue[] entries = {createKeyValue(OPEN, 0, -1, "1"),};
     Map<String,KeyValue[]> logs = new TreeMap<>();
     logs.put("testlog", entries);
     // Recover
-    try {
-      recover(logs, extent);
-      fail("tablet should not have been found");
-    } catch (Throwable t) {}
+    List<Mutation> mutations = recover(logs, extent);
+    // Verify recovered data
+    assertEquals(0, mutations.size());
   }
 
   @Test
@@ -396,7 +426,7 @@ public class SortedLogRecoveryTest {
     Mutation m = new ServerMutation(new Text("row1"));
     m.put(cf, cq, value);
     Mutation m2 = new ServerMutation(new Text("row2"));
-    m2.put(cf, cq, new Value("123".getBytes()));
+    m2.put(cf, cq, new Value("123"));
     KeyValue[] entries =
         {createKeyValue(OPEN, 0, -1, "1"), createKeyValue(DEFINE_TABLET, 1, 1, extent),
             createKeyValue(COMPACTION_START, 3, 1, "/t1/f1"),
@@ -423,7 +453,7 @@ public class SortedLogRecoveryTest {
     Mutation m = new ServerMutation(new Text("row1"));
     m.put(cf, cq, value);
     Mutation m2 = new ServerMutation(new Text("row2"));
-    m2.put(cf, cq, new Value("123".getBytes()));
+    m2.put(cf, cq, new Value("123"));
     KeyValue[] entries = {createKeyValue(OPEN, 0, -1, "1"),
         createKeyValue(DEFINE_TABLET, 1, 1, extent), createKeyValue(COMPACTION_FINISH, 2, 1, null),
         createKeyValue(COMPACTION_START, 4, 1, "/t1/f1"),
@@ -664,7 +694,7 @@ public class SortedLogRecoveryTest {
     Map<String,KeyValue[]> logs = new TreeMap<>();
     logs.put("entries", entries);
 
-    List<Mutation> mutations = recover(logs, Collections.singleton("/t/f1"), extent);
+    List<Mutation> mutations = recover(logs, Collections.singleton("/t/f1"), extent, bufferSize);
 
     assertEquals(0, mutations.size());
   }
@@ -687,7 +717,7 @@ public class SortedLogRecoveryTest {
     Map<String,KeyValue[]> logs = new TreeMap<>();
     logs.put("entries", entries);
 
-    List<Mutation> mutations = recover(logs, Collections.singleton("/t/f1"), extent);
+    List<Mutation> mutations = recover(logs, Collections.singleton("/t/f1"), extent, bufferSize);
 
     assertEquals(1, mutations.size());
     assertEquals(m, mutations.get(0));
@@ -757,6 +787,7 @@ public class SortedLogRecoveryTest {
     assertEquals(1, mutations1.size());
     assertEquals(m2, mutations1.get(0));
 
+    reset(context);
     List<Mutation> mutations2 = recover(logs, e2);
     assertEquals(2, mutations2.size());
     assertEquals(m3, mutations2.get(0));
@@ -767,6 +798,7 @@ public class SortedLogRecoveryTest {
     Arrays.sort(entries2);
     logs.put("entries2", entries2);
 
+    reset(context);
     mutations2 = recover(logs, e2);
     assertEquals(1, mutations2.size());
     assertEquals(m4, mutations2.get(0));
@@ -788,17 +820,16 @@ public class SortedLogRecoveryTest {
     Map<String,KeyValue[]> logs = new TreeMap<>();
     logs.put("entries", entries);
 
-    HashSet<String> filesSet = new HashSet<>();
-    filesSet.addAll(Arrays.asList(tabletFiles));
-    List<Mutation> mutations = recover(logs, filesSet, extent);
+    HashSet<String> filesSet = new HashSet<>(Arrays.asList(tabletFiles));
+    List<Mutation> mutations = recover(logs, filesSet, extent, bufferSize);
 
-    if (!startMatches) {
+    if (startMatches) {
+      assertEquals(1, mutations.size());
+      assertEquals(m2, mutations.get(0));
+    } else {
       assertEquals(2, mutations.size());
       assertEquals(m1, mutations.get(0));
       assertEquals(m2, mutations.get(1));
-    } else {
-      assertEquals(1, mutations.size());
-      assertEquals(m2, mutations.get(0));
     }
   }
 
@@ -807,6 +838,7 @@ public class SortedLogRecoveryTest {
     // test having different paths for the same file. This can happen as a result of upgrade or user
     // changing configuration
     runPathTest(false, "/t1/f1", "/t1/f0");
+    reset(context);
     runPathTest(true, "/t1/f1", "/t1/f0", "/t1/f1");
 
     String[] aliases = {"/t1/f1", "hdfs://nn1/accumulo/tables/8/t1/f1",
@@ -817,9 +849,12 @@ public class SortedLogRecoveryTest {
 
     for (String alias1 : aliases) {
       for (String alias2 : aliases) {
+        reset(context);
         runPathTest(true, alias1, alias2);
         for (String other : others) {
+          reset(context);
           runPathTest(true, alias1, other, alias2);
+          reset(context);
           runPathTest(true, alias1, alias2, other);
         }
       }
@@ -827,6 +862,7 @@ public class SortedLogRecoveryTest {
 
     for (String alias1 : aliases) {
       for (String other : others) {
+        reset(context);
         runPathTest(false, alias1, other);
       }
     }
@@ -855,7 +891,7 @@ public class SortedLogRecoveryTest {
   }
 
   @Test
-  public void testConsecutiveCompactionFinishEvents() throws IOException {
+  public void testConsecutiveCompactionFinishEvents() {
     Mutation m1 = new ServerMutation(new Text("r1"));
     m1.put("f1", "q1", "v1");
 
@@ -876,9 +912,8 @@ public class SortedLogRecoveryTest {
     Map<String,KeyValue[]> logs = new TreeMap<>();
     logs.put("entries1", entries1);
 
-    thrown.expect(IllegalStateException.class);
-    thrown.expectMessage("consecutive " + LogEvents.COMPACTION_FINISH.name());
-    recover(logs, extent);
+    var e = assertThrows(IllegalStateException.class, () -> recover(logs, extent));
+    assertTrue(e.getMessage().contains("consecutive " + LogEvents.COMPACTION_FINISH.name()));
   }
 
   @Test
@@ -907,6 +942,34 @@ public class SortedLogRecoveryTest {
     assertEquals(m2, mutations1.get(0));
   }
 
+  @Test
+  public void testMultipleCompactionStartEvents() throws IOException {
+    Mutation m1 = new ServerMutation(new Text("r1"));
+    m1.put("f1", "q1", "v1");
+
+    Mutation m2 = new ServerMutation(new Text("r2"));
+    m2.put("f1", "q1", "v2");
+
+    // The code that writes compaction start events retries on failures, this could lead to multiple
+    // compaction start events in the log. This should not cause any problems.
+
+    KeyValue[] entries1 = {createKeyValue(OPEN, 0, -1, "1"),
+        createKeyValue(DEFINE_TABLET, 100, 10, extent), createKeyValue(MUTATION, 100, 10, m1),
+        createKeyValue(COMPACTION_START, 102, 10, "/t/f1"),
+        createKeyValue(COMPACTION_START, 102, 10, "/t/f1"),
+        createKeyValue(COMPACTION_START, 102, 10, "/t/f1"),
+        createKeyValue(COMPACTION_FINISH, 103, 10, null), createKeyValue(MUTATION, 103, 10, m2)};
+
+    Arrays.sort(entries1);
+
+    Map<String,KeyValue[]> logs = new TreeMap<>();
+    logs.put("entries1", entries1);
+
+    List<Mutation> mutations1 = recover(logs, extent);
+    assertEquals(1, mutations1.size());
+    assertEquals(m2, mutations1.get(0));
+  }
+
   @Test
   public void testEmptyLogFiles() throws IOException {
     Mutation m1 = new ServerMutation(new Text("r1"));
@@ -950,36 +1013,41 @@ public class SortedLogRecoveryTest {
 
     logs.put("entries2", entries2);
 
+    reset(context);
     mutations = recover(logs, extent);
     assertEquals(1, mutations.size());
     assertEquals(m1, mutations.get(0));
 
     logs.put("entries3", entries3);
 
+    reset(context);
     mutations = recover(logs, extent);
     assertEquals(1, mutations.size());
     assertEquals(m1, mutations.get(0));
 
     logs.put("entries4", entries4);
 
+    reset(context);
     mutations = recover(logs, extent);
     assertEquals(1, mutations.size());
     assertEquals(m1, mutations.get(0));
 
     logs.put("entries5", entries5);
 
+    reset(context);
     mutations = recover(logs, extent);
     assertEquals(0, mutations.size());
 
     logs.put("entries6", entries6);
 
+    reset(context);
     mutations = recover(logs, extent);
     assertEquals(1, mutations.size());
     assertEquals(m2, mutations.get(0));
   }
 
   @Test
-  public void testFileWithoutOpen() throws IOException {
+  public void testFileWithoutOpen() {
     Mutation m1 = new ServerMutation(new Text("r1"));
     m1.put("f1", "q1", "v1");
 
@@ -998,8 +1066,110 @@ public class SortedLogRecoveryTest {
     Map<String,KeyValue[]> logs = new TreeMap<>();
     logs.put("entries1", entries1);
 
-    thrown.expect(IllegalStateException.class);
-    thrown.expectMessage("not " + LogEvents.OPEN);
-    recover(logs, extent);
+    var e = assertThrows(IllegalStateException.class, () -> recover(logs, extent));
+    assertTrue(e.getMessage().contains("not " + LogEvents.OPEN));
+  }
+
+  @Test
+  public void testInvalidLogSortedProperties() {
+    ConfigurationCopy testConfig = new ConfigurationCopy(DefaultConfiguration.getInstance());
+    // test all the possible properties for tserver.sort.file. prefix
+    String prop = Property.TSERV_WAL_SORT_FILE_PREFIX + "invalid";
+    testConfig.set(prop, "snappy");
+    assertThrows(IllegalArgumentException.class, () -> new LogSorter(context, testConfig),
+        "Did not throw IllegalArgumentException for " + prop);
+  }
+
+  @Test
+  public void testLogSortedProperties() throws Exception {
+    Mutation ignored = new ServerMutation(new Text("ignored"));
+    ignored.put(cf, cq, value);
+    Mutation m = new ServerMutation(new Text("row1"));
+    m.put(cf, cq, value);
+    ConfigurationCopy testConfig = new ConfigurationCopy(DefaultConfiguration.getInstance());
+    String sortFileCompression = "none";
+    // test all the possible properties for tserver.sort.file. prefix
+    String prefix = Property.TSERV_WAL_SORT_FILE_PREFIX.toString();
+    testConfig.set(prefix + "compress.type", sortFileCompression);
+    testConfig.set(prefix + "compress.blocksize", "50K");
+    testConfig.set(prefix + "compress.blocksize.index", "56K");
+    testConfig.set(prefix + "blocksize", "256B");
+    testConfig.set(prefix + "replication", "3");
+
+    final String workdir = new File(tempDir, testName()).getAbsolutePath();
+
+    try (var vm = VolumeManagerImpl.getLocalForTesting(workdir)) {
+      CryptoServiceFactory cryptoFactory = new GenericCryptoServiceFactory();
+      expect(context.getCryptoFactory()).andReturn(cryptoFactory).anyTimes();
+      expect(context.getVolumeManager()).andReturn(vm).anyTimes();
+      expect(context.getConfiguration()).andReturn(DefaultConfiguration.getInstance()).anyTimes();
+      replay(context);
+      LogSorter sorter = new LogSorter(context, testConfig);
+
+      final Path workdirPath = new Path("file://" + workdir);
+      vm.deleteRecursively(workdirPath);
+
+      KeyValue[] events =
+          {createKeyValue(OPEN, 0, -1, "1"), createKeyValue(DEFINE_TABLET, 1, 1, extent),
+              createKeyValue(COMPACTION_FINISH, 2, 1, null),
+              createKeyValue(COMPACTION_START, 4, 1, "/t1/f1"),
+              createKeyValue(COMPACTION_FINISH, 5, 1, null),
+              createKeyValue(MUTATION, 3, 1, ignored), createKeyValue(MUTATION, 5, 1, m)};
+      String dest = workdir + "/testLogSortedProperties";
+
+      List<Pair<LogFileKey,LogFileValue>> buffer = new ArrayList<>();
+      int parts = 0;
+      for (KeyValue pair : events) {
+        buffer.add(new Pair<>(pair.key, pair.value));
+        if (buffer.size() >= bufferSize) {
+          sorter.writeBuffer(dest, buffer, parts++);
+          buffer.clear();
+        }
+      }
+      sorter.writeBuffer(dest, buffer, parts);
+      FileSystem fs = vm.getFileSystemByPath(workdirPath);
+
+      // check contents of directory
+      for (var file : fs.listStatus(new Path(dest))) {
+        assertTrue(file.isFile());
+        try (var fileStream = fs.open(file.getPath())) {
+          var algo = getCompressionFromRFile(fileStream, file.getLen());
+          assertEquals(sortFileCompression, algo.getName());
+        }
+      }
+    }
+  }
+
+  /**
+   * Pulled from BCFile.Reader()
+   */
+  private final Utils.Version API_VERSION_3 = new Utils.Version((short) 3, (short) 0);
+
+  private CompressionAlgorithm getCompressionFromRFile(FSDataInputStream fsin, long fileLength)
+      throws IOException {
+    try (var in = new SeekableDataInputStream(fsin)) {
+      int magicNumberSize = 16; // BCFile.Magic.size();
+      // Move the cursor to grab the version and the magic first
+      in.seek(fileLength - magicNumberSize - Utils.Version.size());
+      var version = new Utils.Version(in);
+      assertEquals(API_VERSION_3, version);
+      in.readFully(new byte[16]); // BCFile.Magic.readAndVerify(in); // 16 bytes
+      in.seek(fileLength - magicNumberSize - Utils.Version.size() - 16); // 2 * Long.BYTES = 16
+      long offsetIndexMeta = in.readLong();
+      long offsetCryptoParameters = in.readLong();
+      assertTrue(offsetCryptoParameters > 0);
+
+      // read meta index
+      in.seek(offsetIndexMeta);
+      int count = Utils.readVInt(in);
+      assertTrue(count > 0);
+
+      String fullMetaName = Utils.readString(in);
+      String defaultPrefix = "data:";
+      if (fullMetaName != null && !fullMetaName.startsWith(defaultPrefix)) {
+        throw new IOException("Corrupted Meta region Index");
+      }
+      return Compression.getCompressionAlgorithmByName(Utils.readString(in));
+    }
   }
 }
