@@ -110,10 +110,11 @@ public class ShellCompletor implements Completer {
             if (next != null) {
               current_command_token = next;
 
-              if (current_command_token.getCaseSensitive())
+              if (current_command_token.getCaseSensitive()) {
                 prefix += current_string_token + " ";
-              else
+              } else {
                 prefix += current_string_token.toUpperCase() + " ";
+              }
 
               candidates.addAll(current_command_token.getSubcommandNames());
             }
@@ -124,41 +125,51 @@ public class ShellCompletor implements Completer {
         // need to match current command
         // if we're in -t <table>, -u <user>, or -tn <namespace> complete those
         if (inTableFlag) {
-          for (String a : options.get(Shell.Command.CompletionSet.TABLENAMES))
-            if (a.startsWith(current_string_token))
+          for (String a : options.get(Shell.Command.CompletionSet.TABLENAMES)) {
+            if (a.startsWith(current_string_token)) {
               candidates.add(a);
+            }
+          }
         } else if (inUserFlag) {
-          for (String a : options.get(Shell.Command.CompletionSet.USERNAMES))
-            if (a.startsWith(current_string_token))
+          for (String a : options.get(Shell.Command.CompletionSet.USERNAMES)) {
+            if (a.startsWith(current_string_token)) {
               candidates.add(a);
+            }
+          }
         } else if (inNamespaceFlag) {
-          for (String a : options.get(Shell.Command.CompletionSet.NAMESPACES))
-            if (a.startsWith(current_string_token))
+          for (String a : options.get(Shell.Command.CompletionSet.NAMESPACES)) {
+            if (a.startsWith(current_string_token)) {
               candidates.add(a);
-        } else if (current_command_token != null)
+            }
+          }
+        } else if (current_command_token != null) {
           candidates.addAll(current_command_token.getSubcommandNames(current_string_token));
+        }
 
         Collections.sort(candidates);
         return prefix.length();
       }
 
-      if (current_string_token.trim().equals("-" + Shell.tableOption))
+      if (current_string_token.trim().equals("-" + Shell.tableOption)) {
         inTableFlag = true;
-      else if (current_string_token.trim().equals("-" + Shell.userOption))
+      } else if (current_string_token.trim().equals("-" + Shell.userOption)) {
         inUserFlag = true;
-      else if (current_string_token.trim().equals("-" + Shell.namespaceOption))
+      } else if (current_string_token.trim().equals("-" + Shell.namespaceOption)) {
         inNamespaceFlag = true;
-      else
+      } else {
         inUserFlag = inTableFlag = inNamespaceFlag = false;
+      }
 
-      if (current_command_token != null && current_command_token.getCaseSensitive())
+      if (current_command_token != null && current_command_token.getCaseSensitive()) {
         prefix += current_string_token + " ";
-      else
+      } else {
         prefix += current_string_token.toUpperCase() + " ";
+      }
 
       if (current_command_token != null
-          && current_command_token.getSubcommandNames().contains(current_string_token))
+          && current_command_token.getSubcommandNames().contains(current_string_token)) {
         current_command_token = current_command_token.getSubcommand(current_string_token);
+      }
 
     }
     return 0;
