@@ -53,10 +53,19 @@ import org.jline.reader.LineReader;
 import com.google.common.collect.ImmutableSortedMap;
 
 public class ConfigCommand extends Command {
-  private Option tableOpt, deleteOpt, setOpt, forceOpt, filterOpt, filterWithValuesOpt,
-      disablePaginationOpt, outputFileOpt, namespaceOpt;
+  private Option tableOpt;
+  private Option deleteOpt;
+  private Option setOpt;
+  private Option forceOpt;
+  private Option filterOpt;
+  private Option filterWithValuesOpt;
+  private Option disablePaginationOpt;
+  private Option outputFileOpt;
+  private Option namespaceOpt;
+  private Option showExpOpt;
 
-  private int COL1 = 10, COL2 = 7;
+  private int COL1 = 10;
+  private int COL2 = 7;
   private LineReader reader;
 
   @Override
@@ -80,6 +89,7 @@ public class ConfigCommand extends Command {
     reader = shellState.getReader();
 
     boolean force = cl.hasOption(forceOpt);
+    boolean showExp = cl.hasOption(showExpOpt);
 
     final String tableName = cl.getOptionValue(tableOpt.getOpt());
     if (tableName != null && !shellState.getAccumuloClient().tableOperations().exists(tableName)) {
@@ -91,7 +101,7 @@ public class ConfigCommand extends Command {
       throw new NamespaceNotFoundException(null, namespace, null);
     }
     if (cl.hasOption(deleteOpt.getOpt())) {
-      // delete property from table
+      // delete property from table, namespace, or system
       String property = cl.getOptionValue(deleteOpt.getOpt());
       if (property.contains("=")) {
         throw new BadArgumentException("Invalid '=' operator in delete operation.", fullCommand,
@@ -116,10 +126,10 @@ public class ConfigCommand extends Command {
           Shell.log.warn(invalidTablePropFormatString, property);
         }
         shellState.getAccumuloClient().instanceOperations().removeProperty(property);
-        Shell.log.debug("Successfully deleted system configuration option.");
+        logSysPropChanged(Property.getPropertyByKey(property), "deleted");
       }
     } else if (cl.hasOption(setOpt.getOpt())) {
-      // set property on table
+      // set property on table, namespace, or system
       String property = cl.getOptionValue(setOpt.getOpt());
       String value;
       if (!property.contains("=")) {
@@ -168,7 +178,7 @@ public class ConfigCommand extends Command {
               fullCommand.indexOf(property));
         }
         shellState.getAccumuloClient().instanceOperations().setProperty(property, value);
-        Shell.log.debug("Successfully set system configuration option.");
+        logSysPropChanged(theProp, "set");
       }
     } else {
       boolean warned = false;
@@ -309,7 +319,8 @@ public class ConfigCommand extends Command {
           if (dfault != null && key.toLowerCase().contains("password")) {
             siteVal = sysVal = dfault = curVal = curVal.replaceAll(".", "*");
           }
-          if (defaults.containsKey(key) && !Property.getPropertyByKey(key).isExperimental()) {
+          if (defaults.containsKey(key)
+              && (!Property.getPropertyByKey(key).isExperimental() || showExp)) {
             printConfLine(output, "default", key, dfault);
             printed = true;
           }
@@ -327,7 +338,7 @@ public class ConfigCommand extends Command {
           // If the user can't see the system configuration, then print the default
           // configuration value if the current namespace value is different from it.
           if (sysVal == null && dfault != null && !dfault.equals(nspVal)
-              && !Property.getPropertyByKey(key).isExperimental()) {
+              && (!Property.getPropertyByKey(key).isExperimental() || showExp)) {
             printConfLine(output, "default", key, dfault);
             printed = true;
           }
@@ -342,7 +353,7 @@ public class ConfigCommand extends Command {
           // If the user can't see the system configuration, then print the default
           // configuration value if the current table value is different from it.
           if (nspVal == null && dfault != null && !dfault.equals(curVal)
-              && !Property.getPropertyByKey(key).isExperimental()) {
+              && (!Property.getPropertyByKey(key).isExperimental() || showExp)) {
             printConfLine(output, "default", key, dfault);
             printed = true;
           }
@@ -351,7 +362,7 @@ public class ConfigCommand extends Command {
           // If the user can't see the system configuration, then print the default
           // configuration value if the current namespace value is different from it.
           if (sysVal == null && dfault != null && !dfault.equals(curVal)
-              && !Property.getPropertyByKey(key).isExperimental()) {
+              && (!Property.getPropertyByKey(key).isExperimental() || showExp)) {
             printConfLine(output, "default", key, dfault);
             printed = true;
           }
@@ -400,7 +411,7 @@ public class ConfigCommand extends Command {
 
   @Override
   public String description() {
-    return "prints system properties and table specific properties";
+    return "prints table specific, namespace specific, and system properties";
   }
 
   @Override
@@ -411,10 +422,12 @@ public class ConfigCommand extends Command {
 
     tableOpt = new Option(ShellOptions.tableOption, "table", true,
         "table to display/set/delete properties for");
-    deleteOpt = new Option("d", "delete", true, "delete a per-table property");
-    setOpt = new Option("s", "set", true, "set a per-table property");
+    deleteOpt =
+        new Option("d", "delete", true, "delete a per-table, per-namespace, or system property");
+    setOpt = new Option("s", "set", true, "set a per-table, per-namespace, or system property");
     forceOpt = new Option("force", "force", false,
         "used with set to set a deprecated property without asking");
+    showExpOpt = new Option("show", "show-exp", false, "also show experimental properties");
     filterOpt = new Option("f", "filter", true,
         "show only properties that contain this string in their name.");
     filterWithValuesOpt = new Option("fv", "filter-with-values", true,
@@ -446,6 +459,7 @@ public class ConfigCommand extends Command {
     o.addOption(disablePaginationOpt);
     o.addOption(outputFileOpt);
     o.addOption(forceOpt);
+    o.addOption(showExpOpt);
 
     return o;
   }
@@ -455,4 +469,13 @@ public class ConfigCommand extends Command {
     return 0;
   }
 
+  private void logSysPropChanged(Property prop, String setOrDeleted) {
+    if (Property.isFixedZooPropertyKey(prop)) {
+      Shell.log.warn("Successfully {} a fixed system configuration option. Change will not "
+          + "take effect until related processes are restarted.", setOrDeleted);
+    } else {
+      Shell.log.debug("Successfully {} system configuration option.", setOrDeleted);
+    }
+  }
+
 }
