@@ -33,6 +33,7 @@ import java.util.TreeSet;
 import org.apache.accumulo.core.client.AccumuloException;
 import org.apache.accumulo.core.client.AccumuloSecurityException;
 import org.apache.accumulo.core.client.IteratorSetting;
+import org.apache.accumulo.core.client.NamespaceNotFoundException;
 import org.apache.accumulo.core.client.TableExistsException;
 import org.apache.accumulo.core.client.TableNotFoundException;
 import org.apache.accumulo.core.client.admin.NewTableConfiguration;
@@ -53,7 +54,10 @@ import org.apache.hadoop.io.Text;
 
 public class CreateTableCommand extends Command {
   private Option createTableOptCopySplits;
+  // copies configuration (property hierarchy: system, namespace, table) into table properties
   private Option createTableOptCopyConfig;
+  // copies properties from target table, (omits system and namespace properties in configuration)
+  private Option createTableOptExcludeParentProps;
   private Option createTableOptSplit;
   private Option createTableOptTimeLogical;
   private Option createTableOptTimeMillis;
@@ -69,10 +73,10 @@ public class CreateTableCommand extends Command {
   @Override
   public int execute(final String fullCommand, final CommandLine cl, final Shell shellState)
       throws AccumuloException, AccumuloSecurityException, TableExistsException,
-      TableNotFoundException, IOException {
+      TableNotFoundException, IOException, NamespaceNotFoundException {
 
     final String tableName = cl.getArgs()[0];
-    NewTableConfiguration ntc = new NewTableConfiguration();
+    var ntc = new NewTableConfiguration();
 
     NEW_TABLE_NAME.validate(tableName);
 
@@ -86,17 +90,24 @@ public class CreateTableCommand extends Command {
     // and then the addSplits method was called. Starting with 2.0, the splits will be
     // stored on the file system and created before the table is brought online.
     if (cl.hasOption(createTableOptSplit.getOpt())) {
-      ntc = ntc.withSplits(new TreeSet<>(
+      ntc.withSplits(new TreeSet<>(
           ShellUtil.scanFile(cl.getOptionValue(createTableOptSplit.getOpt()), decode)));
     } else if (cl.hasOption(createTableOptCopySplits.getOpt())) {
       final String oldTable = cl.getOptionValue(createTableOptCopySplits.getOpt());
       if (!shellState.getAccumuloClient().tableOperations().exists(oldTable)) {
         throw new TableNotFoundException(null, oldTable, null);
       }
-      ntc = ntc.withSplits(
+      ntc.withSplits(
           new TreeSet<>(shellState.getAccumuloClient().tableOperations().listSplits(oldTable)));
     }
 
+    // exclude parent properties; only valid with copy config
+    if (cl.hasOption(createTableOptExcludeParentProps.getLongOpt())
+        && !cl.hasOption(createTableOptCopyConfig.getOpt())) {
+      throw new IllegalArgumentException(createTableOptExcludeParentProps.getLongOpt()
+          + " only valid when using " + createTableOptCopyConfig.getLongOpt());
+    }
+
     if (cl.hasOption(createTableOptCopyConfig.getOpt())) {
       final String oldTable = cl.getOptionValue(createTableOptCopyConfig.getOpt());
       if (!shellState.getAccumuloClient().tableOperations().exists(oldTable)) {
@@ -109,48 +120,62 @@ public class CreateTableCommand extends Command {
       timeType = TimeType.LOGICAL;
     }
 
-    Map<String,String> props = ShellUtil.parseMapOpt(cl, createTableOptInitProp);
+    Map<String,String> initProperties =
+        new HashMap<>(ShellUtil.parseMapOpt(cl, createTableOptInitProp));
 
     // Set iterator if supplied
     if (cl.hasOption(createTableOptIteratorProps.getOpt())) {
-      ntc = attachIteratorToNewTable(cl, shellState, ntc);
+      attachIteratorToNewTable(cl, shellState, ntc);
     }
 
     // Set up locality groups, if supplied
     if (cl.hasOption(createTableOptLocalityProps.getOpt())) {
-      ntc = setLocalityForNewTable(cl, ntc);
+      setLocalityForNewTable(cl, ntc);
     }
 
     // set offline table creation property
     if (cl.hasOption(createTableOptOffline.getOpt())) {
-      ntc = ntc.createOffline();
+      ntc.createOffline();
+    }
+
+    // Copy configuration options if flag was set
+    if (cl.hasOption(createTableOptCopyConfig.getOpt())) {
+      String srcTable = cl.getOptionValue(createTableOptCopyConfig.getOpt());
+      if (cl.hasOption(createTableOptExcludeParentProps.getLongOpt())) {
+        // copy properties, excludes parent properties in configuration
+        Map<String,String> tableProps =
+            shellState.getAccumuloClient().tableOperations().getTableProperties(srcTable);
+        tableProps.entrySet().stream()
+            .filter(entry -> Property.isValidTablePropertyKey(entry.getKey()))
+            .forEach(entry -> initProperties.put(entry.getKey(), entry.getValue()));
+      } else {
+        // copy configuration (include parent properties)
+        final Map<String,String> configuration =
+            shellState.getAccumuloClient().tableOperations().getConfiguration(srcTable);
+        configuration.entrySet().stream()
+            .filter(entry -> Property.isValidTablePropertyKey(entry.getKey()))
+            .forEach(entry -> initProperties.put(entry.getKey(), entry.getValue()));
+      }
+    }
+
+    // if no defaults selected, remove, even if copied from configuration or properties
+    if (cl.hasOption(createTableNoDefaultIters.getOpt())) {
+      Set<String> initialProps = IteratorConfigUtil.generateInitialTableProperties(true).keySet();
+      initialProps.forEach(initProperties::remove);
+    }
+
+    // Load custom formatter if set
+    if (cl.hasOption(createTableOptFormatter.getOpt())) {
+      final String formatterClass = cl.getOptionValue(createTableOptFormatter.getOpt());
+      initProperties.put(Property.TABLE_FORMATTER_CLASS.toString(), formatterClass);
     }
 
     // create table.
     shellState.getAccumuloClient().tableOperations().create(tableName,
-        ntc.setTimeType(timeType).setProperties(props));
+        ntc.setTimeType(timeType).setProperties(initProperties));
 
     shellState.setTableName(tableName); // switch shell to new table context
 
-    if (cl.hasOption(createTableNoDefaultIters.getOpt())) {
-      Set<String> initialProps = IteratorConfigUtil.generateInitialTableProperties(true).keySet();
-      shellState.getAccumuloClient().tableOperations().modifyProperties(tableName,
-          properties -> initialProps.forEach(properties::remove));
-    }
-
-    // Copy options if flag was set
-    if (cl.hasOption(createTableOptCopyConfig.getOpt())) {
-      if (shellState.getAccumuloClient().tableOperations().exists(tableName)) {
-        final Map<String,String> configuration = shellState.getAccumuloClient().tableOperations()
-            .getConfiguration(cl.getOptionValue(createTableOptCopyConfig.getOpt()));
-
-        shellState.getAccumuloClient().tableOperations().modifyProperties(tableName,
-            properties -> configuration.entrySet().stream()
-                .filter(entry -> Property.isValidTablePropertyKey(entry.getKey()))
-                .forEach(entry -> properties.put(entry.getKey(), entry.getValue())));
-      }
-    }
-
     if (cl.hasOption(createTableOptEVC.getOpt())) {
       try {
         shellState.getAccumuloClient().tableOperations().addConstraint(tableName,
@@ -161,23 +186,16 @@ public class CreateTableCommand extends Command {
       }
     }
 
-    // Load custom formatter if set
-    if (cl.hasOption(createTableOptFormatter.getOpt())) {
-      final String formatterClass = cl.getOptionValue(createTableOptFormatter.getOpt());
-
-      shellState.getAccumuloClient().tableOperations().setProperty(tableName,
-          Property.TABLE_FORMATTER_CLASS.toString(), formatterClass);
-    }
     return 0;
   }
 
   /**
    * Add supplied locality groups information to a NewTableConfiguration object.
-   *
+   * <p>
    * Used in conjunction with createtable shell command to allow locality groups to be configured
    * upon table creation.
    */
-  private NewTableConfiguration setLocalityForNewTable(CommandLine cl, NewTableConfiguration ntc) {
+  private void setLocalityForNewTable(CommandLine cl, NewTableConfiguration ntc) {
     HashMap<String,Set<Text>> localityGroupMap = new HashMap<>();
     String[] options = cl.getOptionValues(createTableOptLocalityProps.getOpt());
     for (String localityInfo : options) {
@@ -197,17 +215,16 @@ public class CreateTableCommand extends Command {
       }
     }
     ntc.setLocalityGroups(localityGroupMap);
-    return ntc;
   }
 
   /**
    * Add supplied iterator information to NewTableConfiguration object.
-   *
+   * <p>
    * Used in conjunction with createtable shell command to allow an iterator to be configured upon
    * table creation.
    */
-  private NewTableConfiguration attachIteratorToNewTable(final CommandLine cl,
-      final Shell shellState, NewTableConfiguration ntc) {
+  private void attachIteratorToNewTable(final CommandLine cl, final Shell shellState,
+      NewTableConfiguration ntc) {
     EnumSet<IteratorScope> scopeEnumSet;
     IteratorSetting iteratorSetting;
     if (shellState.iteratorProfiles.isEmpty()) {
@@ -254,13 +271,12 @@ public class CreateTableCommand extends Command {
       }
       ntc.attachIterator(iteratorSetting, scopeEnumSet);
     }
-    return ntc;
   }
 
   /**
    * Validate that the provided scope arguments are valid iterator scope settings. Checking for
    * duplicate entries and invalid scope values.
-   *
+   * <p>
    * Returns an EnumSet of scopes to be set.
    */
   private EnumSet<IteratorScope> validateScopes(final List<String> scopeList) {
@@ -294,7 +310,9 @@ public class CreateTableCommand extends Command {
     final Options o = new Options();
 
     createTableOptCopyConfig =
-        new Option("cc", "copy-config", true, "table to copy configuration from");
+        new Option("cc", "copy-config", true, "table to copy effective configuration from");
+    createTableOptExcludeParentProps = new Option(null, "exclude-parent-properties", false,
+        "exclude properties from its parent(s) when copying configuration");
     createTableOptCopySplits =
         new Option("cs", "copy-splits", true, "table to copy current splits from");
     createTableOptSplit = new Option("sf", "splits-file", true,
@@ -345,6 +363,7 @@ public class CreateTableCommand extends Command {
     o.addOptionGroup(timeGroup);
     o.addOption(createTableOptSplit);
     o.addOption(createTableOptCopyConfig);
+    o.addOption(createTableOptExcludeParentProps);
     o.addOption(createTableNoDefaultIters);
     o.addOption(createTableOptEVC);
     o.addOption(createTableOptFormatter);
