@@ -1,18 +1,20 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.shell.commands;
 
@@ -24,11 +26,10 @@ import org.apache.accumulo.shell.Shell.Command;
 import org.apache.commons.cli.CommandLine;
 import org.apache.commons.cli.Option;
 import org.apache.commons.cli.Options;
+import org.jline.reader.History;
 
 import com.google.common.collect.Iterators;
 
-import jline.console.history.History.Entry;
-
 public class HistoryCommand extends Command {
   private Option clearHist;
   private Option disablePaginationOpt;
@@ -37,11 +38,11 @@ public class HistoryCommand extends Command {
   public int execute(final String fullCommand, final CommandLine cl, final Shell shellState)
       throws IOException {
     if (cl.hasOption(clearHist.getOpt())) {
-      shellState.getReader().getHistory().clear();
+      shellState.getReader().getHistory().purge();
     } else {
-      Iterator<Entry> source = shellState.getReader().getHistory().entries();
+      Iterator<History.Entry> source = shellState.getReader().getHistory().iterator();
       Iterator<String> historyIterator = Iterators.transform(source,
-          input -> String.format("%d: %s", input.index() + 1, input.value()));
+          input -> String.format("%d: %s", input.index() + 1, input.line()));
       shellState.printLines(historyIterator, !cl.hasOption(disablePaginationOpt.getOpt()));
     }
 
@@ -50,7 +51,7 @@ public class HistoryCommand extends Command {
 
   @Override
   public String description() {
-    return ("generates a list of commands previously executed");
+    return "generates a list of commands previously executed";
   }
 
   @Override
