@@ -46,7 +46,7 @@ public class MergeCommand extends Command {
     if (cl.hasOption(forceOpt.getOpt())) {
       force = true;
     }
-    if (cl.hasOption(allOpt.getOpt())) {
+    if (cl.hasOption(allOpt)) {
       all = true;
     }
     if (cl.hasOption(sizeOpt.getOpt())) {
@@ -95,9 +95,11 @@ public class MergeCommand extends Command {
         new Option("s", "size", true, "merge tablets to the given size over the entire table");
     forceOpt = new Option("f", "force", false,
         "merge small tablets to large tablets, even if it goes over the given size");
-    allOpt = new Option("", "all", false,
-        "allow an entire table to be merged into one tablet without prompting"
+    // Using the constructor does not allow for empty option
+    Option.Builder builder = Option.builder().longOpt("all").hasArg(false)
+        .desc("allow an entire table to be merged into one tablet without prompting"
             + " the user for confirmation");
+    allOpt = builder.build();
     o.addOption(OptUtil.startRowOpt());
     o.addOption(OptUtil.endRowOpt());
     o.addOption(OptUtil.tableOpt("table to be merged"));
