@@ -1,18 +1,20 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.shell.commands;
 
@@ -48,13 +50,19 @@ public class RevokeCommand extends TableOperation {
         : shellState.getAccumuloClient().whoami();
 
     permission = cl.getArgs()[0].split("\\.", 2);
-    if (cl.hasOption(systemOpt.getOpt()) && permission[0].equalsIgnoreCase("System")) {
-      try {
-        shellState.getAccumuloClient().securityOperations().revokeSystemPermission(user,
-            SystemPermission.valueOf(permission[1]));
-        Shell.log.debug("Revoked from {} the {} permission", user, permission[1]);
-      } catch (IllegalArgumentException e) {
-        throw new BadArgumentException("No such system permission", fullCommand,
+    if (permission[0].equalsIgnoreCase("System")) {
+      if (cl.hasOption(systemOpt.getOpt())) {
+        try {
+          shellState.getAccumuloClient().securityOperations().revokeSystemPermission(user,
+              SystemPermission.valueOf(permission[1]));
+          Shell.log.debug("Revoked from {} the {} permission", user, permission[1]);
+        } catch (IllegalArgumentException e) {
+          throw new BadArgumentException("No such system permission", fullCommand,
+              fullCommand.indexOf(cl.getArgs()[0]));
+        }
+      } else {
+        throw new BadArgumentException(
+            "Missing required option for granting System Permission: -s ", fullCommand,
             fullCommand.indexOf(cl.getArgs()[0]));
       }
     } else if (permission[0].equalsIgnoreCase("Table")) {
