@@ -41,6 +41,7 @@ import org.apache.accumulo.core.iterators.user.RegExFilter;
 import org.apache.accumulo.core.iterators.user.ReqVisFilter;
 import org.apache.accumulo.core.iterators.user.VersioningIterator;
 import org.apache.accumulo.core.metadata.MetadataTable;
+import org.apache.accumulo.core.spi.common.ContextClassLoaderFactory.ContextClassLoaderException;
 import org.apache.accumulo.shell.Shell;
 import org.apache.accumulo.shell.Shell.Command;
 import org.apache.accumulo.shell.ShellCommandException;
@@ -60,7 +61,7 @@ public class SetIterCommand extends Command {
   @Override
   public int execute(final String fullCommand, final CommandLine cl, final Shell shellState)
       throws AccumuloException, AccumuloSecurityException, TableNotFoundException, IOException,
-      ShellCommandException {
+      ShellCommandException, ContextClassLoaderException {
 
     boolean tables =
         cl.hasOption(OptUtil.tableOpt().getOpt()) || !shellState.getTableName().isEmpty();
@@ -109,7 +110,7 @@ public class SetIterCommand extends Command {
     }
 
     // Try to get the name provided by the setiter command
-    String name = cl.getOptionValue(nameOpt.getOpt(), null);
+    String name = cl.getOptionValue(nameOpt.getOpt());
 
     // Cannot continue if no name is provided
     if (name == null && configuredName == null) {
@@ -287,8 +288,9 @@ public class SetIterCommand extends Command {
                 input = new String(input);
               }
 
-              if (input.isEmpty())
+              if (input.isEmpty()) {
                 break;
+              }
 
               String[] sa = input.split(" ", 2);
               localOptions.put(sa[0], sa[1]);
@@ -297,8 +299,9 @@ public class SetIterCommand extends Command {
         }
 
         options.putAll(localOptions);
-        if (!iterOptions.validateOptions(options))
+        if (!iterOptions.validateOptions(options)) {
           writer.println("invalid options for " + clazzName);
+        }
 
       } while (!iterOptions.validateOptions(options));
     } else {
