@@ -1,23 +1,25 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.shell.commands;
 
 import java.util.Arrays;
-import java.util.Iterator;
+import java.util.Map;
 import java.util.Map.Entry;
 
 import org.apache.accumulo.core.client.AccumuloException;
@@ -32,7 +34,6 @@ import org.apache.commons.cli.Option;
 import org.apache.commons.cli.OptionGroup;
 import org.apache.commons.cli.Options;
 import org.apache.commons.cli.ParseException;
-import org.slf4j.LoggerFactory;
 
 public abstract class ShellPluginConfigurationCommand extends Command {
   private Option removePluginOption, pluginClassOption, listPluginOption;
@@ -59,20 +60,15 @@ public abstract class ShellPluginConfigurationCommand extends Command {
       // Remove the property
       removePlugin(cl, shellState, tableName);
 
-      shellState.getReader().println("Removed " + pluginType + " on " + tableName);
+      shellState.getWriter().println("Removed " + pluginType + " on " + tableName);
     } else if (cl.hasOption(listPluginOption.getOpt())) {
       // Get the options for this table
-      final Iterator<Entry<String,String>> iter =
-          shellState.getAccumuloClient().tableOperations().getProperties(tableName).iterator();
-
-      while (iter.hasNext()) {
-        Entry<String,String> ent = iter.next();
-
-        // List all parameters with the property name
-        if (ent.getKey().startsWith(tableProp.toString())) {
-          shellState.getReader().println(ent.getKey() + ": " + ent.getValue());
-        }
-      }
+      shellState.getAccumuloClient().tableOperations().getConfiguration(tableName)
+          .forEach((key, value) -> {
+            if (key.startsWith(tableProp.toString())) {
+              shellState.getWriter().println(key + ": " + value);
+            }
+          });
     } else {
       // Set the plugin with the provided options
       String className = cl.getOptionValue(pluginClassOption.getOpt());
@@ -98,15 +94,14 @@ public abstract class ShellPluginConfigurationCommand extends Command {
 
   public static <T> Class<? extends T> getPluginClass(final String tableName,
       final Shell shellState, final Class<T> clazz, final Property pluginProp) {
-    Iterator<Entry<String,String>> props;
+    Map<String,String> props;
     try {
-      props = shellState.getAccumuloClient().tableOperations().getProperties(tableName).iterator();
+      props = shellState.getAccumuloClient().tableOperations().getConfiguration(tableName);
     } catch (AccumuloException | TableNotFoundException e) {
       return null;
     }
 
-    while (props.hasNext()) {
-      final Entry<String,String> ent = props.next();
+    for (Entry<String,String> ent : props.entrySet()) {
       if (ent.getKey().equals(pluginProp.toString())) {
         Class<? extends T> pluginClazz;
         String[] args = new String[2];
@@ -119,20 +114,16 @@ public abstract class ShellPluginConfigurationCommand extends Command {
           pluginClazz =
               shellState.getClassLoader(cl, shellState).loadClass(ent.getValue()).asSubclass(clazz);
         } catch (ClassNotFoundException e) {
-          LoggerFactory.getLogger(ShellPluginConfigurationCommand.class).error("Class not found {}",
-              e.getMessage());
+          Shell.log.error("Class not found {}", e.getMessage());
           return null;
         } catch (ParseException e) {
-          LoggerFactory.getLogger(ShellPluginConfigurationCommand.class)
-              .error("Error parsing table: {} {}", Arrays.toString(args), e.getMessage());
+          Shell.log.error("Error parsing table: {} {}", Arrays.toString(args), e.getMessage());
           return null;
         } catch (TableNotFoundException e) {
-          LoggerFactory.getLogger(ShellPluginConfigurationCommand.class)
-              .error("Table not found: {} {}", tableName, e.getMessage());
+          Shell.log.error("Table not found: {} {}", tableName, e.getMessage());
           return null;
         } catch (Exception e) {
-          LoggerFactory.getLogger(ShellPluginConfigurationCommand.class).error("Error: {}",
-              e.getMessage());
+          Shell.log.error("Error: {}", e.getMessage());
           return null;
         }
 
