@@ -1,18 +1,20 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.shell.commands;
 
@@ -40,15 +42,15 @@ public class UserPermissionsCommand extends Command {
         cl.getOptionValue(userOpt.getOpt(), shellState.getAccumuloClient().whoami());
 
     String delim = "";
-    shellState.getReader().print("System permissions: ");
+    shellState.getWriter().print("System permissions: ");
     for (SystemPermission p : SystemPermission.values()) {
       if (p != null
           && shellState.getAccumuloClient().securityOperations().hasSystemPermission(user, p)) {
-        shellState.getReader().print(delim + "System." + p.name());
+        shellState.getWriter().print(delim + "System." + p.name());
         delim = ", ";
       }
     }
-    shellState.getReader().println();
+    shellState.getWriter().println();
 
     boolean runOnce = true;
     for (String n : shellState.getAccumuloClient().namespaceOperations().list()) {
@@ -57,16 +59,16 @@ public class UserPermissionsCommand extends Command {
         if (p != null && shellState.getAccumuloClient().securityOperations()
             .hasNamespacePermission(user, n, p)) {
           if (runOnce) {
-            shellState.getReader().print("\nNamespace permissions (" + n + "): ");
+            shellState.getWriter().print("\nNamespace permissions (" + n + "): ");
             runOnce = false;
           }
-          shellState.getReader().print(delim + "Namespace." + p.name());
+          shellState.getWriter().print(delim + "Namespace." + p.name());
           delim = ", ";
         }
       }
       runOnce = true;
     }
-    shellState.getReader().println();
+    shellState.getWriter().println();
 
     runOnce = true;
     for (String t : shellState.getAccumuloClient().tableOperations().list()) {
@@ -75,17 +77,17 @@ public class UserPermissionsCommand extends Command {
         if (shellState.getAccumuloClient().securityOperations().hasTablePermission(user, t, p)
             && p != null) {
           if (runOnce) {
-            shellState.getReader().print("\nTable permissions (" + t + "): ");
+            shellState.getWriter().print("\nTable permissions (" + t + "): ");
             runOnce = false;
           }
-          shellState.getReader().print(delim + "Table." + p.name());
+          shellState.getWriter().print(delim + "Table." + p.name());
           delim = ", ";
         }
 
       }
       runOnce = true;
     }
-    shellState.getReader().println();
+    shellState.getWriter().println();
 
     return 0;
   }
