@@ -1,18 +1,20 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.shell.commands;
 
@@ -22,16 +24,15 @@ import org.apache.accumulo.core.security.Authorizations;
 import org.apache.accumulo.shell.Shell;
 import org.apache.commons.cli.CommandLine;
 import org.easymock.EasyMock;
-import org.junit.Before;
-import org.junit.Test;
-
-import jline.console.ConsoleReader;
+import org.jline.reader.LineReader;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 public class DeleteAuthsCommandTest {
 
   private DeleteAuthsCommand cmd;
 
-  @Before
+  @BeforeEach
   public void setup() {
     cmd = new DeleteAuthsCommand();
 
@@ -44,7 +45,7 @@ public class DeleteAuthsCommandTest {
     AccumuloClient client = EasyMock.createMock(AccumuloClient.class);
     CommandLine cli = EasyMock.createMock(CommandLine.class);
     Shell shellState = EasyMock.createMock(Shell.class);
-    ConsoleReader reader = EasyMock.createMock(ConsoleReader.class);
+    LineReader reader = EasyMock.createMock(LineReader.class);
     SecurityOperations secOps = EasyMock.createMock(SecurityOperations.class);
 
     EasyMock.expect(shellState.getAccumuloClient()).andReturn(client);
@@ -73,7 +74,7 @@ public class DeleteAuthsCommandTest {
     AccumuloClient client = EasyMock.createMock(AccumuloClient.class);
     CommandLine cli = EasyMock.createMock(CommandLine.class);
     Shell shellState = EasyMock.createMock(Shell.class);
-    ConsoleReader reader = EasyMock.createMock(ConsoleReader.class);
+    LineReader reader = EasyMock.createMock(LineReader.class);
     SecurityOperations secOps = EasyMock.createMock(SecurityOperations.class);
 
     EasyMock.expect(shellState.getAccumuloClient()).andReturn(client);
@@ -102,7 +103,7 @@ public class DeleteAuthsCommandTest {
     AccumuloClient client = EasyMock.createMock(AccumuloClient.class);
     CommandLine cli = EasyMock.createMock(CommandLine.class);
     Shell shellState = EasyMock.createMock(Shell.class);
-    ConsoleReader reader = EasyMock.createMock(ConsoleReader.class);
+    LineReader reader = EasyMock.createMock(LineReader.class);
     SecurityOperations secOps = EasyMock.createMock(SecurityOperations.class);
 
     EasyMock.expect(shellState.getAccumuloClient()).andReturn(client);
