@@ -1,36 +1,39 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.shell.commands;
 
+import java.util.Optional;
+
 import org.apache.accumulo.core.client.AccumuloClient;
 import org.apache.accumulo.core.client.admin.SecurityOperations;
 import org.apache.accumulo.shell.Shell;
 import org.apache.commons.cli.CommandLine;
 import org.easymock.EasyMock;
-import org.junit.Before;
-import org.junit.Test;
-
-import jline.console.ConsoleReader;
+import org.jline.reader.LineReader;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 public class DropUserCommandTest {
 
   private DropUserCommand cmd;
 
-  @Before
+  @BeforeEach
   public void setup() {
     cmd = new DropUserCommand();
 
@@ -43,7 +46,7 @@ public class DropUserCommandTest {
     AccumuloClient client = EasyMock.createMock(AccumuloClient.class);
     CommandLine cli = EasyMock.createMock(CommandLine.class);
     Shell shellState = EasyMock.createMock(Shell.class);
-    ConsoleReader reader = EasyMock.createMock(ConsoleReader.class);
+    LineReader reader = EasyMock.createMock(LineReader.class);
     SecurityOperations secOps = EasyMock.createMock(SecurityOperations.class);
 
     EasyMock.expect(shellState.getAccumuloClient()).andReturn(client);
@@ -56,13 +59,7 @@ public class DropUserCommandTest {
 
     // Force option was not provided
     EasyMock.expect(cli.hasOption("f")).andReturn(false);
-    EasyMock.expect(shellState.getReader()).andReturn(reader);
-    reader.flush();
-    EasyMock.expectLastCall().once();
-
-    // Fake a "yes" response
-    EasyMock.expect(shellState.getReader()).andReturn(reader);
-    EasyMock.expect(reader.readLine(EasyMock.anyObject(String.class))).andReturn("yes");
+    EasyMock.expect(shellState.confirm("dropuser { user }")).andReturn(Optional.of(true));
     EasyMock.expect(shellState.getAccumuloClient()).andReturn(client);
 
     EasyMock.expect(client.securityOperations()).andReturn(secOps);
