@@ -1,44 +1,43 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.shell.commands;
 
 import java.io.PrintWriter;
-import java.io.Writer;
-import java.lang.reflect.Field;
 import java.util.EnumSet;
 
+import org.apache.accumulo.core.classloader.ClassLoaderUtil;
 import org.apache.accumulo.core.client.AccumuloClient;
 import org.apache.accumulo.core.client.IteratorSetting;
 import org.apache.accumulo.core.client.admin.TableOperations;
 import org.apache.accumulo.core.iterators.IteratorUtil.IteratorScope;
 import org.apache.accumulo.core.iterators.SortedKeyValueIterator;
 import org.apache.accumulo.shell.Shell;
-import org.apache.accumulo.start.classloader.vfs.AccumuloVFSClassLoader;
 import org.apache.commons.cli.CommandLine;
 import org.easymock.EasyMock;
-import org.junit.Before;
-import org.junit.Test;
-
-import jline.console.ConsoleReader;
+import org.jline.reader.LineReader;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 public class SetIterCommandTest {
   private SetIterCommand cmd;
 
-  @Before
+  @BeforeEach
   public void setup() {
     cmd = new SetIterCommand();
 
@@ -51,8 +50,8 @@ public class SetIterCommandTest {
     AccumuloClient client = EasyMock.createMock(AccumuloClient.class);
     CommandLine cli = EasyMock.createMock(CommandLine.class);
     Shell shellState = EasyMock.createMock(Shell.class);
-    ConsoleReader reader = EasyMock.createMock(ConsoleReader.class);
-    Writer out = EasyMock.createMock(PrintWriter.class);
+    LineReader reader = EasyMock.createMock(LineReader.class);
+    PrintWriter pw = EasyMock.createMock(PrintWriter.class);
     TableOperations tableOperations = EasyMock.createMock(TableOperations.class);
 
     // Command line parsing
@@ -70,22 +69,21 @@ public class SetIterCommandTest {
     EasyMock.expect(cli.hasOption("regex")).andReturn(false);
     EasyMock.expect(cli.hasOption("reqvis")).andReturn(false);
     EasyMock.expect(cli.hasOption("vers")).andReturn(false);
-    EasyMock.expect(cli.getOptionValue("n", null)).andReturn(null);
+    EasyMock.expect(cli.getOptionValue("n")).andReturn(null);
 
     // Loading the class
     EasyMock.expect(shellState.getClassLoader(cli, shellState))
-        .andReturn(AccumuloVFSClassLoader.getClassLoader());
-
-    // Set the output object
-    Field field = reader.getClass().getSuperclass().getDeclaredField("out");
-    field.setAccessible(true);
-    field.set(reader, out);
+        .andReturn(ClassLoaderUtil.getClassLoader(null));
 
     // Parsing iterator options
-    reader.flush();
+    pw.flush();
     EasyMock.expectLastCall().times(3);
 
+    pw.println(EasyMock.anyObject(String.class));
+    EasyMock.expectLastCall().times(2);
+
     EasyMock.expect(shellState.getReader()).andReturn(reader);
+    EasyMock.expect(shellState.getWriter()).andReturn(pw);
 
     // Shell asking for negate option, we pass in an empty string to pickup the default value of
     // 'false'
@@ -117,13 +115,15 @@ public class SetIterCommandTest {
         EasyMock.eq(EnumSet.allOf(IteratorScope.class)));
     EasyMock.expectLastCall().once();
 
-    EasyMock.replay(client, cli, shellState, reader, tableOperations);
+    EasyMock.expect(shellState.getTableName()).andReturn("foo").anyTimes();
+
+    EasyMock.replay(client, cli, shellState, reader, tableOperations, pw);
 
     cmd.execute(
         "setiter -all -p 21 -t foo"
             + " -class org.apache.accumulo.core.iterators.user.ColumnAgeOffFilter",
         cli, shellState);
 
-    EasyMock.verify(client, cli, shellState, reader, tableOperations);
+    EasyMock.verify(client, cli, shellState, reader, tableOperations, pw);
   }
 }
