@@ -1,23 +1,27 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.harness;
 
 import static com.google.common.base.Preconditions.checkState;
 import static java.nio.charset.StandardCharsets.UTF_8;
+import static org.apache.accumulo.harness.AccumuloITBase.STANDALONE_CAPABLE_CLUSTER;
+import static org.junit.jupiter.api.Assumptions.assumeTrue;
 
 import java.io.IOException;
 import java.util.Properties;
@@ -32,27 +36,21 @@ import org.apache.accumulo.core.client.AccumuloClient;
 import org.apache.accumulo.core.client.admin.SecurityOperations;
 import org.apache.accumulo.core.client.admin.TableOperations;
 import org.apache.accumulo.core.client.security.tokens.AuthenticationToken;
-import org.apache.accumulo.core.client.security.tokens.KerberosToken;
 import org.apache.accumulo.core.client.security.tokens.PasswordToken;
 import org.apache.accumulo.core.clientImpl.ClientInfo;
-import org.apache.accumulo.core.conf.Property;
-import org.apache.accumulo.core.security.TablePermission;
 import org.apache.accumulo.harness.conf.AccumuloClusterConfiguration;
 import org.apache.accumulo.harness.conf.AccumuloClusterPropertyConfiguration;
 import org.apache.accumulo.harness.conf.StandaloneAccumuloClusterConfiguration;
 import org.apache.accumulo.miniclusterImpl.MiniAccumuloConfigImpl;
 import org.apache.accumulo.server.ServerContext;
-import org.apache.accumulo.test.categories.StandaloneCapableClusterTests;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.fs.FileSystem;
-import org.apache.hadoop.fs.Path;
 import org.apache.hadoop.security.UserGroupInformation;
-import org.junit.After;
-import org.junit.AfterClass;
-import org.junit.Assume;
-import org.junit.Before;
-import org.junit.BeforeClass;
-import org.junit.experimental.categories.Category;
+import org.junit.jupiter.api.AfterAll;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Tag;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -62,7 +60,7 @@ import org.slf4j.LoggerFactory;
  * advanced ITs that do crazy things. For more typical, expected behavior of a cluster see
  * {@link SharedMiniClusterBase}. This instance can be MAC or a standalone instance.
  */
-@Category(StandaloneCapableClusterTests.class)
+@Tag(STANDALONE_CAPABLE_CLUSTER)
 public abstract class AccumuloClusterHarness extends AccumuloITBase
     implements MiniClusterConfigurationCallback, ClusterUsers {
   private static final Logger log = LoggerFactory.getLogger(AccumuloClusterHarness.class);
@@ -83,7 +81,7 @@ public abstract class AccumuloClusterHarness extends AccumuloITBase
   protected static AccumuloClusterPropertyConfiguration clusterConf;
   protected static TestingKdc krb;
 
-  @BeforeClass
+  @BeforeAll
   public static void setUpHarness() throws Exception {
     clusterConf = AccumuloClusterPropertyConfiguration.get();
     type = clusterConf.getClusterType();
@@ -98,7 +96,7 @@ public abstract class AccumuloClusterHarness extends AccumuloITBase
     initialized = true;
   }
 
-  @AfterClass
+  @AfterAll
   public static void tearDownHarness() {
     if (krb != null) {
       krb.stop();
@@ -112,18 +110,18 @@ public abstract class AccumuloClusterHarness extends AccumuloITBase
     return krb;
   }
 
-  @Before
+  @BeforeEach
   public void setupCluster() throws Exception {
     // Before we try to instantiate the cluster, check to see if the test even wants to run against
     // this type of cluster
-    Assume.assumeTrue(canRunTest(type));
+    assumeTrue(canRunTest(type));
 
     switch (type) {
       case MINI:
         MiniClusterHarness miniClusterHarness = new MiniClusterHarness();
         // Intrinsically performs the callback to let tests alter MiniAccumuloConfig and
         // core-site.xml
-        cluster = miniClusterHarness.create(this, getAdminToken(), krb);
+        cluster = miniClusterHarness.create(this, getAdminToken(), krb, this);
         // Login as the "root" user
         if (krb != null) {
           ClusterUser rootUser = krb.getRootUser();
@@ -174,46 +172,6 @@ public abstract class AccumuloClusterHarness extends AccumuloITBase
       cleanupUsers();
     }
 
-    switch (type) {
-      case MINI:
-        if (krb != null) {
-          final String traceTable = Property.TRACE_TABLE.getDefaultValue();
-          final ClusterUser systemUser = krb.getAccumuloServerUser(), rootUser = krb.getRootUser();
-
-          // Login as the trace user
-          UserGroupInformation.loginUserFromKeytab(systemUser.getPrincipal(),
-              systemUser.getKeytab().getAbsolutePath());
-
-          // Create client as the system user (ensures the user will exist for us to assign
-          // permissions to)
-          UserGroupInformation.loginUserFromKeytab(systemUser.getPrincipal(),
-              systemUser.getKeytab().getAbsolutePath());
-          AccumuloClient c =
-              cluster.createAccumuloClient(systemUser.getPrincipal(), new KerberosToken());
-          c.close();
-
-          // Then, log back in as the "root" user and do the grant
-          UserGroupInformation.loginUserFromKeytab(rootUser.getPrincipal(),
-              rootUser.getKeytab().getAbsolutePath());
-
-          try (AccumuloClient client = Accumulo.newClient().from(getClientProps()).build()) {
-            // Create the trace table
-            client.tableOperations().create(traceTable);
-
-            // Trace user (which is the same kerberos principal as the system user, but using a
-            // normal KerberosToken) needs to be able to read, write and alter the trace table
-            client.securityOperations().grantTablePermission(systemUser.getPrincipal(), traceTable,
-                TablePermission.READ);
-            client.securityOperations().grantTablePermission(systemUser.getPrincipal(), traceTable,
-                TablePermission.WRITE);
-            client.securityOperations().grantTablePermission(systemUser.getPrincipal(), traceTable,
-                TablePermission.ALTER_TABLE);
-          }
-        }
-        break;
-      default:
-        // do nothing
-    }
   }
 
   public void cleanupTables() throws Exception {
@@ -242,7 +200,7 @@ public abstract class AccumuloClusterHarness extends AccumuloITBase
     }
   }
 
-  @After
+  @AfterEach
   public void teardownCluster() throws Exception {
     if (cluster != null) {
       if (type.isDynamic()) {
@@ -330,8 +288,7 @@ public abstract class AccumuloClusterHarness extends AccumuloITBase
           return krb.getClientPrincipal(offset);
         } else {
           // Come up with a mostly unique name
-          String principal =
-              getClass().getSimpleName() + "_" + testName.getMethodName() + "_" + offset;
+          String principal = getClass().getSimpleName() + "_" + testName() + "_" + offset;
           // Username and password are the same
           return new ClusterUser(principal, principal);
         }
@@ -366,13 +323,4 @@ public abstract class AccumuloClusterHarness extends AccumuloITBase
     return true;
   }
 
-  /**
-   * Tries to give a reasonable directory which can be used to create temporary files for the test.
-   * Makes a basic attempt to create the directory if it does not already exist.
-   *
-   * @return A directory which can be expected to exist on the Cluster's FileSystem
-   */
-  public Path getUsableDir() throws IllegalArgumentException {
-    return cluster.getTemporaryPath();
-  }
 }
