@@ -1,24 +1,27 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.test;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
+import java.time.Duration;
 import java.util.TreeSet;
 
 import org.apache.accumulo.core.client.Accumulo;
@@ -33,7 +36,7 @@ import org.apache.hadoop.fs.FsShell;
 import org.apache.hadoop.fs.Path;
 import org.apache.hadoop.fs.RawLocalFileSystem;
 import org.apache.hadoop.io.Text;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -47,8 +50,8 @@ public class BulkImportSequentialRowsIT extends AccumuloClusterHarness {
   private static final long NV = 42000;
 
   @Override
-  public int defaultTimeoutSeconds() {
-    return 60;
+  protected Duration defaultTimeout() {
+    return Duration.ofMinutes(1);
   }
 
   @Override
@@ -67,7 +70,7 @@ public class BulkImportSequentialRowsIT extends AccumuloClusterHarness {
       TableOperations to = client.tableOperations();
       to.create(tableName);
       FileSystem fs = getFileSystem();
-      Path rootPath = new Path(fs.makeQualified(getUsableDir()), getClass().getSimpleName());
+      Path rootPath = new Path(cluster.getTemporaryPath(), getClass().getSimpleName());
       log.info("Writing to {}", rootPath);
       if (fs.exists(rootPath)) {
         assertTrue(fs.delete(rootPath, true));
@@ -87,11 +90,11 @@ public class BulkImportSequentialRowsIT extends AccumuloClusterHarness {
       GenerateSequentialRFile.main(new String[] {"-f", rfile.toUri().toString(), "-nr",
           Long.toString(NR), "-nv", Long.toString(NV)});
 
-      assertTrue("Expected that " + rfile + " exists, but it does not", fs.exists(rfile));
+      assertTrue(fs.exists(rfile), "Expected that " + rfile + " exists, but it does not");
 
       FsShell fsShell = new FsShell(fs.getConf());
-      assertEquals("Failed to chmod " + rootPath, 0,
-          fsShell.run(new String[] {"-chmod", "-R", "777", rootPath.toString()}));
+      assertEquals(0, fsShell.run(new String[] {"-chmod", "-R", "777", rootPath.toString()}),
+          "Failed to chmod " + rootPath);
 
       // Add some splits
       to.addSplits(tableName, getSplits());
