@@ -1,30 +1,32 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to you under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- * http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.test;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
+import java.time.Duration;
 import java.util.Arrays;
 import java.util.Collections;
 import java.util.HashMap;
-import java.util.HashSet;
 import java.util.Iterator;
 import java.util.Map;
 import java.util.Map.Entry;
@@ -46,14 +48,14 @@ import org.apache.accumulo.core.data.Value;
 import org.apache.accumulo.core.iterators.OrIterator;
 import org.apache.accumulo.harness.AccumuloClusterHarness;
 import org.apache.hadoop.io.Text;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 public class OrIteratorIT extends AccumuloClusterHarness {
   private static final String EMPTY = "";
 
   @Override
-  public int defaultTimeoutSeconds() {
-    return 60;
+  protected Duration defaultTimeout() {
+    return Duration.ofMinutes(1);
   }
 
   @Test
@@ -84,16 +86,16 @@ public class OrIteratorIT extends AccumuloClusterHarness {
       expectedData.put("mort", "6");
 
       try (BatchScanner bs = client.createBatchScanner(tableName)) {
-        Set<Range> ranges = new HashSet<>(Arrays.asList(Range.exact("row1"), Range.exact("row2")));
+        Set<Range> ranges = Set.of(Range.exact("row1"), Range.exact("row2"));
         bs.setRanges(ranges);
         bs.addScanIterator(is);
         for (Entry<Key,Value> entry : bs) {
           String term = entry.getKey().getColumnFamily().toString();
           String expectedDocId = expectedData.remove(term);
-          assertNotNull("Found unexpected term: " + term, expectedDocId);
+          assertNotNull(expectedDocId, "Found unexpected term: " + term);
           assertEquals(expectedDocId, entry.getKey().getColumnQualifier().toString());
         }
-        assertTrue("Expected no leftover entries but saw " + expectedData, expectedData.isEmpty());
+        assertTrue(expectedData.isEmpty(), "Expected no leftover entries but saw " + expectedData);
       }
     }
   }
@@ -142,10 +144,10 @@ public class OrIteratorIT extends AccumuloClusterHarness {
         for (Entry<Key,Value> entry : bs) {
           String term = entry.getKey().getColumnFamily().toString();
           String expectedDocId = expectedData.remove(term);
-          assertNotNull("Found unexpected term: " + term, expectedDocId);
+          assertNotNull(expectedDocId, "Found unexpected term: " + term);
           assertEquals(expectedDocId, entry.getKey().getColumnQualifier().toString());
         }
-        assertTrue("Expected no leftover entries but saw " + expectedData, expectedData.isEmpty());
+        assertTrue(expectedData.isEmpty(), "Expected no leftover entries but saw " + expectedData);
       }
     }
   }
@@ -189,11 +191,11 @@ public class OrIteratorIT extends AccumuloClusterHarness {
         for (Entry<Key,Value> entry : bs) {
           String term = entry.getKey().getColumnFamily().toString();
           String expectedDocId = expectedData.remove(term);
-          assertNotNull("Found unexpected term: " + term + " or the docId was unexpectedly null",
-              expectedDocId);
+          assertNotNull(expectedDocId,
+              "Found unexpected term: " + term + " or the docId was unexpectedly null");
           assertEquals(expectedDocId, entry.getKey().getColumnQualifier().toString());
         }
-        assertTrue("Expected no leftover entries but saw " + expectedData, expectedData.isEmpty());
+        assertTrue(expectedData.isEmpty(), "Expected no leftover entries but saw " + expectedData);
       }
     }
   }
@@ -226,7 +228,7 @@ public class OrIteratorIT extends AccumuloClusterHarness {
       try (BatchScanner bs = client.createBatchScanner(tableName)) {
         bs.setRanges(Collections.singleton(new Range()));
         bs.addScanIterator(is);
-        assertFalse("Found matches when none expected", bs.iterator().hasNext());
+        assertFalse(bs.iterator().hasNext(), "Found matches when none expected");
       }
     }
   }
@@ -277,11 +279,11 @@ public class OrIteratorIT extends AccumuloClusterHarness {
         for (Entry<Key,Value> entry : bs) {
           String term = entry.getKey().getColumnFamily().toString();
           String expectedDocId = expectedData.remove(term);
-          assertNotNull("Found unexpected term: " + term + " or the docId was unexpectedly null",
-              expectedDocId);
+          assertNotNull(expectedDocId,
+              "Found unexpected term: " + term + " or the docId was unexpectedly null");
           assertEquals(expectedDocId, entry.getKey().getColumnQualifier().toString());
         }
-        assertTrue("Expected no leftover entries but saw " + expectedData, expectedData.isEmpty());
+        assertTrue(expectedData.isEmpty(), "Expected no leftover entries but saw " + expectedData);
       }
     }
   }
@@ -308,12 +310,12 @@ public class OrIteratorIT extends AccumuloClusterHarness {
         Iterator<Entry<Key,Value>> iter = s.iterator();
         assertTrue(iter.hasNext());
         Key k = iter.next().getKey();
-        assertEquals("Actual key was " + k, 0,
-            k.compareTo(new Key("row1", "steve", "1"), PartialKey.ROW_COLFAM_COLQUAL));
+        assertEquals(0, k.compareTo(new Key("row1", "steve", "1"), PartialKey.ROW_COLFAM_COLQUAL),
+            "Actual key was " + k);
         assertTrue(iter.hasNext());
         k = iter.next().getKey();
-        assertEquals("Actual key was " + k, 0,
-            k.compareTo(new Key("row1", "bob", "2"), PartialKey.ROW_COLFAM_COLQUAL));
+        assertEquals(0, k.compareTo(new Key("row1", "bob", "2"), PartialKey.ROW_COLFAM_COLQUAL),
+            "Actual key was " + k);
         assertFalse(iter.hasNext());
       }
     }
