@@ -1,26 +1,34 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.test;
 
-import static org.junit.Assert.assertEquals;
+import static java.nio.charset.StandardCharsets.UTF_8;
+import static org.junit.jupiter.api.Assertions.assertEquals;
 
+import java.time.Duration;
+import java.util.ArrayList;
 import java.util.Collections;
 import java.util.Iterator;
+import java.util.List;
 import java.util.Map;
+import java.util.TreeSet;
+import java.util.concurrent.atomic.AtomicInteger;
 
 import org.apache.accumulo.core.client.Accumulo;
 import org.apache.accumulo.core.client.AccumuloClient;
@@ -37,10 +45,9 @@ import org.apache.accumulo.core.security.Authorizations;
 import org.apache.accumulo.harness.AccumuloClusterHarness;
 import org.apache.accumulo.miniclusterImpl.MiniAccumuloConfigImpl;
 import org.apache.accumulo.test.functional.YieldingIterator;
-import org.apache.commons.lang3.StringUtils;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.io.Text;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -50,8 +57,8 @@ public class YieldScannersIT extends AccumuloClusterHarness {
   private static final char START_ROW = 'a';
 
   @Override
-  public int defaultTimeoutSeconds() {
-    return 60;
+  protected Duration defaultTimeout() {
+    return Duration.ofMinutes(1);
   }
 
   @Override
@@ -65,11 +72,11 @@ public class YieldScannersIT extends AccumuloClusterHarness {
     final String tableName = getUniqueNames(1)[0];
     try (AccumuloClient client = Accumulo.newClient().from(getClientProps()).build()) {
       client.tableOperations().create(tableName);
-      final BatchWriter writer = client.createBatchWriter(tableName, new BatchWriterConfig());
+      final BatchWriter writer = client.createBatchWriter(tableName);
       for (int i = 0; i < 10; i++) {
         byte[] row = {(byte) (START_ROW + i)};
         Mutation m = new Mutation(new Text(row));
-        m.put(new Text(), new Text(), new Value());
+        m.put("", "", "");
         writer.addMutation(m);
       }
       writer.flush();
@@ -88,28 +95,27 @@ public class YieldScannersIT extends AccumuloClusterHarness {
         int yieldSeekCount = 0;
         while (it.hasNext()) {
           Map.Entry<Key,Value> next = it.next();
-          log.info(Integer.toString(keyCount) + ": Got key " + next.getKey() + " with value "
-              + next.getValue());
+          log.info(keyCount + ": Got key " + next.getKey() + " with value " + next.getValue());
 
           // verify we got the expected key
           char expected = (char) (START_ROW + keyCount);
-          assertEquals("Unexpected row", Character.toString(expected),
-              next.getKey().getRow().toString());
+          assertEquals(Character.toString(expected), next.getKey().getRow().toString(),
+              "Unexpected row");
 
           // determine whether we yielded on a next and seek
           if ((keyCount & 1) != 0) {
             yieldNextCount++;
             yieldSeekCount++;
           }
-          String[] value = StringUtils.split(next.getValue().toString(), ',');
-          assertEquals("Unexpected yield next count", Integer.toString(yieldNextCount), value[0]);
-          assertEquals("Unexpected yield seek count", Integer.toString(yieldSeekCount), value[1]);
-          assertEquals("Unexpected rebuild count",
-              Integer.toString(yieldNextCount + yieldSeekCount), value[2]);
+          String[] value = next.getValue().toString().split(",");
+          assertEquals(Integer.toString(yieldNextCount), value[0], "Unexpected yield next count");
+          assertEquals(Integer.toString(yieldSeekCount), value[1], "Unexpected yield seek count");
+          assertEquals(Integer.toString(yieldNextCount + yieldSeekCount), value[2],
+              "Unexpected rebuild count");
 
           keyCount++;
         }
-        assertEquals("Did not get the expected number of results", 10, keyCount);
+        assertEquals(10, keyCount, "Did not get the expected number of results");
       }
     }
   }
@@ -120,11 +126,11 @@ public class YieldScannersIT extends AccumuloClusterHarness {
     final String tableName = getUniqueNames(1)[0];
     try (AccumuloClient client = Accumulo.newClient().from(getClientProps()).build()) {
       client.tableOperations().create(tableName);
-      final BatchWriter writer = client.createBatchWriter(tableName, new BatchWriterConfig());
+      final BatchWriter writer = client.createBatchWriter(tableName);
       for (int i = 0; i < 10; i++) {
         byte[] row = {(byte) (START_ROW + i)};
         Mutation m = new Mutation(new Text(row));
-        m.put(new Text(), new Text(), new Value());
+        m.put("", "", "");
         writer.addMutation(m);
       }
       writer.flush();
@@ -144,28 +150,74 @@ public class YieldScannersIT extends AccumuloClusterHarness {
         int yieldSeekCount = 0;
         while (it.hasNext()) {
           Map.Entry<Key,Value> next = it.next();
-          log.info(Integer.toString(keyCount) + ": Got key " + next.getKey() + " with value "
-              + next.getValue());
+          log.info(keyCount + ": Got key " + next.getKey() + " with value " + next.getValue());
 
           // verify we got the expected key
           char expected = (char) (START_ROW + keyCount);
-          assertEquals("Unexpected row", Character.toString(expected),
-              next.getKey().getRow().toString());
+          assertEquals(Character.toString(expected), next.getKey().getRow().toString(),
+              "Unexpected row");
 
           // determine whether we yielded on a next and seek
           if ((keyCount & 1) != 0) {
             yieldNextCount++;
             yieldSeekCount++;
           }
-          String[] value = StringUtils.split(next.getValue().toString(), ',');
-          assertEquals("Unexpected yield next count", Integer.toString(yieldNextCount), value[0]);
-          assertEquals("Unexpected yield seek count", Integer.toString(yieldSeekCount), value[1]);
-          assertEquals("Unexpected rebuild count",
-              Integer.toString(yieldNextCount + yieldSeekCount), value[2]);
+          String[] value = next.getValue().toString().split(",");
+          assertEquals(Integer.toString(yieldNextCount), value[0], "Unexpected yield next count");
+          assertEquals(Integer.toString(yieldSeekCount), value[1], "Unexpected yield seek count");
+          assertEquals(Integer.toString(yieldNextCount + yieldSeekCount), value[2],
+              "Unexpected rebuild count");
 
           keyCount++;
         }
-        assertEquals("Did not get the expected number of results", 10, keyCount);
+        assertEquals(10, keyCount, "Did not get the expected number of results");
+      }
+    }
+  }
+
+  @Test
+  public void testBatchScanWithSplits() throws Exception {
+    // make a table
+    final String tableName = getUniqueNames(1)[0];
+    TreeSet<Text> splits = new TreeSet<>();
+    try (AccumuloClient client = Accumulo.newClient().from(getClientProps()).build()) {
+      client.tableOperations().create(tableName);
+      List<Range> ranges = new ArrayList<>();
+      final int alphabetLength = 26;
+      try (BatchWriter writer = client.createBatchWriter(tableName, new BatchWriterConfig())) {
+        for (int i = 0; i < alphabetLength; i++) {
+          byte[] row = new byte[] {(byte) (START_ROW + i)};
+          Text beginRow = new Text(row);
+          Mutation m = new Mutation(beginRow);
+          m.put(new Text(), new Text(), new Value());
+          writer.addMutation(m);
+          Text endRow = new Text(row);
+          endRow.append("\0".getBytes(UTF_8), 0, 1);
+          ranges.add(new Range(new Text(row), endRow));
+          if (i % 4 == 0) {
+            splits.add(beginRow);
+          }
+        }
+        client.tableOperations().addSplits(tableName, splits);
+        writer.flush();
+      }
+
+      log.info("Creating batch scanner");
+      try (BatchScanner scanner = client.createBatchScanner(tableName, Authorizations.EMPTY, 1)) {
+        final IteratorSetting cfg = new IteratorSetting(100, YieldingIterator.class);
+        scanner.addScanIterator(cfg);
+        scanner.setRanges(ranges);
+
+        final AtomicInteger keyCount = new AtomicInteger();
+        scanner.stream().sorted(Map.Entry.comparingByKey()).forEach(entry -> {
+          log.info("{}: Got key '{}' with value '{}'", keyCount, entry.getKey(), entry.getValue());
+          // verify we got the expected key
+          char expected = (char) (START_ROW + keyCount.get());
+          assertEquals(Character.toString(expected), entry.getKey().getRow().toString(),
+              "Unexpected row");
+          keyCount.getAndIncrement();
+        });
+        assertEquals(alphabetLength, keyCount.get(), "Did not get the expected number of results");
       }
     }
   }
