@@ -18,7 +18,7 @@
  */
 package org.apache.accumulo.test.compaction;
 
-import static java.util.concurrent.TimeUnit.NANOSECONDS;
+import static java.util.concurrent.TimeUnit.MILLISECONDS;
 import static org.apache.accumulo.core.util.UtilWaitThread.sleepUninterruptibly;
 import static org.apache.accumulo.test.compaction.ExternalCompactionTestUtils.QUEUE1;
 import static org.apache.accumulo.test.compaction.ExternalCompactionTestUtils.compact;
@@ -183,7 +183,7 @@ public class ExternalCompactionProgressIT extends AccumuloClusterHarness {
           .getCompactions().values().iterator().next();
       RunningCompactionInfo updatedCompactionInfo = new RunningCompactionInfo(updatedCompaction);
 
-      final Duration reportedCompactionDuration = Duration.ofNanos(updatedCompactionInfo.duration);
+      final Duration reportedCompactionDuration = Duration.ofMillis(updatedCompactionInfo.duration);
       final Duration measuredCompactionDuration =
           Duration.ofNanos(System.nanoTime() - compactionStartTime);
       final Duration coordinatorAge = Duration.ofNanos(System.nanoTime() - coordinatorRestartTime);
@@ -270,7 +270,7 @@ public class ExternalCompactionProgressIT extends AccumuloClusterHarness {
    */
   private static Thread getMetricsCheckerThread(AtomicLong totalEntriesRead,
       AtomicLong totalEntriesWritten) {
-    return Threads.createThread("metric-tailer", () -> {
+    return Threads.createNonCriticalThread("metric-tailer", () -> {
       log.info("Starting metric tailer");
 
       sink.getLines().clear();
@@ -282,11 +282,16 @@ public class ExternalCompactionProgressIT extends AccumuloClusterHarness {
             break out;
           }
           TestStatsDSink.Metric metric = TestStatsDSink.parseStatsDMetric(s);
-          if (!metric.getName().startsWith(MetricsProducer.METRICS_COMPACTOR_PREFIX)) {
+          // When the tablet server flushes memory to disk that can cause metrics that may throw the
+          // test off, so only look for metrics from the compactor.
+          String process = metric.getTags().getOrDefault("process.name", "none");
+          if (!metric.getName().startsWith(MetricsProducer.METRICS_COMPACTOR_PREFIX)
+              || !process.equals("compactor")) {
             continue;
           }
           int value = Integer.parseInt(metric.getValue());
-          log.debug("Found metric: {} with value: {}", metric.getName(), value);
+          log.debug("Found metric: {} {} with value: {}", metric.getName(), metric.getTags(),
+              value);
           switch (metric.getName()) {
             case MetricsProducer.METRICS_COMPACTOR_ENTRIES_READ:
               totalEntriesRead.addAndGet(value);
@@ -408,7 +413,7 @@ public class ExternalCompactionProgressIT extends AccumuloClusterHarness {
   }
 
   public Thread startChecker() {
-    return Threads.createThread("RC checker", () -> {
+    return Threads.createNonCriticalThread("RC checker", () -> {
       try {
         while (!stopCheckerThread.get()) {
           checkRunning();
@@ -432,7 +437,7 @@ public class ExternalCompactionProgressIT extends AccumuloClusterHarness {
         RunningCompactionInfo rci = new RunningCompactionInfo(ec);
         RunningCompactionInfo previousRci = runningMap.put(ecid, rci);
         log.debug("ECID {} has been running for {} seconds", ecid,
-            NANOSECONDS.toSeconds(rci.duration));
+            MILLISECONDS.toSeconds(rci.duration));
         if (previousRci == null) {
           log.debug("New ECID {} with inputFiles: {}", ecid, rci.numFiles);
         } else {
