@@ -39,8 +39,9 @@ public class MaxMutationSize implements Constraint {
 
   @Override
   public List<Short> check(Environment env, Mutation mutation) {
-    if (mutation.estimatedMemoryUsed() < MAX_SIZE)
+    if (mutation.estimatedMemoryUsed() < MAX_SIZE) {
       return empty;
+    }
     return violations;
   }
 }
