@@ -19,12 +19,12 @@
 package org.apache.accumulo.test.fate.zookeeper;
 
 import static java.nio.charset.StandardCharsets.UTF_8;
+import static java.util.concurrent.TimeUnit.SECONDS;
 import static org.apache.accumulo.core.fate.ReadOnlyTStore.TStatus.FAILED;
 import static org.apache.accumulo.core.fate.ReadOnlyTStore.TStatus.FAILED_IN_PROGRESS;
 import static org.apache.accumulo.core.fate.ReadOnlyTStore.TStatus.IN_PROGRESS;
 import static org.apache.accumulo.core.fate.ReadOnlyTStore.TStatus.NEW;
 import static org.apache.accumulo.core.fate.ReadOnlyTStore.TStatus.SUBMITTED;
-import static org.apache.accumulo.core.fate.ReadOnlyTStore.TStatus.SUCCESSFUL;
 import static org.apache.accumulo.harness.AccumuloITBase.ZOOKEEPER_TESTING_SERVER;
 import static org.easymock.EasyMock.createMock;
 import static org.easymock.EasyMock.expect;
@@ -40,6 +40,8 @@ import java.util.ArrayList;
 import java.util.List;
 import java.util.UUID;
 import java.util.concurrent.CountDownLatch;
+import java.util.concurrent.ScheduledThreadPoolExecutor;
+import java.util.concurrent.atomic.AtomicBoolean;
 
 import org.apache.accumulo.core.Constants;
 import org.apache.accumulo.core.clientImpl.thrift.TableOperation;
@@ -53,6 +55,7 @@ import org.apache.accumulo.core.fate.FateTxId;
 import org.apache.accumulo.core.fate.ReadOnlyTStore.TStatus;
 import org.apache.accumulo.core.fate.Repo;
 import org.apache.accumulo.core.fate.ZooStore;
+import org.apache.accumulo.core.fate.zookeeper.ZooCache;
 import org.apache.accumulo.core.fate.zookeeper.ZooReaderWriter;
 import org.apache.accumulo.core.util.UtilWaitThread;
 import org.apache.accumulo.manager.Manager;
@@ -64,7 +67,9 @@ import org.apache.accumulo.test.util.Wait;
 import org.apache.accumulo.test.zookeeper.ZooKeeperTestingServer;
 import org.apache.zookeeper.KeeperException;
 import org.junit.jupiter.api.AfterAll;
+import org.junit.jupiter.api.AfterEach;
 import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Tag;
 import org.junit.jupiter.api.Test;
 import org.junit.jupiter.api.Timeout;
@@ -177,6 +182,7 @@ public class FateIT {
 
   private static ZooKeeperTestingServer szk = null;
   private static ZooReaderWriter zk = null;
+  private static ZooCache zc = null;
   private static final String ZK_ROOT = "/accumulo/" + UUID.randomUUID().toString();
   private static final NamespaceId NS = NamespaceId.of("testNameSpace");
   private static final TableId TID = TableId.of("testTable");
@@ -185,6 +191,8 @@ public class FateIT {
   private static CountDownLatch finishCall;
   private static CountDownLatch undoLatch;
 
+  Fate<Manager> fate;
+
   private enum ExceptionLocation {
     CALL, IS_READY
   };
@@ -198,6 +206,29 @@ public class FateIT {
     zk.mkdirs(ZK_ROOT + Constants.ZNAMESPACES + "/" + NS.canonical());
     zk.mkdirs(ZK_ROOT + Constants.ZTABLE_STATE + "/" + TID.canonical());
     zk.mkdirs(ZK_ROOT + Constants.ZTABLES + "/" + TID.canonical());
+    zc = new ZooCache(zk, null);
+  }
+
+  @BeforeEach
+  public void beforeEach() throws Exception {
+    final ZooStore<Manager> zooStore = new ZooStore<>(ZK_ROOT + Constants.ZFATE, zk, zc);
+    final AgeOffStore<Manager> store = new AgeOffStore<>(zooStore, 3000, System::currentTimeMillis);
+
+    Manager manager = createMock(Manager.class);
+    ServerContext sctx = createMock(ServerContext.class);
+    expect(manager.getContext()).andReturn(sctx).anyTimes();
+    expect(sctx.getZooKeeperRoot()).andReturn(ZK_ROOT).anyTimes();
+    expect(sctx.getZooReaderWriter()).andReturn(zk).anyTimes();
+    replay(manager, sctx);
+
+    fate = new Fate<>(manager, store, TraceRepo::toLogString);
+  }
+
+  @AfterEach
+  public void afterEach() {
+    if (fate != null) {
+      fate.shutdown(true);
+    }
   }
 
   @AfterAll
@@ -209,123 +240,92 @@ public class FateIT {
   @Timeout(30)
   public void testTransactionStatus() throws Exception {
 
-    final ZooStore<Manager> zooStore = new ZooStore<Manager>(ZK_ROOT + Constants.ZFATE, zk);
-    final AgeOffStore<Manager> store =
-        new AgeOffStore<Manager>(zooStore, 3000, System::currentTimeMillis);
+    ConfigurationCopy config = new ConfigurationCopy();
+    config.set(Property.GENERAL_THREADPOOL_SIZE, "2");
+    config.set(Property.MANAGER_FATE_THREADPOOL_SIZE, "1");
 
-    Manager manager = createMock(Manager.class);
-    ServerContext sctx = createMock(ServerContext.class);
-    expect(manager.getContext()).andReturn(sctx).anyTimes();
-    expect(sctx.getZooKeeperRoot()).andReturn(ZK_ROOT).anyTimes();
-    expect(sctx.getZooReaderWriter()).andReturn(zk).anyTimes();
-    replay(manager, sctx);
+    callStarted = new CountDownLatch(1);
+    finishCall = new CountDownLatch(1);
 
-    Fate<Manager> fate = new Fate<Manager>(manager, store, TraceRepo::toLogString);
-    try {
-      ConfigurationCopy config = new ConfigurationCopy();
-      config.set(Property.GENERAL_THREADPOOL_SIZE, "2");
-      config.set(Property.MANAGER_FATE_THREADPOOL_SIZE, "1");
+    long txid = fate.startTransaction();
+    assertEquals(TStatus.NEW, getTxStatus(zk, txid));
+    fate.seedTransaction("TestOperation", txid, new TestOperation(NS, TID), true, "Test Op");
+    assertEquals(TStatus.SUBMITTED, getTxStatus(zk, txid));
 
-      callStarted = new CountDownLatch(1);
-      finishCall = new CountDownLatch(1);
+    fate.startTransactionRunners(config, new ScheduledThreadPoolExecutor(2));
+    // Wait for the transaction runner to be scheduled.
+    UtilWaitThread.sleep(3000);
 
-      long txid = fate.startTransaction();
-      assertEquals(TStatus.NEW, getTxStatus(zk, txid));
-      fate.seedTransaction("TestOperation", txid, new TestOperation(NS, TID), true, "Test Op");
-      assertEquals(TStatus.SUBMITTED, getTxStatus(zk, txid));
-
-      fate.startTransactionRunners(config);
-      // Wait for the transaction runner to be scheduled.
-      UtilWaitThread.sleep(3000);
-
-      // wait for call() to be called
-      callStarted.await();
-      assertEquals(IN_PROGRESS, getTxStatus(zk, txid));
-      // tell the op to exit the method
-      finishCall.countDown();
-      // Check that it transitions to SUCCESSFUL
-      TStatus s = getTxStatus(zk, txid);
-      while (s != SUCCESSFUL) {
-        s = getTxStatus(zk, txid);
-        Thread.sleep(10);
-      }
-      // Check that it gets removed
-      boolean errorSeen = false;
-      while (!errorSeen) {
-        try {
-          s = getTxStatus(zk, txid);
-          Thread.sleep(10);
-        } catch (KeeperException e) {
-          if (e.code() == KeeperException.Code.NONODE) {
-            errorSeen = true;
-          } else {
-            fail("Unexpected error thrown: " + e.getMessage());
+    // wait for call() to be called
+    callStarted.await();
+    assertEquals(IN_PROGRESS, getTxStatus(zk, txid));
+    // tell the op to exit the method
+    finishCall.countDown();
+    // Check that it transitions to SUCCESSFUL and gets removed
+    final var sawSuccess = new AtomicBoolean(false);
+    Wait.waitFor(() -> {
+      TStatus s;
+      try {
+        switch (s = getTxStatus(zk, txid)) {
+          case IN_PROGRESS:
+            if (sawSuccess.get()) {
+              fail("Should never see IN_PROGRESS after seeing SUCCESSFUL");
+            }
+            break;
+          case SUCCESSFUL:
+            // expected, but might be too quick to be detected
+            if (sawSuccess.compareAndSet(false, true)) {
+              LOG.debug("Saw expected transaction status change to SUCCESSFUL");
+            }
+            break;
+          default:
+            fail("Saw unexpected status: " + s);
+        }
+      } catch (KeeperException e) {
+        if (e.code() == KeeperException.Code.NONODE) {
+          if (!sawSuccess.get()) {
+            LOG.debug("Never saw transaction status change to SUCCESSFUL, but that's okay");
           }
+          return true;
+        } else {
+          fail("Unexpected error thrown: " + e.getMessage());
         }
       }
-
-    } finally {
-      fate.shutdown();
-    }
+      // keep waiting for NoNode
+      return false;
+    }, SECONDS.toMillis(30), 10);
   }
 
   @Test
   public void testCancelWhileNew() throws Exception {
-    final ZooStore<Manager> zooStore = new ZooStore<Manager>(ZK_ROOT + Constants.ZFATE, zk);
-    final AgeOffStore<Manager> store =
-        new AgeOffStore<Manager>(zooStore, 3000, System::currentTimeMillis);
 
-    Manager manager = createMock(Manager.class);
-    ServerContext sctx = createMock(ServerContext.class);
-    expect(manager.getContext()).andReturn(sctx).anyTimes();
-    expect(sctx.getZooKeeperRoot()).andReturn(ZK_ROOT).anyTimes();
-    expect(sctx.getZooReaderWriter()).andReturn(zk).anyTimes();
-    replay(manager, sctx);
+    ConfigurationCopy config = new ConfigurationCopy();
+    config.set(Property.GENERAL_THREADPOOL_SIZE, "2");
+    config.set(Property.MANAGER_FATE_THREADPOOL_SIZE, "1");
+    fate.startTransactionRunners(config, new ScheduledThreadPoolExecutor(2));
 
-    Fate<Manager> fate = new Fate<Manager>(manager, store, TraceRepo::toLogString);
-    try {
-      ConfigurationCopy config = new ConfigurationCopy();
-      config.set(Property.GENERAL_THREADPOOL_SIZE, "2");
-      config.set(Property.MANAGER_FATE_THREADPOOL_SIZE, "1");
-      fate.startTransactionRunners(config);
+    // Wait for the transaction runner to be scheduled.
+    UtilWaitThread.sleep(3000);
 
-      // Wait for the transaction runner to be scheduled.
-      UtilWaitThread.sleep(3000);
+    callStarted = new CountDownLatch(1);
+    finishCall = new CountDownLatch(1);
 
-      callStarted = new CountDownLatch(1);
-      finishCall = new CountDownLatch(1);
-
-      long txid = fate.startTransaction();
-      LOG.debug("Starting test testCancelWhileNew with {}", FateTxId.formatTid(txid));
-      assertEquals(NEW, getTxStatus(zk, txid));
-      // cancel the transaction
-      assertTrue(fate.cancel(txid));
-      assertTrue(FAILED_IN_PROGRESS == getTxStatus(zk, txid) || FAILED == getTxStatus(zk, txid));
-      fate.seedTransaction("TestOperation", txid, new TestOperation(NS, TID), true, "Test Op");
-      Wait.waitFor(() -> FAILED == getTxStatus(zk, txid));
-      // nothing should have run
-      assertEquals(1, callStarted.getCount());
-      fate.delete(txid);
-      assertThrows(KeeperException.NoNodeException.class, () -> getTxStatus(zk, txid));
-    } finally {
-      fate.shutdown();
-    }
+    long txid = fate.startTransaction();
+    LOG.debug("Starting test testCancelWhileNew with {}", FateTxId.formatTid(txid));
+    assertEquals(NEW, getTxStatus(zk, txid));
+    // cancel the transaction
+    assertTrue(fate.cancel(txid));
+    assertTrue(FAILED_IN_PROGRESS == getTxStatus(zk, txid) || FAILED == getTxStatus(zk, txid));
+    fate.seedTransaction("TestOperation", txid, new TestOperation(NS, TID), true, "Test Op");
+    Wait.waitFor(() -> FAILED == getTxStatus(zk, txid));
+    // nothing should have run
+    assertEquals(1, callStarted.getCount());
+    fate.delete(txid);
+    assertThrows(KeeperException.NoNodeException.class, () -> getTxStatus(zk, txid));
   }
 
   @Test
   public void testCancelWhileSubmittedNotRunning() throws Exception {
-    final ZooStore<Manager> zooStore = new ZooStore<Manager>(ZK_ROOT + Constants.ZFATE, zk);
-    final AgeOffStore<Manager> store =
-        new AgeOffStore<Manager>(zooStore, 3000, System::currentTimeMillis);
-
-    Manager manager = createMock(Manager.class);
-    ServerContext sctx = createMock(ServerContext.class);
-    expect(manager.getContext()).andReturn(sctx).anyTimes();
-    expect(sctx.getZooKeeperRoot()).andReturn(ZK_ROOT).anyTimes();
-    expect(sctx.getZooReaderWriter()).andReturn(zk).anyTimes();
-    replay(manager, sctx);
-
-    Fate<Manager> fate = new Fate<Manager>(manager, store, TraceRepo::toLogString);
     ConfigurationCopy config = new ConfigurationCopy();
     config.set(Property.GENERAL_THREADPOOL_SIZE, "2");
 
@@ -347,88 +347,57 @@ public class FateIT {
 
   @Test
   public void testCancelWhileSubmittedAndRunning() throws Exception {
-    final ZooStore<Manager> zooStore = new ZooStore<Manager>(ZK_ROOT + Constants.ZFATE, zk);
-    final AgeOffStore<Manager> store =
-        new AgeOffStore<Manager>(zooStore, 3000, System::currentTimeMillis);
 
-    Manager manager = createMock(Manager.class);
-    ServerContext sctx = createMock(ServerContext.class);
-    expect(manager.getContext()).andReturn(sctx).anyTimes();
-    expect(sctx.getZooKeeperRoot()).andReturn(ZK_ROOT).anyTimes();
-    expect(sctx.getZooReaderWriter()).andReturn(zk).anyTimes();
-    replay(manager, sctx);
+    ConfigurationCopy config = new ConfigurationCopy();
+    config.set(Property.GENERAL_THREADPOOL_SIZE, "2");
+    config.set(Property.MANAGER_FATE_THREADPOOL_SIZE, "1");
+    fate.startTransactionRunners(config, new ScheduledThreadPoolExecutor(2));
 
-    Fate<Manager> fate = new Fate<Manager>(manager, store, TraceRepo::toLogString);
-    try {
-      ConfigurationCopy config = new ConfigurationCopy();
-      config.set(Property.GENERAL_THREADPOOL_SIZE, "2");
-      config.set(Property.MANAGER_FATE_THREADPOOL_SIZE, "1");
-      fate.startTransactionRunners(config);
+    // Wait for the transaction runner to be scheduled.
+    UtilWaitThread.sleep(3000);
 
-      // Wait for the transaction runner to be scheduled.
-      UtilWaitThread.sleep(3000);
+    callStarted = new CountDownLatch(1);
+    finishCall = new CountDownLatch(1);
 
-      callStarted = new CountDownLatch(1);
-      finishCall = new CountDownLatch(1);
-
-      long txid = fate.startTransaction();
-      LOG.debug("Starting test testCancelWhileSubmitted with {}", FateTxId.formatTid(txid));
-      assertEquals(NEW, getTxStatus(zk, txid));
-      fate.seedTransaction("TestOperation", txid, new TestOperation(NS, TID), false, "Test Op");
-      Wait.waitFor(() -> IN_PROGRESS == getTxStatus(zk, txid));
-      // This is false because the transaction runner has reserved the FaTe
-      // transaction.
-      assertFalse(fate.cancel(txid));
-      callStarted.await();
-      finishCall.countDown();
-      Wait.waitFor(() -> IN_PROGRESS != getTxStatus(zk, txid));
-      fate.delete(txid);
-      assertThrows(KeeperException.NoNodeException.class, () -> getTxStatus(zk, txid));
-    } finally {
-      fate.shutdown();
-    }
+    long txid = fate.startTransaction();
+    LOG.debug("Starting test testCancelWhileSubmitted with {}", FateTxId.formatTid(txid));
+    assertEquals(NEW, getTxStatus(zk, txid));
+    fate.seedTransaction("TestOperation", txid, new TestOperation(NS, TID), false, "Test Op");
+    Wait.waitFor(() -> IN_PROGRESS == getTxStatus(zk, txid));
+    // This is false because the transaction runner has reserved the FaTe
+    // transaction.
+    assertFalse(fate.cancel(txid));
+    callStarted.await();
+    finishCall.countDown();
+    Wait.waitFor(() -> IN_PROGRESS != getTxStatus(zk, txid));
+    fate.delete(txid);
+    assertThrows(KeeperException.NoNodeException.class, () -> getTxStatus(zk, txid));
   }
 
   @Test
   public void testCancelWhileInCall() throws Exception {
-    final ZooStore<Manager> zooStore = new ZooStore<Manager>(ZK_ROOT + Constants.ZFATE, zk);
-    final AgeOffStore<Manager> store =
-        new AgeOffStore<Manager>(zooStore, 3000, System::currentTimeMillis);
 
-    Manager manager = createMock(Manager.class);
-    ServerContext sctx = createMock(ServerContext.class);
-    expect(manager.getContext()).andReturn(sctx).anyTimes();
-    expect(sctx.getZooKeeperRoot()).andReturn(ZK_ROOT).anyTimes();
-    expect(sctx.getZooReaderWriter()).andReturn(zk).anyTimes();
-    replay(manager, sctx);
+    ConfigurationCopy config = new ConfigurationCopy();
+    config.set(Property.GENERAL_THREADPOOL_SIZE, "2");
+    config.set(Property.MANAGER_FATE_THREADPOOL_SIZE, "1");
 
-    Fate<Manager> fate = new Fate<Manager>(manager, store, TraceRepo::toLogString);
-    try {
-      ConfigurationCopy config = new ConfigurationCopy();
-      config.set(Property.GENERAL_THREADPOOL_SIZE, "2");
-      config.set(Property.MANAGER_FATE_THREADPOOL_SIZE, "1");
+    callStarted = new CountDownLatch(1);
+    finishCall = new CountDownLatch(1);
 
-      callStarted = new CountDownLatch(1);
-      finishCall = new CountDownLatch(1);
+    long txid = fate.startTransaction();
+    LOG.debug("Starting test testCancelWhileInCall with {}", FateTxId.formatTid(txid));
+    assertEquals(NEW, getTxStatus(zk, txid));
+    fate.seedTransaction("TestOperation", txid, new TestOperation(NS, TID), true, "Test Op");
+    assertEquals(SUBMITTED, getTxStatus(zk, txid));
 
-      long txid = fate.startTransaction();
-      LOG.debug("Starting test testCancelWhileInCall with {}", FateTxId.formatTid(txid));
-      assertEquals(NEW, getTxStatus(zk, txid));
-      fate.seedTransaction("TestOperation", txid, new TestOperation(NS, TID), true, "Test Op");
-      assertEquals(SUBMITTED, getTxStatus(zk, txid));
-
-      fate.startTransactionRunners(config);
-      // Wait for the transaction runner to be scheduled.
-      UtilWaitThread.sleep(3000);
-
-      // wait for call() to be called
-      callStarted.await();
-      // cancel the transaction
-      assertFalse(fate.cancel(txid));
-    } finally {
-      fate.shutdown();
-    }
+    fate.startTransactionRunners(config, new ScheduledThreadPoolExecutor(2));
+    // Wait for the transaction runner to be scheduled.
+    UtilWaitThread.sleep(3000);
 
+    // wait for call() to be called
+    callStarted.await();
+    // cancel the transaction
+    assertFalse(fate.cancel(txid));
   }
 
   @Test
@@ -440,58 +409,43 @@ public class FateIT {
      * is called and throws an exception (in call() or isReady()). It is then expected that: 1)
      * undo() is called on Repo3, 2) undo() is called on Repo2, 3) undo() is called on Repo1
      */
-    final ZooStore<Manager> zooStore = new ZooStore<Manager>(ZK_ROOT + Constants.ZFATE, zk);
-    final AgeOffStore<Manager> store =
-        new AgeOffStore<Manager>(zooStore, 3000, System::currentTimeMillis);
 
-    Manager manager = createMock(Manager.class);
-    ServerContext sctx = createMock(ServerContext.class);
-    expect(manager.getContext()).andReturn(sctx).anyTimes();
-    expect(sctx.getZooKeeperRoot()).andReturn(ZK_ROOT).anyTimes();
-    expect(sctx.getZooReaderWriter()).andReturn(zk).anyTimes();
-    replay(manager, sctx);
+    ConfigurationCopy config = new ConfigurationCopy();
+    config.set(Property.GENERAL_THREADPOOL_SIZE, "2");
+    config.set(Property.MANAGER_FATE_THREADPOOL_SIZE, "1");
+    fate.startTransactionRunners(config, new ScheduledThreadPoolExecutor(2));
 
-    Fate<Manager> fate = new Fate<Manager>(manager, store, TraceRepo::toLogString);
-    try {
-      ConfigurationCopy config = new ConfigurationCopy();
-      config.set(Property.GENERAL_THREADPOOL_SIZE, "2");
-      config.set(Property.MANAGER_FATE_THREADPOOL_SIZE, "1");
-      fate.startTransactionRunners(config);
+    // Wait for the transaction runner to be scheduled.
+    UtilWaitThread.sleep(3000);
 
-      // Wait for the transaction runner to be scheduled.
-      UtilWaitThread.sleep(3000);
-
-      List<String> expectedUndoOrder = List.of("OP3", "OP2", "OP1");
-      /*
-       * Test exception in call()
-       */
-      undoLatch = new CountDownLatch(TestOperationFails.TOTAL_NUM_OPS);
-      long txid = fate.startTransaction();
-      assertEquals(NEW, getTxStatus(zk, txid));
-      fate.seedTransaction("TestOperationFails", txid,
-          new TestOperationFails(1, ExceptionLocation.CALL), false, "Test Op Fails");
-      // Wait for all the undo() calls to complete
-      undoLatch.await();
-      assertEquals(expectedUndoOrder, TestOperationFails.undoOrder);
-      assertEquals(FAILED, fate.waitForCompletion(txid));
-      assertTrue(fate.getException(txid).getMessage().contains("call() failed"));
-      /*
-       * Test exception in isReady()
-       */
-      TestOperationFails.undoOrder = new ArrayList<>();
-      undoLatch = new CountDownLatch(TestOperationFails.TOTAL_NUM_OPS);
-      txid = fate.startTransaction();
-      assertEquals(NEW, getTxStatus(zk, txid));
-      fate.seedTransaction("TestOperationFails", txid,
-          new TestOperationFails(1, ExceptionLocation.IS_READY), false, "Test Op Fails");
-      // Wait for all the undo() calls to complete
-      undoLatch.await();
-      assertEquals(expectedUndoOrder, TestOperationFails.undoOrder);
-      assertEquals(FAILED, fate.waitForCompletion(txid));
-      assertTrue(fate.getException(txid).getMessage().contains("isReady() failed"));
-    } finally {
-      fate.shutdown();
-    }
+    List<String> expectedUndoOrder = List.of("OP3", "OP2", "OP1");
+    /*
+     * Test exception in call()
+     */
+    undoLatch = new CountDownLatch(TestOperationFails.TOTAL_NUM_OPS);
+    long txid = fate.startTransaction();
+    assertEquals(NEW, getTxStatus(zk, txid));
+    fate.seedTransaction("TestOperationFails", txid,
+        new TestOperationFails(1, ExceptionLocation.CALL), false, "Test Op Fails");
+    // Wait for all the undo() calls to complete
+    undoLatch.await();
+    assertEquals(expectedUndoOrder, TestOperationFails.undoOrder);
+    assertEquals(FAILED, fate.waitForCompletion(txid));
+    assertTrue(fate.getException(txid).getMessage().contains("call() failed"));
+    /*
+     * Test exception in isReady()
+     */
+    TestOperationFails.undoOrder = new ArrayList<>();
+    undoLatch = new CountDownLatch(TestOperationFails.TOTAL_NUM_OPS);
+    txid = fate.startTransaction();
+    assertEquals(NEW, getTxStatus(zk, txid));
+    fate.seedTransaction("TestOperationFails", txid,
+        new TestOperationFails(1, ExceptionLocation.IS_READY), false, "Test Op Fails");
+    // Wait for all the undo() calls to complete
+    undoLatch.await();
+    assertEquals(expectedUndoOrder, TestOperationFails.undoOrder);
+    assertEquals(FAILED, fate.waitForCompletion(txid));
+    assertTrue(fate.getException(txid).getMessage().contains("isReady() failed"));
   }
 
   private static void inCall() throws InterruptedException {
