@@ -217,6 +217,7 @@ public class ServiceLockIT {
     ServiceLock zl = getZooLock(parent, UUID.randomUUID());
 
     assertFalse(zl.isLocked());
+    assertFalse(zl.verifyLockAtSource());
 
     ZooReaderWriter zk = szk.getZooReaderWriter();
 
@@ -235,10 +236,12 @@ public class ServiceLockIT {
 
     assertTrue(lw.locked);
     assertTrue(zl.isLocked());
+    assertTrue(zl.verifyLockAtSource());
     assertNull(lw.exception);
     assertNull(lw.reason);
 
     zl.unlock();
+    assertFalse(zl.verifyLockAtSource());
   }
 
   @Test
@@ -250,6 +253,7 @@ public class ServiceLockIT {
     ServiceLock zl = getZooLock(parent, UUID.randomUUID());
 
     assertFalse(zl.isLocked());
+    assertFalse(zl.verifyLockAtSource());
 
     TestALW lw = new TestALW();
 
@@ -259,6 +263,7 @@ public class ServiceLockIT {
 
     assertFalse(lw.locked);
     assertFalse(zl.isLocked());
+    assertFalse(zl.verifyLockAtSource());
     assertNotNull(lw.exception);
     assertNull(lw.reason);
   }
@@ -275,6 +280,7 @@ public class ServiceLockIT {
     ServiceLock zl = getZooLock(parent, UUID.randomUUID());
 
     assertFalse(zl.isLocked());
+    assertFalse(zl.verifyLockAtSource());
 
     TestALW lw = new TestALW();
 
@@ -284,6 +290,7 @@ public class ServiceLockIT {
 
     assertTrue(lw.locked);
     assertTrue(zl.isLocked());
+    assertTrue(zl.verifyLockAtSource());
     assertNull(lw.exception);
     assertNull(lw.reason);
 
@@ -293,7 +300,7 @@ public class ServiceLockIT {
 
     assertEquals(LockLossReason.LOCK_DELETED, lw.reason);
     assertNull(lw.exception);
-
+    assertFalse(zl.verifyLockAtSource());
   }
 
   @Test
@@ -308,6 +315,7 @@ public class ServiceLockIT {
     ServiceLock zl = getZooLock(parent, UUID.randomUUID());
 
     assertFalse(zl.isLocked());
+    assertFalse(zl.verifyLockAtSource());
 
     TestALW lw = new TestALW();
 
@@ -317,6 +325,7 @@ public class ServiceLockIT {
 
     assertTrue(lw.locked);
     assertTrue(zl.isLocked());
+    assertTrue(zl.verifyLockAtSource());
     assertNull(lw.exception);
     assertNull(lw.reason);
 
@@ -328,6 +337,7 @@ public class ServiceLockIT {
 
     assertFalse(lw2.locked);
     assertFalse(zl2.isLocked());
+    assertFalse(zl2.verifyLockAtSource());
 
     ServiceLock zl3 = getZooLock(parent, UUID.randomUUID());
 
@@ -356,10 +366,12 @@ public class ServiceLockIT {
 
     assertTrue(lw3.locked);
     assertTrue(zl3.isLocked());
+    assertTrue(zl3.verifyLockAtSource());
     assertNull(lw3.exception);
     assertNull(lw3.reason);
 
     zl3.unlock();
+    assertFalse(zl3.verifyLockAtSource());
 
   }
 
@@ -380,6 +392,7 @@ public class ServiceLockIT {
       ServiceLock zl = getZooLock(parent, UUID.randomUUID());
 
       assertFalse(zl.isLocked());
+      assertFalse(zl.verifyLockAtSource());
 
       // would not expect data to be set on this node, but it should not cause problems.....
       zk.setData(parent.toString(), "foo".getBytes(UTF_8), -1);
@@ -392,6 +405,7 @@ public class ServiceLockIT {
 
       assertTrue(lw.locked);
       assertTrue(zl.isLocked());
+      assertTrue(zl.verifyLockAtSource());
       assertNull(lw.exception);
       assertNull(lw.reason);
 
@@ -404,6 +418,7 @@ public class ServiceLockIT {
 
       assertEquals(LockLossReason.LOCK_DELETED, lw.reason);
       assertNull(lw.exception);
+      assertFalse(zl.verifyLockAtSource());
     }
 
   }
@@ -476,8 +491,13 @@ public class ServiceLockIT {
       assertEquals("/zlretryLockSerial/zlock#00000000-0000-0000-0000-aaaaaaaaaaaa#0000000000",
           zl2.getWatching());
 
+      assertTrue(zl1.verifyLockAtSource());
+      assertFalse(zl2.verifyLockAtSource());
+
       zl1.unlock();
       assertFalse(zlw1.isLockHeld());
+      assertFalse(zl1.verifyLockAtSource());
+      assertFalse(zl2.verifyLockAtSource());
       zk1.close();
 
       while (!zlw2.isLockHeld()) {
@@ -485,7 +505,9 @@ public class ServiceLockIT {
       }
 
       assertTrue(zlw2.isLockHeld());
+      assertTrue(zl2.verifyLockAtSource());
       zl2.unlock();
+      assertFalse(zl2.verifyLockAtSource());
     }
 
   }
@@ -689,10 +711,10 @@ public class ServiceLockIT {
       TestALW lw = new TestALW();
 
       zl.lock(lw, "test1".getBytes(UTF_8));
-      assertEquals("test1", new String(zk.getData(zl.getLockPath(), null, null)));
+      assertEquals("test1", new String(zk.getData(zl.getLockPath(), null, null), UTF_8));
 
       zl.replaceLockData("test2".getBytes(UTF_8));
-      assertEquals("test2", new String(zk.getData(zl.getLockPath(), null, null)));
+      assertEquals("test2", new String(zk.getData(zl.getLockPath(), null, null), UTF_8));
     }
   }
 }
