@@ -1,41 +1,41 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.test.functional;
 
 import static java.nio.charset.StandardCharsets.UTF_8;
-import static org.apache.accumulo.fate.util.UtilWaitThread.sleepUninterruptibly;
+import static org.apache.accumulo.core.util.UtilWaitThread.sleepUninterruptibly;
+import static org.apache.accumulo.harness.AccumuloITBase.random;
 
 import java.io.File;
 import java.io.FileInputStream;
 import java.io.IOException;
 import java.io.ObjectInputStream;
-import java.security.SecureRandom;
 import java.util.ArrayList;
 import java.util.Map;
-import java.util.Random;
 import java.util.TreeMap;
 import java.util.UUID;
 import java.util.concurrent.TimeUnit;
 
 import org.apache.accumulo.core.conf.SiteConfiguration;
-import org.apache.accumulo.fate.zookeeper.IZooReaderWriter;
-import org.apache.accumulo.fate.zookeeper.ZooReaderWriter;
-import org.apache.accumulo.fate.zookeeper.ZooUtil.NodeExistsPolicy;
-import org.apache.accumulo.fate.zookeeper.ZooUtil.NodeMissingPolicy;
+import org.apache.accumulo.core.fate.zookeeper.ZooReaderWriter;
+import org.apache.accumulo.core.fate.zookeeper.ZooUtil.NodeExistsPolicy;
+import org.apache.accumulo.core.fate.zookeeper.ZooUtil.NodeMissingPolicy;
 
 import edu.umd.cs.findbugs.annotations.SuppressFBWarnings;
 
@@ -46,7 +46,7 @@ public class CacheTestWriter {
   @SuppressFBWarnings(value = {"PATH_TRAVERSAL_IN", "OBJECT_DESERIALIZATION"},
       justification = "path provided by test; object deserialization is okay for test")
   public static void main(String[] args) throws Exception {
-    IZooReaderWriter zk = new ZooReaderWriter(new SiteConfiguration());
+    var zk = new ZooReaderWriter(SiteConfiguration.auto());
 
     String rootDir = args[0];
     File reportDir = new File(args[1]);
@@ -66,22 +66,20 @@ public class CacheTestWriter {
 
     ArrayList<String> children = new ArrayList<>();
 
-    Random r = new SecureRandom();
-
     while (count++ < numVerifications) {
 
       Map<String,String> expectedData = null;
       // change children in dir
 
-      for (int u = 0; u < r.nextInt(4) + 1; u++) {
+      for (int u = 0; u < random.nextInt(4) + 1; u++) {
         expectedData = new TreeMap<>();
 
-        if (r.nextFloat() < .5) {
+        if (random.nextFloat() < .5) {
           String child = UUID.randomUUID().toString();
           zk.putPersistentData(rootDir + "/dir/" + child, new byte[0], NodeExistsPolicy.SKIP);
           children.add(child);
-        } else if (children.size() > 0) {
-          int index = r.nextInt(children.size());
+        } else if (!children.isEmpty()) {
+          int index = random.nextInt(children.size());
           String child = children.remove(index);
           zk.recursiveDelete(rootDir + "/dir/" + child, NodeMissingPolicy.FAIL);
         }
@@ -92,21 +90,21 @@ public class CacheTestWriter {
 
         // change values
         for (int i = 0; i < numData; i++) {
-          byte[] data = Long.toString(r.nextLong(), 16).getBytes(UTF_8);
+          byte[] data = Long.toString(random.nextLong(), 16).getBytes(UTF_8);
           zk.putPersistentData(rootDir + "/data" + i, data, NodeExistsPolicy.OVERWRITE);
           expectedData.put(rootDir + "/data" + i, new String(data, UTF_8));
         }
 
         // test a data node that does not always exists...
-        if (r.nextFloat() < .5) {
+        if (random.nextFloat() < .5) {
 
-          byte[] data = Long.toString(r.nextLong(), 16).getBytes(UTF_8);
+          byte[] data = Long.toString(random.nextLong(), 16).getBytes(UTF_8);
 
-          if (!dataSExists) {
+          if (dataSExists) {
+            zk.putPersistentData(rootDir + "/dataS", data, NodeExistsPolicy.OVERWRITE);
+          } else {
             zk.putPersistentData(rootDir + "/dataS", data, NodeExistsPolicy.SKIP);
             dataSExists = true;
-          } else {
-            zk.putPersistentData(rootDir + "/dataS", data, NodeExistsPolicy.OVERWRITE);
           }
 
           expectedData.put(rootDir + "/dataS", new String(data, UTF_8));
@@ -159,8 +157,9 @@ public class CacheTestWriter {
             }
           }
 
-          if (ok)
+          if (ok) {
             break;
+          }
         }
 
         sleepUninterruptibly(5, TimeUnit.MILLISECONDS);
