@@ -1,28 +1,29 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.test.functional;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assume.assumeFalse;
+import static org.apache.accumulo.harness.AccumuloITBase.MINI_CLUSTER_ONLY;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
-import java.util.HashMap;
+import java.time.Duration;
 import java.util.Map;
-import java.util.Map.Entry;
 
 import org.apache.accumulo.core.client.Accumulo;
 import org.apache.accumulo.core.client.AccumuloClient;
@@ -35,20 +36,21 @@ import org.apache.accumulo.core.security.Authorizations;
 import org.apache.accumulo.minicluster.ServerType;
 import org.apache.accumulo.miniclusterImpl.MiniAccumuloConfigImpl;
 import org.apache.accumulo.miniclusterImpl.ProcessReference;
-import org.apache.accumulo.test.categories.MiniClusterOnlyTests;
-import org.apache.accumulo.test.categories.PerformanceTests;
-import org.apache.accumulo.test.mrit.IntegrationTestMapReduce;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.fs.RawLocalFileSystem;
-import org.junit.BeforeClass;
-import org.junit.Test;
-import org.junit.experimental.categories.Category;
+import org.junit.jupiter.api.Tag;
+import org.junit.jupiter.api.Test;
 
 import com.google.common.collect.Iterators;
 
-@Category({MiniClusterOnlyTests.class, PerformanceTests.class})
+@Tag(MINI_CLUSTER_ONLY)
 public class DurabilityIT extends ConfigurableMacBase {
 
+  @Override
+  protected Duration defaultTimeout() {
+    return Duration.ofMinutes(4);
+  }
+
   @Override
   public void configure(MiniAccumuloConfigImpl cfg, Configuration hadoopCoreSite) {
     hadoopCoreSite.set("fs.file.impl", RawLocalFileSystem.class.getName());
@@ -56,11 +58,6 @@ public class DurabilityIT extends ConfigurableMacBase {
     cfg.setNumTservers(1);
   }
 
-  @BeforeClass
-  public static void checkMR() {
-    assumeFalse(IntegrationTestMapReduce.isMapReduce());
-  }
-
   static final long N = 100000;
 
   private String[] init(AccumuloClient c) throws Exception {
@@ -87,7 +84,7 @@ public class DurabilityIT extends ConfigurableMacBase {
     c.tableOperations().create(tableName);
   }
 
-  @Test(timeout = 4 * 60 * 1000)
+  @Test
   public void testSync() throws Exception {
     try (AccumuloClient client = Accumulo.newClient().from(getClientProperties()).build()) {
       String[] tableNames = init(client);
@@ -99,7 +96,7 @@ public class DurabilityIT extends ConfigurableMacBase {
     }
   }
 
-  @Test(timeout = 4 * 60 * 1000)
+  @Test
   public void testFlush() throws Exception {
     try (AccumuloClient client = Accumulo.newClient().from(getClientProperties()).build()) {
       String[] tableNames = init(client);
@@ -111,7 +108,7 @@ public class DurabilityIT extends ConfigurableMacBase {
     }
   }
 
-  @Test(timeout = 4 * 60 * 1000)
+  @Test
   public void testLog() throws Exception {
     try (AccumuloClient client = Accumulo.newClient().from(getClientProperties()).build()) {
       String[] tableNames = init(client);
@@ -119,12 +116,12 @@ public class DurabilityIT extends ConfigurableMacBase {
       writeSome(client, tableNames[2], N);
       restartTServer();
       long numResults = readSome(client, tableNames[2]);
-      assertTrue("Expected " + N + " >= " + numResults, numResults <= N);
+      assertTrue(numResults <= N, "Expected " + N + " >= " + numResults);
       cleanup(client, tableNames);
     }
   }
 
-  @Test(timeout = 4 * 60 * 1000)
+  @Test
   public void testNone() throws Exception {
     try (AccumuloClient client = Accumulo.newClient().from(getClientProperties()).build()) {
       String[] tableNames = init(client);
@@ -132,12 +129,12 @@ public class DurabilityIT extends ConfigurableMacBase {
       writeSome(client, tableNames[3], N);
       restartTServer();
       long numResults = readSome(client, tableNames[3]);
-      assertTrue("Expected " + N + " >= " + numResults, numResults <= N);
+      assertTrue(numResults <= N, "Expected " + N + " >= " + numResults);
       cleanup(client, tableNames);
     }
   }
 
-  @Test(timeout = 4 * 60 * 1000)
+  @Test
   public void testIncreaseDurability() throws Exception {
     try (AccumuloClient c = Accumulo.newClient().from(getClientProperties()).build()) {
       String tableName = getUniqueNames(1)[0];
@@ -146,7 +143,7 @@ public class DurabilityIT extends ConfigurableMacBase {
       writeSome(c, tableName, N);
       restartTServer();
       long numResults = readSome(c, tableName);
-      assertTrue("Expected " + N + " >= " + numResults, numResults <= N);
+      assertTrue(numResults <= N, "Expected " + N + " >= " + numResults);
       c.tableOperations().setProperty(tableName, Property.TABLE_DURABILITY.getKey(), "sync");
       writeSome(c, tableName, N);
       restartTServer();
@@ -154,23 +151,15 @@ public class DurabilityIT extends ConfigurableMacBase {
     }
   }
 
-  private static Map<String,String> map(Iterable<Entry<String,String>> entries) {
-    Map<String,String> result = new HashMap<>();
-    for (Entry<String,String> entry : entries) {
-      result.put(entry.getKey(), entry.getValue());
-    }
-    return result;
-  }
-
-  @Test(timeout = 4 * 60 * 1000)
+  @Test
   public void testMetaDurability() throws Exception {
     try (AccumuloClient c = Accumulo.newClient().from(getClientProperties()).build()) {
       String tableName = getUniqueNames(1)[0];
       c.instanceOperations().setProperty(Property.TABLE_DURABILITY.getKey(), "none");
-      Map<String,String> props = map(c.tableOperations().getProperties(MetadataTable.NAME));
+      Map<String,String> props = c.tableOperations().getConfiguration(MetadataTable.NAME);
       assertEquals("sync", props.get(Property.TABLE_DURABILITY.getKey()));
       c.tableOperations().create(tableName);
-      props = map(c.tableOperations().getProperties(tableName));
+      props = c.tableOperations().getConfiguration(tableName);
       assertEquals("none", props.get(Property.TABLE_DURABILITY.getKey()));
       restartTServer();
       assertTrue(c.tableOperations().exists(tableName));
@@ -194,7 +183,7 @@ public class DurabilityIT extends ConfigurableMacBase {
         Mutation m = new Mutation("" + i);
         m.put("", "", "");
         bw.addMutation(m);
-        if (i % (Math.max(1, count / 100)) == 0) {
+        if (i % Math.max(1, count / 100) == 0) {
           bw.flush();
         }
       }
