@@ -38,10 +38,12 @@ import java.util.Iterator;
 import java.util.List;
 import java.util.Map.Entry;
 import java.util.NoSuchElementException;
+import java.util.Set;
 import java.util.TreeMap;
 
 import org.apache.accumulo.core.Constants;
 import org.apache.accumulo.core.data.Key;
+import org.apache.accumulo.core.data.Range;
 import org.apache.accumulo.core.data.Value;
 import org.apache.accumulo.core.iterators.SortedKeyValueIterator;
 import org.apache.accumulo.core.util.Pair;
@@ -548,6 +550,14 @@ public class NativeMapIT {
     assertEquals(0, nm.size());
     assertEquals(0, nm.getMemoryUsed());
 
+    var iter1 = nm.iterator();
+    assertFalse(iter1.hasNext());
+    assertThrows(NoSuchElementException.class, () -> iter1.next());
+
+    var iter2 = nm.iterator(new Key("abc"));
+    assertFalse(iter2.hasNext());
+    assertThrows(NoSuchElementException.class, () -> iter2.next());
+
     nm.delete();
   }
 
@@ -560,6 +570,7 @@ public class NativeMapIT {
     nm.put(newKey(3), newValue(3));
 
     SortedKeyValueIterator<Key,Value> iter = nm.skvIterator();
+    iter.seek(new Range(), Set.of(), false);
 
     // modify map after iter created
     nm.put(newKey(2), newValue(2));
@@ -585,4 +596,14 @@ public class NativeMapIT {
     nm.delete();
   }
 
+  @Test
+  public void testUnseeked() {
+    NativeMap nm = new NativeMap();
+
+    nm.put(newKey(0), newValue(0));
+
+    SortedKeyValueIterator<Key,Value> iter = nm.skvIterator();
+    // hasTop should throw an exception if seek was never called.
+    assertThrows(IllegalStateException.class, iter::hasTop);
+  }
 }
