@@ -1,24 +1,27 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.test.functional;
 
-import static java.nio.charset.StandardCharsets.UTF_8;
-import static org.junit.Assert.assertEquals;
+import static org.apache.accumulo.harness.AccumuloITBase.SUNNY_DAY;
+import static org.junit.jupiter.api.Assertions.assertEquals;
 
+import java.time.Duration;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.HashSet;
@@ -45,26 +48,28 @@ import org.apache.accumulo.core.security.TablePermission;
 import org.apache.accumulo.harness.AccumuloClusterHarness;
 import org.apache.hadoop.io.Text;
 import org.apache.hadoop.security.UserGroupInformation;
-import org.junit.After;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Tag;
+import org.junit.jupiter.api.Test;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+@Tag(SUNNY_DAY)
 public class ScanIteratorIT extends AccumuloClusterHarness {
   private static final Logger log = LoggerFactory.getLogger(ScanIteratorIT.class);
 
-  @Override
-  protected int defaultTimeoutSeconds() {
-    return 60;
-  }
-
   private AccumuloClient accumuloClient;
   private String tableName;
   private String user;
   private boolean saslEnabled;
 
-  @Before
+  @Override
+  protected Duration defaultTimeout() {
+    return Duration.ofMinutes(1);
+  }
+
+  @BeforeEach
   public void setup() throws Exception {
     accumuloClient = Accumulo.newClient().from(getClientProps()).build();
     tableName = getUniqueNames(1)[0];
@@ -91,7 +96,7 @@ public class ScanIteratorIT extends AccumuloClusterHarness {
     accumuloClient.securityOperations().changeUserAuthorizations(user, AuthsIterator.AUTHS);
   }
 
-  @After
+  @AfterEach
   public void tearDown() throws Exception {
     if (user != null) {
       if (saslEnabled) {
@@ -113,10 +118,8 @@ public class ScanIteratorIT extends AccumuloClusterHarness {
       try (BatchWriter bw = c.createBatchWriter(tableName)) {
         for (int i = 0; i < 1000; i++) {
           Mutation m = new Mutation(new Text(String.format("%06d", i)));
-          m.put(new Text("cf1"), new Text("cq1"),
-              new Value(Integer.toString(1000 - i).getBytes(UTF_8)));
-          m.put(new Text("cf1"), new Text("cq2"),
-              new Value(Integer.toString(i - 1000).getBytes(UTF_8)));
+          m.put("cf1", "cq1", Integer.toString(1000 - i));
+          m.put("cf1", "cq2", Integer.toString(i - 1000));
           bw.addMutation(m);
         }
       }
@@ -171,7 +174,7 @@ public class ScanIteratorIT extends AccumuloClusterHarness {
     int expected = start;
     for (Entry<Key,Value> entry : scanner) {
       if (Integer.parseInt(entry.getKey().getRow().toString()) != expected) {
-        throw new Exception("Saw unexpexted " + entry.getKey().getRow() + " " + expected);
+        throw new Exception("Saw unexpected " + entry.getKey().getRow() + " " + expected);
       }
 
       if (entry.getKey().getColumnQualifier().toString().equals("cq2")) {
@@ -242,7 +245,7 @@ public class ScanIteratorIT extends AccumuloClusterHarness {
       throws TableNotFoundException, MutationsRejectedException {
     try (BatchWriter batchWriter = userC.createBatchWriter(tableName)) {
       Mutation m = new Mutation("1");
-      m.put(new Text("2"), new Text("3"), new Value("".getBytes()));
+      m.put("2", "3", "");
       batchWriter.addMutation(m);
       batchWriter.flush();
     }
