@@ -1,27 +1,31 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.test.functional;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertThrows;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.jupiter.api.Assumptions.assumeTrue;
 
 import java.io.IOException;
+import java.time.Duration;
 import java.util.Collections;
 import java.util.Iterator;
 import java.util.Map.Entry;
@@ -38,20 +42,21 @@ import org.apache.accumulo.core.data.Mutation;
 import org.apache.accumulo.core.data.Range;
 import org.apache.accumulo.core.data.Value;
 import org.apache.accumulo.core.security.Authorizations;
-import org.apache.accumulo.fate.util.UtilWaitThread;
+import org.apache.accumulo.core.util.UtilWaitThread;
 import org.apache.accumulo.harness.AccumuloClusterHarness;
 import org.apache.accumulo.miniclusterImpl.MiniAccumuloClusterImpl;
 import org.apache.hadoop.fs.FileSystem;
 import org.apache.hadoop.fs.Path;
-import org.hamcrest.CoreMatchers;
-import org.junit.Assume;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 public class ScannerContextIT extends AccumuloClusterHarness {
 
   private static final String CONTEXT = ScannerContextIT.class.getSimpleName();
-  private static final String CONTEXT_PROPERTY = Property.VFS_CONTEXT_CLASSPATH_PROPERTY + CONTEXT;
+  @SuppressWarnings("removal")
+  private static final Property VFS_CONTEXT_CLASSPATH_PROPERTY =
+      Property.VFS_CONTEXT_CLASSPATH_PROPERTY;
+  private static final String CONTEXT_PROPERTY = VFS_CONTEXT_CLASSPATH_PROPERTY + CONTEXT;
   private static final String CONTEXT_DIR = "file://" + System.getProperty("user.dir") + "/target";
   private static final String CONTEXT_CLASSPATH = CONTEXT_DIR + "/Test.jar";
   private static int ITERATIONS = 10;
@@ -60,14 +65,14 @@ public class ScannerContextIT extends AccumuloClusterHarness {
   private FileSystem fs;
 
   @Override
-  protected int defaultTimeoutSeconds() {
-    return 2 * 60;
+  protected Duration defaultTimeout() {
+    return Duration.ofMinutes(2);
   }
 
-  @Before
+  @BeforeEach
   public void checkCluster() throws Exception {
-    Assume.assumeThat(getClusterType(), CoreMatchers.is(ClusterType.MINI));
-    MiniAccumuloClusterImpl.class.cast(getCluster());
+    assumeTrue(getClusterType() == ClusterType.MINI);
+    assertTrue(MiniAccumuloClusterImpl.class.isInstance(getCluster()));
     fs = FileSystem.get(cluster.getServerContext().getHadoopConf());
   }
 
@@ -110,18 +115,11 @@ public class ScannerContextIT extends AccumuloClusterHarness {
 
       // Check that ValueReversingIterator is not already on the classpath by not setting the
       // context. This should fail.
-      try {
-        scanCheck(c, tableName, cfg, null, "tseT");
-        fail("This should have failed because context was not set");
-      } catch (Exception e) {
-        // Do nothing, this should fail as the classloader context is not set.
-      }
-      try {
-        batchCheck(c, tableName, cfg, null, "tseT");
-        fail("This should have failed because context was not set");
-      } catch (Exception e) {
-        // Do nothing, this should fail as the classloader context is not set.
-      }
+      assertThrows(Exception.class, () -> scanCheck(c, tableName, cfg, null, "tseT"),
+          "This should have failed because context was not set");
+
+      assertThrows(Exception.class, () -> batchCheck(c, tableName, cfg, null, "tseT"),
+          "This should have failed because context was not set");
 
       // Ensure that the value is reversed using the iterator config and classloader context
       scanCheck(c, tableName, cfg, CONTEXT, "tseT");
@@ -139,7 +137,7 @@ public class ScannerContextIT extends AccumuloClusterHarness {
       // Create two contexts FOO and ScanContextIT. The FOO context will point to a classpath
       // that contains nothing. The ScanContextIT context will point to the test iterators jar
       String tableContext = "FOO";
-      String tableContextProperty = Property.VFS_CONTEXT_CLASSPATH_PROPERTY + tableContext;
+      String tableContextProperty = VFS_CONTEXT_CLASSPATH_PROPERTY + tableContext;
       String tableContextDir = "file://" + System.getProperty("user.dir") + "/target";
       String tableContextClasspath = tableContextDir + "/TestFoo.jar";
       // Define both contexts
@@ -149,7 +147,8 @@ public class ScannerContextIT extends AccumuloClusterHarness {
       String tableName = getUniqueNames(1)[0];
       c.tableOperations().create(tableName);
       // Set the FOO context on the table
-      c.tableOperations().setProperty(tableName, Property.TABLE_CLASSPATH.getKey(), tableContext);
+      c.tableOperations().setProperty(tableName, Property.TABLE_CLASSLOADER_CONTEXT.getKey(),
+          tableContext);
       try (BatchWriter bw = c.createBatchWriter(tableName)) {
         for (int i = 0; i < ITERATIONS; i++) {
           Mutation m = new Mutation("row" + i);
@@ -165,18 +164,11 @@ public class ScannerContextIT extends AccumuloClusterHarness {
 
       // Check that ValueReversingIterator is not already on the classpath by not setting the
       // context. This should fail.
-      try {
-        scanCheck(c, tableName, cfg, null, "tseT");
-        fail("This should have failed because context was not set");
-      } catch (Exception e) {
-        // Do nothing, this should fail as the classloader context is not set.
-      }
-      try {
-        batchCheck(c, tableName, cfg, null, "tseT");
-        fail("This should have failed because context was not set");
-      } catch (Exception e) {
-        // Do nothing, this should fail as the classloader context is not set.
-      }
+      assertThrows(Exception.class, () -> scanCheck(c, tableName, cfg, null, "tseT"),
+          "This should have failed because context was not set");
+
+      assertThrows(Exception.class, () -> batchCheck(c, tableName, cfg, null, "tseT"),
+          "This should have failed because context was not set");
 
       // Ensure that the value is reversed using the iterator config and classloader context
       scanCheck(c, tableName, cfg, CONTEXT, "tseT");
