@@ -18,8 +18,6 @@
  */
 package org.apache.accumulo.test.functional;
 
-import static org.apache.accumulo.core.util.UtilWaitThread.sleepUninterruptibly;
-
 import java.io.IOException;
 import java.util.Collection;
 import java.util.Map;
@@ -33,14 +31,17 @@ import org.apache.accumulo.core.data.Value;
 import org.apache.accumulo.core.iterators.IteratorEnvironment;
 import org.apache.accumulo.core.iterators.SortedKeyValueIterator;
 import org.apache.accumulo.core.iterators.WrappingIterator;
+import org.apache.accumulo.core.util.UtilWaitThread;
 
 public class SlowIterator extends WrappingIterator {
 
   private static final String SLEEP_TIME = "sleepTime";
   private static final String SEEK_SLEEP_TIME = "seekSleepTime";
+  private static final String SLEEP_UNINTERRUPTIBLY = "sleepUninterruptibly";
 
   private long sleepTime = 0;
   private long seekSleepTime = 0;
+  private boolean sleepUninterruptibly = true;
 
   public static void setSleepTime(IteratorSetting is, long millis) {
     is.addOption(SLEEP_TIME, Long.toString(millis));
@@ -50,6 +51,22 @@ public class SlowIterator extends WrappingIterator {
     is.addOption(SEEK_SLEEP_TIME, Long.toString(t));
   }
 
+  public static void sleepUninterruptibly(IteratorSetting is, boolean b) {
+    is.addOption(SLEEP_UNINTERRUPTIBLY, Boolean.toString(b));
+  }
+
+  private void sleep(long time) throws IOException {
+    if (sleepUninterruptibly) {
+      UtilWaitThread.sleepUninterruptibly(time, TimeUnit.MILLISECONDS);
+    } else {
+      try {
+        Thread.sleep(sleepTime);
+      } catch (InterruptedException e) {
+        throw new IOException(e);
+      }
+    }
+  }
+
   @Override
   public SortedKeyValueIterator<Key,Value> deepCopy(IteratorEnvironment env) {
     throw new UnsupportedOperationException();
@@ -57,14 +74,14 @@ public class SlowIterator extends WrappingIterator {
 
   @Override
   public void next() throws IOException {
-    sleepUninterruptibly(sleepTime, TimeUnit.MILLISECONDS);
+    sleep(sleepTime);
     super.next();
   }
 
   @Override
   public void seek(Range range, Collection<ByteSequence> columnFamilies, boolean inclusive)
       throws IOException {
-    sleepUninterruptibly(seekSleepTime, TimeUnit.MILLISECONDS);
+    sleep(seekSleepTime);
     super.seek(range, columnFamilies, inclusive);
   }
 
@@ -79,6 +96,10 @@ public class SlowIterator extends WrappingIterator {
     if (options.containsKey(SEEK_SLEEP_TIME)) {
       seekSleepTime = Long.parseLong(options.get(SEEK_SLEEP_TIME));
     }
+
+    if (options.containsKey(SLEEP_UNINTERRUPTIBLY)) {
+      sleepUninterruptibly = Boolean.parseBoolean(options.get(SLEEP_UNINTERRUPTIBLY));
+    }
   }
 
 }
