@@ -1,22 +1,24 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.test.replication;
 
-import static org.junit.Assert.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertEquals;
 
 import java.util.Map.Entry;
 import java.util.UUID;
@@ -36,20 +38,21 @@ import org.apache.accumulo.core.replication.ReplicationSchema.WorkSection;
 import org.apache.accumulo.core.replication.ReplicationTable;
 import org.apache.accumulo.core.replication.ReplicationTarget;
 import org.apache.accumulo.core.security.TablePermission;
-import org.apache.accumulo.master.replication.FinishedWorkUpdater;
+import org.apache.accumulo.manager.replication.FinishedWorkUpdater;
 import org.apache.accumulo.server.replication.proto.Replication.Status;
 import org.apache.accumulo.test.functional.ConfigurableMacBase;
-import org.junit.Before;
-import org.junit.Test;
-
-import com.google.common.collect.Iterables;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Disabled;
+import org.junit.jupiter.api.Test;
 
+@Disabled("Replication ITs are not stable and not currently maintained")
+@Deprecated
 public class FinishedWorkUpdaterIT extends ConfigurableMacBase {
 
   private AccumuloClient client;
   private FinishedWorkUpdater updater;
 
-  @Before
+  @BeforeEach
   public void configureUpdater() {
     client = Accumulo.newClient().from(getClientProperties()).build();
     updater = new FinishedWorkUpdater(client);
@@ -85,7 +88,7 @@ public class FinishedWorkUpdaterIT extends ConfigurableMacBase {
     try (Scanner s = ReplicationTable.getScanner(client)) {
       s.setRange(Range.exact(file));
       StatusSection.limit(s);
-      Entry<Key,Value> entry = Iterables.getOnlyElement(s);
+      Entry<Key,Value> entry = getOnlyElement(s);
 
       assertEquals(entry.getKey().getColumnFamily(), StatusSection.NAME);
       assertEquals(entry.getKey().getColumnQualifier().toString(),
@@ -130,7 +133,7 @@ public class FinishedWorkUpdaterIT extends ConfigurableMacBase {
     try (Scanner s = ReplicationTable.getScanner(client)) {
       s.setRange(Range.exact(file));
       StatusSection.limit(s);
-      Entry<Key,Value> entry = Iterables.getOnlyElement(s);
+      Entry<Key,Value> entry = getOnlyElement(s);
 
       assertEquals(entry.getKey().getColumnFamily(), StatusSection.NAME);
       assertEquals(entry.getKey().getColumnQualifier().toString(),
@@ -175,7 +178,7 @@ public class FinishedWorkUpdaterIT extends ConfigurableMacBase {
     try (Scanner s = ReplicationTable.getScanner(client)) {
       s.setRange(Range.exact(file));
       StatusSection.limit(s);
-      Entry<Key,Value> entry = Iterables.getOnlyElement(s);
+      Entry<Key,Value> entry = getOnlyElement(s);
 
       assertEquals(entry.getKey().getColumnFamily(), StatusSection.NAME);
       assertEquals(entry.getKey().getColumnQualifier().toString(),
