@@ -1,27 +1,30 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.test.replication;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertNotEquals;
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNotEquals;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
+import java.time.Duration;
 import java.util.Arrays;
 import java.util.HashMap;
 import java.util.HashSet;
@@ -35,7 +38,6 @@ import org.apache.accumulo.core.client.AccumuloClient;
 import org.apache.accumulo.core.client.BatchWriter;
 import org.apache.accumulo.core.client.Scanner;
 import org.apache.accumulo.core.clientImpl.ClientContext;
-import org.apache.accumulo.core.clientImpl.MasterClient;
 import org.apache.accumulo.core.conf.ClientProperty;
 import org.apache.accumulo.core.conf.Property;
 import org.apache.accumulo.core.data.Key;
@@ -44,10 +46,13 @@ import org.apache.accumulo.core.data.Range;
 import org.apache.accumulo.core.data.TableId;
 import org.apache.accumulo.core.data.Value;
 import org.apache.accumulo.core.metadata.MetadataTable;
-import org.apache.accumulo.core.metadata.schema.MetadataSchema;
+import org.apache.accumulo.core.metadata.schema.MetadataSchema.ReplicationSection;
+import org.apache.accumulo.core.metadata.schema.MetadataSchema.TabletsSection;
+import org.apache.accumulo.core.metadata.schema.MetadataSchema.TabletsSection.DataFileColumnFamily;
 import org.apache.accumulo.core.protobuf.ProtobufUtil;
 import org.apache.accumulo.core.replication.ReplicationTable;
 import org.apache.accumulo.core.rpc.ThriftUtil;
+import org.apache.accumulo.core.rpc.clients.ThriftClientTypes;
 import org.apache.accumulo.core.security.Authorizations;
 import org.apache.accumulo.core.tabletserver.thrift.TabletClientService.Client;
 import org.apache.accumulo.core.trace.TraceUtil;
@@ -63,7 +68,8 @@ import org.apache.hadoop.fs.FileSystem;
 import org.apache.hadoop.fs.Path;
 import org.apache.hadoop.fs.RawLocalFileSystem;
 import org.apache.hadoop.io.Text;
-import org.junit.Test;
+import org.junit.jupiter.api.Disabled;
+import org.junit.jupiter.api.Test;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -72,6 +78,8 @@ import org.slf4j.LoggerFactory;
  * still continue to use it. Checking that no tablet references a WAL is insufficient to determine
  * if a WAL will never be used in the future.
  */
+@Disabled("Replication ITs are not stable and not currently maintained")
+@Deprecated
 public class GarbageCollectorCommunicatesWithTServersIT extends ConfigurableMacBase {
   private static final Logger log =
       LoggerFactory.getLogger(GarbageCollectorCommunicatesWithTServersIT.class);
@@ -79,8 +87,8 @@ public class GarbageCollectorCommunicatesWithTServersIT extends ConfigurableMacB
   private final int GC_PERIOD_SECONDS = 1;
 
   @Override
-  public int defaultTimeoutSeconds() {
-    return 2 * 60;
+  protected Duration defaultTimeout() {
+    return Duration.ofMinutes(2);
   }
 
   @Override
@@ -91,14 +99,14 @@ public class GarbageCollectorCommunicatesWithTServersIT extends ConfigurableMacB
     cfg.setProperty(Property.GC_CYCLE_DELAY, GC_PERIOD_SECONDS + "s");
     // Wait longer to try to let the replication table come online before a cycle runs
     cfg.setProperty(Property.GC_CYCLE_START, "10s");
-    cfg.setProperty(Property.REPLICATION_NAME, "master");
-    // Set really long delays for the master to do stuff for replication. We don't need
+    cfg.setProperty(Property.REPLICATION_NAME, "manager");
+    // Set really long delays for the manager to do stuff for replication. We don't need
     // it to be doing anything, so just let it sleep
     cfg.setProperty(Property.REPLICATION_WORK_PROCESSOR_DELAY, "240s");
-    cfg.setProperty(Property.MASTER_REPLICATION_SCAN_INTERVAL, "240s");
+    cfg.setProperty(Property.MANAGER_REPLICATION_SCAN_INTERVAL, "240s");
     cfg.setProperty(Property.REPLICATION_DRIVER_DELAY, "240s");
     // Pull down the maximum size of the wal so we can test close()'ing it.
-    cfg.setProperty(Property.TSERV_WALOG_MAX_SIZE, "1M");
+    cfg.setProperty(Property.TSERV_WAL_MAX_SIZE, "1M");
     coreSite.set("fs.file.impl", RawLocalFileSystem.class.getName());
   }
 
@@ -109,7 +117,7 @@ public class GarbageCollectorCommunicatesWithTServersIT extends ConfigurableMacB
     final ServerContext context = getServerContext();
     final String tableId = context.tableOperations().tableIdMap().get(tableName);
 
-    assertNotNull("Could not determine table ID for " + tableName, tableId);
+    assertNotNull(tableId, "Could not determine table ID for " + tableName);
 
     WalStateManager wals = new WalStateManager(context);
 
@@ -128,13 +136,13 @@ public class GarbageCollectorCommunicatesWithTServersIT extends ConfigurableMacB
     final AccumuloClient client = Accumulo.newClient().from(getClientProperties()).build();
     final TableId tableId = TableId.of(client.tableOperations().tableIdMap().get(tableName));
 
-    assertNotNull("Could not determine table ID for " + tableName, tableId);
+    assertNotNull(tableId, "Could not determine table ID for " + tableName);
 
     Set<String> rfiles = new HashSet<>();
     try (Scanner s = client.createScanner(MetadataTable.NAME, Authorizations.EMPTY)) {
-      Range r = MetadataSchema.TabletsSection.getRange(tableId);
+      Range r = TabletsSection.getRange(tableId);
       s.setRange(r);
-      s.fetchColumnFamily(MetadataSchema.TabletsSection.DataFileColumnFamily.NAME);
+      s.fetchColumnFamily(DataFileColumnFamily.NAME);
 
       for (Entry<Key,Value> entry : s) {
         log.debug("Reading RFiles: {}={}", entry.getKey().toStringNoTruncate(), entry.getValue());
@@ -156,17 +164,17 @@ public class GarbageCollectorCommunicatesWithTServersIT extends ConfigurableMacB
     final AccumuloClient client = Accumulo.newClient().from(getClientProperties()).build();
     final String tableId = client.tableOperations().tableIdMap().get(tableName);
 
-    assertNotNull("Could not determine table ID for " + tableName, tableId);
+    assertNotNull(tableId, "Could not determine table ID for " + tableName);
 
     Map<String,Status> fileToStatus = new HashMap<>();
     try (Scanner s = client.createScanner(MetadataTable.NAME, Authorizations.EMPTY)) {
-      Range r = MetadataSchema.ReplicationSection.getRange();
+      Range r = ReplicationSection.getRange();
       s.setRange(r);
-      s.fetchColumn(MetadataSchema.ReplicationSection.COLF, new Text(tableId));
+      s.fetchColumn(ReplicationSection.COLF, new Text(tableId));
 
       for (Entry<Key,Value> entry : s) {
         Text file = new Text();
-        MetadataSchema.ReplicationSection.getFile(entry.getKey(), file);
+        ReplicationSection.getFile(entry.getKey(), file);
         Status status = Status.parseFrom(entry.getValue().get());
         log.info("Got status for {}: {}", file, ProtobufUtil.toString(status));
         fileToStatus.put(file.toString(), status);
@@ -190,23 +198,20 @@ public class GarbageCollectorCommunicatesWithTServersIT extends ConfigurableMacB
 
     log.info("Writing a few mutations to the table");
 
-    BatchWriter bw = client.createBatchWriter(table);
-
-    byte[] empty = new byte[0];
-    for (int i = 0; i < 5; i++) {
-      Mutation m = new Mutation(Integer.toString(i));
-      m.put(empty, empty, empty);
-      bw.addMutation(m);
+    try (BatchWriter bw = client.createBatchWriter(table)) {
+      byte[] empty = new byte[0];
+      for (int i = 0; i < 5; i++) {
+        Mutation m = new Mutation(Integer.toString(i));
+        m.put(empty, empty, empty);
+        bw.addMutation(m);
+      }
     }
 
-    log.info("Flushing mutations to the server");
-    bw.flush();
-
     log.info(
         "Checking that metadata only has two WALs recorded for this table (inUse, and opened)");
 
     Set<String> wals = getWalsForTable(table);
-    assertEquals("Expected to only find two WALs for the table", 2, wals.size());
+    assertEquals(2, wals.size(), "Expected to only find two WALs for the table");
 
     // Flush our test table to remove the WAL references in it
     client.tableOperations().flush(table, null, null, true);
@@ -219,7 +224,7 @@ public class GarbageCollectorCommunicatesWithTServersIT extends ConfigurableMacB
 
     Map<String,Status> fileToStatus = getMetadataStatusForTable(table);
 
-    assertEquals("Expected to only find one replication status message", 1, fileToStatus.size());
+    assertEquals(1, fileToStatus.size(), "Expected to only find one replication status message");
 
     String walName = fileToStatus.keySet().iterator().next();
     wals.retainAll(fileToStatus.keySet());
@@ -227,10 +232,10 @@ public class GarbageCollectorCommunicatesWithTServersIT extends ConfigurableMacB
 
     Status status = fileToStatus.get(walName);
 
-    assertFalse("Expected Status for file to not be closed", status.getClosed());
+    assertFalse(status.getClosed(), "Expected Status for file to not be closed");
 
     Set<String> filesForTable = getFilesForTable(table);
-    assertEquals("Expected to only find one rfile for table", 1, filesForTable.size());
+    assertEquals(1, filesForTable.size(), "Expected to only find one rfile for table");
     log.info("Files for table before MajC: {}", filesForTable);
 
     // Issue a MajC to roll a new file in HDFS
@@ -240,10 +245,10 @@ public class GarbageCollectorCommunicatesWithTServersIT extends ConfigurableMacB
 
     log.info("Files for table after MajC: {}", filesForTableAfterCompaction);
 
-    assertEquals("Expected to only find one rfile for table", 1,
-        filesForTableAfterCompaction.size());
-    assertNotEquals("Expected the files before and after compaction to differ",
-        filesForTableAfterCompaction, filesForTable);
+    assertEquals(1, filesForTableAfterCompaction.size(),
+        "Expected to only find one rfile for table");
+    assertNotEquals(filesForTableAfterCompaction, filesForTable,
+        "Expected the files before and after compaction to differ");
 
     // Use the rfile which was just replaced by the MajC to determine when the GC has ran
     Path fileToBeDeleted = new Path(filesForTable.iterator().next());
@@ -257,15 +262,14 @@ public class GarbageCollectorCommunicatesWithTServersIT extends ConfigurableMacB
     }
 
     Map<String,Status> fileToStatusAfterMinc = getMetadataStatusForTable(table);
-    assertEquals(
-        "Expected to still find only one replication status message: " + fileToStatusAfterMinc, 1,
-        fileToStatusAfterMinc.size());
+    assertEquals(1, fileToStatusAfterMinc.size(),
+        "Expected to still find only one replication status message: " + fileToStatusAfterMinc);
 
-    assertEquals("Status before and after MinC should be identical", fileToStatus,
-        fileToStatusAfterMinc);
+    assertEquals(fileToStatus, fileToStatusAfterMinc,
+        "Status before and after MinC should be identical");
   }
 
-  @Test(timeout = 2 * 60 * 1000)
+  @Test
   public void testUnreferencedWalInTserverIsClosed() throws Exception {
     final String[] names = getUniqueNames(2);
     // `table` will be replicated, `otherTable` is only used to roll the WAL on the tserver
@@ -295,7 +299,7 @@ public class GarbageCollectorCommunicatesWithTServersIT extends ConfigurableMacB
     log.info("Checking that metadata only has one WAL recorded for this table");
 
     Set<String> wals = getWalsForTable(table);
-    assertEquals("Expected to only find two WAL for the table", 2, wals.size());
+    assertEquals(2, wals.size(), "Expected to only find two WAL for the table");
 
     log.info("Compacting the table which will remove all WALs from the tablets");
 
@@ -308,18 +312,18 @@ public class GarbageCollectorCommunicatesWithTServersIT extends ConfigurableMacB
 
     Map<String,Status> fileToStatus = getMetadataStatusForTable(table);
 
-    assertEquals("Expected to only find one replication status message", 1, fileToStatus.size());
+    assertEquals(1, fileToStatus.size(), "Expected to only find one replication status message");
 
     String walName = fileToStatus.keySet().iterator().next();
-    assertTrue("Expected log file name from tablet to equal replication entry",
-        wals.contains(walName));
+    assertTrue(wals.contains(walName),
+        "Expected log file name from tablet to equal replication entry");
 
     Status status = fileToStatus.get(walName);
 
-    assertFalse("Expected Status for file to not be closed", status.getClosed());
+    assertFalse(status.getClosed(), "Expected Status for file to not be closed");
 
     Set<String> filesForTable = getFilesForTable(table);
-    assertEquals("Expected to only find one rfile for table", 1, filesForTable.size());
+    assertEquals(1, filesForTable.size(), "Expected to only find one rfile for table");
     log.info("Files for table before MajC: {}", filesForTable);
 
     // Issue a MajC to roll a new file in HDFS
@@ -329,10 +333,10 @@ public class GarbageCollectorCommunicatesWithTServersIT extends ConfigurableMacB
 
     log.info("Files for table after MajC: {}", filesForTableAfterCompaction);
 
-    assertEquals("Expected to only find one rfile for table", 1,
-        filesForTableAfterCompaction.size());
-    assertNotEquals("Expected the files before and after compaction to differ",
-        filesForTableAfterCompaction, filesForTable);
+    assertEquals(1, filesForTableAfterCompaction.size(),
+        "Expected to only find one rfile for table");
+    assertNotEquals(filesForTableAfterCompaction, filesForTable,
+        "Expected the files before and after compaction to differ");
 
     // Use the rfile which was just replaced by the MajC to determine when the GC has ran
     Path fileToBeDeleted = new Path(filesForTable.iterator().next());
@@ -350,9 +354,8 @@ public class GarbageCollectorCommunicatesWithTServersIT extends ConfigurableMacB
     // for our WAL should not be altered.
 
     Map<String,Status> fileToStatusAfterMinc = getMetadataStatusForTable(table);
-    assertEquals(
-        "Expected to still find only one replication status message: " + fileToStatusAfterMinc, 1,
-        fileToStatusAfterMinc.size());
+    assertEquals(1, fileToStatusAfterMinc.size(),
+        "Expected to still find only one replication status message: " + fileToStatusAfterMinc);
 
     /*
      * To verify that the WALs is still getting closed, we have to force the tserver to close the
@@ -378,25 +381,25 @@ public class GarbageCollectorCommunicatesWithTServersIT extends ConfigurableMacB
 
     client.tableOperations().flush(otherTable, null, null, true);
 
-    // Get the tservers which the master deems as active
+    // Get the tservers which the manager deems as active
     final ClientContext context = (ClientContext) client;
-    List<String> tservers = MasterClient.execute(context,
-        cli -> cli.getActiveTservers(TraceUtil.traceInfo(), context.rpcCreds()));
+    List<String> tservers = ThriftClientTypes.MANAGER.execute(context,
+        mgr -> mgr.getActiveTservers(TraceUtil.traceInfo(), context.rpcCreds()));
 
-    assertEquals("Expected only one active tservers", 1, tservers.size());
+    assertEquals(1, tservers.size(), "Expected only one active tservers");
 
     HostAndPort tserver = HostAndPort.fromString(tservers.get(0));
 
     // Get the active WALs from that server
     log.info("Fetching active WALs from {}", tserver);
 
-    Client cli = ThriftUtil.getTServerClient(tserver, context);
+    Client cli = ThriftUtil.getClient(ThriftClientTypes.TABLET_SERVER, tserver, context);
     List<String> activeWalsForTserver =
         cli.getActiveLogs(TraceUtil.traceInfo(), context.rpcCreds());
 
     log.info("Active wals: {}", activeWalsForTserver);
 
-    assertEquals("Expected to find only one active WAL", 1, activeWalsForTserver.size());
+    assertEquals(1, activeWalsForTserver.size(), "Expected to find only one active WAL");
 
     String activeWal = new Path(activeWalsForTserver.get(0)).toString();
 
@@ -410,8 +413,8 @@ public class GarbageCollectorCommunicatesWithTServersIT extends ConfigurableMacB
       Map<String,Status> replicationStatuses = getMetadataStatusForTable(table);
 
       log.info("Got replication status messages {}", replicationStatuses);
-      assertEquals("Did not expect to find additional status records", 1,
-          replicationStatuses.size());
+      assertEquals(1, replicationStatuses.size(),
+          "Did not expect to find additional status records");
 
       status = replicationStatuses.values().iterator().next();
       log.info("Current status: {}", ProtobufUtil.toString(status));
