@@ -1,24 +1,26 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.test.replication;
 
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.jupiter.api.Assertions.fail;
 
 import java.util.Map.Entry;
 import java.util.Set;
@@ -28,7 +30,6 @@ import java.util.concurrent.atomic.AtomicBoolean;
 import org.apache.accumulo.core.client.Accumulo;
 import org.apache.accumulo.core.client.AccumuloClient;
 import org.apache.accumulo.core.client.BatchWriter;
-import org.apache.accumulo.core.client.BatchWriterConfig;
 import org.apache.accumulo.core.clientImpl.ClientContext;
 import org.apache.accumulo.core.clientImpl.ReplicationOperationsImpl;
 import org.apache.accumulo.core.data.Key;
@@ -46,29 +47,32 @@ import org.apache.accumulo.core.security.TablePermission;
 import org.apache.accumulo.core.securityImpl.thrift.TCredentials;
 import org.apache.accumulo.core.tabletserver.log.LogEntry;
 import org.apache.accumulo.core.trace.thrift.TInfo;
-import org.apache.accumulo.master.Master;
-import org.apache.accumulo.master.MasterClientServiceHandler;
+import org.apache.accumulo.manager.Manager;
+import org.apache.accumulo.manager.ManagerClientServiceHandler;
 import org.apache.accumulo.server.ServerContext;
 import org.apache.accumulo.server.replication.proto.Replication.Status;
 import org.apache.accumulo.test.functional.ConfigurableMacBase;
 import org.apache.hadoop.io.Text;
 import org.apache.thrift.TException;
 import org.easymock.EasyMock;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Disabled;
+import org.junit.jupiter.api.Test;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+@Disabled("Replication ITs are not stable and not currently maintained")
+@Deprecated
 public class ReplicationOperationsImplIT extends ConfigurableMacBase {
   private static final Logger log = LoggerFactory.getLogger(ReplicationOperationsImplIT.class);
 
   private AccumuloClient client;
-  private ServerContext serverContext;
+  private ServerContext context;
 
-  @Before
+  @BeforeEach
   public void configureInstance() throws Exception {
     client = Accumulo.newClient().from(getClientProperties()).build();
-    serverContext = getServerContext();
+    context = getServerContext();
     ReplicationTable.setOnline(client);
     client.securityOperations().grantTablePermission(client.whoami(), MetadataTable.NAME,
         TablePermission.WRITE);
@@ -79,14 +83,14 @@ public class ReplicationOperationsImplIT extends ConfigurableMacBase {
   }
 
   /**
-   * Spoof out the Master so we can call the implementation without starting a full instance.
+   * Spoof out the Manager so we can call the implementation without starting a full instance.
    */
   private ReplicationOperationsImpl getReplicationOperations() {
-    Master master = EasyMock.createMock(Master.class);
-    EasyMock.expect(master.getContext()).andReturn(serverContext).anyTimes();
-    EasyMock.replay(master);
+    Manager manager = EasyMock.createMock(Manager.class);
+    EasyMock.expect(manager.getContext()).andReturn(context).anyTimes();
+    EasyMock.replay(manager);
 
-    final MasterClientServiceHandler mcsh = new MasterClientServiceHandler(master) {
+    final ManagerClientServiceHandler mcsh = new ManagerClientServiceHandler(manager) {
       @Override
       protected TableId getTableId(ClientContext context, String tableName) {
         try {
@@ -100,7 +104,7 @@ public class ReplicationOperationsImplIT extends ConfigurableMacBase {
     ClientContext context = (ClientContext) client;
     return new ReplicationOperationsImpl(context) {
       @Override
-      protected boolean getMasterDrain(final TInfo tinfo, final TCredentials rpcCreds,
+      protected boolean getManagerDrain(final TInfo tinfo, final TCredentials rpcCreds,
           final String tableName, final Set<String> wals) {
         try {
           return mcsh.drainReplicationTable(tinfo, rpcCreds, tableName, wals);
@@ -133,7 +137,7 @@ public class ReplicationOperationsImplIT extends ConfigurableMacBase {
 
     bw.close();
 
-    bw = client.createBatchWriter(MetadataTable.NAME, new BatchWriterConfig());
+    bw = client.createBatchWriter(MetadataTable.NAME);
     m = new Mutation(ReplicationSection.getRowPrefix() + file1);
     m.put(ReplicationSection.COLF, new Text(tableId.canonical()), ProtobufUtil.toValue(stat));
 
@@ -162,7 +166,7 @@ public class ReplicationOperationsImplIT extends ConfigurableMacBase {
     // With the records, we shouldn't be drained
     assertFalse(done.get());
 
-    bw = client.createBatchWriter(MetadataTable.NAME, new BatchWriterConfig());
+    bw = client.createBatchWriter(MetadataTable.NAME);
     m = new Mutation(ReplicationSection.getRowPrefix() + file1);
     m.putDelete(ReplicationSection.COLF, new Text(tableId.canonical()));
     bw.addMutation(m);
@@ -200,8 +204,8 @@ public class ReplicationOperationsImplIT extends ConfigurableMacBase {
     }
 
     // After both metadata and replication
-    assertTrue("Drain never finished", done.get());
-    assertFalse("Saw unexpectetd exception", exception.get());
+    assertTrue(done.get(), "Drain never finished");
+    assertFalse(exception.get(), "Saw unexpected exception");
   }
 
   @Test
@@ -229,7 +233,7 @@ public class ReplicationOperationsImplIT extends ConfigurableMacBase {
 
     bw.close();
 
-    bw = client.createBatchWriter(MetadataTable.NAME, new BatchWriterConfig());
+    bw = client.createBatchWriter(MetadataTable.NAME);
     m = new Mutation(ReplicationSection.getRowPrefix() + file1);
     m.put(ReplicationSection.COLF, new Text(tableId1.canonical()), ProtobufUtil.toValue(stat));
 
@@ -260,7 +264,7 @@ public class ReplicationOperationsImplIT extends ConfigurableMacBase {
     // With the records, we shouldn't be drained
     assertFalse(done.get());
 
-    bw = client.createBatchWriter(MetadataTable.NAME, new BatchWriterConfig());
+    bw = client.createBatchWriter(MetadataTable.NAME);
     m = new Mutation(ReplicationSection.getRowPrefix() + file1);
     m.putDelete(ReplicationSection.COLF, new Text(tableId1.canonical()));
     bw.addMutation(m);
@@ -275,6 +279,7 @@ public class ReplicationOperationsImplIT extends ConfigurableMacBase {
     m.putDelete(StatusSection.NAME, new Text(tableId1.canonical()));
     bw.addMutation(m);
     bw.flush();
+    bw.close();
 
     try {
       t.join(5000);
@@ -283,8 +288,8 @@ public class ReplicationOperationsImplIT extends ConfigurableMacBase {
     }
 
     // After both metadata and replication
-    assertTrue("Drain never completed", done.get());
-    assertFalse("Saw unexpected exception", exception.get());
+    assertTrue(done.get(), "Drain never completed");
+    assertFalse(exception.get(), "Saw unexpected exception");
   }
 
   @Test
@@ -304,10 +309,10 @@ public class ReplicationOperationsImplIT extends ConfigurableMacBase {
     bw.addMutation(m);
     bw.close();
 
-    LogEntry logEntry = new LogEntry(new KeyExtent(tableId1, null, null),
-        System.currentTimeMillis(), "tserver", file1);
+    LogEntry logEntry =
+        new LogEntry(new KeyExtent(tableId1, null, null), System.currentTimeMillis(), file1);
 
-    bw = client.createBatchWriter(MetadataTable.NAME, new BatchWriterConfig());
+    bw = client.createBatchWriter(MetadataTable.NAME);
     m = new Mutation(ReplicationSection.getRowPrefix() + file1);
     m.put(ReplicationSection.COLF, new Text(tableId1.canonical()), ProtobufUtil.toValue(stat));
     bw.addMutation(m);
@@ -338,7 +343,7 @@ public class ReplicationOperationsImplIT extends ConfigurableMacBase {
 
     Status newStatus = Status.newBuilder().setBegin(1000).setEnd(2000).setInfiniteEnd(false)
         .setClosed(true).build();
-    bw = client.createBatchWriter(MetadataTable.NAME, new BatchWriterConfig());
+    bw = client.createBatchWriter(MetadataTable.NAME);
     m = new Mutation(ReplicationSection.getRowPrefix() + file1);
     m.put(ReplicationSection.COLF, new Text(tableId1.canonical()), ProtobufUtil.toValue(newStatus));
     bw.addMutation(m);
@@ -361,8 +366,8 @@ public class ReplicationOperationsImplIT extends ConfigurableMacBase {
     }
 
     // New records, but not fully replicated ones don't cause it to complete
-    assertFalse("Drain somehow finished", done.get());
-    assertFalse("Saw unexpected exception", exception.get());
+    assertFalse(done.get(), "Drain somehow finished");
+    assertFalse(exception.get(), "Saw unexpected exception");
   }
 
   @Test
@@ -381,7 +386,7 @@ public class ReplicationOperationsImplIT extends ConfigurableMacBase {
     bw.addMutation(m);
     bw.close();
 
-    bw = client.createBatchWriter(MetadataTable.NAME, new BatchWriterConfig());
+    bw = client.createBatchWriter(MetadataTable.NAME);
     m = new Mutation(ReplicationSection.getRowPrefix() + file1);
     m.put(ReplicationSection.COLF, new Text(tableId1.canonical()), ProtobufUtil.toValue(stat));
     bw.addMutation(m);
@@ -389,8 +394,10 @@ public class ReplicationOperationsImplIT extends ConfigurableMacBase {
     bw.close();
 
     log.info("Reading metadata first time");
-    for (Entry<Key,Value> e : client.createScanner(MetadataTable.NAME, Authorizations.EMPTY)) {
-      log.info("{}", e.getKey());
+    try (var scanner = client.createScanner(MetadataTable.NAME, Authorizations.EMPTY)) {
+      for (Entry<Key,Value> e : scanner) {
+        log.info("{}", e.getKey());
+      }
     }
 
     final AtomicBoolean done = new AtomicBoolean(false);
@@ -412,7 +419,7 @@ public class ReplicationOperationsImplIT extends ConfigurableMacBase {
     Thread.sleep(2000);
 
     // Write another file, but also delete the old files
-    bw = client.createBatchWriter(MetadataTable.NAME, new BatchWriterConfig());
+    bw = client.createBatchWriter(MetadataTable.NAME);
     m = new Mutation(
         ReplicationSection.getRowPrefix() + "/accumulo/wals/tserver+port/" + UUID.randomUUID());
     m.put(ReplicationSection.COLF, new Text(tableId1.canonical()), ProtobufUtil.toValue(stat));
@@ -423,8 +430,10 @@ public class ReplicationOperationsImplIT extends ConfigurableMacBase {
     bw.close();
 
     log.info("Reading metadata second time");
-    for (Entry<Key,Value> e : client.createScanner(MetadataTable.NAME, Authorizations.EMPTY)) {
-      log.info("{}", e.getKey());
+    try (var scanner = client.createScanner(MetadataTable.NAME, Authorizations.EMPTY)) {
+      for (Entry<Key,Value> e : scanner) {
+        log.info("{}", e.getKey());
+      }
     }
 
     bw = ReplicationTable.getBatchWriter(client);
@@ -441,6 +450,6 @@ public class ReplicationOperationsImplIT extends ConfigurableMacBase {
 
     // We should pass immediately because we aren't waiting on both files to be deleted (just the
     // one that we did)
-    assertTrue("Drain didn't finish", done.get());
+    assertTrue(done.get(), "Drain didn't finish");
   }
 }
