@@ -1,25 +1,27 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.test.replication;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import java.util.Arrays;
 import java.util.Collections;
@@ -34,7 +36,6 @@ import java.util.UUID;
 import org.apache.accumulo.core.client.Accumulo;
 import org.apache.accumulo.core.client.AccumuloClient;
 import org.apache.accumulo.core.client.BatchWriter;
-import org.apache.accumulo.core.client.BatchWriterConfig;
 import org.apache.accumulo.core.client.Scanner;
 import org.apache.accumulo.core.data.Key;
 import org.apache.accumulo.core.data.Mutation;
@@ -47,7 +48,7 @@ import org.apache.accumulo.core.replication.ReplicationSchema.StatusSection;
 import org.apache.accumulo.core.replication.ReplicationTable;
 import org.apache.accumulo.core.security.Authorizations;
 import org.apache.accumulo.core.security.TablePermission;
-import org.apache.accumulo.master.replication.StatusMaker;
+import org.apache.accumulo.manager.replication.StatusMaker;
 import org.apache.accumulo.server.fs.VolumeManager;
 import org.apache.accumulo.server.replication.StatusUtil;
 import org.apache.accumulo.server.replication.proto.Replication.Status;
@@ -57,18 +58,21 @@ import org.apache.hadoop.fs.FileStatus;
 import org.apache.hadoop.fs.Path;
 import org.apache.hadoop.io.Text;
 import org.easymock.EasyMock;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Disabled;
+import org.junit.jupiter.api.Test;
 
 import com.google.common.collect.Iterables;
 import com.google.common.collect.Sets;
 
+@Disabled("Replication ITs are not stable and not currently maintained")
+@Deprecated
 public class StatusMakerIT extends ConfigurableMacBase {
 
   private AccumuloClient client;
   private VolumeManager fs;
 
-  @Before
+  @BeforeEach
   public void setupInstance() throws Exception {
     client = Accumulo.newClient().from(getClientProperties()).build();
     ReplicationTable.setOnline(client);
@@ -81,11 +85,11 @@ public class StatusMakerIT extends ConfigurableMacBase {
 
   @Test
   public void statusRecordsCreated() throws Exception {
-    String sourceTable = testName.getMethodName();
+    String sourceTable = testName();
     client.tableOperations().create(sourceTable);
     ReplicationTableUtil.configureMetadataTable(client, sourceTable);
 
-    BatchWriter bw = client.createBatchWriter(sourceTable, new BatchWriterConfig());
+    BatchWriter bw = client.createBatchWriter(sourceTable);
     String walPrefix = "hdfs://localhost:8020/accumulo/wals/tserver+port/";
     Set<String> files =
         Sets.newHashSet(walPrefix + UUID.randomUUID(), walPrefix + UUID.randomUUID(),
@@ -120,8 +124,8 @@ public class StatusMakerIT extends ConfigurableMacBase {
         StatusSection.getFile(entry.getKey(), file);
         TableId tableId = StatusSection.getTableId(entry.getKey());
 
-        assertTrue("Found unexpected file: " + file, files.contains(file.toString()));
-        assertEquals(fileToTableId.get(file.toString()), new Integer(tableId.canonical()));
+        assertTrue(files.contains(file.toString()), "Found unexpected file: " + file);
+        assertEquals(fileToTableId.get(file.toString()), Integer.valueOf(tableId.canonical()));
         timeCreated = fileToTimeCreated.get(file.toString());
         assertNotNull(timeCreated);
         assertEquals(StatusUtil.fileCreated(timeCreated), Status.parseFrom(entry.getValue().get()));
@@ -131,11 +135,11 @@ public class StatusMakerIT extends ConfigurableMacBase {
 
   @Test
   public void openMessagesAreNotDeleted() throws Exception {
-    String sourceTable = testName.getMethodName();
+    String sourceTable = testName();
     client.tableOperations().create(sourceTable);
     ReplicationTableUtil.configureMetadataTable(client, sourceTable);
 
-    BatchWriter bw = client.createBatchWriter(sourceTable, new BatchWriterConfig());
+    BatchWriter bw = client.createBatchWriter(sourceTable);
     String walPrefix = "hdfs://localhost:8020/accumulo/wals/tserver+port/";
     Set<String> files =
         Sets.newHashSet(walPrefix + UUID.randomUUID(), walPrefix + UUID.randomUUID(),
@@ -170,11 +174,11 @@ public class StatusMakerIT extends ConfigurableMacBase {
 
   @Test
   public void closedMessagesAreDeleted() throws Exception {
-    String sourceTable = testName.getMethodName();
+    String sourceTable = testName();
     client.tableOperations().create(sourceTable);
     ReplicationTableUtil.configureMetadataTable(client, sourceTable);
 
-    BatchWriter bw = client.createBatchWriter(sourceTable, new BatchWriterConfig());
+    BatchWriter bw = client.createBatchWriter(sourceTable);
     String walPrefix = "hdfs://localhost:8020/accumulo/wals/tserver+port/";
     Set<String> files =
         Sets.newHashSet(walPrefix + UUID.randomUUID(), walPrefix + UUID.randomUUID(),
@@ -217,11 +221,11 @@ public class StatusMakerIT extends ConfigurableMacBase {
 
   @Test
   public void closedMessagesCreateOrderRecords() throws Exception {
-    String sourceTable = testName.getMethodName();
+    String sourceTable = testName();
     client.tableOperations().create(sourceTable);
     ReplicationTableUtil.configureMetadataTable(client, sourceTable);
 
-    BatchWriter bw = client.createBatchWriter(sourceTable, new BatchWriterConfig());
+    BatchWriter bw = client.createBatchWriter(sourceTable);
     String walPrefix = "hdfs://localhost:8020/accumulo/wals/tserver+port/";
     List<String> files = Arrays.asList(walPrefix + UUID.randomUUID(), walPrefix + UUID.randomUUID(),
         walPrefix + UUID.randomUUID(), walPrefix + UUID.randomUUID());
@@ -260,7 +264,7 @@ public class StatusMakerIT extends ConfigurableMacBase {
     try (Scanner s = ReplicationTable.getScanner(client)) {
       OrderSection.limit(s);
       iter = s.iterator();
-      assertTrue("Found no order records in replication table", iter.hasNext());
+      assertTrue(iter.hasNext(), "Found no order records in replication table");
 
       expectedFiles = files.iterator();
       Text buff = new Text();
@@ -273,17 +277,17 @@ public class StatusMakerIT extends ConfigurableMacBase {
         assertEquals(fileToTableId.get(file).intValue(), Integer.parseInt(buff.toString()));
       }
     }
-    assertFalse("Found more files unexpectedly", expectedFiles.hasNext());
-    assertFalse("Found more entries in replication table unexpectedly", iter.hasNext());
+    assertFalse(expectedFiles.hasNext(), "Found more files unexpectedly");
+    assertFalse(iter.hasNext(), "Found more entries in replication table unexpectedly");
   }
 
   @Test
   public void orderRecordsCreatedWithNoCreatedTime() throws Exception {
-    String sourceTable = testName.getMethodName();
+    String sourceTable = testName();
     client.tableOperations().create(sourceTable);
     ReplicationTableUtil.configureMetadataTable(client, sourceTable);
 
-    BatchWriter bw = client.createBatchWriter(sourceTable, new BatchWriterConfig());
+    BatchWriter bw = client.createBatchWriter(sourceTable);
     String walPrefix = "hdfs://localhost:8020/accumulo/wals/tserver+port/";
     List<String> files = Arrays.asList(walPrefix + UUID.randomUUID(), walPrefix + UUID.randomUUID(),
         walPrefix + UUID.randomUUID(), walPrefix + UUID.randomUUID());
@@ -329,7 +333,7 @@ public class StatusMakerIT extends ConfigurableMacBase {
     s = ReplicationTable.getScanner(client);
     OrderSection.limit(s);
     Iterator<Entry<Key,Value>> iter = s.iterator();
-    assertTrue("Found no order records in replication table", iter.hasNext());
+    assertTrue(iter.hasNext(), "Found no order records in replication table");
 
     Iterator<String> expectedFiles = files.iterator();
     Text buff = new Text();
@@ -345,8 +349,8 @@ public class StatusMakerIT extends ConfigurableMacBase {
       assertEquals((long) statuses.get(file), status.getCreatedTime());
     }
 
-    assertFalse("Found more files unexpectedly", expectedFiles.hasNext());
-    assertFalse("Found more entries in replication table unexpectedly", iter.hasNext());
+    assertFalse(expectedFiles.hasNext(), "Found more files unexpectedly");
+    assertFalse(iter.hasNext(), "Found more entries in replication table unexpectedly");
 
     s = client.createScanner(sourceTable, Authorizations.EMPTY);
     s.setRange(ReplicationSection.getRange());
@@ -356,7 +360,7 @@ public class StatusMakerIT extends ConfigurableMacBase {
     s = ReplicationTable.getScanner(client);
     s.setRange(ReplicationSection.getRange());
     iter = s.iterator();
-    assertTrue("Found no stat records in replication table", iter.hasNext());
+    assertTrue(iter.hasNext(), "Found no stat records in replication table");
 
     Collections.sort(files);
     expectedFiles = files.iterator();
@@ -368,7 +372,7 @@ public class StatusMakerIT extends ConfigurableMacBase {
       assertEquals((long) statuses.get(file), status.getCreatedTime());
     }
 
-    assertFalse("Found more files unexpectedly", expectedFiles.hasNext());
-    assertFalse("Found more entries in replication table unexpectedly", iter.hasNext());
+    assertFalse(expectedFiles.hasNext(), "Found more files unexpectedly");
+    assertFalse(iter.hasNext(), "Found more entries in replication table unexpectedly");
   }
 }
