@@ -1,23 +1,25 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.test.replication;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import java.util.HashSet;
 import java.util.Map;
@@ -38,18 +40,20 @@ import org.apache.accumulo.core.replication.ReplicationSchema.WorkSection;
 import org.apache.accumulo.core.replication.ReplicationTable;
 import org.apache.accumulo.core.replication.ReplicationTarget;
 import org.apache.accumulo.core.security.TablePermission;
-import org.apache.accumulo.master.replication.WorkMaker;
+import org.apache.accumulo.manager.replication.WorkMaker;
 import org.apache.accumulo.server.replication.StatusUtil;
 import org.apache.accumulo.server.replication.proto.Replication.Status;
 import org.apache.accumulo.test.functional.ConfigurableMacBase;
 import org.apache.hadoop.fs.Path;
 import org.apache.hadoop.io.Text;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Disabled;
+import org.junit.jupiter.api.Test;
 
-import com.google.common.collect.ImmutableMap;
 import com.google.common.collect.Iterables;
 
+@Disabled("Replication ITs are not stable and not currently maintained")
+@Deprecated
 public class WorkMakerIT extends ConfigurableMacBase {
 
   private AccumuloClient client;
@@ -78,7 +82,7 @@ public class WorkMakerIT extends ConfigurableMacBase {
 
   }
 
-  @Before
+  @BeforeEach
   public void setupInstance() throws Exception {
     client = Accumulo.newClient().from(getClientProperties()).build();
     ReplicationTable.setOnline(client);
@@ -90,7 +94,7 @@ public class WorkMakerIT extends ConfigurableMacBase {
 
   @Test
   public void singleUnitSingleTarget() throws Exception {
-    String table = testName.getMethodName();
+    String table = testName();
     client.tableOperations().create(table);
     TableId tableId = TableId.of(client.tableOperations().tableIdMap().get(table));
     String file = "hdfs://localhost:8020/accumulo/wal/123456-1234-1234-12345678";
@@ -116,14 +120,14 @@ public class WorkMakerIT extends ConfigurableMacBase {
       expected = new ReplicationTarget("remote_cluster_1", "4", tableId);
       workMaker.setBatchWriter(bw);
       workMaker.addWorkRecord(new Text(file), StatusUtil.fileCreatedValue(timeCreated),
-          ImmutableMap.of("remote_cluster_1", "4"), tableId);
+          Map.of("remote_cluster_1", "4"), tableId);
     }
 
     // Scan over just the WorkSection
     try (Scanner s = ReplicationTable.getScanner(client)) {
       WorkSection.limit(s);
 
-      Entry<Key,Value> workEntry = Iterables.getOnlyElement(s);
+      Entry<Key,Value> workEntry = getOnlyElement(s);
       Key workKey = workEntry.getKey();
       ReplicationTarget actual = ReplicationTarget.from(workKey.getColumnQualifier());
 
@@ -136,7 +140,7 @@ public class WorkMakerIT extends ConfigurableMacBase {
 
   @Test
   public void singleUnitMultipleTargets() throws Exception {
-    String table = testName.getMethodName();
+    String table = testName();
     client.tableOperations().create(table);
 
     TableId tableId = TableId.of(client.tableOperations().tableIdMap().get(table));
@@ -158,8 +162,8 @@ public class WorkMakerIT extends ConfigurableMacBase {
 
       MockWorkMaker workMaker = new MockWorkMaker(client);
 
-      Map<String,String> targetClusters = ImmutableMap.of("remote_cluster_1", "4",
-          "remote_cluster_2", "6", "remote_cluster_3", "8");
+      Map<String,String> targetClusters =
+          Map.of("remote_cluster_1", "4", "remote_cluster_2", "6", "remote_cluster_3", "8");
 
       for (Entry<String,String> cluster : targetClusters.entrySet()) {
         expectedTargets.add(new ReplicationTarget(cluster.getKey(), cluster.getValue(), tableId));
@@ -182,17 +186,17 @@ public class WorkMakerIT extends ConfigurableMacBase {
       }
 
       for (ReplicationTarget expected : expectedTargets) {
-        assertTrue("Did not find expected target: " + expected, actualTargets.contains(expected));
+        assertTrue(actualTargets.contains(expected), "Did not find expected target: " + expected);
         actualTargets.remove(expected);
       }
 
-      assertTrue("Found extra replication work entries: " + actualTargets, actualTargets.isEmpty());
+      assertTrue(actualTargets.isEmpty(), "Found extra replication work entries: " + actualTargets);
     }
   }
 
   @Test
   public void dontCreateWorkForEntriesWithNothingToReplicate() throws Exception {
-    String table = testName.getMethodName();
+    String table = testName();
     client.tableOperations().create(table);
     String tableId = client.tableOperations().tableIdMap().get(table);
     String file = "hdfs://localhost:8020/accumulo/wal/123456-1234-1234-12345678";
